(function() {
'use strict';
var definitions = {
  defaults: {
    version: "undefined",
    applyCasing: function defaultApplyCasing(casing, text) {
    switch (casing) {
        case 'lower':
            return text.toLowerCase();
        case 'upper':
            return text.toUpperCase();
        case 'initial':
            var headCode = text.charCodeAt(0);
            // The length of the first code unit, as measured in code points.
            var headUnitLength = 1;
            // Is the first character a high surrogate, indicating possible use of UTF-16
            // surrogate pairs?  Also, is the string long enough for there to BE a pair?
            if (text.length > 1 && headCode >= 0xD800 && headCode <= 0xDBFF) {
                // It's possible, so now we check for low surrogates.
                var lowSurrogateCode = text.charCodeAt(1);
                if (lowSurrogateCode >= 0xDC00 && lowSurrogateCode <= 0xDFFF) {
                    // We have a surrogate pair; this pair is the 'first' character.
                    headUnitLength++;
                }
            }
            // Capitalizes the first code unit of the string, leaving the rest intact.
            return text.substring(0, headUnitLength).toUpperCase() // head - uppercased
                .concat(text.substring(headUnitLength)); // tail - lowercased
    }
}
  },  model: {
    searchTermToKey: function defaultCasedSearchTermToKey(wordform, applyCasing) {
    // While this is a bit WET, as the basic `defaultSearchTermToKey` exists and performs some of
    // the same functions, repetition is the easiest way to allow the function to be safely compiled
    // with ease by use of `.toString()`.
    return Array.from(wordform
        .normalize('NFKD')
        // Remove any combining diacritics (if input is in NFKD)
        .replace(/[\u0300-\u036F]/g, '')) // end of `Array.from`
        .map(function (c) { return applyCasing('lower', c); })
        .join('');
}
  },
  applyCasing: function(caseToApply, text) {
        return definitions.defaults.applyCasing(caseToApply, text);
      },
  searchTermToKey: function(text) {
      return definitions.model.searchTermToKey(text, definitions.applyCasing);
    }
};
LMLayerWorker.loadModel(new models.TrieModel({"totalWeight":32873,"root":{"type":"internal","weight":1977,"values":["o","s","u","d","a","w","i","m","e","n","f","t","l","b","k","y","r","j","g","p","h"],"children":{"o":{"type":"internal","weight":1977,"values":["g","n","v","m","l","ð","s","r","t","k","y","p","u"],"children":{"g":{"type":"internal","weight":1977,"values":["﷐","a","u","t","e","g"],"children":{"﷐":{"type":"leaf","weight":1977,"entries":[{"key":"og","weight":1977,"content":"og"}]},"u":{"type":"internal","weight":31,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":31,"entries":[{"key":"ogu","weight":31,"content":"ogų"},{"key":"ogu","weight":31,"content":"ogu"}]},"m":{"type":"leaf","weight":24,"entries":[{"key":"ogum","weight":24,"content":"ogum"}]}}},"a":{"type":"internal","weight":34,"values":["﷐","s","u","ð"],"children":{"﷐":{"type":"leaf","weight":34,"entries":[{"key":"oga","weight":34,"content":"oga"}]},"s":{"type":"leaf","weight":2,"entries":[{"key":"ogas","weight":2,"content":"Ogås"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"ogauseð","weight":1,"content":"ogauseð"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"ogað","weight":1,"content":"ogað"}]}}},"t":{"type":"internal","weight":16,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":16,"entries":[{"key":"ogt","weight":16,"content":"ogt"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"ogtalerum","weight":3,"content":"ogtalerum"}]}}},"e":{"type":"internal","weight":6,"values":["r","s"],"children":{"r":{"type":"leaf","weight":6,"entries":[{"key":"ogera","weight":6,"content":"ogera"},{"key":"oger","weight":1,"content":"oger"}]},"s":{"type":"internal","weight":4,"values":["t"],"children":{"t":{"type":"internal","weight":4,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"ogest","weight":4,"content":"ogest"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"ogestað","weight":3,"content":"ogestað"}]}}}}}}},"g":{"type":"internal","weight":3,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"ogg","weight":3,"content":"ogg"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"ogga","weight":1,"content":"ogga"}]}}}}},"n":{"type":"internal","weight":58,"values":["﷐","n","u","a"],"children":{"﷐":{"type":"leaf","weight":58,"entries":[{"key":"on","weight":58,"content":"on"}]},"n":{"type":"leaf","weight":18,"entries":[{"key":"onn","weight":18,"content":"onn"}]},"u":{"type":"internal","weight":8,"values":["m"],"children":{"m":{"type":"internal","weight":8,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"onum","weight":8,"content":"onum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"onumes","weight":1,"content":"onumes"}]}}}}},"a":{"type":"leaf","weight":6,"entries":[{"key":"ona","weight":6,"content":"ona"}]}}},"v":{"type":"internal","weight":49,"values":["d","k","e","i"],"children":{"d":{"type":"internal","weight":49,"values":["a"],"children":{"a":{"type":"internal","weight":49,"values":["l"],"children":{"l":{"type":"internal","weight":49,"values":["n","i","s"],"children":{"n":{"type":"leaf","weight":49,"entries":[{"key":"ovdaln","weight":49,"content":"Övdaln"}]},"i":{"type":"leaf","weight":48,"entries":[{"key":"ovdalim","weight":48,"content":"Övdalim"}]},"s":{"type":"internal","weight":2,"values":["k"],"children":{"k":{"type":"internal","weight":2,"values":["u","a"],"children":{"u":{"type":"leaf","weight":2,"entries":[{"key":"ovdalskun","weight":2,"content":"övdalskun"},{"key":"ovdalsku","weight":1,"content":"övdalsku"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"ovdalska","weight":1,"content":"övdalska"}]}}}}}}}}}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"ovkallum","weight":1,"content":"övkallum"}]},"e":{"type":"internal","weight":1,"values":["﷐","n","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"ove","weight":1,"content":"öve"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"ovend","weight":1,"content":"övend"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"overalln","weight":1,"content":"overalln"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"ovin","weight":1,"content":"övin"}]}}},"l":{"type":"internal","weight":45,"values":["l","d","m"],"children":{"l":{"type":"internal","weight":45,"values":["﷐","t","u","e","d","s","l"],"children":{"﷐":{"type":"leaf","weight":45,"entries":[{"key":"oll","weight":45,"content":"oll"}]},"t":{"type":"internal","weight":38,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":38,"entries":[{"key":"ollt","weight":38,"content":"ollt"}]},"i":{"type":"leaf","weight":19,"entries":[{"key":"olltiett","weight":19,"content":"olltiett"}]}}},"u":{"type":"leaf","weight":17,"entries":[{"key":"ollum","weight":17,"content":"ollum"},{"key":"ollu","weight":10,"content":"ollu"}]},"e":{"type":"internal","weight":10,"values":["r"],"children":{"r":{"type":"internal","weight":10,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"oller","weight":10,"content":"oller"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"olleriuop","weight":2,"content":"olleriuop"}]}}}}},"d":{"type":"internal","weight":4,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"olld","weight":4,"content":"olld"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"ollder","weight":1,"content":"ollder"}]}}},"s":{"type":"leaf","weight":2,"entries":[{"key":"ollstass","weight":2,"content":"ollstass"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"ollltiett","weight":1,"content":"ollltiett"}]}}},"d":{"type":"internal","weight":18,"values":["e","﷐","u"],"children":{"e":{"type":"leaf","weight":18,"entries":[{"key":"older","weight":18,"content":"older"}]},"﷐":{"type":"leaf","weight":10,"entries":[{"key":"old","weight":10,"content":"old"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"oldum","weight":2,"content":"oldum"}]}}},"m":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"olme","weight":1,"content":"olme"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"olmer","weight":1,"content":"olmer"}]}}}}}}},"m":{"type":"internal","weight":48,"values":["﷐","-"],"children":{"﷐":{"type":"leaf","weight":48,"entries":[{"key":"om","weight":48,"content":"om"}]},"-":{"type":"leaf","weight":20,"entries":[{"key":"om-dar","weight":20,"content":"om-dar"}]}}},"s":{"type":"internal","weight":18,"values":["t","﷐","s"],"children":{"t":{"type":"internal","weight":18,"values":["r","a","n","e"],"children":{"r":{"type":"leaf","weight":18,"entries":[{"key":"ostryvyr","weight":18,"content":"ostryvyr"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"ostakk","weight":4,"content":"östakk"}]},"n":{"type":"leaf","weight":3,"entries":[{"key":"ostn","weight":3,"content":"ostn"}]},"e":{"type":"internal","weight":1,"values":["s","r"],"children":{"s":{"type":"leaf","weight":1,"entries":[{"key":"ostes","weight":1,"content":"ostes"}]},"r":{"type":"internal","weight":1,"values":["m","s"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"ostermykklaingg","weight":1,"content":"Östermykklaingg"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"ostersaiðun","weight":1,"content":"ostersaiðun"}]}}}}}}},"﷐":{"type":"leaf","weight":5,"entries":[{"key":"os","weight":5,"content":"os"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"ossa","weight":1,"content":"Ossa"}]}}},"r":{"type":"internal","weight":16,"values":["n","a"],"children":{"n":{"type":"internal","weight":16,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":16,"entries":[{"key":"orn","weight":16,"content":"örn"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"ornar","weight":4,"content":"örnär"}]},"e":{"type":"internal","weight":3,"values":["r","m"],"children":{"r":{"type":"leaf","weight":3,"entries":[{"key":"orner","weight":3,"content":"örner"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"ornem","weight":1,"content":"örnem"}]}}}}},"a":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"internal","weight":2,"values":["i","﷐"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"orað","weight":1,"content":"orað"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"oraðir","weight":2,"content":"oraðir"}]}}}}}}},"ð":{"type":"internal","weight":20,"values":["e","r"],"children":{"e":{"type":"internal","weight":20,"values":["r"],"children":{"r":{"type":"internal","weight":20,"values":["﷐","n","w"],"children":{"﷐":{"type":"leaf","weight":20,"entries":[{"key":"oðer","weight":20,"content":"oðer"}]},"n":{"type":"leaf","weight":9,"entries":[{"key":"oðern","weight":9,"content":"oðern"}]},"w":{"type":"leaf","weight":4,"entries":[{"key":"oðerwais","weight":4,"content":"oðerwais"}]}}}}},"r":{"type":"internal","weight":5,"values":["e","a"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"oðrer","weight":5,"content":"oðrer"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"oðran","weight":1,"content":"oðran"}]}}}}},"t":{"type":"leaf","weight":7,"entries":[{"key":"ota","weight":7,"content":"otą̊"},{"key":"ot","weight":1,"content":"öt"}]},"k":{"type":"internal","weight":2,"values":["e","i","k"],"children":{"e":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"internal","weight":2,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"okeð","weight":2,"content":"okeð"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"okeðum","weight":1,"content":"okeðum"}]}}}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"okið","weight":1,"content":"okið"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"okkelknaul","weight":1,"content":"okkelknaul"}]}}},"y":{"type":"leaf","weight":1,"entries":[{"key":"oy","weight":1,"content":"öy"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"operira","weight":1,"content":"operira"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"oufaliger","weight":1,"content":"oufaliger"}]}}},"s":{"type":"internal","weight":783,"values":["o","i","a","t","e","j","k","p","n","m","u","l","w","y"],"children":{"o":{"type":"internal","weight":783,"values":["﷐","s","v","n","m","k","f","ð","p"],"children":{"﷐":{"type":"leaf","weight":783,"entries":[{"key":"so","weight":783,"content":"so"}]},"s":{"type":"leaf","weight":161,"entries":[{"key":"sos","weight":161,"content":"sos"}]},"v":{"type":"internal","weight":27,"values":["﷐","i","u"],"children":{"﷐":{"type":"leaf","weight":27,"entries":[{"key":"sov","weight":27,"content":"sov"}]},"i":{"type":"leaf","weight":10,"entries":[{"key":"sovið","weight":10,"content":"sovið"}]},"u":{"type":"leaf","weight":6,"entries":[{"key":"sovu","weight":6,"content":"sovu"}]}}},"n":{"type":"internal","weight":10,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"son","weight":10,"content":"son"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"sone","weight":3,"content":"sonę"}]}}},"m":{"type":"internal","weight":10,"values":["n","m","d"],"children":{"n":{"type":"leaf","weight":10,"entries":[{"key":"somneð","weight":10,"content":"somneð"}]},"m":{"type":"internal","weight":5,"values":["n","i","e"],"children":{"n":{"type":"internal","weight":5,"values":["e","a"],"children":{"e":{"type":"internal","weight":5,"values":["d","ð","r"],"children":{"d":{"type":"leaf","weight":5,"entries":[{"key":"sommned","weight":5,"content":"sommned"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"sommneð","weight":1,"content":"sommneð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"sommner","weight":1,"content":"sommner"}]}}},"a":{"type":"leaf","weight":4,"entries":[{"key":"sommnað","weight":4,"content":"sommnað"}]}}},"i":{"type":"leaf","weight":3,"entries":[{"key":"sommin","weight":3,"content":"sommin"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"sommen","weight":3,"content":"sommen"}]}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"somd","weight":1,"content":"sömd"}]}}},"k":{"type":"leaf","weight":5,"entries":[{"key":"sokk","weight":5,"content":"sokk"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"soffun","weight":1,"content":"soffun"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"soð","weight":1,"content":"soð"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"soppar","weight":1,"content":"soppär"}]}}},"i":{"type":"internal","weight":400,"values":["g","t","r"," ","u","e","k","m","f","n"],"children":{"g":{"type":"internal","weight":400,"values":["﷐","e","l"],"children":{"﷐":{"type":"leaf","weight":400,"entries":[{"key":"sig","weight":400,"content":"sig"}]},"e":{"type":"internal","weight":8,"values":["l"],"children":{"l":{"type":"internal","weight":8,"values":["k"],"children":{"k":{"type":"internal","weight":8,"values":["a"],"children":{"a":{"type":"internal","weight":8,"values":["u"],"children":{"u":{"type":"internal","weight":8,"values":["t"],"children":{"t":{"type":"leaf","weight":8,"entries":[{"key":"sigelkautum","weight":8,"content":"sigelkautum"},{"key":"sigelkaut","weight":1,"content":"sigelkaut"}]}}}}}}}}}}},"l":{"type":"internal","weight":1,"values":["e","u"],"children":{"e":{"type":"internal","weight":1,"values":["n","r","ð"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"siglend","weight":1,"content":"siglend"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"sigler","weight":1,"content":"sigler"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"sigleð","weight":1,"content":"sigleð"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"siglum","weight":1,"content":"siglum"}]}}}}},"t":{"type":"internal","weight":18,"values":["t","﷐"],"children":{"t":{"type":"internal","weight":18,"values":["﷐","j"],"children":{"﷐":{"type":"leaf","weight":18,"entries":[{"key":"sitt","weight":18,"content":"sitt"}]},"j":{"type":"internal","weight":1,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"sittj","weight":1,"content":"sittj"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"sittjum","weight":1,"content":"sittjum"}]}}}}},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"sit","weight":4,"content":"sit"}]}}},"r":{"type":"leaf","weight":18,"entries":[{"key":"sir","weight":18,"content":"sir"}]}," ":{"type":"leaf","weight":18,"entries":[{"key":"si tt","weight":18,"content":"si´tt"}]},"u":{"type":"internal","weight":16,"values":["o"],"children":{"o":{"type":"internal","weight":16,"values":["v","ð","d"],"children":{"v":{"type":"internal","weight":16,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":16,"entries":[{"key":"siuov","weight":16,"content":"siuov"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"siuover","weight":2,"content":"siuover"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"siuovum","weight":1,"content":"siuovum"}]}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"siuoð","weight":1,"content":"siuoð"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"siuoda","weight":1,"content":"siuoda"}]}}}}},"e":{"type":"internal","weight":8,"values":["n"],"children":{"n":{"type":"internal","weight":8,"values":["e"],"children":{"e":{"type":"internal","weight":8,"values":["s","r"],"children":{"s":{"type":"leaf","weight":8,"entries":[{"key":"sienest","weight":8,"content":"sienest"}]},"r":{"type":"leaf","weight":3,"entries":[{"key":"sienera","weight":3,"content":"sienera"}]}}}}}}},"k":{"type":"internal","weight":7,"values":["u","k"],"children":{"u":{"type":"internal","weight":7,"values":["n"],"children":{"n":{"type":"internal","weight":7,"values":["d"],"children":{"d":{"type":"internal","weight":7,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"sikund","weight":7,"content":"sikund"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"sikunda","weight":3,"content":"sikunda"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"sikunder","weight":2,"content":"sikunder"}]}}}}}}},"k":{"type":"leaf","weight":3,"entries":[{"key":"sikk","weight":3,"content":"sikk"}]}}},"m":{"type":"leaf","weight":6,"entries":[{"key":"simma","weight":6,"content":"simma"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"siffrur","weight":1,"content":"siffrur"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"sinur","weight":1,"content":"sinur"}]}}},"a":{"type":"internal","weight":134,"values":["g","k","t","i","r","v","n","m","u","s","'","l"],"children":{"g":{"type":"internal","weight":134,"values":["﷐","g","u"],"children":{"﷐":{"type":"leaf","weight":134,"entries":[{"key":"sag","weight":134,"content":"såg"}]},"g":{"type":"internal","weight":123,"values":["d","t"],"children":{"d":{"type":"internal","weight":123,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":123,"entries":[{"key":"saggd","weight":123,"content":"saggd"}]},"e":{"type":"leaf","weight":10,"entries":[{"key":"saggde","weight":10,"content":"saggde"}]}}},"t":{"type":"leaf","weight":12,"entries":[{"key":"saggt","weight":12,"content":"saggt"}]}}},"u":{"type":"internal","weight":1,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"sagu","weight":1,"content":"sagu"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"sagun","weight":1,"content":"sagun"}]}}}}},"k":{"type":"internal","weight":51,"values":["t","e","r",null],"children":{"t":{"type":"leaf","weight":51,"entries":[{"key":"sakta","weight":51,"content":"sakta"},{"key":"sakt","weight":48,"content":"sakt"}]},"e":{"type":"internal","weight":16,"values":["r"],"children":{"r":{"type":"leaf","weight":16,"entries":[{"key":"sakert","weight":16,"content":"säkert"},{"key":"saker","weight":2,"content":"säker"}]}}},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"sak","weight":3,"content":"sak"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"sakrer","weight":2,"content":"säkrer"}]}}},"t":{"type":"internal","weight":27,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":27,"entries":[{"key":"sat","weight":27,"content":"såt"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"sata","weight":2,"content":"säta"}]},"e":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"sate","weight":1,"content":"säte"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"sateð","weight":1,"content":"säteð"}]}}}}},"r":{"type":"leaf","weight":22,"entries":[{"key":"sart","weight":22,"content":"sårt"}]},"i":{"type":"internal","weight":24,"values":["a","n","u","ð"," "],"children":{"a":{"type":"leaf","weight":24,"entries":[{"key":"saia","weight":24,"content":"saia"}]},"n":{"type":"internal","weight":19,"values":["u","﷐","d","a","g","k","e"],"children":{"u":{"type":"leaf","weight":19,"entries":[{"key":"sainum","weight":19,"content":"sainum"},{"key":"sainu","weight":6,"content":"sainu"}]},"﷐":{"type":"leaf","weight":14,"entries":[{"key":"sain","weight":14,"content":"sain"}]},"d":{"type":"internal","weight":8,"values":["j"],"children":{"j":{"type":"internal","weight":8,"values":["i","e"],"children":{"i":{"type":"leaf","weight":8,"entries":[{"key":"saindjin","weight":8,"content":"saindjin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"saindje","weight":1,"content":"saindję"}]}}}}},"a":{"type":"leaf","weight":7,"entries":[{"key":"saina","weight":7,"content":"saina"}]},"g":{"type":"internal","weight":4,"values":["g"],"children":{"g":{"type":"internal","weight":4,"values":["﷐","u","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"saingg","weight":4,"content":"saingg"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"sainggum","weight":1,"content":"sainggum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"saingger","weight":1,"content":"saingger"}]}}}}},"k":{"type":"leaf","weight":3,"entries":[{"key":"sainkt","weight":3,"content":"sainkt"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"sainer","weight":2,"content":"sainer"}]}}},"u":{"type":"leaf","weight":4,"entries":[{"key":"saium","weight":4,"content":"saium"}]},"ð":{"type":"internal","weight":3,"values":["u"],"children":{"u":{"type":"leaf","weight":3,"entries":[{"key":"saiðun","weight":3,"content":"saiðun"},{"key":"saiðu","weight":1,"content":"saiðu"}]}}}," ":{"type":"leaf","weight":2,"entries":[{"key":"sai ðun","weight":2,"content":"sai ðun"}]}}},"v":{"type":"leaf","weight":10,"entries":[{"key":"sava","weight":10,"content":"såvå"}]},"n":{"type":"internal","weight":6,"values":["d","n","t"],"children":{"d":{"type":"internal","weight":6,"values":["l","n","e"],"children":{"l":{"type":"leaf","weight":6,"entries":[{"key":"sandlaðun","weight":6,"content":"sandlåðun"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"sandem","weight":1,"content":"sandem"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"sandn","weight":2,"content":"sandn"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"sannt","weight":1,"content":"sannt"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"sant","weight":1,"content":"sant"}]}}},"u":{"type":"internal","weight":2,"values":["n","r"],"children":{"n":{"type":"internal","weight":2,"values":["g","d"],"children":{"g":{"type":"leaf","weight":2,"entries":[{"key":"saungg","weight":2,"content":"saungg"}]},"d":{"type":"internal","weight":2,"values":["j"],"children":{"j":{"type":"internal","weight":2,"values":["e","i"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"saundjem","weight":2,"content":"saundjem"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"saundjin","weight":1,"content":"saundjin"}]}}}}}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"sauru","weight":1,"content":"sauru"}]}}},"m":{"type":"internal","weight":5,"values":["a","b"],"children":{"a":{"type":"internal","weight":5,"values":["r"],"children":{"r":{"type":"internal","weight":5,"values":["n","m"],"children":{"n":{"type":"leaf","weight":5,"entries":[{"key":"samarn","weight":5,"content":"såmårn"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"samarmorgun","weight":1,"content":"såmårmorgun"}]}}}}},"b":{"type":"internal","weight":1,"values":["e","l"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"sambel","weight":1,"content":"sambel"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"samblas","weight":1,"content":"samblas"}]}}}}},"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["j"],"children":{"j":{"type":"internal","weight":2,"values":["i"],"children":{"i":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["t","d"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"sastjilt","weight":2,"content":"sästjilt"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"sastjild","weight":1,"content":"sästjild"}]}}}}}}}}}}},"'":{"type":"leaf","weight":2,"entries":[{"key":"sa'tt","weight":2,"content":"sä'tt"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"sal","weight":1,"content":"sal"}]}}},"t":{"type":"internal","weight":133,"values":["i","u","y","j","r","e","a","o"],"children":{"i":{"type":"internal","weight":133,"values":["e","n","a","g","t","k","l"],"children":{"e":{"type":"internal","weight":133,"values":["n","g","r","s",null],"children":{"n":{"type":"internal","weight":133,"values":["﷐","n","e","u","a"],"children":{"﷐":{"type":"leaf","weight":133,"entries":[{"key":"stien","weight":133,"content":"stien"}]},"n":{"type":"internal","weight":22,"values":["a","u"],"children":{"a":{"type":"leaf","weight":22,"entries":[{"key":"stienna","weight":22,"content":"stienna"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"stiennur","weight":1,"content":"stiennur"}]}}},"e":{"type":"internal","weight":7,"values":["m","﷐","r"],"children":{"m":{"type":"leaf","weight":7,"entries":[{"key":"stienem","weight":7,"content":"stienem"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"stiene","weight":3,"content":"stiene"}]},"r":{"type":"leaf","weight":3,"entries":[{"key":"stiener","weight":3,"content":"stiener"}]}}},"u":{"type":"leaf","weight":3,"entries":[{"key":"stienum","weight":3,"content":"stienum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stienar","weight":1,"content":"stienär"}]}}},"undefined":{"type":"leaf","weight":8,"entries":[{"key":"stie","weight":8,"content":"stie"}]},"g":{"type":"leaf","weight":3,"entries":[{"key":"stieg","weight":3,"content":"stieg"}]},"r":{"type":"internal","weight":2,"values":["d"],"children":{"d":{"type":"internal","weight":2,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"stierd","weight":2,"content":"stierd"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"stierder","weight":1,"content":"stierder"}]}}}}},"s":{"type":"internal","weight":1,"values":["a","k"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"stiesate","weight":1,"content":"stiesäte"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"stieskarp","weight":1,"content":"stįeskarp"}]}}}}},"n":{"type":"internal","weight":3,"values":["n"],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"stinner","weight":3,"content":"stinner"},{"key":"stinn","weight":1,"content":"stinn"}]}}},"a":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["s","a","e"],"children":{"s":{"type":"leaf","weight":2,"entries":[{"key":"stials","weight":2,"content":"stiäls"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stialas","weight":1,"content":"stiälås"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"stialend","weight":1,"content":"stiälend"}]}}}}},"g":{"type":"leaf","weight":1,"entries":[{"key":"stig","weight":1,"content":"stig"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"stitji","weight":1,"content":"stitji"}]},"k":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["m","n"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"stikam","weight":1,"content":"stikåm"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"stikan","weight":1,"content":"stikån"}]}}}}},"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"stilla","weight":1,"content":"stilla"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"stillaðer","weight":1,"content":"stillaðer"}]}}}}}}}}},"u":{"type":"internal","weight":49,"values":["r","o","g","s","t","p","n"],"children":{"r":{"type":"internal","weight":49,"values":["﷐","a","e","u","t","g","m","p","s","f","b","j","w","o","k","l"],"children":{"﷐":{"type":"leaf","weight":49,"entries":[{"key":"stur","weight":49,"content":"stur"}]},"a":{"type":"leaf","weight":12,"entries":[{"key":"sturan","weight":12,"content":"sturan"}]},"e":{"type":"leaf","weight":7,"entries":[{"key":"sturer","weight":7,"content":"sturer"}]},"u":{"type":"internal","weight":6,"values":["m","﷐","k"],"children":{"m":{"type":"leaf","weight":6,"entries":[{"key":"sturum","weight":6,"content":"sturum"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"sturu","weight":3,"content":"sturu"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"sturuksan","weight":1,"content":"sturuksan"}]}}},"t":{"type":"internal","weight":5,"values":["﷐","o","r"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"sturt","weight":5,"content":"sturt"}]},"o":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["u","e","n","a"],"children":{"u":{"type":"leaf","weight":2,"entries":[{"key":"sturtollum","weight":2,"content":"sturtollum"}]},"e":{"type":"internal","weight":2,"values":["m","r"],"children":{"m":{"type":"leaf","weight":2,"entries":[{"key":"sturtollem","weight":2,"content":"sturtollem"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"sturtoller","weight":1,"content":"sturtoller"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"sturtolln","weight":1,"content":"sturtolln"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"sturtolla","weight":1,"content":"sturtolla"}]}}}}}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"sturtray","weight":1,"content":"sturtråy"}]}}},"g":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["o","i"],"children":{"o":{"type":"internal","weight":3,"values":["n"],"children":{"n":{"type":"internal","weight":3,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"sturgron","weight":3,"content":"sturgron"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"sturgronum","weight":2,"content":"sturgronum"}]}}}}},"i":{"type":"leaf","weight":2,"entries":[{"key":"sturgriener","weight":2,"content":"sturgriener"}]}}}}},"m":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["y"],"children":{"y":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["e","n","a"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"sturmayre","weight":2,"content":"sturmåyre"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"sturmayrn","weight":1,"content":"sturmåyrn"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"sturmayrar","weight":1,"content":"sturmåyrär"}]}}}}}}}}},"p":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["y"],"children":{"y":{"type":"internal","weight":2,"values":["k","t"],"children":{"k":{"type":"leaf","weight":2,"entries":[{"key":"sturpaykum","weight":2,"content":"sturpåykum"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"sturpaytjin","weight":1,"content":"sturpåytjin"}]}}}}}}},"s":{"type":"internal","weight":2,"values":["t","k","y"],"children":{"t":{"type":"internal","weight":2,"values":["i","y"],"children":{"i":{"type":"leaf","weight":2,"entries":[{"key":"sturstie","weight":2,"content":"sturstię"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"sturstyvel","weight":1,"content":"sturstyvel"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"sturskollan","weight":1,"content":"sturskollan"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"stursyster","weight":1,"content":"stursyster"}]}}},"f":{"type":"leaf","weight":2,"entries":[{"key":"sturfuotjeð","weight":2,"content":"sturfuotjeð"}]},"b":{"type":"internal","weight":1,"values":["r","y"],"children":{"r":{"type":"internal","weight":1,"values":["o","u"],"children":{"o":{"type":"leaf","weight":1,"entries":[{"key":"sturbrot","weight":1,"content":"Sturbrot"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"sturbruoðer","weight":1,"content":"sturbruoðer"}]}}},"y":{"type":"leaf","weight":1,"entries":[{"key":"sturbyonnem","weight":1,"content":"sturbyönnem"}]}}},"j":{"type":"leaf","weight":1,"entries":[{"key":"sturjuoleð","weight":1,"content":"sturjuoleð"}]},"w":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"internal","weight":1,"values":["d"],"children":{"d":{"type":"internal","weight":1,"values":["e","n"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"sturwardem","weight":1,"content":"Sturwardem"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"sturwardn","weight":1,"content":"Sturwardn"}]}}}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"sturwen","weight":1,"content":"sturwen"}]}}},"o":{"type":"internal","weight":1,"values":["g","r"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"sturoga","weight":1,"content":"sturoga"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"sturorað","weight":1,"content":"sturorað"}]}}},"k":{"type":"internal","weight":1,"values":["a","r"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"sturkasungg","weight":1,"content":"sturkasungg"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"sturkrippar","weight":1,"content":"sturkrippär"}]}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"sturlikeð","weight":1,"content":"sturlikeð"}]}}},"o":{"type":"internal","weight":39,"values":["ð","l"],"children":{"ð":{"type":"leaf","weight":39,"entries":[{"key":"stuoð","weight":39,"content":"stuoð"}]},"l":{"type":"internal","weight":4,"values":["e","n","i",null],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"stuolem","weight":4,"content":"stuolem"}]},"n":{"type":"leaf","weight":4,"entries":[{"key":"stuoln","weight":4,"content":"stuoln"}]},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"stuol","weight":3,"content":"stuol"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"stuoliðs","weight":2,"content":"stuoliðs"}]}}}}},"g":{"type":"internal","weight":12,"values":["u"],"children":{"u":{"type":"internal","weight":12,"values":["﷐","n","m","r","w","k"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"stugu","weight":12,"content":"stugu"}]},"n":{"type":"leaf","weight":11,"entries":[{"key":"stugun","weight":11,"content":"stugun"}]},"m":{"type":"leaf","weight":8,"entries":[{"key":"stugum","weight":8,"content":"stugum"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"stugur","weight":2,"content":"stugur"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"stuguweddjin","weight":1,"content":"stuguweddjin"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"stuguknautn","weight":1,"content":"stuguknautn"}]}}}}},"s":{"type":"leaf","weight":5,"entries":[{"key":"stusseð","weight":5,"content":"stusseð"}]},"t":{"type":"internal","weight":5,"values":["t"],"children":{"t":{"type":"internal","weight":5,"values":["﷐","e","k"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"stutt","weight":5,"content":"stutt"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"stuttera","weight":3,"content":"stuttera"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"stuttkalsaungg","weight":1,"content":"stuttkalsaungg"}]}}}}},"p":{"type":"internal","weight":5,"values":["p","e"],"children":{"p":{"type":"internal","weight":5,"values":["e"],"children":{"e":{"type":"internal","weight":5,"values":["ð","r","d"],"children":{"ð":{"type":"leaf","weight":5,"entries":[{"key":"stuppeð","weight":5,"content":"stuppeð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"stupper","weight":1,"content":"stupper"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"stupped","weight":1,"content":"stupped"}]}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"stuped","weight":1,"content":"stuped"}]}}},"n":{"type":"internal","weight":2,"values":["g"],"children":{"g":{"type":"internal","weight":2,"values":["n","i"],"children":{"n":{"type":"internal","weight":2,"values":["u","a"],"children":{"u":{"type":"leaf","weight":2,"entries":[{"key":"stungnum","weight":2,"content":"stungnum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stungna","weight":1,"content":"stungna"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"stungin","weight":1,"content":"stungin"}]}}}}}}},"y":{"type":"internal","weight":16,"values":["p","o","v","r"],"children":{"p":{"type":"internal","weight":16,"values":["p"],"children":{"p":{"type":"internal","weight":16,"values":["l","e"],"children":{"l":{"type":"internal","weight":16,"values":["a","e"],"children":{"a":{"type":"leaf","weight":16,"entries":[{"key":"stypplas","weight":16,"content":"stypplas"}]},"e":{"type":"internal","weight":14,"values":["s","n"],"children":{"s":{"type":"leaf","weight":14,"entries":[{"key":"stypples","weight":14,"content":"stypples"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"stypplend","weight":1,"content":"stypplend"}]}}}}},"e":{"type":"leaf","weight":6,"entries":[{"key":"styppelbru","weight":6,"content":"Styppelbru"}]}}}}},"o":{"type":"internal","weight":6,"values":["r","s"],"children":{"r":{"type":"internal","weight":6,"values":["r","u"],"children":{"r":{"type":"internal","weight":6,"values":["e","﷐","a"],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"styorrera","weight":6,"content":"styörrera"}]},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"styorr","weight":4,"content":"styörr"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"styorra","weight":2,"content":"styörra"}]}}},"u":{"type":"leaf","weight":2,"entries":[{"key":"styoru","weight":2,"content":"styöru"}]}}},"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["n","﷐","a"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"styostn","weight":2,"content":"styöstn"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"styost","weight":2,"content":"styöst"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"styostam","weight":1,"content":"styöstam"}]}}}}}}},"v":{"type":"internal","weight":5,"values":["l"],"children":{"l":{"type":"internal","weight":5,"values":["e","u"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"styvle","weight":5,"content":"styvle"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"styvlum","weight":2,"content":"styvlum"}]}}}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"styrde","weight":1,"content":"styrde"}]}}},"j":{"type":"internal","weight":15,"values":["y","i","u","a","e"],"children":{"y":{"type":"internal","weight":15,"values":["o","l","m","d"],"children":{"o":{"type":"internal","weight":15,"values":["r"],"children":{"r":{"type":"internal","weight":15,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":15,"entries":[{"key":"stjyor","weight":15,"content":"stjyör"}]},"u":{"type":"internal","weight":5,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"stjyoru","weight":5,"content":"stjyöru"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"stjyorumtil","weight":1,"content":"stjyörumtil"}]}}}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"stjylter","weight":1,"content":"stjylter"}]},"m":{"type":"internal","weight":1,"values":["m","t"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"stjymma","weight":1,"content":"stjymma"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"stjymt","weight":1,"content":"stjymt"}]}}},"d":{"type":"internal","weight":1,"values":["d"],"children":{"d":{"type":"internal","weight":1,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"stjydd","weight":1,"content":"stjydd"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stjydda","weight":1,"content":"stjydda"}]}}}}}}},"i":{"type":"internal","weight":5,"values":["e","n","k","l"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"stjien","weight":5,"content":"stjien"}]},"n":{"type":"internal","weight":4,"values":["n","e"],"children":{"n":{"type":"internal","weight":4,"values":["k","e","r","s","f"],"children":{"k":{"type":"internal","weight":4,"values":["u"],"children":{"u":{"type":"internal","weight":4,"values":["p"],"children":{"p":{"type":"internal","weight":4,"values":["p"],"children":{"p":{"type":"internal","weight":4,"values":["u","a"],"children":{"u":{"type":"internal","weight":4,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"stjinnkuppu","weight":4,"content":"stjinnkuppu"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"stjinnkuppum","weight":1,"content":"stjinnkuppum"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"stjinnkuppan","weight":1,"content":"stjinnkuppan"}]}}}}}}}}},"e":{"type":"internal","weight":2,"values":["t","ð"],"children":{"t":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"stjinnett","weight":2,"content":"stjinnett"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"stjinnettur","weight":1,"content":"stjinnettur"}]}}}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"stjinneð","weight":1,"content":"stjinneð"}]}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"stjinnriem","weight":1,"content":"stjinnriem"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"stjinnstyvlum","weight":1,"content":"stjinnstyvlum"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"stjinnfeld","weight":1,"content":"stjinnfeld"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"stjinett","weight":1,"content":"stjinett"}]}}},"l":{"type":"internal","weight":1,"values":["d","t"],"children":{"d":{"type":"internal","weight":1,"values":["e","a"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"stjildes","weight":1,"content":"stjildes"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stjildas","weight":1,"content":"stjildas"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"stjilt","weight":1,"content":"stjilt"}]}}},"k":{"type":"internal","weight":2,"values":["k"],"children":{"k":{"type":"internal","weight":2,"values":["e","﷐"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"stjikk","weight":1,"content":"stjikk"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"stjikkeð","weight":2,"content":"stjikkeð"}]}}}}}}},"u":{"type":"internal","weight":5,"values":["o"],"children":{"o":{"type":"internal","weight":5,"values":["t","r","s"],"children":{"t":{"type":"internal","weight":5,"values":["﷐","f","a"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"stjuot","weight":5,"content":"stjuot"}]},"f":{"type":"leaf","weight":2,"entries":[{"key":"stjuotfelteð","weight":2,"content":"stjuotfelteð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stjuota","weight":1,"content":"stjuota"}]}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"stjuortu","weight":1,"content":"stjuortu"}]},"s":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"stjuoss","weight":1,"content":"stjuoss"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stjuossað","weight":1,"content":"stjuossað"}]}}}}}}}}},"a":{"type":"internal","weight":3,"values":["n","r","v","f","l"],"children":{"n":{"type":"internal","weight":3,"values":["s"],"children":{"s":{"type":"leaf","weight":3,"entries":[{"key":"stjansn","weight":3,"content":"stjansn"},{"key":"stjans","weight":1,"content":"stjans"}]}}},"r":{"type":"leaf","weight":2,"entries":[{"key":"stjara","weight":2,"content":"stjärå"},{"key":"stjar","weight":1,"content":"stjär"}]},"v":{"type":"internal","weight":2,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"stjav","weight":2,"content":"stjåv"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stjava","weight":1,"content":"stjåva"}]}}},"f":{"type":"leaf","weight":1,"entries":[{"key":"stjaf","weight":1,"content":"stjäf"}]},"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["a","u"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"stjalla","weight":1,"content":"stjälla"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"stjallur","weight":1,"content":"stjällur"}]}}}}}}},"e":{"type":"internal","weight":3,"values":["l"],"children":{"l":{"type":"internal","weight":3,"values":["l"],"children":{"l":{"type":"internal","weight":3,"values":["u","a"],"children":{"u":{"type":"internal","weight":3,"values":["r","﷐","m"],"children":{"r":{"type":"leaf","weight":3,"entries":[{"key":"stjellur","weight":3,"content":"stjellur"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"stjellu","weight":1,"content":"stjellu"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"stjellum","weight":1,"content":"stjellum"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"stjella","weight":1,"content":"stjella"},{"key":"stjella","weight":1,"content":"stjellą"}]}}}}}}}}},"e":{"type":"internal","weight":12,"values":["l","k","n","t"],"children":{"l":{"type":"internal","weight":12,"values":["l"],"children":{"l":{"type":"internal","weight":12,"values":["e","d","u",null],"children":{"e":{"type":"leaf","weight":12,"entries":[{"key":"stelle","weight":12,"content":"stelle"}]},"d":{"type":"leaf","weight":11,"entries":[{"key":"stelld","weight":11,"content":"stelld"}]},"undefined":{"type":"leaf","weight":10,"entries":[{"key":"stell","weight":10,"content":"stell"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"stellum","weight":1,"content":"stellum"}]}}}}},"k":{"type":"internal","weight":5,"values":["k"],"children":{"k":{"type":"internal","weight":5,"values":["t"],"children":{"t":{"type":"internal","weight":5,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"stekkt","weight":5,"content":"stekkt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"stekkte","weight":1,"content":"stekkte"}]}}}}}}},"n":{"type":"leaf","weight":5,"entries":[{"key":"stendeð","weight":5,"content":"stendeð"}]},"t":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["j"],"children":{"j":{"type":"internal","weight":2,"values":["a","e"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"stettja","weight":2,"content":"stettja"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"stettjer","weight":1,"content":"stettjer"}]}}}}}}}}},"r":{"type":"internal","weight":13,"values":["a","e","i","u"],"children":{"a":{"type":"internal","weight":13,"values":["i","k","l","u"],"children":{"i":{"type":"internal","weight":13,"values":["ð","t"],"children":{"t":{"type":"leaf","weight":12,"entries":[{"key":"straitt","weight":12,"content":"straitt"}]},"ð":{"type":"internal","weight":13,"values":["e",null],"children":{"e":{"type":"internal","weight":13,"values":["s","r"],"children":{"s":{"type":"leaf","weight":13,"entries":[{"key":"straiðest","weight":13,"content":"straiðest"}]},"r":{"type":"leaf","weight":10,"entries":[{"key":"straiðera","weight":10,"content":"straiðera"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"straið","weight":2,"content":"straið"}]}}}}},"k":{"type":"leaf","weight":10,"entries":[{"key":"straks","weight":10,"content":"straks"}]},"l":{"type":"internal","weight":1,"values":["e","n"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"strale","weight":1,"content":"stråle"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"straln","weight":1,"content":"stråln"}]}}},"u":{"type":"internal","weight":1,"values":["p"],"children":{"p":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"straupam","weight":1,"content":"straupam"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"straupe","weight":1,"content":"straupe"}]}}}}}}},"e":{"type":"leaf","weight":4,"entries":[{"key":"strekkt","weight":4,"content":"strekkt"}]},"i":{"type":"internal","weight":3,"values":["k","u"],"children":{"k":{"type":"leaf","weight":3,"entries":[{"key":"strik","weight":3,"content":"strik"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"striuokstikkur","weight":1,"content":"striuokstikkur"}]}}},"u":{"type":"internal","weight":2,"values":["t","o"],"children":{"t":{"type":"internal","weight":2,"values":["t","a","e"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"strutte","weight":2,"content":"strutte"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"struta","weight":1,"content":"struta"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"struter","weight":1,"content":"struter"}]}}},"o":{"type":"leaf","weight":1,"entries":[{"key":"struokstikk","weight":1,"content":"struokstikk"}]}}}}},"a":{"type":"internal","weight":10,"values":["r","n","k","l","ð","t","i","m","'"],"children":{"r":{"type":"internal","weight":10,"values":["k","t"],"children":{"k":{"type":"internal","weight":10,"values":["﷐","e","t"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"stark","weight":10,"content":"stark"}]},"e":{"type":"internal","weight":4,"values":["r","s"],"children":{"r":{"type":"internal","weight":4,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"starker","weight":4,"content":"starker"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"starkera","weight":3,"content":"starkera"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"starkester","weight":1,"content":"starkester"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"starkt","weight":1,"content":"starkt"}]}}},"t":{"type":"leaf","weight":2,"entries":[{"key":"starteð","weight":2,"content":"starteð"}]}}},"n":{"type":"internal","weight":7,"values":["d","n"],"children":{"d":{"type":"leaf","weight":7,"entries":[{"key":"stand","weight":7,"content":"stand"}]},"n":{"type":"internal","weight":5,"values":["e"],"children":{"e":{"type":"internal","weight":5,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"stanne","weight":5,"content":"stanne"}]},"ð":{"type":"leaf","weight":4,"entries":[{"key":"stanneð","weight":4,"content":"stanneð"}]}}}}}}},"k":{"type":"internal","weight":6,"values":["k","i"],"children":{"k":{"type":"internal","weight":6,"values":["﷐","e","a","u","t"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"stakk","weight":6,"content":"stakk"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"stakkarem","weight":1,"content":"stakkarem"}]},"e":{"type":"internal","weight":2,"values":["r","s"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"stakker","weight":2,"content":"stakker"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"stakkes","weight":1,"content":"stakkes"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"stakkum","weight":1,"content":"stakkum"}]},"t":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["y"],"children":{"y":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["i","n"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"stakktjyolim","weight":1,"content":"Stakktjyölim"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"stakktjyoln","weight":1,"content":"Stakktjyöln"}]}}}}}}}}}}}}},"i":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["ð","d"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"stakieteð","weight":2,"content":"stakieteð"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"stakieted","weight":1,"content":"stakieted"}]}}}}}}}}}}},"l":{"type":"leaf","weight":6,"entries":[{"key":"stals","weight":6,"content":"stals"}]},"ð":{"type":"leaf","weight":6,"entries":[{"key":"stað","weight":6,"content":"stað"}]},"t":{"type":"internal","weight":1,"values":["y","t"],"children":{"y":{"type":"leaf","weight":1,"entries":[{"key":"statyer","weight":1,"content":"statyer"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"stattjem","weight":1,"content":"stattjem"}]}}},"i":{"type":"internal","weight":1,"values":["n","e","g"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"stainggt","weight":1,"content":"stainggt"},{"key":"stain","weight":1,"content":"stain"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"staiem","weight":1,"content":"staiem"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"staig","weight":1,"content":"staig"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"stampeð","weight":1,"content":"stampeð"}]},"'":{"type":"leaf","weight":1,"entries":[{"key":"sta'nnum","weight":1,"content":"sta'nnum"}]}}},"o":{"type":"internal","weight":1,"values":["k","l"],"children":{"k":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"stokkol","weight":1,"content":"Stokkol"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"stokkolmern","weight":1,"content":"stokkolmern"}]}}}}}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"stolleð","weight":1,"content":"stolleð"}]}}}}},"e":{"type":"internal","weight":121,"values":["﷐","t","g","s","r","n","ð","l"],"children":{"﷐":{"type":"leaf","weight":121,"entries":[{"key":"se","weight":121,"content":"sę"}]},"t":{"type":"internal","weight":45,"values":["t","﷐","i"],"children":{"t":{"type":"internal","weight":45,"values":["﷐","j"],"children":{"﷐":{"type":"leaf","weight":45,"entries":[{"key":"sett","weight":45,"content":"sett"}]},"j":{"type":"leaf","weight":7,"entries":[{"key":"settj","weight":7,"content":"settj"}]}}},"﷐":{"type":"leaf","weight":12,"entries":[{"key":"set","weight":12,"content":"set"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"setið","weight":1,"content":"setið"}]}}},"g":{"type":"leaf","weight":20,"entries":[{"key":"seg","weight":20,"content":"seg"}]},"s":{"type":"leaf","weight":15,"entries":[{"key":"ses","weight":15,"content":"ses"}]},"r":{"type":"leaf","weight":10,"entries":[{"key":"ser","weight":10,"content":"ser"}]},"n":{"type":"internal","weight":7,"values":["e","n","t"],"children":{"e":{"type":"leaf","weight":7,"entries":[{"key":"sener","weight":7,"content":"sener"}]},"n":{"type":"leaf","weight":6,"entries":[{"key":"senn","weight":6,"content":"senn"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"sentimieter","weight":2,"content":"sentimieter"}]}}},"ð":{"type":"leaf","weight":3,"entries":[{"key":"seð","weight":3,"content":"seð"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"seln","weight":2,"content":"Seln"}]}}},"j":{"type":"internal","weight":77,"values":["a","u"],"children":{"a":{"type":"internal","weight":77,"values":["﷐","i","k","l"],"children":{"﷐":{"type":"leaf","weight":77,"entries":[{"key":"sja","weight":77,"content":"sjå"}]},"i":{"type":"leaf","weight":56,"entries":[{"key":"sjaið","weight":56,"content":"sjåið"}]},"k":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"sjaks","weight":2,"content":"sjäks"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"sjakst","weight":1,"content":"sjäkst"}]}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"sjal","weight":1,"content":"sjal"}]}}},"u":{"type":"internal","weight":17,"values":["﷐","o","k","m","u"],"children":{"﷐":{"type":"leaf","weight":17,"entries":[{"key":"sju","weight":17,"content":"sju"}]},"o":{"type":"internal","weight":10,"values":["v"],"children":{"v":{"type":"internal","weight":10,"values":["﷐","e","t"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"sjuov","weight":10,"content":"sjuov"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"sjuover","weight":2,"content":"sjuover"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"sjuovt","weight":1,"content":"sjuovt"}]}}}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"sjuklað","weight":1,"content":"sjuklað"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"sjumm","weight":1,"content":"sjumm"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"sjuund","weight":1,"content":"sjuund"}]}}}}},"p":{"type":"internal","weight":36,"values":["u","a","r","o","i","e","y"],"children":{"u":{"type":"internal","weight":36,"values":["o","n","t"],"children":{"o":{"type":"internal","weight":36,"values":["r","n"],"children":{"r":{"type":"internal","weight":36,"values":["d","t"],"children":{"d":{"type":"leaf","weight":36,"entries":[{"key":"spuord","weight":36,"content":"spuord"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"spuort","weight":2,"content":"spuort"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"spuonneð","weight":1,"content":"spuonneð"}]}}},"n":{"type":"leaf","weight":2,"entries":[{"key":"spuni","weight":2,"content":"spuni"}]},"t":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["﷐","ð","n"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"sputte","weight":2,"content":"sputte"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"sputteð","weight":2,"content":"sputteð"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"sputtend","weight":1,"content":"sputtend"}]}}}}}}}}},"a":{"type":"internal","weight":7,"values":["n","r","ð"],"children":{"n":{"type":"leaf","weight":7,"entries":[{"key":"spann","weight":7,"content":"spann"}]},"r":{"type":"internal","weight":7,"values":["t","k"],"children":{"t":{"type":"internal","weight":7,"values":["j"],"children":{"j":{"type":"internal","weight":7,"values":["i","e"],"children":{"i":{"type":"leaf","weight":7,"entries":[{"key":"spartjin","weight":7,"content":"spartjin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"spartjem","weight":1,"content":"spartjem"}]}}}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"spark","weight":1,"content":"spark"}]}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"spaðir","weight":1,"content":"spaðir"}]}}},"r":{"type":"internal","weight":5,"values":["a","u","y"],"children":{"a":{"type":"internal","weight":5,"values":["k","t"],"children":{"k":{"type":"internal","weight":5,"values":["a","e"],"children":{"a":{"type":"internal","weight":5,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"spraka","weight":5,"content":"språka"}]},"ð":{"type":"leaf","weight":4,"entries":[{"key":"sprakað","weight":4,"content":"spräkäð"}]}}},"e":{"type":"leaf","weight":5,"entries":[{"key":"sprakeð","weight":5,"content":"språkeð"}]}}},"t":{"type":"leaf","weight":3,"entries":[{"key":"spratjeð","weight":3,"content":"språtjeð"}]}}},"u":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["e","a"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"spruteð","weight":2,"content":"spruteð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"spruta","weight":1,"content":"spruta"}]}}}}},"y":{"type":"leaf","weight":1,"entries":[{"key":"spryndjur","weight":1,"content":"spryndjur"}]}}},"o":{"type":"internal","weight":5,"values":["r"],"children":{"r":{"type":"internal","weight":5,"values":["t"],"children":{"t":{"type":"internal","weight":5,"values":["a","d"],"children":{"a":{"type":"leaf","weight":5,"entries":[{"key":"sportallem","weight":5,"content":"sportallem"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"sportdryttjin","weight":1,"content":"sportdryttjin"}]}}}}}}},"i":{"type":"internal","weight":5,"values":["e","l","n","ð"],"children":{"l":{"type":"internal","weight":4,"values":["a","m"],"children":{"a":{"type":"internal","weight":4,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"spila","weight":4,"content":"spilå"},{"key":"spila","weight":1,"content":"spilä"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"spilað","weight":1,"content":"spiläð"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"spilmennistjur","weight":1,"content":"spilmennistjur"}]}}},"e":{"type":"leaf","weight":5,"entries":[{"key":"spienna","weight":5,"content":"spienna"}]},"n":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["a","r"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"spinnas","weight":2,"content":"spinnas"}]},"r":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["k","t"],"children":{"k":{"type":"leaf","weight":2,"entries":[{"key":"spinnrukk","weight":2,"content":"spinnrukk"}]},"t":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["e","i"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"spinnruttjem","weight":1,"content":"spinnruttjem"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"spinnruttjin","weight":1,"content":"spinnruttjin"}]}}}}}}}}}}}}}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"spið","weight":1,"content":"spið"}]}}},"e":{"type":"internal","weight":4,"values":["n","s"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"spennend","weight":4,"content":"spennend"}]},"s":{"type":"leaf","weight":2,"entries":[{"key":"spesiellt","weight":2,"content":"spesiellt"}]}}},"y":{"type":"leaf","weight":2,"entries":[{"key":"spyra","weight":2,"content":"spyra"}]}}},"m":{"type":"internal","weight":32,"values":["a","e","y"],"children":{"a":{"type":"internal","weight":32,"values":["﷐","k","l","g"],"children":{"﷐":{"type":"leaf","weight":32,"entries":[{"key":"sma","weight":32,"content":"små"}]},"k":{"type":"internal","weight":5,"values":["a","k"],"children":{"a":{"type":"internal","weight":5,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"smaka","weight":5,"content":"småkå"},{"key":"smaka","weight":3,"content":"smäkä"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"smakað","weight":1,"content":"smäkäð"}]}}},"k":{"type":"leaf","weight":2,"entries":[{"key":"smakkeð","weight":2,"content":"smakkeð"}]}}},"l":{"type":"internal","weight":2,"values":["l","t","e",null],"children":{"l":{"type":"leaf","weight":2,"entries":[{"key":"small","weight":2,"content":"small"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"smalt","weight":1,"content":"smalt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"smaler","weight":1,"content":"smaler"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"smal","weight":1,"content":"smal"}]}}},"g":{"type":"leaf","weight":1,"entries":[{"key":"smagan","weight":1,"content":"Smågan"}]}}},"e":{"type":"internal","weight":8,"values":["l"],"children":{"l":{"type":"internal","weight":8,"values":["l","t"],"children":{"l":{"type":"internal","weight":8,"values":["﷐","d","n"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"smell","weight":8,"content":"smell"}]},"d":{"type":"leaf","weight":4,"entries":[{"key":"smelld","weight":4,"content":"smelld"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"smelln","weight":1,"content":"smelln"}]}}},"t":{"type":"internal","weight":1,"values":["a","w"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"smelta","weight":1,"content":"smelta"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"smeltwattneð","weight":1,"content":"smeltwattneð"}]}}}}}}},"y":{"type":"internal","weight":3,"values":["g","o"],"children":{"g":{"type":"internal","weight":3,"values":["e"],"children":{"e":{"type":"internal","weight":3,"values":["ð","n"],"children":{"ð":{"type":"leaf","weight":3,"entries":[{"key":"smygeð","weight":3,"content":"smygeð"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"smygend","weight":2,"content":"smygend"}]}}}}},"o":{"type":"leaf","weight":1,"entries":[{"key":"smyoreð","weight":1,"content":"smyöreð"}]}}}}},"k":{"type":"internal","weight":43,"values":["o","a","u","r","w","e"],"children":{"o":{"type":"internal","weight":43,"values":["l","t"],"children":{"l":{"type":"internal","weight":43,"values":["l"],"children":{"l":{"type":"internal","weight":43,"values":["a","n","e"],"children":{"a":{"type":"internal","weight":43,"values":["n","m","r",null],"children":{"m":{"type":"leaf","weight":31,"entries":[{"key":"skollam","weight":31,"content":"skollam"}]},"n":{"type":"leaf","weight":43,"entries":[{"key":"skollan","weight":43,"content":"skollan"}]},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"skolla","weight":2,"content":"skolla"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"skollar","weight":1,"content":"skollär"}]}}},"n":{"type":"leaf","weight":29,"entries":[{"key":"skolln","weight":29,"content":"Skolln"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"skolle","weight":1,"content":"skolle"}]}}}}},"t":{"type":"internal","weight":3,"values":["e","﷐"],"children":{"e":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["n","﷐","l","s"],"children":{"n":{"type":"internal","weight":3,"values":["﷐","y"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"skotern","weight":3,"content":"skotern"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"skoternytjyln","weight":1,"content":"skoternytjyln"}]}}},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"skoter","weight":2,"content":"skoter"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"skoterlieðn","weight":1,"content":"skoterlieðn"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"skoterstyvle","weight":1,"content":"skoterstyvle"}]}}}}},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"skot","weight":3,"content":"skot"}]}}}}},"u":{"type":"internal","weight":9,"values":["o","g","d","l"],"children":{"o":{"type":"internal","weight":9,"values":["t","n","e","m","l","g",null],"children":{"t":{"type":"leaf","weight":9,"entries":[{"key":"skuotið","weight":9,"content":"skuotið"},{"key":"skuot","weight":1,"content":"skuot"}]},"n":{"type":"internal","weight":5,"values":["a","﷐"],"children":{"a":{"type":"internal","weight":5,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"skuona","weight":5,"content":"skuona"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"skuonar","weight":1,"content":"skuonär"}]}}},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"skuon","weight":3,"content":"skuon"}]}}},"e":{"type":"leaf","weight":3,"entries":[{"key":"skuoem","weight":3,"content":"skuoem"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"skuom","weight":1,"content":"skuom"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"skuolað","weight":1,"content":"skuoläð"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"skuo","weight":1,"content":"skuo"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"skuog","weight":1,"content":"skuog"}]}}},"d":{"type":"leaf","weight":4,"entries":[{"key":"skuddjin","weight":4,"content":"skuddjin"}]},"g":{"type":"internal","weight":7,"values":["g"],"children":{"g":{"type":"internal","weight":7,"values":["e","a"],"children":{"e":{"type":"leaf","weight":7,"entries":[{"key":"skugge","weight":7,"content":"skugge"}]},"a":{"type":"internal","weight":2,"values":["m","n"],"children":{"m":{"type":"leaf","weight":2,"entries":[{"key":"skuggam","weight":2,"content":"skuggam"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"skuggan","weight":2,"content":"skuggan"}]}}}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"skuld","weight":1,"content":"skuld"}]}}},"a":{"type":"internal","weight":14,"values":["i","v","k","u","r","ð","y","m","p","t","'"],"children":{"i":{"type":"internal","weight":14,"values":["ð","s","n","d"],"children":{"ð":{"type":"internal","weight":14,"values":["u","a","r","b","s"],"children":{"u":{"type":"internal","weight":14,"values":["m","r"],"children":{"m":{"type":"leaf","weight":14,"entries":[{"key":"skaiðum","weight":14,"content":"skaiðum"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"skaiður","weight":1,"content":"skaiður"}]}}},"a":{"type":"leaf","weight":6,"entries":[{"key":"skaiðar","weight":6,"content":"skaiðär"}]},"r":{"type":"internal","weight":6,"values":["e"],"children":{"e":{"type":"internal","weight":6,"values":["n"],"children":{"n":{"type":"internal","weight":6,"values":["n"],"children":{"n":{"type":"internal","weight":6,"values":["e"],"children":{"e":{"type":"internal","weight":6,"values":["r"],"children":{"r":{"type":"internal","weight":6,"values":["u","﷐","a","e","n"],"children":{"u":{"type":"leaf","weight":6,"entries":[{"key":"skaiðrennerum","weight":6,"content":"skaiðrennerum"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"skaiðrenner","weight":3,"content":"skaiðrenner"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"skaiðrenneram","weight":1,"content":"skaiðrenneram"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"skaiðrennerer","weight":1,"content":"skaiðrennerer"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"skaiðrennern","weight":1,"content":"skaiðrennern"}]}}}}}}}}}}}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"skaiðbokkum","weight":1,"content":"skaiðbokkum"}]},"s":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"skaiðstorar","weight":1,"content":"skaiðstorär"},{"key":"skaiðstor","weight":1,"content":"skaiðstor"}]}}}}}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"skaistorum","weight":1,"content":"skaistorum"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"skain","weight":1,"content":"skain"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"skaidum","weight":1,"content":"skaidum"}]}}},"v":{"type":"internal","weight":9,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"skav","weight":9,"content":"skåv"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"skavu","weight":2,"content":"skåvu"}]}}},"u":{"type":"internal","weight":8,"values":["l","r"],"children":{"l":{"type":"internal","weight":8,"values":["a","n","e","u","k"],"children":{"a":{"type":"leaf","weight":8,"entries":[{"key":"skaulam","weight":8,"content":"skaulam"}]},"n":{"type":"leaf","weight":8,"entries":[{"key":"skauln","weight":8,"content":"skauln"}]},"e":{"type":"leaf","weight":5,"entries":[{"key":"skaule","weight":5,"content":"skaule"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"skaulum","weight":2,"content":"skaulum"}]},"k":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["m"],"children":{"m":{"type":"internal","weight":1,"values":["r","p"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"skaulkamrater","weight":1,"content":"skaulkamrater"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"skaulkampisar","weight":1,"content":"skaulkåmpisär"}]}}}}}}}}},"r":{"type":"internal","weight":1,"values":["m"],"children":{"m":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"skaurman","weight":1,"content":"skaurman"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"skaurmannsmuolne","weight":1,"content":"skaurmannsmuolnę"}]}}}}}}}}}}},"k":{"type":"internal","weight":9,"values":["a"],"children":{"a":{"type":"internal","weight":9,"values":["ð","﷐","r"],"children":{"ð":{"type":"leaf","weight":9,"entries":[{"key":"skakað","weight":9,"content":"skäkäð"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"skaka","weight":2,"content":"skåkå"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"skakar","weight":1,"content":"skäkär"}]}}}}},"r":{"type":"internal","weight":4,"values":["p","a","d"],"children":{"p":{"type":"internal","weight":4,"values":["t","e","b","i","l",null],"children":{"t":{"type":"leaf","weight":4,"entries":[{"key":"skarpt","weight":4,"content":"skarpt"}]},"e":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"skarper","weight":3,"content":"skarper"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"skarpera","weight":3,"content":"skarpera"}]}}}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"skarp","weight":1,"content":"skarp"}]},"b":{"type":"internal","weight":2,"values":["o"],"children":{"o":{"type":"internal","weight":2,"values":["k","t"],"children":{"k":{"type":"internal","weight":2,"values":["k"],"children":{"k":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["n","m"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"skarpbokkam","weight":1,"content":"skarpbokkam"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"skarpbokkan","weight":2,"content":"skarpbokkan"}]}}}}}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"skarpbottjin","weight":1,"content":"skarpbottjin"}]}}}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"skarpin","weight":1,"content":"skarpin"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"skarpliuose","weight":1,"content":"skarpliuose"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"skarabrind","weight":2,"content":"skåråbrind"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"skard","weight":1,"content":"skard"}]}}},"ð":{"type":"leaf","weight":2,"entries":[{"key":"skaða","weight":2,"content":"skåðå"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"skaya","weight":1,"content":"skåya"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"skamper","weight":1,"content":"skamper"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"skapnaðum","weight":1,"content":"skapnaðum"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"skat a","weight":1,"content":"skät ą̊"}]},"'":{"type":"leaf","weight":1,"entries":[{"key":"ska'tt a","weight":1,"content":"skä'tt ą̊"}]}}},"r":{"type":"internal","weight":5,"values":["a","i","e","o"],"children":{"a":{"type":"internal","weight":5,"values":["y","p"],"children":{"y":{"type":"internal","weight":5,"values":["t"],"children":{"t":{"type":"internal","weight":5,"values":["t","a","e"],"children":{"t":{"type":"internal","weight":5,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"skraytt","weight":5,"content":"skråytt"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"skraytte","weight":2,"content":"skråytte"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"skrayter","weight":1,"content":"skråyter"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"skrayta","weight":2,"content":"skråyta"}]}}}}},"p":{"type":"leaf","weight":1,"entries":[{"key":"skrapar","weight":1,"content":"skräpär"}]}}},"i":{"type":"internal","weight":5,"values":["e","a"],"children":{"e":{"type":"internal","weight":5,"values":["v","ð","r"],"children":{"v":{"type":"internal","weight":5,"values":["﷐","a","d"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"skriev","weight":5,"content":"skriev"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"skrieva","weight":2,"content":"skrieva"}]},"d":{"type":"leaf","weight":2,"entries":[{"key":"skrievde","weight":2,"content":"skrievde"}]}}},"ð":{"type":"leaf","weight":4,"entries":[{"key":"skrieð","weight":4,"content":"skrieð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"skrier","weight":1,"content":"skrier"}]}}},"a":{"type":"leaf","weight":3,"entries":[{"key":"skria","weight":3,"content":"skria"}]}}},"e":{"type":"internal","weight":4,"values":["m","t"],"children":{"m":{"type":"internal","weight":4,"values":["d","a","e","t"],"children":{"d":{"type":"internal","weight":4,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"skremd","weight":4,"content":"skremd"}]},"e":{"type":"internal","weight":1,"values":["r","s"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"skremder","weight":1,"content":"skremder"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"skremdes","weight":1,"content":"skremdes"}]}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"skremas","weight":1,"content":"skremas"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"skremer","weight":1,"content":"skremer"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"skremt","weight":1,"content":"skremt"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"skrettjem","weight":1,"content":"skrettjem"}]}}},"o":{"type":"leaf","weight":1,"entries":[{"key":"skromt","weight":1,"content":"skromt"}]}}},"w":{"type":"internal","weight":4,"values":["a","e"],"children":{"a":{"type":"internal","weight":4,"values":["p"],"children":{"p":{"type":"internal","weight":4,"values":["a","e"],"children":{"a":{"type":"internal","weight":4,"values":["﷐","ð","r"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"skwapa","weight":4,"content":"skwäpä"},{"key":"skwapa","weight":4,"content":"skwåpå"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"skwapað","weight":1,"content":"skwäpäð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"skwapar","weight":1,"content":"skwäpär"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"skwaped","weight":1,"content":"skwäped"}]}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"skwekt","weight":1,"content":"skwekt"}]}}},"e":{"type":"internal","weight":4,"values":["r","g","l","m"],"children":{"r":{"type":"internal","weight":4,"values":["e","s","w","i",null],"children":{"s":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"skersetu","weight":2,"content":"skersetu"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"skersetun","weight":2,"content":"skersetun"}]}}}}}}}}},"w":{"type":"leaf","weight":2,"entries":[{"key":"skerweddjin","weight":2,"content":"skerweddjin"}]},"e":{"type":"leaf","weight":4,"entries":[{"key":"skereð","weight":4,"content":"skereð"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"sker","weight":1,"content":"sker"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"skeri","weight":2,"content":"skerį"}]}}},"g":{"type":"leaf","weight":2,"entries":[{"key":"skegg","weight":2,"content":"skegg"}]},"l":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["d","e","t"],"children":{"d":{"type":"leaf","weight":2,"entries":[{"key":"skelld","weight":2,"content":"skelld"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"skeller","weight":2,"content":"skeller"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"skellt","weight":1,"content":"skellt"}]}}}}},"m":{"type":"leaf","weight":2,"entries":[{"key":"skemmdes","weight":2,"content":"skemmdes"}]}}}}},"n":{"type":"internal","weight":36,"values":["j","i","a","u","y","o","e"],"children":{"j":{"type":"leaf","weight":36,"entries":[{"key":"snjast","weight":36,"content":"snjäst"}]},"i":{"type":"internal","weight":25,"values":["u","ð","e"],"children":{"u":{"type":"internal","weight":25,"values":["o"],"children":{"o":{"type":"internal","weight":25,"values":["﷐","m","'","r","s"],"children":{"﷐":{"type":"leaf","weight":25,"entries":[{"key":"sniuo","weight":25,"content":"sniuo"}]},"m":{"type":"leaf","weight":5,"entries":[{"key":"sniuomm","weight":5,"content":"sniuomm"}]},"'":{"type":"leaf","weight":3,"entries":[{"key":"sniuo'nn","weight":3,"content":"sniuo'nn"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"sniuoreku","weight":1,"content":"sniuoreku"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"sniuosteð","weight":1,"content":"sniuosteð"}]}}}}},"ð":{"type":"leaf","weight":3,"entries":[{"key":"snið","weight":3,"content":"snið"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"snieð","weight":1,"content":"snieð"}]}}},"a":{"type":"internal","weight":10,"values":["r","u","i"],"children":{"r":{"type":"leaf","weight":10,"entries":[{"key":"snart","weight":10,"content":"snart"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"snaia","weight":1,"content":"snaia"}]},"u":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["u","a"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"snauta","weight":1,"content":"snauta"}]},"u":{"type":"internal","weight":2,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"snautu","weight":2,"content":"snautu"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"snautum","weight":1,"content":"snautum"}]}}}}}}}}},"u":{"type":"internal","weight":3,"values":["r","s"],"children":{"s":{"type":"internal","weight":2,"values":["t","﷐","e"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"snust","weight":2,"content":"snust"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"snus","weight":1,"content":"snus"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"snuseð","weight":1,"content":"snuseð"}]}}},"r":{"type":"leaf","weight":3,"entries":[{"key":"snurreð","weight":3,"content":"snurreð"}]}}},"y":{"type":"leaf","weight":2,"entries":[{"key":"snyore","weight":2,"content":"snyöre"}]},"o":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"snoð","weight":1,"content":"snoð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"snorun","weight":1,"content":"snorun"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"snett","weight":1,"content":"snett"}]}}},"u":{"type":"internal","weight":21,"values":["o","m","ð","n","t","e"],"children":{"o":{"type":"internal","weight":21,"values":["l","r","ð","d"],"children":{"l":{"type":"internal","weight":21,"values":["e","n","t","s","b","d","u"],"children":{"e":{"type":"leaf","weight":21,"entries":[{"key":"suole","weight":21,"content":"suole"}]},"n":{"type":"leaf","weight":5,"entries":[{"key":"suoln","weight":5,"content":"suoln"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"suoltn","weight":3,"content":"suoltn"}]},"s":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["j","r"],"children":{"j":{"type":"leaf","weight":3,"entries":[{"key":"suolstjini","weight":3,"content":"suolstjinį"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"suolstralar","weight":1,"content":"suolstrålär"}]}}}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"suolbrend","weight":1,"content":"suolbrend"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"suoldater","weight":1,"content":"suoldater"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"suolur","weight":1,"content":"suolur"}]}}},"r":{"type":"internal","weight":10,"values":["a","e"],"children":{"a":{"type":"internal","weight":10,"values":["d","ð"],"children":{"ð":{"type":"leaf","weight":8,"entries":[{"key":"suorað","weight":8,"content":"suoräð"}]},"d":{"type":"leaf","weight":10,"entries":[{"key":"suorad","weight":10,"content":"suoräd"}]}}},"e":{"type":"leaf","weight":6,"entries":[{"key":"suoreð","weight":6,"content":"suoreð"}]}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"suoðið","weight":1,"content":"suoðið"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"suodwattneð","weight":1,"content":"suodwattneð"}]}}},"m":{"type":"internal","weight":19,"values":["m","u","b"],"children":{"m":{"type":"internal","weight":19,"values":["u","s","e"],"children":{"u":{"type":"internal","weight":19,"values":["﷐","l"],"children":{"﷐":{"type":"leaf","weight":19,"entries":[{"key":"summu","weight":19,"content":"summu"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"summulund","weight":2,"content":"summulund"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"summstas","weight":1,"content":"summstas"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"summer","weight":1,"content":"summer"}]}}},"u":{"type":"leaf","weight":14,"entries":[{"key":"sumu","weight":14,"content":"sumu"}]},"b":{"type":"internal","weight":5,"values":["r","e"],"children":{"r":{"type":"internal","weight":5,"values":["a","e"],"children":{"a":{"type":"leaf","weight":5,"entries":[{"key":"sumbra","weight":5,"content":"sumbra"}]},"e":{"type":"internal","weight":2,"values":["m","r"],"children":{"m":{"type":"leaf","weight":2,"entries":[{"key":"sumbrem","weight":2,"content":"sumbrem"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"sumbrer","weight":1,"content":"sumbrer"}]}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"sumber","weight":1,"content":"sumber"}]}}}}},"ð":{"type":"leaf","weight":6,"entries":[{"key":"suðyvyr","weight":6,"content":"suðyvyr"}]},"n":{"type":"internal","weight":5,"values":["d","n"],"children":{"d":{"type":"internal","weight":5,"values":["﷐","a","r"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"sund","weight":5,"content":"sund"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"sundag","weight":1,"content":"sundag"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"sundrivner","weight":1,"content":"sundrivner"}]}}},"n":{"type":"internal","weight":2,"values":["a","d"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"sunna","weight":2,"content":"sunną̊"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"sunndan","weight":1,"content":"sunndan"}]}}}}},"t":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["e","j"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"sutterwester","weight":2,"content":"sutterwester"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"suttjeð","weight":1,"content":"suttjeð"}]}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"sueð","weight":1,"content":"sueð"}]}}},"l":{"type":"internal","weight":20,"values":["u","a","e","i"],"children":{"u":{"type":"internal","weight":20,"values":["t","o","n"],"children":{"t":{"type":"internal","weight":20,"values":["﷐","e","a","u"],"children":{"﷐":{"type":"leaf","weight":20,"entries":[{"key":"slut","weight":20,"content":"slut"}]},"e":{"type":"leaf","weight":15,"entries":[{"key":"sluteð","weight":15,"content":"sluteð"}]},"a":{"type":"internal","weight":3,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"sluta","weight":3,"content":"sluta"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"slutað","weight":2,"content":"slutað"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"slutum","weight":1,"content":"slutum"}]}}},"o":{"type":"leaf","weight":14,"entries":[{"key":"sluo","weight":14,"content":"sluo"}]},"n":{"type":"internal","weight":1,"values":["d","g"],"children":{"d":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["e","i"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"slundjeð","weight":1,"content":"slundjeð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"slundjin","weight":1,"content":"slundjin"}]}}}}},"g":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"slungga","weight":1,"content":"slungga"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"slungge","weight":1,"content":"slungge"}]}}}}}}}}},"a":{"type":"internal","weight":12,"values":["i","k","s","u","r","p","t",null],"children":{"i":{"type":"internal","weight":12,"values":["k","s","ð","t"],"children":{"k":{"type":"internal","weight":12,"values":["t","﷐","u","a","e"],"children":{"t":{"type":"leaf","weight":12,"entries":[{"key":"slaikt","weight":12,"content":"slaikt"}]},"﷐":{"type":"leaf","weight":10,"entries":[{"key":"slaik","weight":10,"content":"slaik"}]},"u":{"type":"internal","weight":2,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"slaiku","weight":2,"content":"slaiku"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"slaikum","weight":1,"content":"slaikum"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"slaikan","weight":1,"content":"slaikan"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"slaiker","weight":1,"content":"slaiker"}]}}},"s":{"type":"leaf","weight":10,"entries":[{"key":"slais","weight":10,"content":"slais"}]},"ð":{"type":"leaf","weight":4,"entries":[{"key":"slaið","weight":4,"content":"slaið"}]},"t":{"type":"internal","weight":1,"values":["a"," "],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"slaita","weight":1,"content":"slaita"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"slait av","weight":1,"content":"slait åv"}]}}}}},"k":{"type":"internal","weight":12,"values":["t"],"children":{"t":{"type":"internal","weight":12,"values":["﷐","l"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"slakt","weight":12,"content":"släkt"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"slaktliðum","weight":1,"content":"släktliðum"}]}}}}},"undefined":{"type":"leaf","weight":7,"entries":[{"key":"sla","weight":7,"content":"slå"}]},"s":{"type":"internal","weight":4,"values":["p"],"children":{"p":{"type":"internal","weight":4,"values":["e","a"],"children":{"e":{"type":"internal","weight":4,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":4,"entries":[{"key":"slaspeð","weight":4,"content":"slaspeð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"slasper","weight":1,"content":"slasper"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"slaspa","weight":2,"content":"slaspa"}]}}}}},"u":{"type":"leaf","weight":4,"entries":[{"key":"slaungg","weight":4,"content":"slaungg"}]},"r":{"type":"internal","weight":4,"values":["v"],"children":{"v":{"type":"internal","weight":4,"values":["a","﷐","u"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"slarv","weight":2,"content":"slarv"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"slarva","weight":4,"content":"slarva"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"slarvu","weight":1,"content":"slarvu"}]}}}}},"p":{"type":"leaf","weight":1,"entries":[{"key":"slapp","weight":1,"content":"slapp"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"slatja","weight":1,"content":"slätja"}]}}},"e":{"type":"internal","weight":8,"values":["p"],"children":{"p":{"type":"internal","weight":8,"values":["p"],"children":{"p":{"type":"leaf","weight":8,"entries":[{"key":"sleppt","weight":8,"content":"sleppt"},{"key":"slepp","weight":5,"content":"slepp"}]}}}}},"i":{"type":"internal","weight":5,"values":["ð","e","n"],"children":{"ð":{"type":"internal","weight":5,"values":["i","u"],"children":{"i":{"type":"internal","weight":5,"values":["r","n",null],"children":{"r":{"type":"leaf","weight":5,"entries":[{"key":"sliðir","weight":5,"content":"sliðir"}]},"n":{"type":"leaf","weight":3,"entries":[{"key":"sliðin","weight":3,"content":"sliðin"}]},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"sliði","weight":2,"content":"sliði"}]}}},"u":{"type":"leaf","weight":3,"entries":[{"key":"sliðum","weight":3,"content":"sliðum"}]}}},"e":{"type":"internal","weight":4,"values":["t"],"children":{"t":{"type":"internal","weight":4,"values":["a","t",null],"children":{"a":{"type":"leaf","weight":4,"entries":[{"key":"slieta","weight":4,"content":"slieta"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"sliett","weight":3,"content":"sliett"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"sliet","weight":1,"content":"sliet"}]}}}}},"n":{"type":"internal","weight":2,"values":["g"],"children":{"g":{"type":"internal","weight":2,"values":["g"],"children":{"g":{"type":"internal","weight":2,"values":["a","﷐"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"slingg","weight":1,"content":"slingg"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"slingga","weight":2,"content":"slingga"}]}}}}}}}}}}},"w":{"type":"internal","weight":17,"values":["a","e","i"],"children":{"a":{"type":"internal","weight":17,"values":["r","i","l","g"],"children":{"r":{"type":"internal","weight":17,"values":["t",null],"children":{"t":{"type":"internal","weight":17,"values":["n","a","u","p","r","s","w","b",null],"children":{"n":{"type":"leaf","weight":17,"entries":[{"key":"swartn","weight":17,"content":"swartn"}]},"a":{"type":"internal","weight":9,"values":["m","n"],"children":{"m":{"type":"leaf","weight":9,"entries":[{"key":"swartam","weight":9,"content":"swartam"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"swartan","weight":1,"content":"swartan"}]}}},"undefined":{"type":"leaf","weight":8,"entries":[{"key":"swart","weight":8,"content":"swart"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"swartu","weight":3,"content":"swartu"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"swartplastn","weight":1,"content":"swartplastn"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"swartruta","weight":1,"content":"swartruta"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"swartsjuok","weight":1,"content":"swartsjuok"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"swartwattneð","weight":1,"content":"swartwattneð"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"swartbiln","weight":1,"content":"swartbiln"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"swar","weight":1,"content":"swar"}]}}},"i":{"type":"internal","weight":2,"values":["n","ð"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"swainggd","weight":2,"content":"swainggd"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"swaiða","weight":2,"content":"swaiða"}]}}},"l":{"type":"internal","weight":1,"values":["t","e"],"children":{"t":{"type":"leaf","weight":1,"entries":[{"key":"swalt","weight":1,"content":"swalt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"swalera","weight":1,"content":"swalera"}]}}},"g":{"type":"internal","weight":1,"values":["t","u","d"],"children":{"t":{"type":"leaf","weight":1,"entries":[{"key":"swagt","weight":1,"content":"swagt"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"swagulin","weight":1,"content":"swagulin"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"swagde","weight":1,"content":"swagde"}]}}}}},"e":{"type":"internal","weight":7,"values":["m","n","g","t","l","r"],"children":{"m":{"type":"internal","weight":7,"values":["n","m"],"children":{"n":{"type":"leaf","weight":7,"entries":[{"key":"swemnem","weight":7,"content":"swemnem"}]},"m":{"type":"internal","weight":1,"values":["e","i"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"swemmen","weight":1,"content":"swemmen"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"swemmin","weight":1,"content":"swemmin"}]}}}}},"n":{"type":"internal","weight":3,"values":["s"],"children":{"s":{"type":"internal","weight":3,"values":["k"],"children":{"k":{"type":"internal","weight":3,"values":["a","u","e"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"swenska","weight":3,"content":"swenska"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"swensku","weight":1,"content":"swensku"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"swenskeð","weight":1,"content":"swenskeð"}]}}}}}}},"g":{"type":"internal","weight":3,"values":["d"],"children":{"d":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"swegd","weight":3,"content":"swegd"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"swegde","weight":1,"content":"swegde"}]}}}}},"l":{"type":"leaf","weight":2,"entries":[{"key":"swelt","weight":2,"content":"swelt"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"swerre","weight":2,"content":"Swerre"}]},"t":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["n","u","e",null],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"swettn","weight":3,"content":"swettn"}]},"u":{"type":"internal","weight":3,"values":["n","g"],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"swettun","weight":3,"content":"swettun"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"swettug","weight":1,"content":"swettug"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"swett","weight":1,"content":"swett"}]},"e":{"type":"internal","weight":1,"values":["m","s"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"swettem","weight":1,"content":"swettem"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"swettes","weight":1,"content":"swettes"}]}}}}}}}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"swipeð","weight":1,"content":"swipeð"}]}}},"y":{"type":"internal","weight":8,"values":["n","s","k","o","l","ð"],"children":{"n":{"type":"internal","weight":8,"values":["t","e",null],"children":{"t":{"type":"leaf","weight":8,"entries":[{"key":"syntes","weight":8,"content":"syntes"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"synes","weight":3,"content":"synes"}]},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"syn","weight":2,"content":"syn"}]}}},"s":{"type":"internal","weight":5,"values":["t","k"],"children":{"t":{"type":"leaf","weight":5,"entries":[{"key":"syster","weight":5,"content":"syster"}]},"k":{"type":"leaf","weight":2,"entries":[{"key":"syskun","weight":2,"content":"syskun"}]}}},"k":{"type":"internal","weight":4,"values":["t"],"children":{"t":{"type":"internal","weight":4,"values":["e","a",null],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"sykta","weight":3,"content":"sykta"}]},"e":{"type":"internal","weight":4,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":4,"entries":[{"key":"sykteð","weight":4,"content":"sykteð"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"sykter","weight":2,"content":"sykter"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"sykt","weight":1,"content":"sykt"}]}}}}},"o":{"type":"internal","weight":3,"values":["k"],"children":{"k":{"type":"internal","weight":3,"values":["s"],"children":{"s":{"type":"internal","weight":3,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"syoks","weight":3,"content":"syöks"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"syoksum","weight":2,"content":"syöksum"}]}}}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"syler","weight":1,"content":"syler"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"syðerlutun","weight":1,"content":"syðerlutun"}]}}}}},"u":{"type":"internal","weight":700,"values":["u","p","m","n","l","o","v","k","g","a","s"],"children":{"u":{"type":"leaf","weight":700,"entries":[{"key":"uupið","weight":700,"content":"uupið"}]},"p":{"type":"internal","weight":650,"values":["p","i","a","y","t",null],"children":{"p":{"type":"internal","weight":650,"values":["u","e","a","t","i","m","-","y","d","f","g","s",null],"children":{"u":{"type":"leaf","weight":650,"entries":[{"key":"uppum","weight":650,"content":"uppum"}]},"e":{"type":"internal","weight":175,"values":["﷐","ð","s"],"children":{"﷐":{"type":"leaf","weight":175,"entries":[{"key":"uppe","weight":175,"content":"uppe"}]},"ð":{"type":"leaf","weight":169,"entries":[{"key":"uppeð","weight":169,"content":"uppeð"}]},"s":{"type":"leaf","weight":2,"entries":[{"key":"uppes","weight":2,"content":"uppes"}]}}},"a":{"type":"internal","weight":152,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":152,"entries":[{"key":"uppa","weight":152,"content":"uppa"},{"key":"uppa","weight":90,"content":"uppą̊"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"uppað","weight":2,"content":"uppað"}]}}},"undefined":{"type":"leaf","weight":152,"entries":[{"key":"upp","weight":152,"content":"upp"}]},"i":{"type":"leaf","weight":92,"entries":[{"key":"uppi","weight":92,"content":"uppi"}]},"t":{"type":"internal","weight":96,"values":["e","a"],"children":{"e":{"type":"leaf","weight":96,"entries":[{"key":"uppter","weight":96,"content":"uppter"}]},"a":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["ð"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"upptaiðner","weight":1,"content":"upptaiðner"},{"key":"upptaið","weight":1,"content":"upptaið"}]}}}}}}},"m":{"type":"leaf","weight":90,"entries":[{"key":"uppmin","weight":90,"content":"uppmin"}]},"-":{"type":"leaf","weight":5,"entries":[{"key":"upp-að","weight":5,"content":"upp-að"}]},"y":{"type":"internal","weight":5,"values":["r","v"],"children":{"r":{"type":"leaf","weight":5,"entries":[{"key":"uppyr","weight":5,"content":"uppyr"}]},"v":{"type":"leaf","weight":4,"entries":[{"key":"uppyvyr","weight":4,"content":"uppyvyr"}]}}},"d":{"type":"internal","weight":3,"values":["a"],"children":{"a":{"type":"internal","weight":3,"values":["i"],"children":{"i":{"type":"internal","weight":3,"values":["n"],"children":{"n":{"type":"internal","weight":3,"values":["g"],"children":{"g":{"type":"internal","weight":3,"values":["g"],"children":{"g":{"type":"internal","weight":3,"values":["d"],"children":{"d":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"uppdainggd","weight":3,"content":"uppdainggd"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"uppdainggder","weight":1,"content":"uppdainggder"}]}}}}}}}}}}}}}}},"f":{"type":"leaf","weight":2,"entries":[{"key":"uppfer","weight":2,"content":"uppfer"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"uppgainum","weight":1,"content":"uppgainum"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"uppstuppað","weight":1,"content":"uppstuppað"}]}}},"i":{"type":"leaf","weight":87,"entries":[{"key":"upi","weight":87,"content":"upi"}]},"y":{"type":"leaf","weight":3,"entries":[{"key":"upyr","weight":3,"content":"upyr"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"upað","weight":4,"content":"upað"},{"key":"upa","weight":1,"content":"upą̊"}]},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"up","weight":2,"content":"up"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"upter","weight":2,"content":"upter"}]}}},"m":{"type":"internal","weight":202,"values":["﷐","m","s","r"],"children":{"﷐":{"type":"leaf","weight":202,"entries":[{"key":"um","weight":202,"content":"um"}]},"m":{"type":"leaf","weight":15,"entries":[{"key":"umm","weight":15,"content":"umm"}]},"s":{"type":"internal","weight":12,"values":["t","l"],"children":{"t":{"type":"leaf","weight":12,"entries":[{"key":"umstað","weight":12,"content":"umstað"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"umslaeð","weight":1,"content":"umslaeð"}]}}},"r":{"type":"internal","weight":5,"values":["i","a"],"children":{"i":{"type":"leaf","weight":5,"entries":[{"key":"umringg","weight":5,"content":"umringg"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"umrað","weight":1,"content":"umråð"}]}}}}},"n":{"type":"internal","weight":121,"values":["g","d","n"],"children":{"g":{"type":"internal","weight":121,"values":["g"],"children":{"g":{"type":"internal","weight":121,"values":["a","e","u","r"],"children":{"a":{"type":"leaf","weight":121,"entries":[{"key":"unggar","weight":121,"content":"unggär"},{"key":"ungga","weight":27,"content":"unggą"},{"key":"ungga","weight":26,"content":"ungga"}]},"e":{"type":"leaf","weight":97,"entries":[{"key":"ungger","weight":97,"content":"ungger"},{"key":"ungge","weight":1,"content":"ungge"}]},"u":{"type":"leaf","weight":87,"entries":[{"key":"unggum","weight":87,"content":"unggum"}]},"r":{"type":"leaf","weight":10,"entries":[{"key":"unggrun","weight":10,"content":"unggrun"}]}}}}},"d":{"type":"internal","weight":34,"values":["e","a","r"],"children":{"e":{"type":"internal","weight":34,"values":["r","l"],"children":{"r":{"type":"internal","weight":34,"values":["﷐","l"],"children":{"﷐":{"type":"leaf","weight":34,"entries":[{"key":"under","weight":34,"content":"under"}]},"l":{"type":"internal","weight":3,"values":["i"],"children":{"i":{"type":"internal","weight":3,"values":["g","t","n"],"children":{"g":{"type":"internal","weight":3,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"underlig","weight":3,"content":"underlig"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"underligan","weight":1,"content":"underligan"}]}}},"t":{"type":"leaf","weight":2,"entries":[{"key":"underlit","weight":2,"content":"underlit"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"underlin","weight":1,"content":"underlin"}]}}}}}}},"l":{"type":"internal","weight":5,"values":["i"],"children":{"i":{"type":"internal","weight":5,"values":["t","g"],"children":{"t":{"type":"leaf","weight":5,"entries":[{"key":"undelit","weight":5,"content":"undelit"}]},"g":{"type":"internal","weight":2,"values":["﷐","u","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"undelig","weight":2,"content":"undelig"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"undeligum","weight":2,"content":"undeligum"},{"key":"undeligu","weight":1,"content":"undeligu"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"undeliger","weight":1,"content":"undeliger"}]}}}}}}}}},"a":{"type":"leaf","weight":25,"entries":[{"key":"unda","weight":25,"content":"undå"},{"key":"unda","weight":5,"content":"undą̊"}]},"r":{"type":"internal","weight":15,"values":["e","a","u"],"children":{"e":{"type":"leaf","weight":15,"entries":[{"key":"undres","weight":15,"content":"undres"}]},"a":{"type":"leaf","weight":7,"entries":[{"key":"undrað","weight":7,"content":"undrað"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"undrum","weight":1,"content":"undrum"}]}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"unngar","weight":1,"content":"unngär"}]}}},"l":{"type":"internal","weight":64,"values":["l","d","u","i","a","t",null],"children":{"l":{"type":"internal","weight":64,"values":["d","t","u","s"],"children":{"d":{"type":"internal","weight":64,"values":["﷐","u","e"],"children":{"﷐":{"type":"leaf","weight":64,"entries":[{"key":"ulld","weight":64,"content":"ulld"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"ulldum","weight":3,"content":"ulldum"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"ullde","weight":2,"content":"ullde"}]}}},"t":{"type":"internal","weight":1,"values":["u","r"],"children":{"u":{"type":"leaf","weight":1,"entries":[{"key":"ulltuss","weight":1,"content":"ulltuss"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"ulltrayur","weight":1,"content":"ulltråyur"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"ulluottu","weight":1,"content":"ulluottu"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"ullsukkur","weight":1,"content":"ullsukkur"}]}}},"d":{"type":"leaf","weight":26,"entries":[{"key":"uld","weight":26,"content":"uld"}]},"u":{"type":"leaf","weight":19,"entries":[{"key":"ulum","weight":19,"content":"ulum"}]},"undefined":{"type":"leaf","weight":12,"entries":[{"key":"ul","weight":12,"content":"ul"}]},"i":{"type":"leaf","weight":14,"entries":[{"key":"ulið","weight":14,"content":"ulið"}]},"a":{"type":"internal","weight":3,"values":["ð","﷐"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"ula","weight":2,"content":"ula"}]},"ð":{"type":"leaf","weight":3,"entries":[{"key":"ulað","weight":3,"content":"ulað"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"ultrarapið","weight":1,"content":"ultrarapið"}]}}},"o":{"type":"internal","weight":52,"values":["r","s","n","l","k","t","g","p","d","ð","e","b"],"children":{"r":{"type":"internal","weight":52,"values":["t","d","k","m","r","u",null],"children":{"t":{"type":"leaf","weight":52,"entries":[{"key":"uorteð","weight":52,"content":"uorteð"},{"key":"uort","weight":5,"content":"uort"}]},"d":{"type":"internal","weight":3,"values":["﷐","u","l"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"uord","weight":3,"content":"uord"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"uordum","weight":1,"content":"uordum"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"uordlist","weight":1,"content":"uordlist"}]}}},"k":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"uorka","weight":1,"content":"uorka"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"uorkeð","weight":1,"content":"uorkeð"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"uorm","weight":1,"content":"uorm"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"uor","weight":1,"content":"uor"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"uorrum","weight":1,"content":"uorrum"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"uoruoliger","weight":1,"content":"ųoruoliger"}]}}},"s":{"type":"internal","weight":29,"values":["﷐","s","y","t","a"],"children":{"﷐":{"type":"leaf","weight":29,"entries":[{"key":"uos","weight":29,"content":"uos"}]},"s":{"type":"leaf","weight":17,"entries":[{"key":"uoss","weight":17,"content":"uoss"}]},"y":{"type":"internal","weight":5,"values":["n"],"children":{"n":{"type":"internal","weight":5,"values":["l"],"children":{"l":{"type":"internal","weight":5,"values":["i"],"children":{"i":{"type":"internal","weight":5,"values":["n","g"],"children":{"n":{"type":"leaf","weight":5,"entries":[{"key":"uosynlin","weight":5,"content":"uosynlin"}]},"g":{"type":"internal","weight":5,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"uosynlig","weight":5,"content":"uosynlig"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"uosynligan","weight":2,"content":"uosynligan"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"uosynliger","weight":1,"content":"ųosynliger"}]}}}}}}}}}}},"t":{"type":"internal","weight":4,"values":["e","﷐","g","n"],"children":{"e":{"type":"internal","weight":4,"values":["ð"],"children":{"ð":{"type":"leaf","weight":4,"entries":[{"key":"uosteð","weight":4,"content":"uosteð"},{"key":"uosteð","weight":1,"content":"ųosteð"}]}}},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"uost","weight":2,"content":"uost"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"uostgas","weight":1,"content":"uostgą̊s"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"uostn","weight":1,"content":"uostn"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"uosamser","weight":1,"content":"ųosamser"}]}}},"n":{"type":"internal","weight":16,"values":["a","d","i","u","l","n",null],"children":{"a":{"type":"leaf","weight":16,"entries":[{"key":"uona","weight":16,"content":"uona"}]},"d":{"type":"internal","weight":12,"values":["e","l"],"children":{"e":{"type":"leaf","weight":12,"entries":[{"key":"uonde","weight":12,"content":"uonde"}]},"l":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["k","f"],"children":{"k":{"type":"leaf","weight":1,"entries":[{"key":"uondloskrytyre","weight":1,"content":"uondloskrytyre"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"uondlosfugeln","weight":1,"content":"uondlosfugeln"}]}}}}}}}}},"i":{"type":"leaf","weight":7,"entries":[{"key":"uoni","weight":7,"content":"uoni"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"uonun","weight":3,"content":"uonun"},{"key":"uonu","weight":3,"content":"uonu"}]},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"uon","weight":4,"content":"uon"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"uonlos","weight":1,"content":"uonlos"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"uonne","weight":1,"content":"uonne"}]}}},"l":{"type":"internal","weight":7,"values":["﷐","e","i","t","a"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"uol","weight":7,"content":"uol"}]},"e":{"type":"internal","weight":2,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"uole","weight":2,"content":"uole"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"uoleð","weight":1,"content":"uoleð"}]}}},"i":{"type":"leaf","weight":2,"entries":[{"key":"uoli","weight":2,"content":"uolį"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"uolteð","weight":2,"content":"uolteð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"uolaiker","weight":1,"content":"ųolaiker"}]}}},"k":{"type":"internal","weight":4,"values":["﷐","u","n"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"uok","weight":4,"content":"uok"}]},"u":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["g","t"],"children":{"g":{"type":"leaf","weight":2,"entries":[{"key":"uokunnug","weight":2,"content":"ųokunnug"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"uokunnut","weight":2,"content":"uokunnut"},{"key":"uokunnut","weight":2,"content":"ųokunnut"}]}}}}}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"uoknaulskiuoknaul","weight":1,"content":"uoknaulskiuoknaul"}]}}},"t":{"type":"internal","weight":4,"values":["t","a","e","u"],"children":{"t":{"type":"internal","weight":4,"values":["u","l"],"children":{"u":{"type":"internal","weight":4,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"uottu","weight":4,"content":"uottu"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"uottum","weight":1,"content":"uottum"}]}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"uottlos","weight":1,"content":"uottlos"}]}}},"a":{"type":"internal","weight":2,"values":["'","g"],"children":{"'":{"type":"leaf","weight":2,"entries":[{"key":"uota'n","weight":2,"content":"ųotä'n"}]},"g":{"type":"leaf","weight":2,"entries":[{"key":"uotag","weight":2,"content":"ųotäg"}]}}},"e":{"type":"leaf","weight":2,"entries":[{"key":"uoteð","weight":2,"content":"uoteð"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"uotuoluger","weight":1,"content":"ųotuoluger"}]}}},"g":{"type":"internal","weight":3,"values":["a","r"],"children":{"a":{"type":"internal","weight":3,"values":["s"],"children":{"s":{"type":"leaf","weight":3,"entries":[{"key":"uogas","weight":3,"content":"ųogås"},{"key":"uogas","weight":1,"content":"ųogäs"}]}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"uogrotteli","weight":1,"content":"ųogrotteli"}]}}},"p":{"type":"internal","weight":2,"values":["﷐","e","i"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"uop","weight":2,"content":"uop"}]},"e":{"type":"internal","weight":2,"values":["m","r"],"children":{"m":{"type":"leaf","weight":2,"entries":[{"key":"uopem","weight":2,"content":"uopem"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"uoper","weight":2,"content":"uoper"}]}}},"i":{"type":"leaf","weight":2,"entries":[{"key":"uopin","weight":2,"content":"uopin"}]}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"uodal","weight":1,"content":"ųodäl"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"uoðeð","weight":1,"content":"uoðeð"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"uoendes","weight":1,"content":"uoendes"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"uoborger","weight":1,"content":"ųobörger"}]}}},"v":{"type":"internal","weight":15,"values":["e","l","s","o","k","n","m"],"children":{"e":{"type":"leaf","weight":15,"entries":[{"key":"uvendes","weight":15,"content":"uvendes"}]},"l":{"type":"internal","weight":5,"values":["j","i"],"children":{"j":{"type":"leaf","weight":5,"entries":[{"key":"uvljuott","weight":5,"content":"uvljuott"}]},"i":{"type":"leaf","weight":4,"entries":[{"key":"uvliuott","weight":4,"content":"uvliuott"}]}}},"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["u","i"],"children":{"u":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"uvsturer","weight":2,"content":"uvsturer"},{"key":"uvstur","weight":2,"content":"uvstur"}]}}},"i":{"type":"internal","weight":1,"values":["e","n"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"uvstierd","weight":1,"content":"uvstierd"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"uvstinn","weight":1,"content":"uvstinn"}]}}}}}}},"o":{"type":"internal","weight":2,"values":["n","g"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"uvonað","weight":2,"content":"uvonað"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"uvogt","weight":1,"content":"uvogt"}]}}},"k":{"type":"leaf","weight":2,"entries":[{"key":"uvkollt","weight":2,"content":"uvkollt"}]},"m":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["k","t"],"children":{"k":{"type":"leaf","weight":1,"entries":[{"key":"uvmikkel","weight":1,"content":"uvmikkel"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"uvmitjið","weight":1,"content":"uvmitjið"}]}}}}},"n":{"type":"leaf","weight":2,"entries":[{"key":"uvner","weight":2,"content":"uvner"}]}}},"k":{"type":"internal","weight":13,"values":["i","k","a","s","u"],"children":{"i":{"type":"leaf","weight":13,"entries":[{"key":"ukin","weight":13,"content":"ukin"}]},"k":{"type":"internal","weight":4,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"ukk","weight":4,"content":"ukk"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"ukker","weight":1,"content":"ukker"}]}}},"a":{"type":"leaf","weight":4,"entries":[{"key":"ukað","weight":4,"content":"ukað"}]},"s":{"type":"internal","weight":1,"values":["a","b","n"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"uksam","weight":1,"content":"uksam"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"uksbjarr","weight":1,"content":"Uksbjärr"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"uksn","weight":1,"content":"uksn"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"ukum","weight":1,"content":"ukum"}]}}},"g":{"type":"internal","weight":12,"values":["s","e"],"children":{"s":{"type":"internal","weight":12,"values":["t","e","a"],"children":{"t":{"type":"internal","weight":12,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"ugst","weight":12,"content":"ugst"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"ugste","weight":1,"content":"ugste"}]}}},"e":{"type":"leaf","weight":3,"entries":[{"key":"ugser","weight":3,"content":"ugser"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"ugsa","weight":2,"content":"ugsa"}]}}},"e":{"type":"leaf","weight":5,"entries":[{"key":"ugel","weight":5,"content":"ugel"}]}}},"a":{"type":"internal","weight":2,"values":["n","l"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"uansig","weight":2,"content":"uansig"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"ualaiku","weight":1,"content":"uälaiku"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"usekt","weight":1,"content":"usekt"}]}}},"d":{"type":"internal","weight":612,"values":["i","a","u","y","j","r","o","e"],"children":{"i":{"type":"internal","weight":612,"values":["e","g","s","r","m","u"],"children":{"e":{"type":"internal","weight":612,"values":["r","m","l"],"children":{"r":{"type":"internal","weight":612,"values":["﷐","-","a"],"children":{"﷐":{"type":"leaf","weight":612,"entries":[{"key":"dier","weight":612,"content":"dier"}]},"-":{"type":"leaf","weight":21,"entries":[{"key":"dier-dar","weight":21,"content":"dier-dar"}]},"a":{"type":"leaf","weight":12,"entries":[{"key":"dieras","weight":12,"content":"dieras"}]}}},"m":{"type":"internal","weight":168,"values":["﷐","-"],"children":{"﷐":{"type":"leaf","weight":168,"entries":[{"key":"diem","weight":168,"content":"diem"}]},"-":{"type":"leaf","weight":8,"entries":[{"key":"diem-dar","weight":8,"content":"diem-dar"}]}}},"l":{"type":"internal","weight":3,"values":["d","﷐","e"],"children":{"d":{"type":"leaf","weight":3,"entries":[{"key":"dield","weight":3,"content":"dield"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"diel","weight":2,"content":"diel"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"dieler","weight":1,"content":"dieler"}]}}}}},"g":{"type":"internal","weight":39,"values":["﷐","e","r","l"],"children":{"﷐":{"type":"leaf","weight":39,"entries":[{"key":"dig","weight":39,"content":"dig"}]},"e":{"type":"internal","weight":5,"values":["r","l"],"children":{"r":{"type":"internal","weight":5,"values":["﷐","b","u"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"diger","weight":5,"content":"diger"}]},"b":{"type":"leaf","weight":5,"entries":[{"key":"digerbjarrsween","weight":5,"content":"Digerbjärrsween"}]},"u":{"type":"internal","weight":1,"values":["l","o"],"children":{"l":{"type":"leaf","weight":1,"entries":[{"key":"digerulluottu","weight":1,"content":"digerulluottu"}]},"o":{"type":"leaf","weight":1,"entries":[{"key":"digeruotta","weight":1,"content":"digeruotta"}]}}}}},"l":{"type":"leaf","weight":2,"entries":[{"key":"digel","weight":2,"content":"digel"}]}}},"r":{"type":"leaf","weight":4,"entries":[{"key":"digrer","weight":4,"content":"digrer"}]},"l":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"digleð","weight":1,"content":"digleð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"digler","weight":1,"content":"digler"}]}}}}}}},"s":{"type":"internal","weight":6,"values":["t","a","﷐","e","k"],"children":{"t":{"type":"internal","weight":6,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"dist","weight":6,"content":"dist"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"diste","weight":1,"content":"diste"}]}}},"﷐":{"type":"leaf","weight":5,"entries":[{"key":"dis","weight":5,"content":"dis"}]},"a":{"type":"leaf","weight":6,"entries":[{"key":"disa","weight":6,"content":"disa"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"diser","weight":1,"content":"diser"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"diskripp","weight":1,"content":"diskripp"}]}}},"r":{"type":"leaf","weight":4,"entries":[{"key":"direkt","weight":4,"content":"direkt"}]},"m":{"type":"leaf","weight":3,"entries":[{"key":"dimb","weight":3,"content":"dimb"}]},"u":{"type":"internal","weight":2,"values":["o"],"children":{"o":{"type":"internal","weight":2,"values":["p"],"children":{"p":{"type":"internal","weight":2,"values":["u","a"],"children":{"u":{"type":"leaf","weight":2,"entries":[{"key":"diuopu","weight":2,"content":"diuopu"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"diuopa","weight":1,"content":"diuopa"}]}}}}}}}}},"a":{"type":"internal","weight":342,"values":["r","﷐","g","i","n","l","m","e","a","u"],"children":{"r":{"type":"internal","weight":342,"values":["﷐","f","i","e"],"children":{"﷐":{"type":"leaf","weight":342,"entries":[{"key":"dar","weight":342,"content":"dar"}]},"f":{"type":"leaf","weight":2,"entries":[{"key":"darfra","weight":2,"content":"darfrą̊"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"daretter","weight":1,"content":"daretter"}]},"i":{"type":"internal","weight":2,"values":["n","﷐"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"dari","weight":1,"content":"dari"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"darinne","weight":2,"content":"darinne"}]}}}}},"﷐":{"type":"leaf","weight":40,"entries":[{"key":"da","weight":40,"content":"dą̊"}]},"g":{"type":"internal","weight":33,"values":["﷐","a","u"],"children":{"﷐":{"type":"leaf","weight":33,"entries":[{"key":"dag","weight":33,"content":"dag"}]},"a":{"type":"leaf","weight":10,"entries":[{"key":"daga","weight":10,"content":"dågå"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"dagum","weight":1,"content":"dagum"}]}}},"n":{"type":"internal","weight":30,"values":["﷐","s","e"],"children":{"﷐":{"type":"leaf","weight":30,"entries":[{"key":"dan","weight":30,"content":"dan"}]},"s":{"type":"internal","weight":5,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"dans","weight":5,"content":"dans"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"danseð","weight":3,"content":"danseð"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"dane","weight":1,"content":"dane"}]}}},"i":{"type":"internal","weight":31,"values":["t","n",null],"children":{"t":{"type":"internal","weight":31,"values":["-","﷐","i","a","t","u","y","e","o"],"children":{"﷐":{"type":"leaf","weight":24,"entries":[{"key":"dait","weight":24,"content":"dait"}]},"-":{"type":"leaf","weight":31,"entries":[{"key":"dait-að","weight":31,"content":"dait-að"}]},"i":{"type":"leaf","weight":16,"entries":[{"key":"daiti","weight":16,"content":"daiti"}]},"a":{"type":"leaf","weight":14,"entries":[{"key":"daitað","weight":14,"content":"daitað"},{"key":"daita","weight":4,"content":"daitą̊"}]},"t":{"type":"leaf","weight":6,"entries":[{"key":"daitter","weight":6,"content":"daitter"}]},"u":{"type":"leaf","weight":6,"entries":[{"key":"daitum","weight":6,"content":"daitum"}]},"y":{"type":"leaf","weight":3,"entries":[{"key":"daityvyr","weight":3,"content":"daityvyr"}]},"e":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"leaf","weight":3,"entries":[{"key":"daiterað","weight":3,"content":"daiterað"},{"key":"daiter","weight":1,"content":"daiter"}]}}},"o":{"type":"leaf","weight":2,"entries":[{"key":"daitonað","weight":2,"content":"daitonað"}]}}},"n":{"type":"internal","weight":4,"values":["d","g","e"],"children":{"d":{"type":"internal","weight":4,"values":["j"],"children":{"j":{"type":"internal","weight":4,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"daindj","weight":4,"content":"daindj"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"daindja","weight":2,"content":"daindja"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"daindjer","weight":1,"content":"daindjer"}]}}}}},"g":{"type":"internal","weight":2,"values":["g"],"children":{"g":{"type":"internal","weight":2,"values":["t","d"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"dainggt","weight":2,"content":"dainggt"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"dainggd","weight":1,"content":"dainggd"}]}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"dainer","weight":1,"content":"dainer"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"dai","weight":2,"content":"dai"}]}}},"l":{"type":"internal","weight":9,"values":["t","s","i","n","e","a",null],"children":{"t":{"type":"leaf","weight":9,"entries":[{"key":"dalt","weight":9,"content":"dält"}]},"s":{"type":"internal","weight":4,"values":["k"],"children":{"k":{"type":"internal","weight":4,"values":["a","e"],"children":{"a":{"type":"leaf","weight":4,"entries":[{"key":"dalska","weight":4,"content":"dalska"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"dalskeð","weight":2,"content":"dalskeð"}]}}}}},"undefined":{"type":"leaf","weight":5,"entries":[{"key":"dal","weight":5,"content":"däl"}]},"i":{"type":"internal","weight":3,"values":["m","e"],"children":{"m":{"type":"leaf","weight":3,"entries":[{"key":"dalim","weight":3,"content":"dalim"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"daliete","weight":1,"content":"däliete"}]}}},"n":{"type":"leaf","weight":2,"entries":[{"key":"daln","weight":2,"content":"daln"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"daler","weight":1,"content":"däler"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"dalarna","weight":1,"content":"Dalarna"}]}}},"m":{"type":"internal","weight":5,"values":["b"],"children":{"b":{"type":"internal","weight":5,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"damb","weight":5,"content":"damb"}]},"e":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"dambe","weight":1,"content":"dambe"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"dambeð","weight":1,"content":"dambeð"}]}}}}}}},"e":{"type":"internal","weight":4,"values":["m","r","ð"],"children":{"m":{"type":"leaf","weight":4,"entries":[{"key":"daem","weight":4,"content":"daem"}]},"r":{"type":"leaf","weight":4,"entries":[{"key":"daer","weight":4,"content":"daer"}]},"ð":{"type":"leaf","weight":3,"entries":[{"key":"daeð","weight":3,"content":"däeð"}]}}},"a":{"type":"leaf","weight":3,"entries":[{"key":"daar","weight":3,"content":"daär"},{"key":"daa","weight":1,"content":"däa"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"daungneð","weight":1,"content":"daungneð"}]}}},"u":{"type":"internal","weight":184,"values":["﷐","g","m","k","r","n","o"],"children":{"﷐":{"type":"leaf","weight":184,"entries":[{"key":"du","weight":184,"content":"du"}]},"g":{"type":"internal","weight":24,"values":["d","﷐","a","i","u"],"children":{"d":{"type":"internal","weight":24,"values":["﷐","e","u","i"],"children":{"﷐":{"type":"leaf","weight":24,"entries":[{"key":"dugd","weight":24,"content":"dugd"}]},"e":{"type":"leaf","weight":12,"entries":[{"key":"dugde","weight":12,"content":"dugde"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"dugdum","weight":1,"content":"dugdum"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"dugdið","weight":1,"content":"dugdið"}]}}},"﷐":{"type":"leaf","weight":17,"entries":[{"key":"dug","weight":17,"content":"dug"}]},"a":{"type":"internal","weight":11,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":11,"entries":[{"key":"duga","weight":11,"content":"dugå"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"dugað","weight":1,"content":"dugåð"}]}}},"i":{"type":"leaf","weight":2,"entries":[{"key":"dugið","weight":2,"content":"dugið"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"dugum","weight":2,"content":"dugum"}]}}},"m":{"type":"internal","weight":7,"values":["m","b"],"children":{"m":{"type":"internal","weight":7,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"dumm","weight":7,"content":"dumm"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"dummt","weight":1,"content":"dummt"}]}}},"b":{"type":"internal","weight":2,"values":["a","e","u"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"dumba","weight":2,"content":"dumba"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"dumbe","weight":2,"content":"dumbe"}]},"u":{"type":"internal","weight":1,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"dumbu","weight":1,"content":"dumbu"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"dumbun","weight":1,"content":"dumbun"}]}}}}}}},"k":{"type":"internal","weight":6,"values":["t"],"children":{"t":{"type":"internal","weight":6,"values":["i"],"children":{"i":{"type":"internal","weight":6,"values":["n","g","t"],"children":{"n":{"type":"leaf","weight":6,"entries":[{"key":"duktin","weight":6,"content":"duktin"}]},"g":{"type":"leaf","weight":2,"entries":[{"key":"duktiger","weight":2,"content":"duktiger"},{"key":"duktig","weight":2,"content":"duktig"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"duktit","weight":1,"content":"duktit"}]}}}}}}},"r":{"type":"internal","weight":4,"values":["r"],"children":{"r":{"type":"internal","weight":4,"values":["e","n"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"durreð","weight":4,"content":"durreð"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"durrninggar","weight":1,"content":"durrninggär"}]}}}}},"n":{"type":"internal","weight":3,"values":["a","k","e"],"children":{"k":{"type":"leaf","weight":2,"entries":[{"key":"dunkeð","weight":2,"content":"dunkeð"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"dunað","weight":3,"content":"dunäð"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"duneð","weight":2,"content":"duneð"}]}}},"o":{"type":"leaf","weight":2,"entries":[{"key":"duona","weight":2,"content":"duona"}]}}},"y":{"type":"internal","weight":54,"values":["o","k"],"children":{"o":{"type":"internal","weight":54,"values":["﷐","-","s"],"children":{"﷐":{"type":"leaf","weight":54,"entries":[{"key":"dyo","weight":54,"content":"dyö"}]},"-":{"type":"leaf","weight":11,"entries":[{"key":"dyo-ðar","weight":11,"content":"dyö-ðar"}]},"s":{"type":"leaf","weight":2,"entries":[{"key":"dyosummu","weight":2,"content":"dyösummu"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"dykt","weight":1,"content":"dykt"}]}}},"j":{"type":"internal","weight":34,"values":["a","i"],"children":{"a":{"type":"internal","weight":34,"values":["r","v"],"children":{"r":{"type":"internal","weight":34,"values":["d","a","u",null],"children":{"d":{"type":"leaf","weight":34,"entries":[{"key":"djarde","weight":34,"content":"djärde"},{"key":"djard","weight":4,"content":"djärd"}]},"a":{"type":"leaf","weight":34,"entries":[{"key":"djara","weight":34,"content":"djärå"}]},"undefined":{"type":"leaf","weight":16,"entries":[{"key":"djar","weight":16,"content":"djär"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"djarum","weight":1,"content":"djärum"}]}}},"v":{"type":"internal","weight":6,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"djav","weight":6,"content":"djäv"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"djava","weight":3,"content":"djävå"}]}}}}},"i":{"type":"internal","weight":29,"values":["k","n","e","v"],"children":{"k":{"type":"leaf","weight":29,"entries":[{"key":"djikk","weight":29,"content":"djikk"}]},"n":{"type":"internal","weight":18,"values":["g"],"children":{"g":{"type":"internal","weight":18,"values":["g"],"children":{"g":{"type":"internal","weight":18,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":18,"entries":[{"key":"djingg","weight":18,"content":"djingg"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"djinggum","weight":1,"content":"djinggum"}]}}}}}}},"e":{"type":"internal","weight":5,"values":["n","t"],"children":{"n":{"type":"internal","weight":5,"values":["n"],"children":{"n":{"type":"internal","weight":5,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"djienn","weight":5,"content":"djienn"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"djienna","weight":1,"content":"djienna"}]}}}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"djiet","weight":1,"content":"djiet"}]}}},"v":{"type":"leaf","weight":3,"entries":[{"key":"djivið","weight":3,"content":"djivið"}]}}}}},"r":{"type":"internal","weight":22,"values":["u","o","a","i","y"],"children":{"u":{"type":"internal","weight":22,"values":["o","s","p","k"],"children":{"o":{"type":"leaf","weight":22,"entries":[{"key":"druog","weight":22,"content":"druog"}]},"s":{"type":"internal","weight":5,"values":["t","a","e"],"children":{"t":{"type":"internal","weight":5,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"drust","weight":5,"content":"drust"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"druste","weight":1,"content":"druste"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"drusa","weight":2,"content":"drusa"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"druser","weight":1,"content":"druser"}]}}},"p":{"type":"internal","weight":4,"values":["a","i"],"children":{"a":{"type":"internal","weight":4,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"drupa","weight":4,"content":"drupå"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"drupað","weight":1,"content":"drupäð"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"drupin","weight":1,"content":"drupin"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"drukkner","weight":1,"content":"drukkner"}]}}},"o":{"type":"internal","weight":5,"values":["m","k","p"],"children":{"m":{"type":"internal","weight":5,"values":["d","e","a","t","i","u",null],"children":{"d":{"type":"internal","weight":5,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"dromd","weight":5,"content":"drömd"}]},"e":{"type":"leaf","weight":4,"entries":[{"key":"dromde","weight":4,"content":"drömde"}]}}},"e":{"type":"internal","weight":5,"values":["m","r"],"children":{"m":{"type":"leaf","weight":5,"entries":[{"key":"dromem","weight":5,"content":"drömem"}]},"r":{"type":"leaf","weight":4,"entries":[{"key":"dromer","weight":4,"content":"drömer"}]}}},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"drom","weight":4,"content":"dröm"}]},"a":{"type":"internal","weight":2,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"droma","weight":2,"content":"dröma"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"dromar","weight":1,"content":"drömär"}]}}},"t":{"type":"leaf","weight":2,"entries":[{"key":"dromt","weight":2,"content":"drömt"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"dromin","weight":1,"content":"drömin"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"dromum","weight":1,"content":"drömum"}]}}},"k":{"type":"leaf","weight":4,"entries":[{"key":"drokk","weight":4,"content":"drokk"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"drop","weight":1,"content":"drop"}]}}},"i":{"type":"internal","weight":3,"values":["k","e","t","v"],"children":{"k":{"type":"internal","weight":3,"values":["k"],"children":{"k":{"type":"internal","weight":3,"values":["﷐","a","u"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"drikk","weight":3,"content":"drikk"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"drikka","weight":1,"content":"drikka"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"drikkum","weight":1,"content":"drikkum"}]}}}}},"e":{"type":"internal","weight":2,"values":["t","v"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"driet","weight":2,"content":"driet"}]},"v":{"type":"leaf","weight":1,"entries":[{"key":"driev","weight":1,"content":"driev"}]}}},"t":{"type":"internal","weight":2,"values":["i","u","s","e"],"children":{"i":{"type":"leaf","weight":2,"entries":[{"key":"driti","weight":2,"content":"dritį"}]},"u":{"type":"internal","weight":1,"values":["g","n"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"drituger","weight":1,"content":"drituger"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"dritun","weight":1,"content":"dritun"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"dritstattjem","weight":1,"content":"dritstattjem"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"driteð","weight":1,"content":"driteð"}]}}},"v":{"type":"leaf","weight":1,"entries":[{"key":"drivur","weight":1,"content":"drivur"}]}}},"a":{"type":"internal","weight":4,"values":["i","g","r"],"children":{"i":{"type":"internal","weight":4,"values":["ð","t"],"children":{"ð":{"type":"leaf","weight":4,"entries":[{"key":"draið","weight":4,"content":"draið"}]},"t":{"type":"internal","weight":2,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"drait","weight":2,"content":"drait"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"draita","weight":1,"content":"draita"}]}}}}},"g":{"type":"internal","weight":2,"values":["﷐","a","t"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"drag","weight":2,"content":"drag"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"draga","weight":1,"content":"drågå"}]},"t":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["a","u"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"dragtjaia","weight":1,"content":"dragtjaia"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"dragtjaiur","weight":1,"content":"dragtjaiur"}]}}}}}}}}}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"drar","weight":1,"content":"drar"}]}}},"y":{"type":"leaf","weight":1,"entries":[{"key":"dryttjin","weight":1,"content":"dryttjin"}]}}},"o":{"type":"internal","weight":10,"values":["r","g","'","a","d"],"children":{"r":{"type":"internal","weight":10,"values":["a","u"],"children":{"a":{"type":"internal","weight":10,"values":["r","p"],"children":{"r":{"type":"leaf","weight":10,"entries":[{"key":"dorar","weight":10,"content":"dörär"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"dorapar","weight":1,"content":"döråpar"}]}}},"u":{"type":"leaf","weight":5,"entries":[{"key":"dorum","weight":5,"content":"dörum"}]}}},"g":{"type":"leaf","weight":1,"entries":[{"key":"dogg","weight":1,"content":"dogg"}]},"'":{"type":"leaf","weight":1,"entries":[{"key":"do'nnað","weight":1,"content":"dǫ'nnað"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"doa","weight":1,"content":"döa"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"doddjeð","weight":1,"content":"doddjeð"}]}}},"e":{"type":"internal","weight":3,"values":["n","t"],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"denn","weight":3,"content":"denn"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"dett","weight":2,"content":"dett"}]}}}}},"a":{"type":"internal","weight":608,"values":["n","d","v","u","ð","r","t","l","y","k","m","i","s","p","j"," "],"children":{"n":{"type":"internal","weight":608,"values":["﷐","-","n","d","e","l"],"children":{"﷐":{"type":"leaf","weight":608,"entries":[{"key":"an","weight":608,"content":"an"}]},"-":{"type":"leaf","weight":44,"entries":[{"key":"an-dar","weight":44,"content":"an-dar"}]},"n":{"type":"internal","weight":5,"values":["﷐","l"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"ann","weight":5,"content":"ann"}]},"l":{"type":"internal","weight":2,"values":["i"],"children":{"i":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["u","e"],"children":{"u":{"type":"leaf","weight":2,"entries":[{"key":"annlitum","weight":2,"content":"annlitum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"annliteð","weight":1,"content":"annliteð"}]}}}}}}}}},"d":{"type":"internal","weight":4,"values":["y","e",null],"children":{"y":{"type":"internal","weight":4,"values":["r"],"children":{"r":{"type":"internal","weight":4,"values":["u","﷐","a"],"children":{"u":{"type":"internal","weight":4,"values":["n","﷐","r"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"andyrun","weight":4,"content":"andyrun"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"andyru","weight":1,"content":"andyru"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"andyrur","weight":1,"content":"andyrur"}]}}},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"andyr","weight":3,"content":"andyr"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"andyra","weight":2,"content":"andyra"}]}}}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"and","weight":2,"content":"and"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"andes","weight":2,"content":"andes"}]}}},"e":{"type":"internal","weight":1,"values":["﷐","ð","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"ane","weight":1,"content":"åne"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"aneð","weight":1,"content":"aneð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"aner","weight":1,"content":"aner"}]}}},"l":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"anlit","weight":1,"content":"anlit"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"anlitum","weight":1,"content":"anlitum"}]}}}}}}}}},"d":{"type":"internal","weight":461,"values":["d"],"children":{"d":{"type":"internal","weight":461,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":461,"entries":[{"key":"add","weight":461,"content":"add"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"adde","weight":2,"content":"adde"}]}}}}},"v":{"type":"internal","weight":214,"values":["﷐","a","e","t","i","u","s","w",null],"children":{"﷐":{"type":"leaf","weight":214,"entries":[{"key":"av","weight":214,"content":"åv"}]},"a":{"type":"internal","weight":76,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":76,"entries":[{"key":"ava","weight":76,"content":"åvå"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"avan","weight":2,"content":"åvan"}]}}},"undefined":{"type":"leaf","weight":10,"entries":[{"key":"av","weight":10,"content":"av"},{"key":"av","weight":1,"content":"äv"}]},"e":{"type":"internal","weight":7,"values":["s","n"],"children":{"s":{"type":"leaf","weight":7,"entries":[{"key":"avesbjarr","weight":7,"content":"Ävesbjärr"}]},"n":{"type":"internal","weight":4,"values":["t"],"children":{"t":{"type":"internal","weight":4,"values":["y"],"children":{"y":{"type":"internal","weight":4,"values":["r"],"children":{"r":{"type":"internal","weight":4,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"aventyr","weight":4,"content":"äventyr"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"aventyreð","weight":1,"content":"äventyreð"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"aventyrum","weight":1,"content":"äventyrum"}]}}}}}}}}}}},"t":{"type":"leaf","weight":4,"entries":[{"key":"avtaim","weight":4,"content":"åvtaim"}]},"i":{"type":"leaf","weight":3,"entries":[{"key":"avið","weight":3,"content":"avið"}]},"u":{"type":"internal","weight":2,"values":["t","g","n"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"avut","weight":2,"content":"avut"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"avuger","weight":1,"content":"avuger"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"avun","weight":1,"content":"avun"}]}}},"s":{"type":"leaf","weight":2,"entries":[{"key":"avsukkur","weight":2,"content":"åvsukkur"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"avwegs","weight":1,"content":"åvwegs"}]}}},"u":{"type":"internal","weight":126,"values":["t","a","r","s",null],"children":{"t":{"type":"internal","weight":126,"values":["﷐","i","y","a","f","e","s"],"children":{"﷐":{"type":"leaf","weight":126,"entries":[{"key":"aut","weight":126,"content":"aut"}]},"i":{"type":"leaf","weight":47,"entries":[{"key":"auti","weight":47,"content":"auti"}]},"y":{"type":"internal","weight":24,"values":["r","v"],"children":{"r":{"type":"leaf","weight":24,"entries":[{"key":"autyr","weight":24,"content":"autyr"}]},"v":{"type":"leaf","weight":3,"entries":[{"key":"autyvyr","weight":3,"content":"autyvyr"}]}}},"a":{"type":"leaf","weight":18,"entries":[{"key":"auta","weight":18,"content":"autå"},{"key":"auta","weight":9,"content":"autą̊"}]},"f":{"type":"internal","weight":17,"values":["o","e"],"children":{"o":{"type":"leaf","weight":17,"entries":[{"key":"autfor","weight":17,"content":"autför"}]},"e":{"type":"internal","weight":7,"values":["r"],"children":{"r":{"type":"internal","weight":7,"values":["i","n"],"children":{"i":{"type":"leaf","weight":7,"entries":[{"key":"autferin","weight":7,"content":"autferin"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"autferner","weight":1,"content":"autferner"}]}}}}}}},"e":{"type":"leaf","weight":15,"entries":[{"key":"aute","weight":15,"content":"aute"}]},"s":{"type":"internal","weight":6,"values":["e","a"],"children":{"e":{"type":"internal","weight":6,"values":["t"],"children":{"t":{"type":"internal","weight":6,"values":["t"],"children":{"t":{"type":"leaf","weight":6,"entries":[{"key":"autsetter","weight":6,"content":"autsetter"},{"key":"autsett","weight":1,"content":"autsett"}]}}}}},"a":{"type":"leaf","weight":4,"entries":[{"key":"autsaiðun","weight":4,"content":"autsaiðun"}]}}}}},"undefined":{"type":"leaf","weight":19,"entries":[{"key":"au","weight":19,"content":"au"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"auauau","weight":4,"content":"auauau"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"aurweðreð","weight":1,"content":"aurweðreð"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"auseð","weight":1,"content":"auseð"}]}}},"ð":{"type":"internal","weight":119,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":119,"entries":[{"key":"að","weight":119,"content":"að"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"aðn","weight":1,"content":"äðn"}]}}},"r":{"type":"internal","weight":80,"values":["﷐","d","a","u","e","t","m","g"," ","b","p","r",null],"children":{"﷐":{"type":"leaf","weight":80,"entries":[{"key":"ar","weight":80,"content":"ar"}]},"d":{"type":"internal","weight":40,"values":["﷐","e","a","i","n","u"],"children":{"﷐":{"type":"leaf","weight":40,"entries":[{"key":"ard","weight":40,"content":"ärd"}]},"e":{"type":"leaf","weight":15,"entries":[{"key":"ardes","weight":15,"content":"ärdes"},{"key":"arde","weight":1,"content":"ärde"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"ardas","weight":2,"content":"ärdas"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"ardið","weight":1,"content":"ärdið"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"ardningg","weight":1,"content":"årdningg"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"ardum","weight":1,"content":"ärdum"}]}}},"undefined":{"type":"leaf","weight":14,"entries":[{"key":"ar","weight":14,"content":"år"}]},"a":{"type":"internal","weight":14,"values":["﷐","s"],"children":{"﷐":{"type":"leaf","weight":14,"entries":[{"key":"ara","weight":14,"content":"ära"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"aras","weight":1,"content":"äras"}]}}},"u":{"type":"internal","weight":9,"values":["﷐","m","n","r","g"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"aru","weight":9,"content":"äru"}]},"m":{"type":"leaf","weight":5,"entries":[{"key":"arum","weight":5,"content":"ärum"},{"key":"arum","weight":1,"content":"årum"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"arun","weight":1,"content":"årun"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"arur","weight":1,"content":"ärur"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"aruger","weight":1,"content":"åruger"},{"key":"arug","weight":1,"content":"årug"}]}}},"e":{"type":"internal","weight":7,"values":["﷐","r","ð"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"are","weight":7,"content":"årę"}]},"r":{"type":"leaf","weight":3,"entries":[{"key":"arer","weight":3,"content":"ärer"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"areð","weight":2,"content":"åreð"}]}}},"t":{"type":"leaf","weight":7,"entries":[{"key":"art","weight":7,"content":"ärt"}]},"m":{"type":"internal","weight":2,"values":["u","i","a","e",null],"children":{"u":{"type":"leaf","weight":2,"entries":[{"key":"armum","weight":2,"content":"armum"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"armin","weight":2,"content":"armin"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"arm","weight":1,"content":"arm"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"armar","weight":1,"content":"armär"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"armem","weight":1,"content":"armem"}]}}},"g":{"type":"leaf","weight":2,"entries":[{"key":"argrav","weight":2,"content":"Ärgrav"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"ar snorkellindje","weight":1,"content":"ar snorkellindje"}]},"b":{"type":"internal","weight":1,"values":["i","o"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"arbiet","weight":1,"content":"arbiet"}]},"o":{"type":"leaf","weight":1,"entries":[{"key":"arbollar","weight":1,"content":"årbollär"}]}}},"p":{"type":"internal","weight":1,"values":["e","r","a"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"arpeð","weight":1,"content":"arpeð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"arproppa","weight":1,"content":"ärproppa"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"arpa","weight":1,"content":"arpa"}]}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"arre","weight":1,"content":"ärre"}]}}},"t":{"type":"internal","weight":76,"values":["t","u","a","j",null],"children":{"t":{"type":"internal","weight":76,"values":["﷐","e","o","r","a"],"children":{"﷐":{"type":"leaf","weight":76,"entries":[{"key":"att","weight":76,"content":"att"}]},"e":{"type":"internal","weight":41,"values":["n","﷐","r","p"],"children":{"n":{"type":"leaf","weight":41,"entries":[{"key":"atten","weight":41,"content":"atten"}]},"﷐":{"type":"leaf","weight":17,"entries":[{"key":"atte","weight":17,"content":"atte"}]},"r":{"type":"leaf","weight":6,"entries":[{"key":"atter","weight":6,"content":"atter"}]},"p":{"type":"internal","weight":1,"values":["p"],"children":{"p":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"atteppt","weight":1,"content":"atteppt"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"attepptu","weight":1,"content":"attepptu"}]}}}}}}}}},"o":{"type":"internal","weight":14,"values":["n"],"children":{"n":{"type":"internal","weight":14,"values":["a","i"],"children":{"a":{"type":"leaf","weight":14,"entries":[{"key":"attonað","weight":14,"content":"attonað"}]},"i":{"type":"leaf","weight":5,"entries":[{"key":"attoni","weight":5,"content":"attoni"}]}}}}},"r":{"type":"internal","weight":7,"values":["y","u","a"],"children":{"y":{"type":"leaf","weight":7,"entries":[{"key":"attryvyr","weight":7,"content":"attryvyr"}]},"u":{"type":"internal","weight":5,"values":["m"],"children":{"m":{"type":"internal","weight":5,"values":["﷐","a","s"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"attrum","weight":5,"content":"attrum"}]},"a":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["ð"],"children":{"ð":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"attrumaisað","weight":1,"content":"attrumaisað"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"attrumaisaðer","weight":1,"content":"attrumaisaðer"}]}}}}}}}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"attrumsni'dder","weight":1,"content":"attrumsni'dder"}]}}}}},"a":{"type":"leaf","weight":5,"entries":[{"key":"attrað","weight":5,"content":"attrað"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"atta","weight":1,"content":"attą̊"}]}}},"undefined":{"type":"leaf","weight":10,"entries":[{"key":"at","weight":10,"content":"åt"}]},"u":{"type":"leaf","weight":6,"entries":[{"key":"atut","weight":6,"content":"åtut"},{"key":"atu","weight":4,"content":"åtu"}]},"a":{"type":"leaf","weight":6,"entries":[{"key":"ata","weight":6,"content":"åta"}]},"j":{"type":"leaf","weight":4,"entries":[{"key":"atjeð","weight":4,"content":"ätjeð"}]}}},"l":{"type":"internal","weight":55,"values":["﷐","k"],"children":{"﷐":{"type":"leaf","weight":55,"entries":[{"key":"al","weight":55,"content":"al"}]},"k":{"type":"leaf","weight":2,"entries":[{"key":"alkeð","weight":2,"content":"alkeð"}]}}},"y":{"type":"internal","weight":55,"values":["v","t","k"],"children":{"v":{"type":"internal","weight":55,"values":["e","u"],"children":{"e":{"type":"leaf","weight":55,"entries":[{"key":"ayve","weight":55,"content":"åyve"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"ayvum","weight":3,"content":"åyvum"}]}}},"t":{"type":"leaf","weight":5,"entries":[{"key":"aytjbjarr","weight":5,"content":"Åytjbjärr"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"ayk","weight":1,"content":"Åyk"}]}}},"m":{"type":"internal","weight":12,"values":["m","b"],"children":{"m":{"type":"internal","weight":12,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"amm","weight":12,"content":"amm"}]},"e":{"type":"leaf","weight":6,"entries":[{"key":"amme","weight":6,"content":"amme"}]}}},"b":{"type":"internal","weight":1,"values":["r","e"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"ambrer","weight":1,"content":"ambrer"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"amberrais","weight":1,"content":"Amberrais"}]}}}}},"i":{"type":"internal","weight":11,"values":["n","s"],"children":{"n":{"type":"internal","weight":11,"values":["g","d"],"children":{"g":{"type":"internal","weight":11,"values":["g"],"children":{"g":{"type":"internal","weight":11,"values":["d","t","e"],"children":{"d":{"type":"leaf","weight":11,"entries":[{"key":"ainggd","weight":11,"content":"ainggd"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"ainggt","weight":3,"content":"ainggt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"ainggel","weight":1,"content":"ainggel"}]}}}}},"d":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["n","r"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"aindjend","weight":1,"content":"aindjend"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"aindjer","weight":1,"content":"aindjer"}]}}}}}}}}},"s":{"type":"internal","weight":3,"values":["n","e","k","u","a","b",null],"children":{"e":{"type":"internal","weight":2,"values":["m","r"],"children":{"m":{"type":"leaf","weight":2,"entries":[{"key":"aisem","weight":2,"content":"aisem"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"aiser","weight":1,"content":"aiser"}]}}},"n":{"type":"leaf","weight":3,"entries":[{"key":"aisn","weight":3,"content":"aisn"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"ais","weight":1,"content":"ais"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"aiskolder","weight":1,"content":"aiskolder"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"aisum","weight":1,"content":"aisum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"aisa","weight":1,"content":"aisa"}]},"b":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"aisbit","weight":1,"content":"aisbit"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"aisbiter","weight":1,"content":"aisbiter"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"aisbitum","weight":1,"content":"aisbitum"}]}}}}}}}}}}},"k":{"type":"internal","weight":18,"values":["k","u","a"],"children":{"k":{"type":"internal","weight":18,"values":["a","e"],"children":{"a":{"type":"leaf","weight":18,"entries":[{"key":"akka","weight":18,"content":"akka"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"akkeð","weight":3,"content":"akkeð"}]}}},"u":{"type":"internal","weight":2,"values":["d","﷐","ð","n","t"],"children":{"d":{"type":"leaf","weight":2,"entries":[{"key":"akudireð","weight":2,"content":"akudireð"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"aku","weight":2,"content":"aku"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"akuðira","weight":1,"content":"akuðira"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"akun","weight":1,"content":"akun"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"akutienn","weight":1,"content":"akutienn"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"aka","weight":2,"content":"åka"}]}}},"s":{"type":"internal","weight":6,"values":["e","n","t"],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"asem","weight":6,"content":"åsem"}]},"n":{"type":"leaf","weight":4,"entries":[{"key":"asn","weight":4,"content":"åsn"}]},"t":{"type":"internal","weight":4,"values":["a"],"children":{"a":{"type":"internal","weight":4,"values":["b"],"children":{"b":{"type":"internal","weight":4,"values":["l"],"children":{"l":{"type":"internal","weight":4,"values":["e"],"children":{"e":{"type":"internal","weight":4,"values":["t"],"children":{"t":{"type":"internal","weight":4,"values":["t"],"children":{"t":{"type":"leaf","weight":4,"entries":[{"key":"astabletta","weight":4,"content":"åstabletta"},{"key":"astablett","weight":2,"content":"åstablett"}]}}}}}}}}}}}}}}},"p":{"type":"internal","weight":5,"values":["t","r","e",null],"children":{"t":{"type":"leaf","weight":5,"entries":[{"key":"apt","weight":5,"content":"apt"}]},"r":{"type":"internal","weight":4,"values":["i"],"children":{"i":{"type":"internal","weight":4,"values":["l"],"children":{"l":{"type":"internal","weight":4,"values":["l"],"children":{"l":{"type":"leaf","weight":4,"entries":[{"key":"aprilla","weight":4,"content":"aprilla"},{"key":"aprill","weight":4,"content":"aprill"}]}}}}}}},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"ap","weight":3,"content":"åp"}]},"e":{"type":"internal","weight":4,"values":["ð"],"children":{"ð":{"type":"leaf","weight":4,"entries":[{"key":"apeð","weight":4,"content":"äpeð"},{"key":"apeð","weight":1,"content":"åpeð"}]}}}}},"j":{"type":"leaf","weight":3,"entries":[{"key":"aja","weight":3,"content":"äja"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"a by","weight":1,"content":"ą̊ by"}]}}},"w":{"type":"internal","weight":531,"values":["a","e","i","y"],"children":{"a":{"type":"internal","weight":531,"values":["r","t","i","k","n","l","s","g","p","v"],"children":{"r":{"type":"internal","weight":531,"values":["﷐","t","a","i","m","d","g","u","b","s","e"," ",null],"children":{"﷐":{"type":"leaf","weight":531,"entries":[{"key":"war","weight":531,"content":"war"}]},"t":{"type":"leaf","weight":153,"entries":[{"key":"wart","weight":153,"content":"wart"}]},"a":{"type":"leaf","weight":24,"entries":[{"key":"wara","weight":24,"content":"wårå"}]},"undefined":{"type":"leaf","weight":15,"entries":[{"key":"war","weight":15,"content":"wär"},{"key":"war","weight":5,"content":"wår"}]},"i":{"type":"leaf","weight":12,"entries":[{"key":"wari","weight":12,"content":"wari"}]},"m":{"type":"internal","weight":9,"values":["t","﷐","a","k"],"children":{"t":{"type":"leaf","weight":9,"entries":[{"key":"warmt","weight":9,"content":"warmt"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"warm","weight":2,"content":"warm"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"warman","weight":2,"content":"warman"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"warmkakao","weight":1,"content":"warmkakao"}]}}},"d":{"type":"internal","weight":4,"values":["n","e"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"wardn","weight":4,"content":"wärdn"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"warde","weight":1,"content":"wärde"}]}}},"g":{"type":"internal","weight":2,"values":["a","m",null],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"wargar","weight":2,"content":"wargär"}]},"m":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["y"],"children":{"y":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"wargmayrn","weight":1,"content":"Wargmåyrn"},{"key":"wargmayr","weight":1,"content":"Wargmåyr"}]}}}}}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"warg","weight":1,"content":"warg"}]}}},"u":{"type":"internal","weight":2,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"waru","weight":2,"content":"waru"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"warut","weight":1,"content":"warut"}]}}},"b":{"type":"leaf","weight":2,"entries":[{"key":"warbistyr","weight":2,"content":"wårbistyr"}]},"s":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"warsain","weight":1,"content":"wårsain"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"warsenn","weight":1,"content":"wårsenn"}]}}},"e":{"type":"internal","weight":1,"values":["﷐","s"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"ware","weight":1,"content":"wåre"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"wares","weight":1,"content":"wåres"}]}}}," ":{"type":"leaf","weight":1,"entries":[{"key":"war sett","weight":1,"content":"wår sett"}]}}},"t":{"type":"internal","weight":11,"values":["t","j","a","u","e","k",null],"children":{"t":{"type":"internal","weight":11,"values":["n","u"],"children":{"n":{"type":"internal","weight":11,"values":["e",null],"children":{"e":{"type":"internal","weight":11,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":11,"entries":[{"key":"wattne","weight":11,"content":"wattnę"}]},"ð":{"type":"leaf","weight":6,"entries":[{"key":"wattneð","weight":6,"content":"wattneð"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"wattn","weight":2,"content":"wattn"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"wattustakk","weight":1,"content":"wattustakk"}]}}},"j":{"type":"leaf","weight":6,"entries":[{"key":"watjin","weight":6,"content":"watjin"}]},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"wat","weight":4,"content":"wåt"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"watara","weight":3,"content":"wätära"},{"key":"wata","weight":2,"content":"wåta"}]},"u":{"type":"internal","weight":2,"values":["s","k","n","w"],"children":{"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["t","k"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"watustattjin","weight":2,"content":"watustattjin"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"watustakktjin","weight":1,"content":"watustakktjin"}]}}}}}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"watukruk","weight":1,"content":"watukruk"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"watun","weight":1,"content":"watun"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"watuwaigdn","weight":1,"content":"watuwaigdn"}]}}},"e":{"type":"internal","weight":1,"values":["r","s"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"watera","weight":1,"content":"wätera"},{"key":"water","weight":1,"content":"wåter"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"watest","weight":1,"content":"wätest"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"watklauta","weight":1,"content":"wåtklauta"}]}}},"i":{"type":"internal","weight":11,"values":["s","t","l","n","ð","g"],"children":{"s":{"type":"internal","weight":11,"values":["﷐","t","a","e","u"],"children":{"﷐":{"type":"leaf","weight":11,"entries":[{"key":"wais","weight":11,"content":"wais"}]},"t":{"type":"leaf","weight":11,"entries":[{"key":"waist","weight":11,"content":"waist"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"waisa","weight":1,"content":"waisa"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"waiser","weight":1,"content":"waiser"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"waisur","weight":1,"content":"waisur"}]}}},"t":{"type":"internal","weight":6,"values":["t","o","e","f","k","a","p","u",null],"children":{"t":{"type":"internal","weight":6,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"waitt","weight":6,"content":"waitt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"waittennar","weight":1,"content":"waittennär"}]}}},"o":{"type":"leaf","weight":5,"entries":[{"key":"waitogum","weight":5,"content":"waitogum"}]},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"wait","weight":4,"content":"wait"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"waiter","weight":1,"content":"waiter"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"waitfjaðrar","weight":1,"content":"waitfjäðrär"}]},"k":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["d","u"],"children":{"d":{"type":"leaf","weight":1,"entries":[{"key":"waitkladd","weight":1,"content":"waitklädd"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"waitklauta","weight":1,"content":"waitklauta"}]}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"waitan","weight":1,"content":"waitan"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"waitprikkar","weight":1,"content":"waitprikkär"}]},"u":{"type":"internal","weight":1,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"waitu","weight":1,"content":"waitu"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"waitum","weight":1,"content":"waitum"}]}}}}},"l":{"type":"internal","weight":6,"values":["﷐","a","e","t","d"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"wail","weight":6,"content":"wail"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"waila","weight":2,"content":"waila"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"wailer","weight":2,"content":"wailer"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"wailt","weight":2,"content":"wailt"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"waild","weight":1,"content":"waild"}]}}},"n":{"type":"internal","weight":4,"values":["g"],"children":{"g":{"type":"internal","weight":4,"values":["g"],"children":{"g":{"type":"internal","weight":4,"values":["a","u"],"children":{"a":{"type":"internal","weight":4,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"waingga","weight":4,"content":"waingga"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"wainggar","weight":1,"content":"wainggär"}]}}},"u":{"type":"leaf","weight":2,"entries":[{"key":"wainggum","weight":2,"content":"wainggum"}]}}}}}}},"ð":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["m"],"children":{"m":{"type":"internal","weight":2,"values":["﷐","t","u","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"waiðum","weight":2,"content":"waiðum"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"waiðumum","weight":1,"content":"waiðumum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"waiðumera","weight":1,"content":"waiðumera"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"waiðumt","weight":2,"content":"waiðumt"}]}}}}}}},"g":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"waig","weight":1,"content":"waig"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"waiger","weight":1,"content":"waiger"}]}}}}},"k":{"type":"internal","weight":9,"values":["k","a","e"],"children":{"k":{"type":"internal","weight":9,"values":["k","n","e","i"],"children":{"k":{"type":"leaf","weight":9,"entries":[{"key":"wakkkneð","weight":9,"content":"wakkkneð"}]},"n":{"type":"internal","weight":7,"values":["a","e","i","u"],"children":{"a":{"type":"leaf","weight":7,"entries":[{"key":"wakknað","weight":7,"content":"wakknað"}]},"e":{"type":"internal","weight":5,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":5,"entries":[{"key":"wakkneð","weight":5,"content":"wakkneð"}]},"r":{"type":"leaf","weight":3,"entries":[{"key":"wakkner","weight":3,"content":"wakkner"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"wakknið","weight":1,"content":"wakknið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"wakknum","weight":1,"content":"wakknum"}]}}},"e":{"type":"leaf","weight":2,"entries":[{"key":"wakken","weight":2,"content":"wakken"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"wakkin","weight":2,"content":"wakkin"}]}}},"a":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"waka","weight":1,"content":"wåkå"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"wakað","weight":1,"content":"wåkåð"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"waker","weight":1,"content":"wäker"}]}}},"n":{"type":"internal","weight":8,"values":["l","n"],"children":{"l":{"type":"internal","weight":8,"values":["i"],"children":{"i":{"type":"internal","weight":8,"values":["t","n","g"],"children":{"t":{"type":"leaf","weight":8,"entries":[{"key":"wanlit","weight":8,"content":"wanlit"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"wanlin","weight":2,"content":"wanlin"}]},"g":{"type":"internal","weight":2,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"wanlig","weight":2,"content":"wanlig"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"wanligu","weight":1,"content":"wanligu"}]}}}}}}},"n":{"type":"leaf","weight":6,"entries":[{"key":"wann","weight":6,"content":"wann"}]}}},"l":{"type":"leaf","weight":6,"entries":[{"key":"walt","weight":6,"content":"walt"}]},"s":{"type":"internal","weight":5,"values":["a","s","k","n"],"children":{"a":{"type":"internal","weight":5,"values":["l"],"children":{"l":{"type":"internal","weight":5,"values":["o"],"children":{"o":{"type":"internal","weight":5,"values":["p"],"children":{"p":{"type":"internal","weight":5,"values":["p"],"children":{"p":{"type":"internal","weight":5,"values":["e","s"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"wasaloppeð","weight":5,"content":"Wasaloppeð"}]},"s":{"type":"leaf","weight":2,"entries":[{"key":"wasaloppsandyrun","weight":2,"content":"wasaloppsandyrun"}]}}}}}}}}}}},"s":{"type":"internal","weight":2,"values":["t","a"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"wasst","weight":2,"content":"wasst"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"wassað","weight":1,"content":"wassað"}]}}},"k":{"type":"internal","weight":1,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"wask","weight":1,"content":"wask"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wasker","weight":1,"content":"wasker"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"waskuger","weight":1,"content":"waskuger"}]}}},"n":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"wasnas","weight":1,"content":"wäsnas"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wasnes","weight":1,"content":"wäsnes"}]}}}}},"g":{"type":"leaf","weight":2,"entries":[{"key":"wagur","weight":2,"content":"wågur"},{"key":"wag","weight":1,"content":"wåg"}]},"p":{"type":"internal","weight":2,"values":["p"],"children":{"p":{"type":"internal","weight":2,"values":["l","e"],"children":{"l":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"wappleð","weight":2,"content":"wappleð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"wappler","weight":1,"content":"wappler"}]}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"wappel","weight":1,"content":"wappel"}]}}}}},"v":{"type":"internal","weight":2,"values":["e","l"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"wavel","weight":2,"content":"wavel"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"wavleð","weight":2,"content":"wavleð"}]}}}}},"e":{"type":"internal","weight":62,"values":["n","r","g","t","e","l","ð","k","s","d","p"],"children":{"n":{"type":"internal","weight":62,"values":["n","﷐","d","e","a","t"],"children":{"n":{"type":"leaf","weight":62,"entries":[{"key":"wenn","weight":62,"content":"wenn"}]},"﷐":{"type":"leaf","weight":31,"entries":[{"key":"wen","weight":31,"content":"wen"}]},"d":{"type":"internal","weight":22,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":22,"entries":[{"key":"wend","weight":22,"content":"wend"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wende","weight":1,"content":"wende"}]},"u":{"type":"internal","weight":1,"values":["m","r"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"wendum","weight":1,"content":"wendum"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"wendur","weight":1,"content":"wendur"}]}}}}},"e":{"type":"internal","weight":5,"values":["s","v"],"children":{"s":{"type":"leaf","weight":5,"entries":[{"key":"wenest","weight":5,"content":"wenest"}]},"v":{"type":"leaf","weight":1,"entries":[{"key":"weneviga","weight":1,"content":"weneviga"}]}}},"a":{"type":"leaf","weight":5,"entries":[{"key":"wenanan","weight":5,"content":"wenanan"}]},"t":{"type":"internal","weight":1,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"went","weight":1,"content":"went"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"wenta","weight":1,"content":"wenta"}]},"e":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"wenteð","weight":1,"content":"wenteð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"wenter","weight":1,"content":"wenter"}]}}}}}}},"r":{"type":"internal","weight":58,"values":["d","o","i","t","k","r","m","e","a"],"children":{"d":{"type":"internal","weight":58,"values":["﷐","a","e","i","u"," "],"children":{"﷐":{"type":"leaf","weight":58,"entries":[{"key":"werd","weight":58,"content":"werd"}]},"a":{"type":"internal","weight":4,"values":["﷐","s"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"werda","weight":4,"content":"werda"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"werdas","weight":1,"content":"werdas"}]}}},"e":{"type":"leaf","weight":2,"entries":[{"key":"werdes","weight":2,"content":"werdes"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"werdið","weight":1,"content":"werdið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"werdum","weight":1,"content":"werdum"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"werd iwari","weight":1,"content":"werd iwari"}]}}},"o":{"type":"internal","weight":21,"values":["ð"],"children":{"ð":{"type":"internal","weight":21,"values":["r","e"],"children":{"r":{"type":"internal","weight":21,"values":["u","e"],"children":{"u":{"type":"leaf","weight":21,"entries":[{"key":"weroðrum","weight":21,"content":"weroðrum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"weroðrer","weight":1,"content":"weroðrer"}]}}},"e":{"type":"leaf","weight":5,"entries":[{"key":"weroðer","weight":5,"content":"weroðer"}]}}}}},"t":{"type":"leaf","weight":10,"entries":[{"key":"wert","weight":10,"content":"wert"}]},"i":{"type":"leaf","weight":13,"entries":[{"key":"werið","weight":13,"content":"werið"}]},"k":{"type":"internal","weight":6,"values":["l"],"children":{"l":{"type":"internal","weight":6,"values":["i"],"children":{"i":{"type":"internal","weight":6,"values":["g"],"children":{"g":{"type":"internal","weight":6,"values":["e","i"],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"werkligen","weight":6,"content":"werkligen"}]},"i":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["n","e"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"werkligietn","weight":1,"content":"werkligietn"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"werkligiete","weight":1,"content":"werkligiete"}]}}}}}}}}}}}}}}},"m":{"type":"internal","weight":4,"values":["﷐","d","a","i"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"werm","weight":4,"content":"werm"}]},"d":{"type":"leaf","weight":3,"entries":[{"key":"wermd","weight":3,"content":"wermd"}]},"a":{"type":"internal","weight":3,"values":["m","n"],"children":{"m":{"type":"leaf","weight":3,"entries":[{"key":"wermam","weight":3,"content":"wermam"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"werman","weight":1,"content":"werman"}]}}},"i":{"type":"leaf","weight":2,"entries":[{"key":"wermin","weight":2,"content":"wermin"}]}}},"r":{"type":"internal","weight":5,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"werr","weight":5,"content":"werr"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"werra","weight":1,"content":"werra"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"weres","weight":1,"content":"weres"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"weras","weight":1,"content":"weras"}]}}},"g":{"type":"internal","weight":36,"values":["﷐","g","a","u"],"children":{"﷐":{"type":"leaf","weight":36,"entries":[{"key":"weg","weight":36,"content":"weg"}]},"g":{"type":"internal","weight":2,"values":["﷐","u","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"wegg","weight":2,"content":"wegg"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"weggum","weight":2,"content":"weggum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wegger","weight":1,"content":"wegger"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"wegastjili","weight":2,"content":"wegåstjilį"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"wegum","weight":1,"content":"wegum"}]}}},"t":{"type":"internal","weight":27,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":27,"entries":[{"key":"wet","weight":27,"content":"wet"}]},"t":{"type":"internal","weight":6,"values":["j"],"children":{"j":{"type":"internal","weight":6,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"wettj","weight":6,"content":"wettj"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wettjer","weight":1,"content":"wettjer"}]}}}}}}},"e":{"type":"leaf","weight":23,"entries":[{"key":"weem","weight":23,"content":"weem"}]},"ð":{"type":"internal","weight":17,"values":["r","e",null],"children":{"r":{"type":"internal","weight":17,"values":["e"],"children":{"e":{"type":"leaf","weight":17,"entries":[{"key":"weðreð","weight":17,"content":"weðreð"},{"key":"weðre","weight":6,"content":"weðrę"},{"key":"weðre","weight":2,"content":"weðre"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"weð","weight":2,"content":"weð"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"weðerkuonn","weight":2,"content":"weðerkuonn"}]}}},"l":{"type":"internal","weight":18,"values":["e","﷐","l","t","k","i"],"children":{"e":{"type":"leaf","weight":18,"entries":[{"key":"welest","weight":18,"content":"welest"}]},"﷐":{"type":"leaf","weight":10,"entries":[{"key":"wel","weight":10,"content":"wel"}]},"l":{"type":"internal","weight":7,"values":["t","e"],"children":{"t":{"type":"leaf","weight":7,"entries":[{"key":"wellt","weight":7,"content":"wellt"}]},"e":{"type":"internal","weight":1,"values":["r","s"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"wellera","weight":1,"content":"wellera"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"wellest","weight":1,"content":"wellest"}]}}}}},"t":{"type":"leaf","weight":3,"entries":[{"key":"welta","weight":3,"content":"welta"}]},"k":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["m"],"children":{"m":{"type":"internal","weight":1,"values":["i","n"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"welkumin","weight":1,"content":"welkumin"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"welkumner","weight":1,"content":"welkumner"}]}}}}}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"welindjin","weight":1,"content":"welindjin"}]}}},"k":{"type":"internal","weight":6,"values":["s","k"],"children":{"s":{"type":"internal","weight":6,"values":["t","﷐","a","e"],"children":{"t":{"type":"internal","weight":6,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"wekst","weight":6,"content":"wekst"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wekste","weight":1,"content":"wekste"}]}}},"﷐":{"type":"leaf","weight":5,"entries":[{"key":"weks","weight":5,"content":"weks"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"weksa","weight":1,"content":"weksa"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wekseð","weight":1,"content":"wekseð"}]}}},"k":{"type":"leaf","weight":5,"entries":[{"key":"wekkt","weight":5,"content":"wekkt"}]}}},"s":{"type":"internal","weight":6,"values":["s","t"],"children":{"s":{"type":"internal","weight":6,"values":["n","l"],"children":{"n":{"type":"leaf","weight":6,"entries":[{"key":"wessn","weight":6,"content":"wessn"}]},"l":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"wessl","weight":1,"content":"wessl"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wessleð","weight":1,"content":"wessleð"}]}}}}},"t":{"type":"internal","weight":6,"values":["r","a","e"],"children":{"r":{"type":"leaf","weight":6,"entries":[{"key":"westryvyr","weight":6,"content":"westryvyr"}]},"a":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"westa","weight":1,"content":"westą̊"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"westað","weight":1,"content":"westað"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"wester","weight":1,"content":"wester"}]}}}}},"d":{"type":"internal","weight":4,"values":["d"],"children":{"d":{"type":"internal","weight":4,"values":["j"],"children":{"j":{"type":"internal","weight":4,"values":["i","e"],"children":{"i":{"type":"leaf","weight":4,"entries":[{"key":"weddjin","weight":4,"content":"weddjin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"weddje","weight":1,"content":"weddje"}]}}}}}}},"p":{"type":"leaf","weight":1,"entries":[{"key":"wepa","weight":1,"content":"wepa"}]}}},"i":{"type":"internal","weight":33,"values":["s","l","ð","t","k","e","n","i"],"children":{"s":{"type":"internal","weight":33,"values":["s","o","e","t",null],"children":{"s":{"type":"internal","weight":33,"values":["﷐","t","e"],"children":{"﷐":{"type":"leaf","weight":33,"entries":[{"key":"wiss","weight":33,"content":"wiss"}]},"t":{"type":"leaf","weight":4,"entries":[{"key":"wisst","weight":4,"content":"wisst"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wisse","weight":1,"content":"wisse"}]}}},"o":{"type":"leaf","weight":17,"entries":[{"key":"wiso","weight":17,"content":"wiso"}]},"undefined":{"type":"leaf","weight":11,"entries":[{"key":"wis","weight":11,"content":"wis"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"wiseð","weight":2,"content":"wiseð"}]},"t":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["f","﷐","s"],"children":{"f":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["m"],"children":{"m":{"type":"internal","weight":2,"values":["f"],"children":{"f":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["o"],"children":{"o":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["n","e"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"wisterframfuotn","weight":2,"content":"wisterframfuotn"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wisterframfuotem","weight":1,"content":"wisterframfuotem"}]}}}}}}}}}}}}}}}}},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"wister","weight":1,"content":"wister"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"wistersaiðun","weight":1,"content":"wistersaiðun"}]}}}}}}}}},"l":{"type":"internal","weight":29,"values":["l","d","a","u",null],"children":{"l":{"type":"internal","weight":29,"values":["d","﷐"],"children":{"d":{"type":"internal","weight":29,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":29,"entries":[{"key":"willd","weight":29,"content":"willd"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"willde","weight":3,"content":"willde"}]}}},"﷐":{"type":"leaf","weight":25,"entries":[{"key":"will","weight":25,"content":"will"}]}}},"d":{"type":"internal","weight":11,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":11,"entries":[{"key":"wild","weight":11,"content":"wild"}]},"e":{"type":"internal","weight":9,"values":["r","s"],"children":{"r":{"type":"leaf","weight":9,"entries":[{"key":"wildera","weight":9,"content":"wildera"}]},"s":{"type":"leaf","weight":3,"entries":[{"key":"wildest","weight":3,"content":"wildest"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"wildum","weight":1,"content":"wildum"}]}}},"a":{"type":"internal","weight":10,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"wila","weight":10,"content":"wila"}]},"ð":{"type":"leaf","weight":10,"entries":[{"key":"wilað","weight":10,"content":"wilað"}]}}},"undefined":{"type":"leaf","weight":9,"entries":[{"key":"wil","weight":9,"content":"wil"}]},"u":{"type":"leaf","weight":5,"entries":[{"key":"wilum","weight":5,"content":"wilum"}]}}},"t":{"type":"internal","weight":21,"values":["a","t","u","e","i"],"children":{"a":{"type":"internal","weight":21,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":21,"entries":[{"key":"wita","weight":21,"content":"witå"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"witað","weight":1,"content":"witåð"}]}}},"t":{"type":"internal","weight":10,"values":["e","r"],"children":{"e":{"type":"internal","weight":10,"values":["r"],"children":{"r":{"type":"internal","weight":10,"values":["n","d","k",null],"children":{"n":{"type":"leaf","weight":10,"entries":[{"key":"wittern","weight":10,"content":"wittern"}]},"d":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["g"],"children":{"g":{"type":"internal","weight":2,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"witterdag","weight":2,"content":"witterdag"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"witterdaga","weight":1,"content":"witterdågå"}]}}}}}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"witterkweld","weight":1,"content":"witterkweld"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"witter","weight":1,"content":"witter"}]}}}}},"r":{"type":"internal","weight":3,"values":["a","e"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"wittra","weight":3,"content":"wittra"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"wittrem","weight":1,"content":"wittrem"}]}}}}},"u":{"type":"leaf","weight":4,"entries":[{"key":"witun","weight":4,"content":"witun"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"witeð","weight":2,"content":"witeð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"witið","weight":1,"content":"witið"}]}}},"ð":{"type":"internal","weight":25,"values":["﷐","a","e","l"],"children":{"﷐":{"type":"leaf","weight":25,"entries":[{"key":"wið","weight":25,"content":"wið"}]},"a":{"type":"internal","weight":5,"values":["b","s","k","l","p"],"children":{"b":{"type":"internal","weight":5,"values":["i"],"children":{"i":{"type":"internal","weight":5,"values":["t"],"children":{"t":{"type":"internal","weight":5,"values":["﷐","u","a"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"wiðabit","weight":5,"content":"wiðåbit"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"wiðabitum","weight":1,"content":"wiðåbitum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"wiðabita","weight":1,"content":"wiðåbita"}]}}}}}}},"s":{"type":"internal","weight":3,"values":["t","p"],"children":{"t":{"type":"leaf","weight":3,"entries":[{"key":"wiðastakk","weight":3,"content":"wiðåstakk"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"wiðaspisn","weight":1,"content":"wiðåspisn"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"wiðakabb","weight":1,"content":"wiðåkabb"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"wiðalað","weight":1,"content":"wiðålåð"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"wiðapinna","weight":1,"content":"wiðåpinna"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"wiðera","weight":1,"content":"wiðera"}]},"l":{"type":"internal","weight":1,"values":["y"],"children":{"y":{"type":"internal","weight":1,"values":["p"],"children":{"p":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["g","n"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"wiðlyptuger","weight":1,"content":"wiðlyptuger"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"wiðlyptun","weight":1,"content":"wiðlyptun"}]}}}}}}}}}}}}},"k":{"type":"internal","weight":7,"values":["u","k","t"],"children":{"u":{"type":"leaf","weight":7,"entries":[{"key":"wikur","weight":7,"content":"wikur"},{"key":"wiku","weight":3,"content":"wiku"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"wikkneð","weight":1,"content":"wikkneð"}]},"t":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["g","n","t"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"wiktugan","weight":1,"content":"wiktugan"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"wiktun","weight":1,"content":"wiktun"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"wiktut","weight":1,"content":"wiktut"}]}}}}}}},"e":{"type":"leaf","weight":6,"entries":[{"key":"wiek","weight":6,"content":"wiek"}]},"n":{"type":"internal","weight":5,"values":["d","n","k","t","g"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"winn","weight":4,"content":"winn"}]},"d":{"type":"internal","weight":5,"values":["a","﷐","e","f"],"children":{"a":{"type":"internal","weight":5,"values":["g","﷐","ð"],"children":{"g":{"type":"leaf","weight":5,"entries":[{"key":"windagd","weight":5,"content":"windägd"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"winda","weight":1,"content":"winda"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"windað","weight":1,"content":"windað"}]}}},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"wind","weight":3,"content":"wind"}]},"e":{"type":"internal","weight":1,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"winde","weight":1,"content":"winde"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"winder","weight":1,"content":"winder"}]}}},"f":{"type":"leaf","weight":1,"entries":[{"key":"windfelle","weight":1,"content":"windfelle"}]}}},"k":{"type":"internal","weight":3,"values":["e","l"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"winkeð","weight":3,"content":"winkeð"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"winklum","weight":1,"content":"winklum"}]}}},"t":{"type":"leaf","weight":2,"entries":[{"key":"wint","weight":2,"content":"wint"}]},"g":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["e","l"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"winggel","weight":1,"content":"winggel"}]},"l":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"winggla","weight":1,"content":"winggla"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"winggler","weight":1,"content":"winggler"}]}}}}}}}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"wiitrum","weight":1,"content":"wiitrum"}]}}},"y":{"type":"leaf","weight":1,"entries":[{"key":"wyum","weight":1,"content":"wyum"}]}}},"i":{"type":"internal","weight":405,"values":["e","r","g","t","n","u","m","s","w","j","l","ð"," "],"children":{"e":{"type":"internal","weight":405,"values":["n","t","s","l","m","g","r",null],"children":{"n":{"type":"internal","weight":405,"values":["﷐","u","d","n","k"],"children":{"﷐":{"type":"leaf","weight":405,"entries":[{"key":"ien","weight":405,"content":"ien"}]},"u":{"type":"internal","weight":51,"values":["m"],"children":{"m":{"type":"internal","weight":51,"values":["﷐","d"],"children":{"﷐":{"type":"leaf","weight":51,"entries":[{"key":"ienum","weight":51,"content":"ienum"}]},"d":{"type":"leaf","weight":2,"entries":[{"key":"ienumdier","weight":2,"content":"ienumdier"}]}}}}},"d":{"type":"internal","weight":9,"values":["i","a",null],"children":{"i":{"type":"leaf","weight":9,"entries":[{"key":"iendier","weight":9,"content":"iendier"}]},"a":{"type":"leaf","weight":5,"entries":[{"key":"ienda","weight":5,"content":"ienda"}]},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"iend","weight":2,"content":"iend"}]}}},"n":{"type":"internal","weight":3,"values":["﷐","d"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"ienn","weight":3,"content":"ienn"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"ienndier","weight":1,"content":"ienndier"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"ienkelt","weight":1,"content":"ienkelt"}]}}},"t":{"type":"internal","weight":43,"values":["t","i",null],"children":{"t":{"type":"internal","weight":43,"values":["﷐","e","d"],"children":{"﷐":{"type":"leaf","weight":43,"entries":[{"key":"iett","weight":43,"content":"iett"}]},"e":{"type":"internal","weight":24,"values":["r","ð"],"children":{"r":{"type":"leaf","weight":24,"entries":[{"key":"ietter","weight":24,"content":"ietter"}]},"ð":{"type":"leaf","weight":14,"entries":[{"key":"ietteð","weight":14,"content":"ietteð"}]}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"iettdier","weight":1,"content":"iettdier"}]}}},"undefined":{"type":"leaf","weight":21,"entries":[{"key":"iet","weight":21,"content":"iet"}]},"i":{"type":"leaf","weight":8,"entries":[{"key":"ietið","weight":8,"content":"ietið"}]}}},"s":{"type":"internal","weight":23,"values":["s","u","n"],"children":{"s":{"type":"leaf","weight":23,"entries":[{"key":"iessn","weight":23,"content":"iessn"}]},"u":{"type":"internal","weight":2,"values":["m"],"children":{"m":{"type":"internal","weight":2,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"iesum","weight":2,"content":"iesum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"iesumer","weight":1,"content":"iesumer"}]}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"iesn","weight":1,"content":"iesn"}]}}},"undefined":{"type":"leaf","weight":20,"entries":[{"key":"ie","weight":20,"content":"įe"}]},"l":{"type":"internal","weight":18,"values":["﷐","a","t"],"children":{"﷐":{"type":"leaf","weight":18,"entries":[{"key":"iel","weight":18,"content":"iel"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"ielan","weight":2,"content":"ielan"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"ielt","weight":1,"content":"ielt"}]}}},"m":{"type":"internal","weight":12,"values":["﷐","a","s","i","b","n","l","t"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"iem","weight":12,"content":"iem"}]},"a":{"type":"internal","weight":10,"values":["t","﷐","ð"],"children":{"t":{"type":"leaf","weight":10,"entries":[{"key":"iemat","weight":10,"content":"iemat"}]},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"iema","weight":4,"content":"iema"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"iemað","weight":2,"content":"iemað"}]}}},"s":{"type":"internal","weight":4,"values":["k","m"],"children":{"k":{"type":"leaf","weight":4,"entries":[{"key":"iemskt","weight":4,"content":"iemskt"},{"key":"iemsk","weight":2,"content":"iemsk"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"iemsmaidd","weight":1,"content":"iemsmaidd"}]}}},"i":{"type":"leaf","weight":4,"entries":[{"key":"iemi","weight":4,"content":"iemi"}]},"b":{"type":"internal","weight":2,"values":["y","l"],"children":{"y":{"type":"leaf","weight":2,"entries":[{"key":"iembygdsgardn","weight":2,"content":"iembygdsgardn"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"iembleð","weight":1,"content":"iembleð"}]}}},"n":{"type":"leaf","weight":2,"entries":[{"key":"iemnest","weight":2,"content":"iemnest"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"iemligiet","weight":1,"content":"iemligiet"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"iemtjiennaðsmyoreð","weight":1,"content":"iemtjiennaðsmyöreð"}]}}},"g":{"type":"internal","weight":2,"values":["a","﷐","d"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"iega","weight":2,"content":"iega"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"ieg","weight":1,"content":"ieg"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"iegde","weight":1,"content":"iegde"}]}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"ier","weight":1,"content":"ier"}]}}},"r":{"type":"internal","weight":303,"values":["﷐","a","u","i"],"children":{"﷐":{"type":"leaf","weight":303,"entries":[{"key":"ir","weight":303,"content":"ir"}]},"a":{"type":"leaf","weight":44,"entries":[{"key":"ira","weight":44,"content":"irå"}]},"u":{"type":"leaf","weight":11,"entries":[{"key":"irum","weight":11,"content":"irum"}]},"i":{"type":"leaf","weight":11,"entries":[{"key":"irið","weight":11,"content":"irið"}]}}},"g":{"type":"internal","weight":280,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":280,"entries":[{"key":"ig","weight":280,"content":"ig"}]},"a":{"type":"internal","weight":1,"values":["r","u"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"igar","weight":1,"content":"igår"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"igaungg","weight":1,"content":"igaungg"}]}}}}},"t":{"type":"internal","weight":224,"values":["﷐","j","t"],"children":{"﷐":{"type":"leaf","weight":224,"entries":[{"key":"it","weight":224,"content":"it"}]},"j":{"type":"internal","weight":11,"values":["e","a"],"children":{"e":{"type":"leaf","weight":11,"entries":[{"key":"itje","weight":11,"content":"itje"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"itja","weight":4,"content":"itjä"}]}}},"t":{"type":"internal","weight":5,"values":["a","e",null],"children":{"a":{"type":"internal","weight":5,"values":["ð"],"children":{"ð":{"type":"leaf","weight":5,"entries":[{"key":"ittað-jar","weight":5,"content":"ittað-jär"},{"key":"ittað","weight":3,"content":"ittað"}]}}},"e":{"type":"internal","weight":4,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"itte","weight":4,"content":"itte"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"itter","weight":2,"content":"itter"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"itt","weight":2,"content":"itt"}]}}}}},"n":{"type":"internal","weight":69,"values":["t","n","i","g","d","a","s","u"],"children":{"t":{"type":"internal","weight":69,"values":["﷐","e","n","r"],"children":{"﷐":{"type":"leaf","weight":69,"entries":[{"key":"int","weight":69,"content":"int"}]},"e":{"type":"leaf","weight":6,"entries":[{"key":"inte","weight":6,"content":"inte"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"intnoð","weight":1,"content":"intnoð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"intressirað","weight":1,"content":"intressirað"}]}}},"n":{"type":"internal","weight":67,"values":["i","﷐","a","t","u","e","w","s"],"children":{"i":{"type":"leaf","weight":67,"entries":[{"key":"inni","weight":67,"content":"inni"}]},"﷐":{"type":"leaf","weight":59,"entries":[{"key":"inn","weight":59,"content":"inn"}]},"a":{"type":"internal","weight":22,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":22,"entries":[{"key":"inna","weight":22,"content":"inną̊"}]},"ð":{"type":"leaf","weight":4,"entries":[{"key":"innað","weight":4,"content":"innað"}]}}},"t":{"type":"leaf","weight":5,"entries":[{"key":"innter","weight":5,"content":"innter"}]},"u":{"type":"internal","weight":3,"values":["n","m"],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"innunder","weight":3,"content":"innunder"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"innum","weight":2,"content":"innum"}]}}},"e":{"type":"leaf","weight":2,"entries":[{"key":"inne","weight":2,"content":"inne"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"innwið","weight":1,"content":"innwið"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"innsaidun","weight":1,"content":"innsaidun"}]}}},"i":{"type":"leaf","weight":51,"entries":[{"key":"ini","weight":51,"content":"ini"}]},"g":{"type":"internal","weight":20,"values":["g"],"children":{"g":{"type":"internal","weight":20,"values":["a","﷐","u"],"children":{"a":{"type":"leaf","weight":20,"entries":[{"key":"inggan","weight":20,"content":"inggan"}]},"﷐":{"type":"leaf","weight":11,"entries":[{"key":"ingg","weight":11,"content":"ingg"}]},"u":{"type":"internal","weight":9,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"inggu","weight":9,"content":"inggu"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"inggum","weight":1,"content":"inggum"}]}}}}}}},"d":{"type":"internal","weight":16,"values":["j","r"],"children":{"j":{"type":"leaf","weight":16,"entries":[{"key":"indjin","weight":16,"content":"indjin"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"indreð","weight":1,"content":"indreð"}]}}},"a":{"type":"leaf","weight":4,"entries":[{"key":"inað","weight":4,"content":"inað"},{"key":"ina","weight":1,"content":"iną̊"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"insleppter","weight":1,"content":"insleppter"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"inunder","weight":1,"content":"inunder"}]}}},"u":{"type":"internal","weight":14,"values":["o"],"children":{"o":{"type":"internal","weight":14,"values":["p"],"children":{"p":{"type":"internal","weight":14,"values":["﷐","k","r"],"children":{"﷐":{"type":"leaf","weight":14,"entries":[{"key":"iuop","weight":14,"content":"iuop"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"iuopkrupner","weight":1,"content":"iuopkrupner"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"iuoprullað","weight":1,"content":"iuoprullað"}]}}}}}}},"m":{"type":"internal","weight":8,"values":["i","b"],"children":{"i":{"type":"leaf","weight":8,"entries":[{"key":"imiln","weight":8,"content":"imiln"}]},"b":{"type":"leaf","weight":3,"entries":[{"key":"imblem","weight":3,"content":"imblem"}]}}},"s":{"type":"internal","weight":8,"values":["n","s","u","a"],"children":{"n":{"type":"leaf","weight":8,"entries":[{"key":"isn-jar","weight":8,"content":"isn-jär"}]},"s":{"type":"internal","weight":5,"values":["a","﷐","u","e"],"children":{"a":{"type":"leaf","weight":5,"entries":[{"key":"issanjar","weight":5,"content":"issanjär"}]},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"iss","weight":4,"content":"iss"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"issu","weight":3,"content":"issu"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"isser","weight":1,"content":"isser"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"isu","weight":1,"content":"isu"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"isan","weight":1,"content":"isan"}]}}},"w":{"type":"internal","weight":7,"values":["a","e"],"children":{"a":{"type":"leaf","weight":7,"entries":[{"key":"iwari","weight":7,"content":"iwari"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"iweg","weight":1,"content":"iweg"}]}}},"j":{"type":"internal","weight":6,"values":["u","e"],"children":{"u":{"type":"leaf","weight":6,"entries":[{"key":"ijug","weight":6,"content":"ijug"}]},"e":{"type":"leaf","weight":5,"entries":[{"key":"ijel","weight":5,"content":"ijel"}]}}},"l":{"type":"internal","weight":6,"values":["l","a","u"],"children":{"l":{"type":"internal","weight":6,"values":["﷐","r","a"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"ill","weight":6,"content":"ill"}]},"r":{"type":"internal","weight":3,"values":["o"],"children":{"o":{"type":"internal","weight":3,"values":["k"],"children":{"k":{"type":"internal","weight":3,"values":["k"],"children":{"k":{"type":"internal","weight":3,"values":["﷐","e","t"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"illrokk","weight":3,"content":"illrokk"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"illrokker","weight":2,"content":"illrokker"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"illrokkt","weight":2,"content":"illrokkt"}]}}}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"illat","weight":1,"content":"illät"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"ilun","weight":1,"content":"ilun"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"ila","weight":2,"content":"ila"}]}}},"ð":{"type":"leaf","weight":4,"entries":[{"key":"ið","weight":4,"content":"ið"}]}," ":{"type":"internal","weight":1,"values":["g","d","s"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"i garmorgus","weight":1,"content":"i gårmorgus"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"i dag","weight":1,"content":"i dag"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"i sigelkautum","weight":1,"content":"i sigelkautum"}]}}}}},"m":{"type":"internal","weight":284,"values":["e","i","u","j","a","o","y"],"children":{"e":{"type":"internal","weight":284,"values":["n","s","r","t",null],"children":{"n":{"type":"internal","weight":284,"values":["n","﷐","i","e"],"children":{"n":{"type":"internal","weight":284,"values":["﷐","i","a","e"],"children":{"﷐":{"type":"leaf","weight":284,"entries":[{"key":"menn","weight":284,"content":"menn"}]},"i":{"type":"internal","weight":54,"values":["s"],"children":{"s":{"type":"internal","weight":54,"values":["t"],"children":{"t":{"type":"internal","weight":54,"values":["j"],"children":{"j":{"type":"internal","weight":54,"values":["u","﷐","k","f","w"],"children":{"u":{"type":"internal","weight":54,"values":["r","m"],"children":{"r":{"type":"leaf","weight":54,"entries":[{"key":"mennistjur","weight":54,"content":"mennistjur"}]},"m":{"type":"internal","weight":9,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"mennistjum","weight":9,"content":"mennistjum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"mennistjumes","weight":1,"content":"mennistjumes"}]}}}}},"﷐":{"type":"leaf","weight":13,"entries":[{"key":"mennistj","weight":13,"content":"mennistj"}]},"k":{"type":"leaf","weight":2,"entries":[{"key":"mennistjkrippar","weight":2,"content":"mennistjkrippär"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"mennistjferdum","weight":1,"content":"mennistjferdum"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"mennistjweem","weight":1,"content":"mennistjweem"}]}}}}}}}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"menna","weight":2,"content":"menna"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"menner","weight":1,"content":"menner"}]}}},"﷐":{"type":"leaf","weight":269,"entries":[{"key":"men","weight":269,"content":"men"}]},"i":{"type":"internal","weight":6,"values":["s"],"children":{"s":{"type":"internal","weight":6,"values":["t"],"children":{"t":{"type":"internal","weight":6,"values":["j"],"children":{"j":{"type":"internal","weight":6,"values":["u","﷐"],"children":{"u":{"type":"internal","weight":6,"values":["r","m"],"children":{"r":{"type":"leaf","weight":6,"entries":[{"key":"menistjur","weight":6,"content":"menistjur"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"menistjum","weight":1,"content":"menistjum"}]}}},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"menistj","weight":3,"content":"menistj"}]}}}}}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"mener","weight":1,"content":"mener"}]}}},"s":{"type":"leaf","weight":175,"entries":[{"key":"mes","weight":175,"content":"mes"}]},"r":{"type":"internal","weight":60,"values":["n","u","a","e","k","t","s"],"children":{"n":{"type":"leaf","weight":60,"entries":[{"key":"mern","weight":60,"content":"męrn"}]},"u":{"type":"leaf","weight":60,"entries":[{"key":"merum","weight":60,"content":"męrum"}]},"a":{"type":"leaf","weight":60,"entries":[{"key":"merar","weight":60,"content":"męrär"}]},"e":{"type":"internal","weight":60,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":60,"entries":[{"key":"mere","weight":60,"content":"męre"},{"key":"mere","weight":60,"content":"męrę"}]},"r":{"type":"leaf","weight":60,"entries":[{"key":"merer","weight":60,"content":"męrer"}]}}},"k":{"type":"leaf","weight":2,"entries":[{"key":"merkt","weight":2,"content":"merkt"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"mertje","weight":1,"content":"mertje"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"merstattjin","weight":1,"content":"męrstattjin"}]}}},"undefined":{"type":"leaf","weight":53,"entries":[{"key":"me","weight":53,"content":"mę"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"mettan","weight":3,"content":"mettan"}]}}},"i":{"type":"internal","weight":239,"values":["n","g","l","e","t","k"],"children":{"n":{"type":"internal","weight":239,"values":["﷐","n","u"],"children":{"﷐":{"type":"leaf","weight":239,"entries":[{"key":"min","weight":239,"content":"min"}]},"n":{"type":"internal","weight":17,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":17,"entries":[{"key":"minn","weight":17,"content":"minn"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"minntes","weight":1,"content":"minntes"}]}}},"u":{"type":"internal","weight":5,"values":["t"],"children":{"t":{"type":"internal","weight":5,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"minut","weight":5,"content":"minut"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"minuta","weight":4,"content":"minuta"}]}}}}}}},"g":{"type":"leaf","weight":63,"entries":[{"key":"mig","weight":63,"content":"mig"}]},"l":{"type":"internal","weight":25,"values":["l","u"],"children":{"l":{"type":"leaf","weight":25,"entries":[{"key":"milla","weight":25,"content":"millå"}]},"u":{"type":"leaf","weight":14,"entries":[{"key":"milumað","weight":14,"content":"milumað"}]}}},"e":{"type":"internal","weight":24,"values":["r","t","n","ð"],"children":{"r":{"type":"internal","weight":24,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":24,"entries":[{"key":"mier","weight":24,"content":"mier"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"miereld","weight":2,"content":"miereld"}]}}},"t":{"type":"leaf","weight":5,"entries":[{"key":"mieter","weight":5,"content":"mieter"}]},"n":{"type":"internal","weight":4,"values":["a","d","e"],"children":{"d":{"type":"internal","weight":3,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"miend","weight":3,"content":"miend"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"miendas","weight":1,"content":"miendas"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"miende","weight":1,"content":"miende"}]}}},"a":{"type":"leaf","weight":4,"entries":[{"key":"mienas","weight":4,"content":"mienas"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"miener","weight":1,"content":"miener"}]}}},"ð":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"mieð","weight":3,"content":"mieð"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"mieðer","weight":1,"content":"mieðer"}]}}}}},"t":{"type":"internal","weight":14,"values":["j","t"],"children":{"t":{"type":"internal","weight":12,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"mitt","weight":12,"content":"mitt"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"mittn","weight":1,"content":"mittn"}]}}},"j":{"type":"leaf","weight":14,"entries":[{"key":"mitjið","weight":14,"content":"mitjið"}]}}},"k":{"type":"internal","weight":9,"values":["k"],"children":{"k":{"type":"internal","weight":9,"values":["l","e"],"children":{"l":{"type":"internal","weight":9,"values":["u","e"],"children":{"u":{"type":"internal","weight":9,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"mikklu","weight":9,"content":"mikklu"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"mikklum","weight":1,"content":"mikklum"}]}}},"e":{"type":"leaf","weight":2,"entries":[{"key":"mikkler","weight":2,"content":"mikkler"}]}}},"e":{"type":"leaf","weight":7,"entries":[{"key":"mikkel","weight":7,"content":"mikkel"}]}}}}}}},"u":{"type":"internal","weight":142,"values":["n","m","o","r","k","s"],"children":{"n":{"type":"internal","weight":142,"values":["﷐","u","a","n","k","e"],"children":{"﷐":{"type":"leaf","weight":142,"entries":[{"key":"mun","weight":142,"content":"mun"}]},"u":{"type":"internal","weight":14,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":14,"entries":[{"key":"munu","weight":14,"content":"munu"}]},"r":{"type":"leaf","weight":5,"entries":[{"key":"munur","weight":5,"content":"munur"}]}}},"a":{"type":"leaf","weight":12,"entries":[{"key":"muna","weight":12,"content":"muna"}]},"n":{"type":"internal","weight":11,"values":["﷐","e","s"],"children":{"﷐":{"type":"leaf","weight":11,"entries":[{"key":"munn","weight":11,"content":"munn"}]},"e":{"type":"leaf","weight":8,"entries":[{"key":"munnem","weight":8,"content":"munnem"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"munnstjyddeð","weight":1,"content":"munnstjyddeð"}]}}},"k":{"type":"internal","weight":7,"values":["a"],"children":{"a":{"type":"internal","weight":7,"values":["ð"],"children":{"ð":{"type":"internal","weight":7,"values":["n","e"],"children":{"n":{"type":"leaf","weight":7,"entries":[{"key":"munkaðn","weight":7,"content":"Munkäðn"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"munkaðe","weight":2,"content":"Munkäðe"}]}}}}}}},"e":{"type":"leaf","weight":2,"entries":[{"key":"munes","weight":2,"content":"munes"}]}}},"m":{"type":"leaf","weight":16,"entries":[{"key":"mumun","weight":16,"content":"mumun"}]},"o":{"type":"internal","weight":11,"values":["s","t","l","r"],"children":{"s":{"type":"internal","weight":11,"values":["k","a","s"],"children":{"k":{"type":"internal","weight":11,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":11,"entries":[{"key":"muosk","weight":11,"content":"muosk"}]},"e":{"type":"internal","weight":2,"values":["r","ð"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"muoskera","weight":2,"content":"muoskera"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"muoskeð","weight":1,"content":"muoskeð"}]}}}}},"a":{"type":"internal","weight":3,"values":["m","n"],"children":{"m":{"type":"leaf","weight":3,"entries":[{"key":"muosam","weight":3,"content":"muosåm"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"muosan","weight":2,"content":"muosån"}]}}},"s":{"type":"internal","weight":1,"values":["i","a"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"muossi","weight":1,"content":"Muossi"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"muossam","weight":1,"content":"Muossam"}]}}}}},"t":{"type":"leaf","weight":7,"entries":[{"key":"muot","weight":7,"content":"muot"}]},"l":{"type":"internal","weight":3,"values":["n"],"children":{"n":{"type":"internal","weight":3,"values":["﷐","u","e","g"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"muoln","weight":3,"content":"muoln"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"muolnum","weight":2,"content":"muolnum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"muolne","weight":1,"content":"muolnę"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"muolngubb","weight":1,"content":"muolngubb"}]}}}}},"r":{"type":"leaf","weight":2,"entries":[{"key":"muora","weight":2,"content":"Muora"}]}}},"r":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["a","e"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"murra","weight":3,"content":"murra"}]},"e":{"type":"internal","weight":2,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"murre","weight":2,"content":"murre"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"murreð","weight":2,"content":"murreð"}]}}}}}}},"k":{"type":"internal","weight":2,"values":["e","a"],"children":{"e":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"internal","weight":2,"values":["﷐","i","u"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"mukeð","weight":2,"content":"mukeð"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"mukeðið","weight":2,"content":"mukeðið"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"mukeðum","weight":2,"content":"mukeðum"}]}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"mukað","weight":1,"content":"mukäð"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"musitjem","weight":1,"content":"musitjem"}]}}},"j":{"type":"internal","weight":61,"values":["a","o"],"children":{"a":{"type":"internal","weight":61,"values":["s","r"],"children":{"s":{"type":"internal","weight":61,"values":["t"],"children":{"t":{"type":"leaf","weight":61,"entries":[{"key":"mjasta","weight":61,"content":"mjästa"},{"key":"mjast","weight":61,"content":"mjäst"}]}}},"r":{"type":"leaf","weight":2,"entries":[{"key":"mjarg","weight":2,"content":"mjärg"}]}}},"o":{"type":"internal","weight":6,"values":["t","k"],"children":{"t":{"type":"internal","weight":6,"values":["j","s"],"children":{"j":{"type":"internal","weight":6,"values":["e","i"],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"mjotje","weight":6,"content":"mjotje"}]},"i":{"type":"leaf","weight":3,"entries":[{"key":"mjotjin","weight":3,"content":"mjotjin"}]}}},"s":{"type":"leaf","weight":3,"entries":[{"key":"mjotse","weight":3,"content":"mjotse"}]}}},"k":{"type":"internal","weight":2,"values":["﷐","s","a","b","n"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"mjok","weight":2,"content":"mjok"}]},"s":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["w"],"children":{"w":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["t","k"],"children":{"t":{"type":"internal","weight":1,"values":["a","u"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"mjokskwektar","weight":1,"content":"mjokskwektär"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"mjokskwektum","weight":1,"content":"mjokskwektum"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"mjokskwekkt","weight":1,"content":"mjokskwekkt"}]}}}}}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"mjokausa","weight":1,"content":"mjokausa"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"mjokbytt","weight":1,"content":"mjokbytt"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"mjoknindje","weight":1,"content":"mjoknindje"}]}}}}}}},"a":{"type":"internal","weight":12,"values":["y","i","s","u","r","k","l","t","n",null],"children":{"y":{"type":"internal","weight":12,"values":["r","s"],"children":{"r":{"type":"internal","weight":12,"values":["e","n","u","l","a","b","k"],"children":{"e":{"type":"leaf","weight":12,"entries":[{"key":"mayre","weight":12,"content":"måyre"}]},"n":{"type":"leaf","weight":10,"entries":[{"key":"mayrn","weight":10,"content":"måyrn"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"mayrum","weight":2,"content":"måyrum"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"mayrlandskapeð","weight":1,"content":"måyrlandskapeð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"mayrar","weight":1,"content":"måyrär"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"mayrbere","weight":1,"content":"måyrberę"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"mayrkantem","weight":1,"content":"måyrkantem"}]}}},"s":{"type":"internal","weight":3,"values":["a","e"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"maysar","weight":3,"content":"måysär"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"mayser","weight":2,"content":"måyser"}]}}}}},"i":{"type":"internal","weight":6,"values":["n","g",null],"children":{"n":{"type":"internal","weight":6,"values":["u","﷐","e"],"children":{"u":{"type":"leaf","weight":6,"entries":[{"key":"mainum","weight":6,"content":"mainum"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"main","weight":3,"content":"main"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"mainer","weight":1,"content":"mainer"}]}}},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"mai","weight":3,"content":"mai"}]},"g":{"type":"leaf","weight":4,"entries":[{"key":"maiga","weight":4,"content":"maiga"},{"key":"maig","weight":1,"content":"maig"}]}}},"undefined":{"type":"leaf","weight":5,"entries":[{"key":"ma","weight":5,"content":"mą̊"}]},"u":{"type":"internal","weight":4,"values":["s","n"],"children":{"s":{"type":"internal","weight":4,"values":["﷐","a","u"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"maus","weight":4,"content":"maus"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"mausarur","weight":1,"content":"mausärur"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"mausum","weight":1,"content":"mausum"}]}}},"n":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["g","s"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"maunggsbuðum","weight":1,"content":"Maunggsbuðum"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"maungsbuder","weight":1,"content":"Maungsbuder"}]}}}}}}},"s":{"type":"internal","weight":5,"values":["s","i"],"children":{"s":{"type":"leaf","weight":5,"entries":[{"key":"masse","weight":5,"content":"masse"}]},"i":{"type":"leaf","weight":3,"entries":[{"key":"masin","weight":3,"content":"masin"}]}}},"r":{"type":"leaf","weight":2,"entries":[{"key":"maru","weight":2,"content":"maru"}]},"k":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["﷐","e","l"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"makk","weight":1,"content":"makk"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"makker","weight":1,"content":"makker"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"makklit","weight":1,"content":"makklit"}]}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"malaðkallar","weight":1,"content":"målaðkallär"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"matað","weight":1,"content":"mätäð"}]},"n":{"type":"internal","weight":1,"values":["a","d","n"],"children":{"a":{"type":"internal","weight":1,"values":["ð"],"children":{"ð":{"type":"internal","weight":1,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"manað","weight":1,"content":"månað"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"manaðir","weight":1,"content":"månaðir"}]}}}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"mandan","weight":1,"content":"måndan"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"manngnietar","weight":1,"content":"manngnietär"}]}}}}},"o":{"type":"internal","weight":6,"values":["r","d","k","t"],"children":{"r":{"type":"internal","weight":6,"values":["g","k","d"],"children":{"g":{"type":"internal","weight":6,"values":["u"],"children":{"u":{"type":"internal","weight":6,"values":["n","s"],"children":{"n":{"type":"leaf","weight":6,"entries":[{"key":"morgun","weight":6,"content":"morgun"}]},"s":{"type":"leaf","weight":5,"entries":[{"key":"morgus","weight":5,"content":"morgus"}]}}}}},"k":{"type":"internal","weight":6,"values":["t","n","a","e","b",null],"children":{"t":{"type":"leaf","weight":6,"entries":[{"key":"morkt","weight":6,"content":"mörkt"}]},"n":{"type":"leaf","weight":5,"entries":[{"key":"morkne","weight":5,"content":"mörkne"}]},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"mork","weight":4,"content":"mörk"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"morkan","weight":2,"content":"mörkan"},{"key":"morka","weight":1,"content":"mörka"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"morkera","weight":1,"content":"mörkera"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"morkbrun","weight":1,"content":"mörkbrun"}]}}},"d":{"type":"internal","weight":3,"values":["e"],"children":{"e":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"morder","weight":3,"content":"mörder"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"mordern","weight":1,"content":"mördern"}]}}}}}}}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"modarner","weight":1,"content":"modärner"}]},"k":{"type":"internal","weight":1,"values":["a","n"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"mokað","weight":1,"content":"mokað"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"mokner","weight":1,"content":"mokner"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"motjeð","weight":1,"content":"motjeð"}]}}},"y":{"type":"internal","weight":1,"values":["ð","k","o","s"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"myðn","weight":1,"content":"myðn"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"mykklaingsbrune","weight":1,"content":"mykklaingsbrune"}]},"o":{"type":"leaf","weight":1,"entries":[{"key":"myotesplass","weight":1,"content":"myötesplass"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"myssmyoreð","weight":1,"content":"myssmyöreð"}]}}}}},"e":{"type":"internal","weight":273,"values":["ð","t","d","l","v","n","s","r","m","k","g","x"],"children":{"ð":{"type":"internal","weight":273,"values":["﷐","-"],"children":{"﷐":{"type":"leaf","weight":273,"entries":[{"key":"eð","weight":273,"content":"eð"}]},"-":{"type":"leaf","weight":42,"entries":[{"key":"eð-dar","weight":42,"content":"eð-dar"}]}}},"t":{"type":"internal","weight":145,"values":["t","e","a"," ","b"],"children":{"t":{"type":"internal","weight":145,"values":["e","a","u"],"children":{"e":{"type":"internal","weight":145,"values":["r"],"children":{"r":{"type":"internal","weight":145,"values":["﷐","s","f","m","a"],"children":{"﷐":{"type":"leaf","weight":145,"entries":[{"key":"etter","weight":145,"content":"etter"}]},"s":{"type":"leaf","weight":16,"entries":[{"key":"ettersos","weight":16,"content":"ettersos"}]},"f":{"type":"internal","weight":9,"values":["u"],"children":{"u":{"type":"internal","weight":9,"values":["o"],"children":{"o":{"type":"internal","weight":9,"values":["t"],"children":{"t":{"type":"internal","weight":9,"values":["a","u","e",null],"children":{"a":{"type":"internal","weight":9,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"etterfuota","weight":9,"content":"etterfuota"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"etterfuotar","weight":1,"content":"etterfuotär"}]}}},"u":{"type":"leaf","weight":8,"entries":[{"key":"etterfuotum","weight":8,"content":"etterfuotum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"etterfuotem","weight":1,"content":"etterfuotem"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"etterfuot","weight":1,"content":"etterfuot"}]}}}}}}}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"ettermiddan","weight":1,"content":"ettermiddan"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"etterat","weight":1,"content":"etteråt"}]}}}}},"a":{"type":"leaf","weight":5,"entries":[{"key":"etta","weight":5,"content":"etta"}]},"u":{"type":"internal","weight":2,"values":["r","m"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"ettur","weight":2,"content":"ettur"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"ettum","weight":1,"content":"ettum"}]}}}}},"e":{"type":"internal","weight":21,"values":["r"],"children":{"r":{"type":"internal","weight":21,"values":["﷐","s"],"children":{"﷐":{"type":"leaf","weight":21,"entries":[{"key":"eter","weight":21,"content":"eter"}]},"s":{"type":"leaf","weight":2,"entries":[{"key":"etersos","weight":2,"content":"etersos"}]}}}}},"a":{"type":"leaf","weight":6,"entries":[{"key":"eta","weight":6,"content":"etą̊"}]}," ":{"type":"internal","weight":1,"values":["l","n","f","k"],"children":{"l":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["n","i"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"et lands","weight":1,"content":"et lands"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"et laivs","weight":1,"content":"et laivs"}]}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"et nyes","weight":1,"content":"et nyes"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"et friðs","weight":1,"content":"et friðs"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"et kwells","weight":1,"content":"et kwells"}]}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"etbaker","weight":1,"content":"etbaker"}]}}},"d":{"type":"internal","weight":83,"values":["d"],"children":{"d":{"type":"internal","weight":83,"values":["﷐","j","u","i"],"children":{"﷐":{"type":"leaf","weight":83,"entries":[{"key":"edd","weight":83,"content":"edd"}]},"j":{"type":"internal","weight":7,"values":["e"],"children":{"e":{"type":"internal","weight":7,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"eddje","weight":7,"content":"eddje"}]},"ð":{"type":"leaf","weight":3,"entries":[{"key":"eddjeð","weight":3,"content":"eddjeð"}]}}}}},"u":{"type":"leaf","weight":3,"entries":[{"key":"eddum","weight":3,"content":"eddum"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"eddið","weight":1,"content":"eddið"}]}}}}},"l":{"type":"internal","weight":59,"values":["d","l","a","e","s","u"],"children":{"d":{"type":"leaf","weight":59,"entries":[{"key":"eld","weight":59,"content":"eld"}]},"l":{"type":"internal","weight":41,"values":["e","d","j","o","a"],"children":{"e":{"type":"internal","weight":41,"values":["r","s"],"children":{"r":{"type":"leaf","weight":41,"entries":[{"key":"eller","weight":41,"content":"eller"}]},"s":{"type":"leaf","weight":7,"entries":[{"key":"ellest","weight":7,"content":"ellest"}]}}},"d":{"type":"leaf","weight":2,"entries":[{"key":"elld","weight":2,"content":"elld"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"elljuosandyrun","weight":1,"content":"elljuosandyrun"}]},"o":{"type":"leaf","weight":1,"entries":[{"key":"ellopt","weight":1,"content":"ellopt"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"ellav","weight":1,"content":"ellåv"}]}}},"a":{"type":"leaf","weight":11,"entries":[{"key":"ela","weight":11,"content":"ela"}]},"s":{"type":"internal","weight":2,"values":["t","n"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"elst","weight":2,"content":"elst"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"elsningger","weight":1,"content":"elsningger"}]}}},"e":{"type":"internal","weight":3,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":3,"entries":[{"key":"eleð","weight":3,"content":"eleð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"eler","weight":1,"content":"eler"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"elum","weight":1,"content":"elum"}]}}},"n":{"type":"internal","weight":37,"values":["d","n","e","t",null],"children":{"d":{"type":"internal","weight":37,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":37,"entries":[{"key":"end","weight":37,"content":"end"}]},"a":{"type":"internal","weight":16,"values":["﷐","m","r"],"children":{"﷐":{"type":"leaf","weight":16,"entries":[{"key":"enda","weight":16,"content":"endą̊"},{"key":"enda","weight":7,"content":"enda"}]},"m":{"type":"leaf","weight":4,"entries":[{"key":"endam","weight":4,"content":"endam"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"endar","weight":1,"content":"endar"}]}}},"e":{"type":"internal","weight":5,"values":["﷐","r","l"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"ende","weight":5,"content":"ende"}]},"r":{"type":"leaf","weight":3,"entries":[{"key":"ender","weight":3,"content":"ender"}]},"l":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"endels","weight":1,"content":"endels"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"endelse","weight":1,"content":"endelse"}]}}}}}}}}},"n":{"type":"internal","weight":31,"values":["﷐","e","-","t","d"],"children":{"﷐":{"type":"leaf","weight":31,"entries":[{"key":"enn","weight":31,"content":"enn"}]},"e":{"type":"internal","weight":23,"values":["r","s",null],"children":{"r":{"type":"internal","weight":23,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":23,"entries":[{"key":"enner","weight":23,"content":"enner"}]},"e":{"type":"leaf","weight":4,"entries":[{"key":"enneres","weight":4,"content":"enneres"}]}}},"s":{"type":"leaf","weight":19,"entries":[{"key":"ennes","weight":19,"content":"ennes"}]},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"enne","weight":4,"content":"enne"}]}}},"-":{"type":"leaf","weight":14,"entries":[{"key":"enn-dar","weight":14,"content":"enn-dar"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"ennt","weight":3,"content":"ennt"}]},"d":{"type":"leaf","weight":2,"entries":[{"key":"ennda","weight":2,"content":"ennda"}]}}},"undefined":{"type":"leaf","weight":17,"entries":[{"key":"en","weight":17,"content":"en"}]},"e":{"type":"internal","weight":6,"values":["r","s"],"children":{"r":{"type":"leaf","weight":6,"entries":[{"key":"ener","weight":6,"content":"ener"}]},"s":{"type":"leaf","weight":3,"entries":[{"key":"enes","weight":3,"content":"enes"}]}}},"t":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"ent","weight":3,"content":"ent"}]},"e":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["﷐","g"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"enteli","weight":1,"content":"enteli"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"entelig","weight":1,"content":"entelig"}]}}}}}}}}}}},"v":{"type":"internal","weight":38,"values":["﷐","a","d"],"children":{"﷐":{"type":"leaf","weight":38,"entries":[{"key":"ev","weight":38,"content":"ev"}]},"a":{"type":"leaf","weight":11,"entries":[{"key":"eva","weight":11,"content":"eva"}]},"d":{"type":"internal","weight":1,"values":["e","u"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"evde","weight":1,"content":"evde"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"evdum","weight":1,"content":"evdum"}]}}}}},"r":{"type":"internal","weight":6,"values":["d","m","v","i","r"],"children":{"d":{"type":"internal","weight":6,"values":["e","u","n","a","s"],"children":{"e":{"type":"internal","weight":6,"values":["﷐","m","r"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"erde","weight":6,"content":"erde"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"erdem","weight":2,"content":"erdem"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"erder","weight":1,"content":"erder"}]}}},"n":{"type":"leaf","weight":2,"entries":[{"key":"erdn","weight":2,"content":"erdn"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"erdum","weight":3,"content":"erdum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"erdar","weight":1,"content":"erdär"}]},"s":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["ð"],"children":{"ð":{"type":"internal","weight":1,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"erdskaið","weight":1,"content":"erdskaið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"erdskaiðum","weight":1,"content":"erdskaiðum"}]}}}}}}}}}}}}},"m":{"type":"leaf","weight":2,"entries":[{"key":"ermas","weight":2,"content":"ermas"}]},"v":{"type":"internal","weight":1,"values":["d","a"],"children":{"d":{"type":"leaf","weight":1,"entries":[{"key":"ervde","weight":1,"content":"ervde"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"erva","weight":1,"content":"erva"}]}}},"i":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"eril","weight":1,"content":"eril"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"erilem","weight":1,"content":"erilem"}]}}}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"errur","weight":1,"content":"errur"}]}}},"s":{"type":"internal","weight":7,"values":["t"],"children":{"t":{"type":"internal","weight":7,"values":["e","u","n","s",null],"children":{"e":{"type":"internal","weight":7,"values":["r","m"],"children":{"m":{"type":"leaf","weight":5,"entries":[{"key":"estem","weight":5,"content":"estem"}]},"r":{"type":"leaf","weight":7,"entries":[{"key":"ester","weight":7,"content":"ester"}]}}},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"est","weight":4,"content":"est"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"estum","weight":3,"content":"estum"}]},"n":{"type":"leaf","weight":3,"entries":[{"key":"estn","weight":3,"content":"estn"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"eststjuoss","weight":1,"content":"eststjuoss"}]}}}}},"m":{"type":"leaf","weight":3,"entries":[{"key":"emes","weight":3,"content":"emes"}]},"k":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["e","r"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"ekster","weight":2,"content":"ekster"}]},"r":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"ekstra","weight":1,"content":"ekstra"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"ekstrer","weight":1,"content":"ekstrer"}]}}}}}}}}},"g":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"egg","weight":1,"content":"egg"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"eggum","weight":1,"content":"eggum"}]}}}}},"x":{"type":"leaf","weight":1,"entries":[{"key":"extratrayur","weight":1,"content":"extratråyur"}]}}},"n":{"type":"internal","weight":220,"values":["u","o","e","i","a","y"],"children":{"u":{"type":"internal","weight":220,"values":["﷐","o"],"children":{"﷐":{"type":"leaf","weight":220,"entries":[{"key":"nu","weight":220,"content":"nų"}]},"o":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["g","a"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"nuoggrannt","weight":1,"content":"nuoggrannt"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"nuoga","weight":1,"content":"nuoga"}]}}}}}}},"o":{"type":"internal","weight":78,"values":["g","ð","n","s","r","t"],"children":{"ð":{"type":"leaf","weight":77,"entries":[{"key":"noð","weight":77,"content":"noð"}]},"g":{"type":"internal","weight":78,"values":["e","﷐","u","r"],"children":{"e":{"type":"leaf","weight":78,"entries":[{"key":"noger","weight":78,"content":"noger"}]},"﷐":{"type":"leaf","weight":35,"entries":[{"key":"nog","weight":35,"content":"nog"}]},"u":{"type":"internal","weight":13,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":13,"entries":[{"key":"nogu","weight":13,"content":"nogu"}]},"m":{"type":"internal","weight":7,"values":["﷐","s"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"nogum","weight":7,"content":"nogum"}]},"s":{"type":"leaf","weight":4,"entries":[{"key":"nogumstas","weight":4,"content":"nogumstas"}]}}}}},"r":{"type":"leaf","weight":3,"entries":[{"key":"nogrer","weight":3,"content":"nogrer"}]}}},"n":{"type":"leaf","weight":25,"entries":[{"key":"non","weight":25,"content":"non"}]},"s":{"type":"leaf","weight":9,"entries":[{"key":"nossn","weight":9,"content":"nossn"}]},"r":{"type":"internal","weight":6,"values":["d","r","t",null],"children":{"d":{"type":"internal","weight":6,"values":["y","o","a"],"children":{"y":{"type":"leaf","weight":6,"entries":[{"key":"nordyvyr","weight":6,"content":"nordyvyr"}]},"o":{"type":"leaf","weight":2,"entries":[{"key":"nordonað","weight":2,"content":"nordonað"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"norda","weight":1,"content":"nordą̊"}]}}},"r":{"type":"leaf","weight":2,"entries":[{"key":"norre","weight":2,"content":"Norre"}]},"t":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"norterwester","weight":2,"content":"norterwester"},{"key":"norter","weight":1,"content":"norter"}]}}}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"nor","weight":1,"content":"nor"}]}}},"t":{"type":"leaf","weight":3,"entries":[{"key":"note","weight":3,"content":"note"}]}}},"e":{"type":"internal","weight":44,"values":["s","m","v","r","t","b"],"children":{"s":{"type":"internal","weight":44,"values":["t","e","i","s"],"children":{"t":{"type":"internal","weight":44,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":44,"entries":[{"key":"nest","weight":44,"content":"nest"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"nesta","weight":3,"content":"nesta"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"neseð","weight":1,"content":"Neseð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"nesi","weight":1,"content":"Nesį"}]},"s":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["m","n"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"nessjumm","weight":1,"content":"Nessjumm"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"nessjunn","weight":1,"content":"Nessjunn"}]}}}}}}}}},"m":{"type":"internal","weight":27,"values":["m"],"children":{"m":{"type":"internal","weight":27,"values":["e"],"children":{"e":{"type":"internal","weight":27,"values":["r","s"],"children":{"r":{"type":"leaf","weight":27,"entries":[{"key":"nemmera","weight":27,"content":"nemmera"},{"key":"nemmer","weight":1,"content":"nemmer"}]},"s":{"type":"leaf","weight":4,"entries":[{"key":"nemmest","weight":4,"content":"nemmest"}]}}}}}}},"v":{"type":"internal","weight":15,"values":["a","e","u","i"],"children":{"a":{"type":"internal","weight":15,"values":["n","m"],"children":{"n":{"type":"leaf","weight":15,"entries":[{"key":"nevan","weight":15,"content":"nevån"}]},"m":{"type":"leaf","weight":5,"entries":[{"key":"nevam","weight":5,"content":"nevåm"}]}}},"e":{"type":"leaf","weight":14,"entries":[{"key":"neveð","weight":14,"content":"neveð"}]},"u":{"type":"leaf","weight":7,"entries":[{"key":"nevum","weight":7,"content":"nevum"}]},"i":{"type":"leaf","weight":6,"entries":[{"key":"nevi","weight":6,"content":"nevi"},{"key":"nevi","weight":6,"content":"nevį"}]}}},"r":{"type":"internal","weight":7,"values":["﷐","v"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"ner","weight":7,"content":"ner"}]},"v":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"nerva","weight":1,"content":"nerva"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"nervar","weight":1,"content":"nervär"}]}}}}}}},"t":{"type":"internal","weight":2,"values":["a","i"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"netar","weight":2,"content":"netär"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"netinnum","weight":1,"content":"netinnum"}]}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"nebbem","weight":1,"content":"nebbem"}]}}},"i":{"type":"internal","weight":35,"values":["ð","t","k","s","u"],"children":{"ð":{"type":"internal","weight":35,"values":["i","a","﷐","m","e","f","o","w","y","u"],"children":{"i":{"type":"leaf","weight":35,"entries":[{"key":"niði","weight":35,"content":"niði"}]},"﷐":{"type":"leaf","weight":23,"entries":[{"key":"nið","weight":23,"content":"nið"}]},"a":{"type":"internal","weight":24,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":24,"entries":[{"key":"niða","weight":24,"content":"niðą̊"}]},"ð":{"type":"leaf","weight":3,"entries":[{"key":"niðað","weight":3,"content":"niðað"}]}}},"m":{"type":"leaf","weight":12,"entries":[{"key":"niðmin","weight":12,"content":"niðmin"}]},"e":{"type":"internal","weight":5,"values":["r"],"children":{"r":{"type":"internal","weight":5,"values":["﷐","f"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"niðer","weight":5,"content":"niðer"}]},"f":{"type":"internal","weight":1,"values":["o","e"],"children":{"o":{"type":"leaf","weight":1,"entries":[{"key":"niðerfor","weight":1,"content":"niðerför"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"niðerfer","weight":1,"content":"niðerfer"}]}}}}}}},"f":{"type":"leaf","weight":3,"entries":[{"key":"niðfor","weight":3,"content":"niðför"}]},"o":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["a","i"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"niðonað","weight":2,"content":"niðonað"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"niðoni","weight":1,"content":"niðoni"}]}}}}},"w":{"type":"leaf","weight":2,"entries":[{"key":"niðwið","weight":2,"content":"niðwið"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"niðyvyr","weight":1,"content":"niðyvyr"}]},"u":{"type":"internal","weight":1,"values":["m","n"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"niðum","weight":1,"content":"niðum"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"niðunder","weight":1,"content":"niðunder"}]}}}}},"t":{"type":"internal","weight":11,"values":["t"],"children":{"t":{"type":"internal","weight":11,"values":["e"],"children":{"e":{"type":"internal","weight":11,"values":["r"],"children":{"r":{"type":"internal","weight":11,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":11,"entries":[{"key":"nitter","weight":11,"content":"nitter"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"nitterað","weight":1,"content":"nitterað"}]}}}}}}}}},"k":{"type":"leaf","weight":3,"entries":[{"key":"nikkeð","weight":3,"content":"nikkeð"}]},"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["a","u"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"nista","weight":2,"content":"nista"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"nistun","weight":1,"content":"nistun"}]}}}}},"u":{"type":"internal","weight":1,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"niu","weight":1,"content":"niu"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"niund","weight":1,"content":"niund"}]}}}}},"a":{"type":"internal","weight":22,"values":["i","u","m","k","b","j","'","t",null],"children":{"i":{"type":"leaf","weight":22,"entries":[{"key":"nai","weight":22,"content":"nai"},{"key":"nai","weight":2,"content":"näi"}]},"u":{"type":"leaf","weight":18,"entries":[{"key":"naug","weight":18,"content":"naug"}]},"undefined":{"type":"leaf","weight":6,"entries":[{"key":"na","weight":6,"content":"ną̊"}]},"m":{"type":"internal","weight":6,"values":["n","m"],"children":{"m":{"type":"internal","weight":5,"values":["e","i","n"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"nammen","weight":5,"content":"nammen"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"nammin","weight":2,"content":"nammin"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"nammneð","weight":1,"content":"nammneð"}]}}},"n":{"type":"internal","weight":6,"values":["e"],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"namneð","weight":6,"content":"namneð"},{"key":"namne","weight":1,"content":"namnę"}]}}}}},"k":{"type":"internal","weight":3,"values":["k"],"children":{"k":{"type":"internal","weight":3,"values":["s","a"],"children":{"s":{"type":"leaf","weight":3,"entries":[{"key":"nakkstjinneð","weight":3,"content":"nakkstjinneð"}]},"a":{"type":"internal","weight":1,"values":["n","r"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"nakkan","weight":1,"content":"nakkan"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"nakkareð","weight":1,"content":"nakkåreð"}]}}}}}}},"b":{"type":"leaf","weight":3,"entries":[{"key":"nabbjargum","weight":3,"content":"Nabbjärgum"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"naj","weight":1,"content":"näj"}]},"'":{"type":"leaf","weight":1,"entries":[{"key":"na'dd","weight":1,"content":"nå'dd"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"nat","weight":1,"content":"ną̊t"}]}}},"y":{"type":"internal","weight":9,"values":["﷐","t","k","p","s","a","e","u"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"ny","weight":9,"content":"ny"}]},"t":{"type":"internal","weight":5,"values":["t","j"],"children":{"t":{"type":"internal","weight":5,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"nytt","weight":5,"content":"nytt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"nytter","weight":1,"content":"nytter"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"nyttugieter","weight":1,"content":"nyttugieter"}]}}},"j":{"type":"internal","weight":2,"values":["y"],"children":{"y":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"leaf","weight":2,"entries":[{"key":"nytjyln","weight":2,"content":"nytjyln"},{"key":"nytjyl","weight":2,"content":"nytjyl"}]}}}}}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"nykklem","weight":1,"content":"nykklem"}]},"p":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["p"],"children":{"p":{"type":"internal","weight":1,"values":["p"],"children":{"p":{"type":"internal","weight":1,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"nypansupp","weight":1,"content":"nypånsupp"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"nypansuppu","weight":1,"content":"nypånsuppu"}]}}}}}}}}}}}}}}},"s":{"type":"internal","weight":1,"values":["i","l","p"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"nysilaðmjotje","weight":1,"content":"nysilaðmjotję"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"nyslipaðknaivar","weight":1,"content":"nyslipaðknaivär"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"nyspuoraðer","weight":1,"content":"nyspuoråðer"}]}}},"a":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"nyar","weight":1,"content":"nyår"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"nyareð","weight":1,"content":"nyåreð"}]}}}}},"e":{"type":"internal","weight":1,"values":["r","s"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"nyer","weight":1,"content":"nyer"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"nyes","weight":1,"content":"nyes"}]}}},"u":{"type":"internal","weight":1,"values":["﷐","p"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"nyu","weight":1,"content":"nyu"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"nyuppsett","weight":1,"content":"nyuppsett"}]}}}}}}},"f":{"type":"internal","weight":195,"values":["o","e","u","i","r","a","l","y","j","n"],"children":{"o":{"type":"internal","weight":195,"values":["r","l"],"children":{"r":{"type":"internal","weight":195,"values":["﷐","s","e","u","b","t","a","o","w","l"],"children":{"﷐":{"type":"leaf","weight":195,"entries":[{"key":"for","weight":195,"content":"för"}]},"s":{"type":"internal","weight":18,"values":["t","i","w"],"children":{"t":{"type":"internal","weight":18,"values":["a","u","i"],"children":{"a":{"type":"internal","weight":18,"values":["u","i"],"children":{"u":{"type":"leaf","weight":18,"entries":[{"key":"forstaum","weight":18,"content":"förståum"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"forstaið","weight":2,"content":"förståið"}]}}},"u":{"type":"leaf","weight":18,"entries":[{"key":"forstuoð","weight":18,"content":"förstuoð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"forstienðer","weight":1,"content":"förstienðer"}]}}},"i":{"type":"leaf","weight":10,"entries":[{"key":"forsiktut","weight":10,"content":"försiktut"}]},"w":{"type":"internal","weight":5,"values":["a"],"children":{"a":{"type":"internal","weight":5,"values":["n"],"children":{"n":{"type":"internal","weight":5,"values":["n"],"children":{"n":{"type":"internal","weight":5,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"forswann","weight":5,"content":"förswann"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"forswannu","weight":2,"content":"förswannu"}]}}}}}}}}}}},"e":{"type":"internal","weight":11,"values":["l","s"],"children":{"l":{"type":"leaf","weight":11,"entries":[{"key":"foreld","weight":11,"content":"föreld"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"forestellningg","weight":1,"content":"förestellningg"}]}}},"u":{"type":"leaf","weight":6,"entries":[{"key":"forunder","weight":6,"content":"förunder"}]},"b":{"type":"internal","weight":4,"values":["i"],"children":{"i":{"type":"internal","weight":4,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"forbi","weight":4,"content":"förbi"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"forbirieð","weight":1,"content":"förbirieð"}]}}}}},"t":{"type":"leaf","weight":3,"entries":[{"key":"fortuorvað","weight":3,"content":"förtuorvað"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"forareð","weight":2,"content":"föråreð"}]},"o":{"type":"leaf","weight":2,"entries":[{"key":"forostn","weight":2,"content":"förostn"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"forwandlað","weight":1,"content":"förwandlað"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"forlat","weight":1,"content":"förlåt"}]}}},"l":{"type":"internal","weight":3,"values":["d","l"],"children":{"d":{"type":"leaf","weight":3,"entries":[{"key":"fold","weight":3,"content":"föld"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"foll","weight":1,"content":"foll"}]}}}}},"e":{"type":"internal","weight":109,"values":["l","r","ð","m","s","k"],"children":{"l":{"type":"internal","weight":109,"values":["﷐","d","l"],"children":{"﷐":{"type":"leaf","weight":109,"entries":[{"key":"fel","weight":109,"content":"fel"}]},"d":{"type":"internal","weight":6,"values":["﷐","n","e"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"feld","weight":6,"content":"feld"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"feldn","weight":1,"content":"feldn"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"feldem","weight":1,"content":"feldem"}]}}},"l":{"type":"internal","weight":3,"values":["e","i"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"felleð","weight":3,"content":"felleð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"fellið","weight":1,"content":"fellið"}]}}}}},"r":{"type":"internal","weight":61,"values":["﷐","i","s","g","u","d","b","t"],"children":{"﷐":{"type":"leaf","weight":61,"entries":[{"key":"fer","weight":61,"content":"fer"}]},"s":{"type":"internal","weight":7,"values":["t","i","w"],"children":{"t":{"type":"leaf","weight":7,"entries":[{"key":"ferstuoð","weight":7,"content":"ferstuoð"}]},"i":{"type":"leaf","weight":5,"entries":[{"key":"fersiktut","weight":5,"content":"fersiktut"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"ferswið","weight":1,"content":"ferswið"}]}}},"i":{"type":"leaf","weight":11,"entries":[{"key":"ferið","weight":11,"content":"ferið"}]},"g":{"type":"internal","weight":3,"values":["u","﷐","a"],"children":{"u":{"type":"internal","weight":3,"values":["r","m"],"children":{"r":{"type":"leaf","weight":3,"entries":[{"key":"fergur","weight":3,"content":"fergur"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"fergum","weight":2,"content":"fergum"}]}}},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"ferg","weight":2,"content":"ferg"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"ferga","weight":2,"content":"ferga"}]}}},"u":{"type":"leaf","weight":2,"entries":[{"key":"ferunder","weight":2,"content":"ferunder"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"ferbi","weight":1,"content":"ferbi"}]},"d":{"type":"internal","weight":2,"values":["e","u"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"ferder","weight":2,"content":"ferder"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"ferdum","weight":1,"content":"ferdum"}]}}},"t":{"type":"internal","weight":1,"values":["j","u","a"],"children":{"j":{"type":"leaf","weight":1,"entries":[{"key":"fertjyld","weight":1,"content":"fertjyld"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"fertuorvað","weight":1,"content":"fertuorvað"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"fertaiðn","weight":1,"content":"fertaiðn"}]}}}}},"ð":{"type":"leaf","weight":5,"entries":[{"key":"feð","weight":5,"content":"feð"}]},"k":{"type":"internal","weight":3,"values":["t","s","l"],"children":{"t":{"type":"internal","weight":3,"values":["﷐","e","a"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"fekt","weight":3,"content":"fekt"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"fekteð","weight":2,"content":"fekteð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"fektas","weight":1,"content":"fektas"}]}}},"s":{"type":"leaf","weight":2,"entries":[{"key":"fekst","weight":2,"content":"fekst"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"feklara","weight":1,"content":"feklara"}]}}},"m":{"type":"internal","weight":5,"values":["﷐","t","m"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"fem","weight":5,"content":"fem"}]},"t":{"type":"internal","weight":1,"values":["i","a"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"femti","weight":1,"content":"femti"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"femta","weight":1,"content":"femtą̊"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"femmt","weight":1,"content":"femmt"}]}}},"s":{"type":"internal","weight":5,"values":["t","i","k","u"],"children":{"t":{"type":"internal","weight":5,"values":["e","﷐","a"," ","u"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"fest","weight":2,"content":"fest"}]},"e":{"type":"internal","weight":5,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":5,"entries":[{"key":"festeð","weight":5,"content":"festeð"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"fester","weight":2,"content":"fester"}]}}}," ":{"type":"leaf","weight":1,"entries":[{"key":"fest i","weight":1,"content":"fest i"}]},"a":{"type":"internal","weight":2,"values":["ð","r","﷐","'"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"festar","weight":1,"content":"festår"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"festa","weight":1,"content":"festå"}]},"'":{"type":"leaf","weight":1,"entries":[{"key":"festa'ss","weight":1,"content":"festå'ss"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"festað","weight":2,"content":"festað"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"festuoð","weight":1,"content":"festuoð"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"fesiktut","weight":1,"content":"fesiktut"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"fesk","weight":1,"content":"fesk"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"fesuonneð","weight":1,"content":"fesuonneð"}]}}}}},"u":{"type":"internal","weight":84,"values":["o","k","l","g","n"],"children":{"o":{"type":"internal","weight":84,"values":["r","s","t","l","k"],"children":{"r":{"type":"internal","weight":84,"values":["﷐","t","e","u","m"],"children":{"﷐":{"type":"leaf","weight":84,"entries":[{"key":"fuor","weight":84,"content":"fuor"}]},"t":{"type":"internal","weight":25,"values":["s","f"],"children":{"s":{"type":"leaf","weight":25,"entries":[{"key":"fuortsett","weight":25,"content":"fuortsett"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"fuortfarend","weight":1,"content":"fuortfarend"}]}}},"e":{"type":"internal","weight":4,"values":["l"],"children":{"l":{"type":"internal","weight":4,"values":["d"],"children":{"d":{"type":"internal","weight":4,"values":["r"],"children":{"r":{"type":"internal","weight":4,"values":["a","e","u"],"children":{"a":{"type":"leaf","weight":4,"entries":[{"key":"fuoreldrar","weight":4,"content":"fuoreldrär"},{"key":"fuoreldra","weight":2,"content":"fuoreldra"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"fuoreldrer","weight":3,"content":"fuoreldrer"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"fuoreldrum","weight":2,"content":"fuoreldrum"}]}}}}}}}}},"u":{"type":"leaf","weight":3,"entries":[{"key":"fuoru","weight":3,"content":"fuoru"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"fuorm","weight":2,"content":"fuorm"}]}}},"s":{"type":"internal","weight":26,"values":["t","s","k"],"children":{"t":{"type":"internal","weight":26,"values":["﷐","a","g","n"],"children":{"﷐":{"type":"leaf","weight":26,"entries":[{"key":"fuost","weight":26,"content":"fuost"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"fuostað","weight":3,"content":"fuostað"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"fuostgaundjin","weight":1,"content":"fuostgaundjin"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"fuostn","weight":1,"content":"fuostn"}]}}},"s":{"type":"leaf","weight":2,"entries":[{"key":"fuosseð","weight":2,"content":"fuosseð"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"fuoskerar","weight":1,"content":"fuoskerär"}]}}},"t":{"type":"internal","weight":15,"values":["u","a","j","l","n","e","d",null],"children":{"u":{"type":"leaf","weight":15,"entries":[{"key":"fuotum","weight":15,"content":"fuotum"}]},"a":{"type":"internal","weight":7,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"fuota","weight":7,"content":"fuota"}]},"r":{"type":"leaf","weight":4,"entries":[{"key":"fuotar","weight":4,"content":"fuotär"}]}}},"j":{"type":"leaf","weight":3,"entries":[{"key":"fuotjeð","weight":3,"content":"fuotjeð"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"fuotlos","weight":2,"content":"fuotlos"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"fuotn","weight":2,"content":"fuotn"}]},"e":{"type":"internal","weight":1,"values":["m","n"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"fuotem","weight":1,"content":"fuotem"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"fuotendam","weight":1,"content":"fuotendam"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"fuot","weight":1,"content":"fuot"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"fuotdieln","weight":1,"content":"fuotdieln"}]}}},"l":{"type":"internal","weight":5,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"fuol","weight":5,"content":"fuol"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"fuola","weight":1,"content":"fuola"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"fuoler","weight":1,"content":"fuoler"}]}}},"k":{"type":"internal","weight":3,"values":["s","﷐"],"children":{"s":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["a"],"children":{"a":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["j"],"children":{"j":{"type":"internal","weight":3,"values":["i","e"],"children":{"i":{"type":"leaf","weight":3,"entries":[{"key":"fuokstattjin","weight":3,"content":"fuokstattjin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"fuokstattjem","weight":1,"content":"fuokstattjem"}]}}}}}}}}}}}}},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"fuok","weight":3,"content":"fuok"}]}}}}},"k":{"type":"leaf","weight":9,"entries":[{"key":"fuku","weight":9,"content":"fuku"}]},"l":{"type":"internal","weight":7,"values":["l"],"children":{"l":{"type":"internal","weight":7,"values":["﷐","t","a","e","u"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"full","weight":7,"content":"full"}]},"t":{"type":"leaf","weight":6,"entries":[{"key":"fullt","weight":6,"content":"fullt"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"fullan","weight":1,"content":"fullan"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"fuller","weight":1,"content":"fuller"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"fullu","weight":1,"content":"fullu"}]}}}}},"g":{"type":"internal","weight":7,"values":["e","l"],"children":{"e":{"type":"internal","weight":7,"values":["l"],"children":{"l":{"type":"internal","weight":7,"values":["﷐","b","n"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"fugel","weight":7,"content":"fugel"}]},"b":{"type":"leaf","weight":2,"entries":[{"key":"fugelbu","weight":2,"content":"fugelbu"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"fugeln","weight":2,"content":"fugeln"}]}}}}},"l":{"type":"internal","weight":5,"values":["a","e"],"children":{"a":{"type":"leaf","weight":5,"entries":[{"key":"fuglar","weight":5,"content":"fuglär"},{"key":"fugla","weight":1,"content":"fugla"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"fugler","weight":1,"content":"fugler"}]}}}}},"n":{"type":"internal","weight":5,"values":["n","d","g"],"children":{"n":{"type":"internal","weight":5,"values":["d","e"],"children":{"d":{"type":"internal","weight":5,"values":["i"],"children":{"i":{"type":"internal","weight":5,"values":["r"],"children":{"r":{"type":"internal","weight":5,"values":["e","a","s"],"children":{"a":{"type":"leaf","weight":4,"entries":[{"key":"funndira","weight":4,"content":"funndira"}]},"e":{"type":"leaf","weight":5,"entries":[{"key":"funndireð","weight":5,"content":"funndireð"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"funndirsammer","weight":1,"content":"funndirsammer"}]}}}}}}},"e":{"type":"leaf","weight":4,"entries":[{"key":"funneð","weight":4,"content":"funneð"}]}}},"d":{"type":"leaf","weight":2,"entries":[{"key":"fundirsam","weight":2,"content":"fundirsam"}]},"g":{"type":"leaf","weight":2,"entries":[{"key":"funggirer","weight":2,"content":"funggirer"}]}}}}},"i":{"type":"internal","weight":64,"values":["k","n","u","r","l","e","s","b"],"children":{"k":{"type":"internal","weight":64,"values":["k","s"],"children":{"k":{"type":"internal","weight":64,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":64,"entries":[{"key":"fikk","weight":64,"content":"fikk"}]},"u":{"type":"leaf","weight":14,"entries":[{"key":"fikkun","weight":14,"content":"fikkun"},{"key":"fikku","weight":5,"content":"fikku"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"fikst","weight":1,"content":"fikst"}]}}},"n":{"type":"internal","weight":17,"values":["g","n","t","a","e",null],"children":{"g":{"type":"internal","weight":17,"values":["g"],"children":{"g":{"type":"internal","weight":17,"values":["﷐","r","e"],"children":{"﷐":{"type":"leaf","weight":17,"entries":[{"key":"fingg","weight":17,"content":"fingg"}]},"r":{"type":"internal","weight":6,"values":["u","e"],"children":{"u":{"type":"leaf","weight":6,"entries":[{"key":"finggrum","weight":6,"content":"finggrum"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"finggreð","weight":2,"content":"finggreð"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"fingger","weight":1,"content":"fingger"}]}}}}},"n":{"type":"internal","weight":14,"values":["g","s","a","l",null],"children":{"g":{"type":"leaf","weight":14,"entries":[{"key":"finngum","weight":14,"content":"finngum"},{"key":"finng","weight":1,"content":"finng"}]},"s":{"type":"leaf","weight":11,"entries":[{"key":"finns","weight":11,"content":"finns"}]},"undefined":{"type":"leaf","weight":7,"entries":[{"key":"finn","weight":7,"content":"finn"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"finnas","weight":2,"content":"finnas"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"finnlassby","weight":2,"content":"Finnlassby"}]}}},"undefined":{"type":"leaf","weight":7,"entries":[{"key":"fin","weight":7,"content":"fin"}]},"t":{"type":"leaf","weight":4,"entries":[{"key":"fint","weight":4,"content":"fint"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"finan","weight":2,"content":"finan"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"finer","weight":1,"content":"finer"}]}}},"u":{"type":"internal","weight":5,"values":["o"],"children":{"o":{"type":"internal","weight":5,"values":["r"],"children":{"r":{"type":"internal","weight":5,"values":["﷐","d","t","u"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"fiuor","weight":5,"content":"fiuor"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"fiuord","weight":1,"content":"fiuord"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"fiuorta","weight":1,"content":"fiuortą̊"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"fiuorum","weight":1,"content":"fiuorum"}]}}}}}}},"r":{"type":"internal","weight":4,"values":["i"],"children":{"i":{"type":"internal","weight":4,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"firi","weight":4,"content":"firi"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"firiað","weight":4,"content":"firiað"}]}}}}},"l":{"type":"internal","weight":3,"values":["﷐","a","u"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"fil","weight":3,"content":"fil"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"fila","weight":1,"content":"fila"}]},"u":{"type":"internal","weight":1,"values":["m","r"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"filum","weight":1,"content":"filum"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"filur","weight":1,"content":"filur"}]}}}}},"e":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["a","e"],"children":{"a":{"type":"internal","weight":3,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"fieta","weight":3,"content":"fieta"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"fietan","weight":1,"content":"fietan"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"fieter","weight":1,"content":"fieter"}]}}}}},"s":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["a","e"],"children":{"a":{"type":"internal","weight":2,"values":["﷐","s"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"fissla","weight":2,"content":"fissla"}]},"s":{"type":"leaf","weight":2,"entries":[{"key":"fisslas","weight":2,"content":"fisslas"}]}}},"e":{"type":"internal","weight":2,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"fissleð","weight":2,"content":"fissleð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"fissler","weight":1,"content":"fissler"}]}}}}}}}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"fibbern","weight":1,"content":"fibbern"}]}}},"r":{"type":"internal","weight":46,"values":["a","o","e","i","u","ð"],"children":{"a":{"type":"internal","weight":46,"values":["﷐","m","t","a","g"],"children":{"﷐":{"type":"leaf","weight":46,"entries":[{"key":"fra","weight":46,"content":"frą̊"},{"key":"fra","weight":44,"content":"frå"}]},"m":{"type":"internal","weight":39,"values":["m","﷐","t","y","a","f","s"],"children":{"m":{"type":"internal","weight":39,"values":["﷐","e","i","l"],"children":{"﷐":{"type":"leaf","weight":39,"entries":[{"key":"framm","weight":39,"content":"framm"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"framme","weight":1,"content":"framme"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"frammin","weight":1,"content":"frammin"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"frammlest","weight":1,"content":"frammlest"}]}}},"﷐":{"type":"leaf","weight":38,"entries":[{"key":"fram","weight":38,"content":"fram"}]},"t":{"type":"leaf","weight":13,"entries":[{"key":"framter","weight":13,"content":"framter"}]},"y":{"type":"leaf","weight":8,"entries":[{"key":"framyvyr","weight":8,"content":"framyvyr"}]},"a":{"type":"internal","weight":8,"values":["﷐","n","ð"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"frama","weight":8,"content":"framą̊"}]},"n":{"type":"internal","weight":2,"values":["a","i"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"framanað","weight":2,"content":"fråmånað"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"framani","weight":2,"content":"fråmåni"}]}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"framað","weight":1,"content":"framað"}]}}},"f":{"type":"internal","weight":3,"values":["u"],"children":{"u":{"type":"internal","weight":3,"values":["o"],"children":{"o":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["u","e"],"children":{"u":{"type":"leaf","weight":3,"entries":[{"key":"framfuotum","weight":3,"content":"framfuotum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"framfuotem","weight":1,"content":"framfuotem"}]}}}}}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"framsaiðun","weight":1,"content":"framsaiðun"}]}}},"t":{"type":"internal","weight":4,"values":["a"],"children":{"a":{"type":"internal","weight":4,"values":["r","﷐","d",null],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"frata","weight":3,"content":"fråtå"}]},"d":{"type":"leaf","weight":2,"entries":[{"key":"fratadraja","weight":2,"content":"fråtådråja"}]},"r":{"type":"leaf","weight":4,"entries":[{"key":"fratar","weight":4,"content":"frätär"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"frata","weight":1,"content":"frätä"}]}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"fraað","weight":1,"content":"fråað"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"fragum","weight":1,"content":"frågum"}]}}},"e":{"type":"internal","weight":16,"values":["k","n","s"],"children":{"k":{"type":"internal","weight":16,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":16,"entries":[{"key":"frek","weight":16,"content":"frek"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"frekt","weight":1,"content":"frekt"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"fren","weight":1,"content":"fren"}]},"s":{"type":"internal","weight":1,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"fres","weight":1,"content":"fręs"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"frest","weight":1,"content":"fręst"}]}}}}},"o":{"type":"internal","weight":20,"values":["m","s","ð"],"children":{"m":{"type":"internal","weight":20,"values":["o"],"children":{"o":{"type":"internal","weight":20,"values":["n"],"children":{"n":{"type":"internal","weight":20,"values":["a","i"],"children":{"a":{"type":"leaf","weight":20,"entries":[{"key":"fromonað","weight":20,"content":"fromonað"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"fromoni","weight":1,"content":"fromoni"}]}}}}}}},"s":{"type":"internal","weight":4,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"fros","weight":4,"content":"fros"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"frostaðglas","weight":1,"content":"frostaðglas"}]}}},"ð":{"type":"internal","weight":3,"values":["a","u"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"froða","weight":3,"content":"froða"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"froðun","weight":1,"content":"froðun"}]}}}}},"i":{"type":"internal","weight":10,"values":["ð","u","a","s"],"children":{"ð":{"type":"internal","weight":10,"values":["a","n","o"],"children":{"a":{"type":"leaf","weight":10,"entries":[{"key":"friðað","weight":10,"content":"friðåð"},{"key":"friða","weight":1,"content":"friðå"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"friðn","weight":2,"content":"friðn"}]},"o":{"type":"leaf","weight":1,"entries":[{"key":"friðoðer","weight":1,"content":"friðoðer"}]}}},"u":{"type":"internal","weight":5,"values":["o"],"children":{"o":{"type":"internal","weight":5,"values":["s"],"children":{"s":{"type":"internal","weight":5,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"friuos","weight":5,"content":"friuos"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"friuosa","weight":1,"content":"friuosa"}]}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"friar","weight":1,"content":"friär"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"frisk","weight":1,"content":"frisk"}]}}},"u":{"type":"internal","weight":3,"values":["t","k","n","s"],"children":{"t":{"type":"leaf","weight":3,"entries":[{"key":"frutt","weight":3,"content":"frutt"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"frukuost","weight":1,"content":"frukuost"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"frunda","weight":1,"content":"frunda"}]},"s":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["ð","n"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"frusið","weight":1,"content":"frusið"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"frusin","weight":1,"content":"frusin"}]}}}}}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"frðiar","weight":1,"content":"frðiär"}]}}},"a":{"type":"internal","weight":41,"values":["r","﷐","s","i","f","n","ð","m","l","t"],"children":{"r":{"type":"internal","weight":41,"values":["﷐","a","u","t","l","i",null],"children":{"﷐":{"type":"leaf","weight":41,"entries":[{"key":"far","weight":41,"content":"far"}]},"a":{"type":"leaf","weight":11,"entries":[{"key":"fara","weight":11,"content":"fårå"}]},"u":{"type":"leaf","weight":6,"entries":[{"key":"farum","weight":6,"content":"farum"}]},"t":{"type":"internal","weight":6,"values":["n","﷐","e"],"children":{"n":{"type":"leaf","weight":6,"entries":[{"key":"fartn","weight":6,"content":"fartn"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"fart","weight":3,"content":"fart"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"fartem","weight":2,"content":"fartem"}]}}},"l":{"type":"internal","weight":4,"values":["l","i"],"children":{"l":{"type":"internal","weight":4,"values":["i"],"children":{"i":{"type":"internal","weight":4,"values":["t","g","n"],"children":{"t":{"type":"leaf","weight":4,"entries":[{"key":"farllit","weight":4,"content":"farllit"}]},"g":{"type":"leaf","weight":3,"entries":[{"key":"farlliger","weight":3,"content":"farlliger"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"farllin","weight":2,"content":"farllin"}]}}}}},"i":{"type":"leaf","weight":4,"entries":[{"key":"farlin","weight":4,"content":"farlin"}]}}},"i":{"type":"leaf","weight":3,"entries":[{"key":"fari","weight":3,"content":"fari"}]},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"far","weight":3,"content":"fą̊r"}]}}},"﷐":{"type":"leaf","weight":41,"entries":[{"key":"fa","weight":41,"content":"fą̊"}]},"s":{"type":"internal","weight":33,"values":["t","s","n"],"children":{"t":{"type":"internal","weight":33,"values":["﷐","k"],"children":{"﷐":{"type":"leaf","weight":33,"entries":[{"key":"fast","weight":33,"content":"fast"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"fastkliemað","weight":1,"content":"fastkliemað"}]}}},"s":{"type":"internal","weight":4,"values":["n"],"children":{"n":{"type":"internal","weight":4,"values":["e","a"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"fassneð","weight":4,"content":"fassneð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"fassnað","weight":1,"content":"fassnað"}]}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"fasn","weight":1,"content":"fasn"}]}}},"i":{"type":"internal","weight":26,"values":["ð","n"],"children":{"ð":{"type":"leaf","weight":26,"entries":[{"key":"faið","weight":26,"content":"faið"},{"key":"faið","weight":1,"content":"fåið"}]},"n":{"type":"internal","weight":5,"values":["g"],"children":{"g":{"type":"internal","weight":5,"values":["e","n","i"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"faingen","weight":5,"content":"faingen"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"faingner","weight":2,"content":"faingner"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"faingin","weight":1,"content":"faingin"}]}}}}}}},"f":{"type":"leaf","weight":15,"entries":[{"key":"fafar","weight":15,"content":"fafar"}]},"n":{"type":"internal","weight":14,"values":["n","t"],"children":{"n":{"type":"internal","weight":14,"values":["﷐","s"],"children":{"﷐":{"type":"leaf","weight":14,"entries":[{"key":"fann","weight":14,"content":"fann"}]},"s":{"type":"leaf","weight":6,"entries":[{"key":"fanns","weight":6,"content":"fanns"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"fanta","weight":1,"content":"fanta"}]}}},"ð":{"type":"leaf","weight":12,"entries":[{"key":"faðer","weight":12,"content":"faðer"}]},"m":{"type":"internal","weight":7,"values":["m","i"],"children":{"m":{"type":"leaf","weight":7,"entries":[{"key":"famm","weight":7,"content":"fåmm"}]},"i":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["j","l"],"children":{"j":{"type":"leaf","weight":1,"entries":[{"key":"familjem","weight":1,"content":"familjem"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"familln","weight":1,"content":"familln"}]}}}}}}},"l":{"type":"leaf","weight":2,"entries":[{"key":"falla","weight":2,"content":"falla"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"fat","weight":1,"content":"fat"}]}}},"l":{"type":"internal","weight":17,"values":["i","o","a","e","y","u"],"children":{"i":{"type":"internal","weight":17,"values":["e","u","n"],"children":{"e":{"type":"internal","weight":17,"values":["r"],"children":{"r":{"type":"internal","weight":17,"values":["﷐","u","e"],"children":{"﷐":{"type":"leaf","weight":17,"entries":[{"key":"flier","weight":17,"content":"flier"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"flierum","weight":3,"content":"flierum"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"flierer","weight":2,"content":"flierer"}]}}}}},"u":{"type":"internal","weight":3,"values":["o"],"children":{"o":{"type":"internal","weight":3,"values":["g"],"children":{"g":{"type":"internal","weight":3,"values":["e","﷐"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"fliuog","weight":2,"content":"fliuog"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"fliuogend","weight":3,"content":"fliuogend"}]}}}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"flineð","weight":1,"content":"flineð"}]}}},"o":{"type":"leaf","weight":16,"entries":[{"key":"flog","weight":16,"content":"flog"}]},"a":{"type":"internal","weight":6,"values":["k","y","ð","t"],"children":{"y":{"type":"leaf","weight":4,"entries":[{"key":"flay","weight":4,"content":"Flåy"}]},"k":{"type":"internal","weight":6,"values":["s"],"children":{"s":{"type":"internal","weight":6,"values":["e","a"],"children":{"e":{"type":"internal","weight":6,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":6,"entries":[{"key":"flakseð","weight":6,"content":"flakseð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"flakser","weight":1,"content":"flakser"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"flaksa","weight":2,"content":"flaksa"}]}}}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"flaðrend","weight":1,"content":"flaðrend"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"flatar","weight":1,"content":"flätär"}]}}},"e":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["a","e"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"flettas","weight":3,"content":"flettas"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"flettes","weight":3,"content":"flettes"}]}}}}}}},"y":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["a","e"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"flytta","weight":3,"content":"flytta"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"flytteð","weight":1,"content":"flytteð"}]}}}}}}},"u":{"type":"internal","weight":1,"values":["e","g"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"flueð","weight":1,"content":"flueð"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"flugum","weight":1,"content":"flugum"}]}}}}},"y":{"type":"internal","weight":16,"values":["g","﷐","e","o","a"],"children":{"g":{"type":"internal","weight":16,"values":["d","t"],"children":{"d":{"type":"leaf","weight":16,"entries":[{"key":"fygd","weight":16,"content":"fygd"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"fygt","weight":3,"content":"fygt"}]}}},"﷐":{"type":"leaf","weight":14,"entries":[{"key":"fy","weight":14,"content":"fy"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"fyer","weight":2,"content":"fyer"}]},"o":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["d","t"],"children":{"d":{"type":"leaf","weight":2,"entries":[{"key":"fyord","weight":2,"content":"fyörd"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"fyort","weight":1,"content":"fyört"}]}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"fya","weight":1,"content":"fya"}]}}},"j":{"type":"internal","weight":4,"values":["a"],"children":{"a":{"type":"internal","weight":4,"values":["l","k"],"children":{"l":{"type":"leaf","weight":4,"entries":[{"key":"fjall","weight":4,"content":"fjäll"}]},"k":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["e","﷐","a"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"fjakseð","weight":1,"content":"fjåkseð"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"fjaks","weight":1,"content":"fjåks"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"fjaksas","weight":1,"content":"fjåksas"}]}}}}}}}}},"n":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["e","﷐","a"],"children":{"e":{"type":"internal","weight":2,"values":["n","﷐","r"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"fnallendes","weight":2,"content":"fnallendes"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"fnalle","weight":1,"content":"fnalle"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"fnaller","weight":1,"content":"fnaller"}]}}},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"fnall","weight":2,"content":"fnall"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"fnalla","weight":1,"content":"fnalla"}]}}}}}}}}}}},"t":{"type":"internal","weight":140,"values":["i","e","u","y","o","a","r","j","w"],"children":{"i":{"type":"internal","weight":140,"values":["l","ð","e","u","t","'","m"],"children":{"l":{"type":"internal","weight":140,"values":["﷐","s"],"children":{"﷐":{"type":"leaf","weight":140,"entries":[{"key":"til","weight":140,"content":"til"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"tilsaggd","weight":1,"content":"tilsaggd"}]}}},"e":{"type":"internal","weight":8,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"tie","weight":8,"content":"tie"}]},"n":{"type":"internal","weight":2,"values":["n","u","a"],"children":{"n":{"type":"internal","weight":2,"values":["a","e","u"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"tiennan","weight":2,"content":"tiennan"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"tienne","weight":2,"content":"tienne"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"tiennu","weight":1,"content":"tiennu"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"tienu","weight":1,"content":"tienu"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"tienam","weight":1,"content":"tienam"}]}}}}},"ð":{"type":"leaf","weight":10,"entries":[{"key":"tiðn","weight":10,"content":"tiðn"},{"key":"tið","weight":1,"content":"tið"}]},"u":{"type":"internal","weight":5,"values":["﷐","o","g","n"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"tiu","weight":5,"content":"tiu"}]},"o":{"type":"internal","weight":4,"values":["g"],"children":{"g":{"type":"internal","weight":4,"values":["a","e"],"children":{"a":{"type":"leaf","weight":4,"entries":[{"key":"tiuoga","weight":4,"content":"tiuoga"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"tiuoger","weight":1,"content":"tiuoger"}]}}}}},"g":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["﷐","f"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"tiugu","weight":1,"content":"tiugu"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"tiugufem","weight":1,"content":"tiugufem"}]}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"tiund","weight":1,"content":"tiund"}]}}},"t":{"type":"leaf","weight":3,"entries":[{"key":"tittera","weight":3,"content":"tittera"}]},"'":{"type":"leaf","weight":2,"entries":[{"key":"ti'tt","weight":2,"content":"ti'tt"}]},"m":{"type":"internal","weight":1,"values":["b"],"children":{"b":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["b"],"children":{"b":{"type":"internal","weight":1,"values":["b"],"children":{"b":{"type":"internal","weight":1,"values":["e","u","a"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"timberkabbe","weight":1,"content":"timberkabbe"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"timberkabbum","weight":1,"content":"timberkabbum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"timberkabba","weight":1,"content":"timberkabba"}]}}}}}}}}}}}}}}}}}}},"e":{"type":"internal","weight":82,"values":["﷐","p","k","g","m","t","n"],"children":{"﷐":{"type":"leaf","weight":82,"entries":[{"key":"te","weight":82,"content":"te"}]},"p":{"type":"internal","weight":10,"values":["p","﷐","t"],"children":{"p":{"type":"leaf","weight":10,"entries":[{"key":"teppt","weight":10,"content":"teppt"},{"key":"tepp","weight":1,"content":"tepp"}]},"﷐":{"type":"leaf","weight":6,"entries":[{"key":"tep","weight":6,"content":"tep"}]},"t":{"type":"internal","weight":4,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"tept","weight":4,"content":"tept"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"teptes","weight":1,"content":"teptes"}]}}}}},"k":{"type":"internal","weight":3,"values":["t","s","n"],"children":{"t":{"type":"internal","weight":3,"values":["n","﷐","e"],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"tektn","weight":3,"content":"tektn"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"tekt","weight":1,"content":"tekt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"tektem","weight":1,"content":"tektem"}]}}},"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"tekstn","weight":2,"content":"tekstn"},{"key":"tekst","weight":1,"content":"tekst"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"teknitjin","weight":1,"content":"teknitjin"}]}}},"g":{"type":"internal","weight":3,"values":["g","﷐"],"children":{"g":{"type":"internal","weight":3,"values":["u","﷐"," ","a"],"children":{"u":{"type":"internal","weight":3,"values":["m"],"children":{"m":{"type":"leaf","weight":3,"entries":[{"key":"teggummi","weight":3,"content":"teggummi"},{"key":"teggum","weight":1,"content":"teggum"}]}}},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"tegg","weight":1,"content":"tegg"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"tegg og teg","weight":1,"content":"tegg og teg"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"tegga","weight":1,"content":"tegga"}]}}},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"teg","weight":1,"content":"teg"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"temblem","weight":1,"content":"temblem"}]},"t":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["e","j","b"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"tettje","weight":1,"content":"tettje"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"tettjjakku","weight":1,"content":"tettjjäkku"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"tettjbryokum","weight":1,"content":"tettjbryökum"}]}}}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"tennar","weight":1,"content":"tennär"}]}}},"u":{"type":"internal","weight":53,"values":["o","l","n","r","d","g","s","p"],"children":{"o":{"type":"internal","weight":53,"values":["v","g","m","k","r","l","s",null],"children":{"g":{"type":"internal","weight":52,"values":["﷐","i","u"],"children":{"﷐":{"type":"leaf","weight":52,"entries":[{"key":"tuog","weight":52,"content":"tuog"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"tuogið","weight":1,"content":"tuogið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"tuogum","weight":1,"content":"tuogum"}]}}},"v":{"type":"leaf","weight":53,"entries":[{"key":"tuova","weight":53,"content":"tuova"}]},"m":{"type":"internal","weight":4,"values":["t"],"children":{"t":{"type":"internal","weight":4,"values":["﷐","k"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"tuomt","weight":4,"content":"tuomt"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"tuomtkall","weight":1,"content":"tuomtkall"}]}}}}},"k":{"type":"internal","weight":4,"values":["u","a","e",null],"children":{"u":{"type":"internal","weight":4,"values":["t","g","n"],"children":{"t":{"type":"leaf","weight":4,"entries":[{"key":"tuokut","weight":4,"content":"tuokut"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"tuokug","weight":1,"content":"tuokug"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"tuokun","weight":1,"content":"tuokun"}]}}},"a":{"type":"leaf","weight":3,"entries":[{"key":"tuokas","weight":3,"content":"tuokas"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"tuokes","weight":2,"content":"tuokes"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tuok","weight":1,"content":"tuok"}]}}},"r":{"type":"internal","weight":3,"values":["r","a","n"],"children":{"r":{"type":"internal","weight":3,"values":["k","﷐","e","t"],"children":{"k":{"type":"leaf","weight":3,"entries":[{"key":"tuorrklauta","weight":3,"content":"tuorrklauta"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"tuorr","weight":2,"content":"tuorr"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"tuorrer","weight":2,"content":"tuorrer"}]},"t":{"type":"internal","weight":2,"values":["o",null],"children":{"o":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["y"],"children":{"y":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"internal","weight":1,"values":["w"],"children":{"w":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["a","ð"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"tuorrtolltyorwiarwraið","weight":1,"content":"tuorrtolltyörwiårwraið"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"tuorrtolltyorwiðarwaiður","weight":1,"content":"tuorrtolltyörwiðårwaiður"}]}}}}}}}}}}}}}}}}}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"tuorrt","weight":2,"content":"tuorrt"}]}}}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"tuoras","weight":2,"content":"tuorås"}]},"n":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"tuorne","weight":2,"content":"tuornę"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"tuorneð","weight":2,"content":"tuorneð"}]}}}}}}},"l":{"type":"leaf","weight":3,"entries":[{"key":"tuold","weight":3,"content":"tuold"}]},"s":{"type":"internal","weight":2,"values":["﷐","k","t"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"tuos","weight":2,"content":"tuos"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"tuosk","weight":1,"content":"tuosk"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"tuost","weight":1,"content":"tuost"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"tuo","weight":2,"content":"tųo"}]}}},"l":{"type":"internal","weight":16,"values":["t","l"],"children":{"t":{"type":"internal","weight":16,"values":["a","u"],"children":{"a":{"type":"leaf","weight":16,"entries":[{"key":"tulta","weight":16,"content":"tulta"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"tultun","weight":2,"content":"tultun"}]}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"tullan","weight":1,"content":"tullan"}]}}},"n":{"type":"internal","weight":7,"values":["g","d","n"],"children":{"g":{"type":"internal","weight":7,"values":["g","n"],"children":{"g":{"type":"internal","weight":7,"values":["u","l","i","t",null],"children":{"u":{"type":"internal","weight":7,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"tunggu","weight":7,"content":"tunggu"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"tunggun","weight":1,"content":"tunggun"}]}}},"l":{"type":"leaf","weight":4,"entries":[{"key":"tunggleð","weight":4,"content":"tunggleð"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tungg","weight":1,"content":"tungg"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"tunggin","weight":1,"content":"tunggin"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"tunggt","weight":1,"content":"tunggt"}]}}},"n":{"type":"internal","weight":3,"values":["e","a"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"tungner","weight":3,"content":"tungner"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"tungna","weight":1,"content":"tungna"}]}}}}},"d":{"type":"leaf","weight":2,"entries":[{"key":"tundjin","weight":2,"content":"tundjin"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"tunnest","weight":1,"content":"tunnest"}]}}},"r":{"type":"internal","weight":4,"values":["﷐","i","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"tur","weight":4,"content":"tur"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"turist","weight":2,"content":"turist"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"turem","weight":1,"content":"turem"}]}}},"g":{"type":"leaf","weight":1,"entries":[{"key":"tugar","weight":1,"content":"tugär"}]},"d":{"type":"leaf","weight":2,"entries":[{"key":"tuddjeð","weight":2,"content":"tuddjeð"}]},"s":{"type":"internal","weight":1,"values":["n","s"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"tusn","weight":1,"content":"tusn"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"tussem","weight":1,"content":"tussem"}]}}},"p":{"type":"leaf","weight":1,"entries":[{"key":"tuppstjinneð","weight":1,"content":"tuppstjinneð"}]}}},"y":{"type":"internal","weight":40,"values":["s","k","o","t","l","'","d","e"],"children":{"s":{"type":"internal","weight":40,"values":["t","k"],"children":{"t":{"type":"internal","weight":40,"values":["e","﷐"],"children":{"e":{"type":"internal","weight":40,"values":["r"],"children":{"r":{"type":"internal","weight":40,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":40,"entries":[{"key":"tyster","weight":40,"content":"tyster"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"tystera","weight":2,"content":"tystera"}]}}}}},"﷐":{"type":"leaf","weight":35,"entries":[{"key":"tyst","weight":35,"content":"tyst"}]}}},"k":{"type":"internal","weight":3,"values":["u","a"],"children":{"u":{"type":"leaf","weight":3,"entries":[{"key":"tyskum","weight":3,"content":"tyskum"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"tyskar","weight":3,"content":"tyskär"},{"key":"tyska","weight":3,"content":"tyska"}]}}}}},"k":{"type":"leaf","weight":15,"entries":[{"key":"tykkt","weight":15,"content":"tykkt"}]},"t":{"type":"internal","weight":6,"values":["t"],"children":{"t":{"type":"internal","weight":6,"values":["j","k","a"],"children":{"j":{"type":"internal","weight":6,"values":["e","u","a",null],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"tyttjer","weight":6,"content":"tyttjer"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"tyttjum","weight":1,"content":"tyttjum"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tyttj","weight":1,"content":"tyttj"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"tyttja","weight":1,"content":"tyttja"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"tyttkall","weight":1,"content":"tyttkall"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"tytta","weight":1,"content":"tytta"}]}}}}},"o":{"type":"internal","weight":7,"values":["r","ð","l"],"children":{"r":{"type":"internal","weight":7,"values":["e","w"],"children":{"e":{"type":"leaf","weight":7,"entries":[{"key":"tyoreð","weight":7,"content":"työreð"}]},"w":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["ð"],"children":{"ð":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"tyorwiðim","weight":1,"content":"työrwiðim"},{"key":"tyorwiði","weight":1,"content":"työrwiði"}]}}}}}}}}},"ð":{"type":"internal","weight":6,"values":["u","r"],"children":{"u":{"type":"internal","weight":6,"values":["r"],"children":{"r":{"type":"leaf","weight":6,"entries":[{"key":"tyoðurn","weight":6,"content":"työðurn"},{"key":"tyoður","weight":1,"content":"työður"}]}}},"r":{"type":"internal","weight":1,"values":["u","e"],"children":{"u":{"type":"leaf","weight":1,"entries":[{"key":"tyoðrum","weight":1,"content":"työðrum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"tyoðrem","weight":1,"content":"työðrem"}]}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"tyolbun","weight":1,"content":"työlbun"}]}}},"l":{"type":"internal","weight":4,"values":["a","l"],"children":{"a":{"type":"leaf","weight":4,"entries":[{"key":"tyla","weight":4,"content":"tyla"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"tylld","weight":2,"content":"tylld"}]}}},"'":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"ty'lla","weight":1,"content":"ty'lla"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"ty'ller","weight":1,"content":"ty'ller"}]}}}}}}},"d":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["g","n"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"tydlig","weight":1,"content":"tydlig"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"tydlin","weight":1,"content":"tydlin"}]}}}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"tyeð","weight":1,"content":"tyeð"}]}}},"o":{"type":"internal","weight":25,"values":["k","l","r","g","n","m"],"children":{"k":{"type":"internal","weight":25,"values":["k"],"children":{"k":{"type":"internal","weight":25,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":25,"entries":[{"key":"tokk","weight":25,"content":"tokk"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"tokkað","weight":1,"content":"tokkað"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"tokkeð","weight":1,"content":"tokkeð"}]}}}}},"l":{"type":"internal","weight":10,"values":["l","u","p"],"children":{"l":{"type":"internal","weight":10,"values":["e","n","t","k","u",null],"children":{"e":{"type":"leaf","weight":10,"entries":[{"key":"tollem","weight":10,"content":"tollem"},{"key":"tolle","weight":8,"content":"tolle"}]},"n":{"type":"leaf","weight":8,"entries":[{"key":"tolln","weight":8,"content":"tolln"}]},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"toll","weight":4,"content":"toll"}]},"t":{"type":"internal","weight":3,"values":["u"],"children":{"u":{"type":"internal","weight":3,"values":["l"],"children":{"l":{"type":"internal","weight":3,"values":["l"],"children":{"l":{"type":"internal","weight":3,"values":["a","﷐"],"children":{"a":{"type":"internal","weight":3,"values":["m","n"],"children":{"m":{"type":"leaf","weight":3,"entries":[{"key":"tolltullam","weight":3,"content":"tolltullam"},{"key":"tolltullam","weight":1,"content":"Tolltullam"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"tolltullan","weight":1,"content":"tolltullan"}]}}},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"tolltull","weight":2,"content":"tolltull"}]}}}}}}}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"tollum","weight":1,"content":"tollum"}]},"k":{"type":"internal","weight":2,"values":["w"],"children":{"w":{"type":"internal","weight":2,"values":["i"],"children":{"i":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["a","u"],"children":{"a":{"type":"internal","weight":2,"values":["﷐","r",null],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"tollkwista","weight":2,"content":"tollkwistą"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"tollkwistar","weight":1,"content":"tollkwistär"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tollkwista","weight":1,"content":"tollkwista"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"tollkwistum","weight":1,"content":"tollkwistum"}]}}}}}}}}}}}}},"u":{"type":"leaf","weight":4,"entries":[{"key":"toluger","weight":4,"content":"toluger"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"tolpt","weight":1,"content":"tolpt"}]}}},"r":{"type":"internal","weight":4,"values":["n","k"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"torn","weight":4,"content":"torn"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"torkeð","weight":1,"content":"torkeð"}]}}},"g":{"type":"leaf","weight":3,"entries":[{"key":"togg","weight":3,"content":"togg"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"toner","weight":2,"content":"töner"},{"key":"ton","weight":1,"content":"ton"}]},"m":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"tom","weight":1,"content":"tom"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"tomer","weight":1,"content":"tomer"}]}}}}},"a":{"type":"internal","weight":23,"values":["s","k","i","g","u","r","p","e","t","v","n","l"],"children":{"s":{"type":"internal","weight":23,"values":["t","s"],"children":{"t":{"type":"leaf","weight":23,"entries":[{"key":"tast","weight":23,"content":"tast"}]},"s":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["ð","n"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"tasseð","weight":1,"content":"tasseð"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"tassend","weight":1,"content":"tassend"}]}}}}}}},"k":{"type":"internal","weight":20,"values":["k"],"children":{"k":{"type":"internal","weight":20,"values":["u","t","a","l","s","j"],"children":{"u":{"type":"internal","weight":20,"values":["r","m"],"children":{"r":{"type":"leaf","weight":20,"entries":[{"key":"takkur","weight":20,"content":"takkur"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"takkum","weight":2,"content":"takkum"}]}}},"t":{"type":"internal","weight":4,"values":["j"],"children":{"j":{"type":"internal","weight":4,"values":["y","i"],"children":{"y":{"type":"leaf","weight":4,"entries":[{"key":"takktjyoteð","weight":4,"content":"takktjyöteð"}]},"i":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["n","a",null],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"takktjittn","weight":3,"content":"takktjittn"}]},"a":{"type":"internal","weight":3,"values":["m","n"],"children":{"m":{"type":"leaf","weight":3,"entries":[{"key":"takktjittam","weight":3,"content":"takktjittam"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"takktjittan","weight":2,"content":"takktjittan"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"takktjitt","weight":2,"content":"takktjitt"}]}}}}}}}}}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"takka","weight":2,"content":"takka"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"takkluptn","weight":1,"content":"takkluptn"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"takkstjinne","weight":1,"content":"takkstjinnę"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"takkjaktn","weight":1,"content":"takkjaktn"}]}}}}},"i":{"type":"internal","weight":17,"values":["n","ð","m","a"],"children":{"n":{"type":"internal","weight":17,"values":["k","t"],"children":{"k":{"type":"leaf","weight":17,"entries":[{"key":"tainkt","weight":17,"content":"tainkt"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"taintj","weight":1,"content":"taintj"}]}}},"m":{"type":"internal","weight":10,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"taim","weight":10,"content":"taim"}]},"a":{"type":"leaf","weight":6,"entries":[{"key":"taima","weight":6,"content":"taima"}]}}},"ð":{"type":"leaf","weight":13,"entries":[{"key":"taið","weight":13,"content":"taið"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"taia","weight":1,"content":"taia"}]}}},"g":{"type":"internal","weight":13,"values":["﷐","a","u","g","i"],"children":{"﷐":{"type":"leaf","weight":13,"entries":[{"key":"tag","weight":13,"content":"tag"}]},"a":{"type":"leaf","weight":6,"entries":[{"key":"taga","weight":6,"content":"tågå"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"tagum","weight":1,"content":"tagum"}]},"g":{"type":"internal","weight":1,"values":["d","t"],"children":{"d":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"taggd","weight":1,"content":"taggd"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"taggde","weight":1,"content":"taggde"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"taggt","weight":1,"content":"taggt"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"tagið","weight":1,"content":"tagið"}]}}},"u":{"type":"internal","weight":7,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"tau","weight":7,"content":"tau"}]},"n":{"type":"internal","weight":1,"values":["g","k"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"taungna","weight":1,"content":"taungna"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"taunke","weight":1,"content":"taunke"}]}}}}},"r":{"type":"internal","weight":6,"values":["﷐","a","u"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"tar","weight":6,"content":"tar"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"tarar","weight":4,"content":"tårär"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"tarum","weight":1,"content":"tårum"}]}}},"e":{"type":"leaf","weight":3,"entries":[{"key":"taeð","weight":3,"content":"taeð"}]},"t":{"type":"internal","weight":2,"values":["j","u"],"children":{"j":{"type":"leaf","weight":2,"entries":[{"key":"tatjeð","weight":2,"content":"tatjeð"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"tatuira","weight":1,"content":"tatuira"}]}}},"v":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["i"],"children":{"i":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["d","g"],"children":{"d":{"type":"leaf","weight":2,"entries":[{"key":"tavlindje","weight":2,"content":"tävlindje"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"tavlingger","weight":1,"content":"tävlingger"}]}}}}}}}}},"n":{"type":"internal","weight":2,"values":["n","﷐","u"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"tannum","weight":2,"content":"tannum"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"tan","weight":1,"content":"tån"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"tanun","weight":1,"content":"tanun"}]}}},"p":{"type":"internal","weight":4,"values":["p"],"children":{"p":{"type":"internal","weight":4,"values":["e","﷐","a"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"tappeð","weight":4,"content":"tappeð"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"tapp","weight":1,"content":"tapp"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"tappa","weight":1,"content":"tappa"}]}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"talas","weight":1,"content":"tålås"}]}}},"r":{"type":"internal","weight":21,"values":["a","u","i","e","o","y"],"children":{"a":{"type":"internal","weight":21,"values":["i","t","m","u","'","y","n",null],"children":{"i":{"type":"internal","weight":21,"values":["r","n","m","t","v",null],"children":{"r":{"type":"leaf","weight":21,"entries":[{"key":"trair","weight":21,"content":"trair"}]},"n":{"type":"internal","weight":10,"values":["e","u"],"children":{"e":{"type":"leaf","weight":10,"entries":[{"key":"traine","weight":10,"content":"traine"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"trainu","weight":3,"content":"trainu"}]}}},"m":{"type":"leaf","weight":9,"entries":[{"key":"traimm","weight":9,"content":"traimm"}]},"undefined":{"type":"leaf","weight":5,"entries":[{"key":"trai","weight":5,"content":"trai"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"traitt","weight":2,"content":"traitt"}]},"v":{"type":"leaf","weight":1,"entries":[{"key":"traivs","weight":1,"content":"traivs"}]}}},"t":{"type":"internal","weight":12,"values":["t"],"children":{"t":{"type":"internal","weight":12,"values":["﷐","e","a"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"tratt","weight":12,"content":"trätt"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"tratter","weight":3,"content":"trätter"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"trattan","weight":1,"content":"trättan"}]}}}}},"m":{"type":"internal","weight":5,"values":["p"],"children":{"p":{"type":"internal","weight":5,"values":["u","a","e"],"children":{"u":{"type":"leaf","weight":5,"entries":[{"key":"trampur","weight":5,"content":"trampur"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"trampa","weight":1,"content":"trampa"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"trampeð","weight":1,"content":"trampeð"}]}}}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"tra","weight":2,"content":"trå"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"traum","weight":2,"content":"tråum"}]},"'":{"type":"leaf","weight":1,"entries":[{"key":"tra'ttneð","weight":1,"content":"trä'ttneð"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"tray","weight":1,"content":"tråy"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"transtrand","weight":1,"content":"Transtrand"}]}}},"u":{"type":"internal","weight":20,"values":["o"],"children":{"o":{"type":"internal","weight":20,"values":["r","d","l","e"],"children":{"r":{"type":"leaf","weight":20,"entries":[{"key":"truor","weight":20,"content":"truor"}]},"d":{"type":"leaf","weight":2,"entries":[{"key":"truodde","weight":2,"content":"truodde"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"truoligen","weight":2,"content":"truoligen"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"truoeð","weight":1,"content":"truoeð"}]}}}}},"i":{"type":"internal","weight":5,"values":["﷐","m","u","v","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"tri","weight":5,"content":"tri"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"trimm","weight":1,"content":"trimm"},{"key":"trim","weight":1,"content":"trim"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"triuo","weight":1,"content":"triuo"}]},"v":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["g","n"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"trivlig","weight":1,"content":"trivlig"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"trivlin","weight":1,"content":"trivlin"}]}}}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"trievs","weight":1,"content":"trievs"}]}}},"e":{"type":"internal","weight":2,"values":["n","t"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"trena","weight":2,"content":"trena"}]},"t":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["i","u"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"tretti","weight":1,"content":"tretti"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"trettund","weight":1,"content":"trettund"}]}}}}}}},"o":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"troðað","weight":2,"content":"troðäð"},{"key":"troðað","weight":1,"content":"troðåð"}]}}}}}}},"y":{"type":"internal","weight":1,"values":["l","s","t"],"children":{"l":{"type":"leaf","weight":1,"entries":[{"key":"tryllkallkull","weight":1,"content":"tryllkallkull"}]},"s":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["a","u"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"trysklar","weight":1,"content":"trysklär"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"trysklum","weight":1,"content":"trysklum"}]}}}}}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"tryttj","weight":1,"content":"tryttj"}]}}}}},"j":{"type":"internal","weight":19,"values":["a","y","i"],"children":{"a":{"type":"internal","weight":19,"values":["r","p","l"],"children":{"r":{"type":"internal","weight":19,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":19,"entries":[{"key":"tjar","weight":19,"content":"tjär"}]},"e":{"type":"leaf","weight":4,"entries":[{"key":"tjare","weight":4,"content":"tjäre"}]}}},"p":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["a","u",null],"children":{"a":{"type":"internal","weight":2,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"tjapta","weight":2,"content":"tjäpta"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"tjaptar","weight":2,"content":"tjäptär"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tjapt","weight":1,"content":"tjäpt"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"tjaptum","weight":1,"content":"tjäptum"}]}}}}},"l":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["a","g","n","t",null],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"tjalleram","weight":2,"content":"tjälleram"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"tjallerglasi","weight":1,"content":"tjällerglasį"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"tjallern","weight":1,"content":"tjällern"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tjaller","weight":1,"content":"tjäller"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"tjallertatjeð","weight":1,"content":"tjällertatjeð"}]}}}}}}}}}}},"i":{"type":"internal","weight":9,"values":["k","p","l","t","r","s"],"children":{"k":{"type":"internal","weight":9,"values":["k","e"],"children":{"k":{"type":"internal","weight":9,"values":["u","a","e",null],"children":{"u":{"type":"leaf","weight":9,"entries":[{"key":"tjikkum","weight":9,"content":"tjikkum"}]},"a":{"type":"internal","weight":5,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"tjikka","weight":5,"content":"tjikka"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"tjikkar","weight":1,"content":"tjikkär"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tjikk","weight":1,"content":"tjikk"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"tjikke","weight":1,"content":"tjikke"}]}}},"e":{"type":"internal","weight":2,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"tjikeð","weight":2,"content":"tjikeð"}]},"r":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["y"],"children":{"y":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"tjikersykte","weight":1,"content":"tjikersykte"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"tjikersykteð","weight":1,"content":"tjikersykteð"}]}}}}}}}}}}}}}}}}},"p":{"type":"leaf","weight":3,"entries":[{"key":"tjipptes","weight":3,"content":"tjipptes"}]},"l":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"tjilu","weight":2,"content":"tjilu"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"tjilumieter","weight":2,"content":"tjilumieter"}]}}}}},"t":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["﷐","a","s"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"tjitt","weight":2,"content":"tjitt"}]},"a":{"type":"internal","weight":1,"values":["m","n"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"tjittam","weight":1,"content":"tjittam"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"tjittan","weight":1,"content":"tjittan"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"tjittstainggsleð","weight":1,"content":"tjittstainggsleð"}]}}}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"tjirurg","weight":1,"content":"tjirurg"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"tjisslas","weight":1,"content":"tjisslas"}]}}},"y":{"type":"internal","weight":11,"values":["o","n","r","m"],"children":{"o":{"type":"internal","weight":11,"values":["t","l","r","p","k"],"children":{"t":{"type":"internal","weight":11,"values":["e","m","j"],"children":{"e":{"type":"leaf","weight":11,"entries":[{"key":"tjyoteð","weight":11,"content":"tjyöteð"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"tjyotmaungg","weight":2,"content":"tjyötmaungg"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"tjyotji","weight":1,"content":"tjyötjį"}]}}},"l":{"type":"internal","weight":4,"values":["b"],"children":{"b":{"type":"internal","weight":4,"values":["u"],"children":{"u":{"type":"internal","weight":4,"values":["ð"],"children":{"ð":{"type":"internal","weight":4,"values":["n","s","e",null],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"tjyolbuðn","weight":4,"content":"tjyölbuðn"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"tjyolbuðsweddjin","weight":1,"content":"tjyölbuðsweddjin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"tjyolbuðe","weight":1,"content":"tjyölbuðe"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tjyolbuð","weight":1,"content":"tjyölbuð"}]}}}}}}}}},"r":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["j",null],"children":{"j":{"type":"internal","weight":3,"values":["b"],"children":{"b":{"type":"internal","weight":3,"values":["y"],"children":{"y":{"type":"internal","weight":3,"values":["n","m"],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"tjyortjbynn","weight":3,"content":"Tjyörtjbynn"}]},"m":{"type":"leaf","weight":3,"entries":[{"key":"tjyortjbymm","weight":3,"content":"Tjyörtjbymm"}]}}}}}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"tjyort","weight":1,"content":"tjyört"}]}}}}},"p":{"type":"leaf","weight":1,"entries":[{"key":"tjyopt","weight":1,"content":"tjyöpt"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"tjyoksbuord","weight":1,"content":"tjyöksbuord"}]}}},"n":{"type":"leaf","weight":4,"entries":[{"key":"tjyner","weight":4,"content":"tjyner"}]},"r":{"type":"internal","weight":2,"values":["e","﷐","f"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"tjyre","weight":2,"content":"tjyre"},{"key":"tjyre","weight":1,"content":"tjyrę"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"tjyr","weight":1,"content":"tjyr"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"tjyrferdum","weight":1,"content":"tjyrferdum"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"tjymm","weight":1,"content":"tjymm"}]}}}}},"w":{"type":"internal","weight":10,"values":["e","a","i"],"children":{"e":{"type":"internal","weight":10,"values":["r","s","m"],"children":{"r":{"type":"internal","weight":10,"values":["﷐","s","w","a","u","k","r"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"twer","weight":10,"content":"twer"}]},"s":{"type":"internal","weight":5,"values":["o","p","t","a","l"],"children":{"o":{"type":"internal","weight":5,"values":["m"],"children":{"m":{"type":"internal","weight":5,"values":["n","m"],"children":{"n":{"type":"leaf","weight":5,"entries":[{"key":"twersomneð","weight":5,"content":"twersomneð"}]},"m":{"type":"leaf","weight":3,"entries":[{"key":"twersommneð","weight":3,"content":"twersommneð"}]}}}}},"p":{"type":"leaf","weight":1,"entries":[{"key":"twerspuord","weight":1,"content":"twerspuord"}]},"t":{"type":"internal","weight":1,"values":["a","i"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"twersta'neð","weight":1,"content":"twerstą'neð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"twerstierd","weight":1,"content":"twerstierd"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"twersaker","weight":1,"content":"twersäker"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"twerslaungg","weight":1,"content":"twerslaungg"}]}}},"w":{"type":"internal","weight":5,"values":["a","e"],"children":{"a":{"type":"internal","weight":5,"values":["k","r"],"children":{"k":{"type":"leaf","weight":5,"entries":[{"key":"twerwakkneð","weight":5,"content":"twerwakkneð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"twerwart","weight":1,"content":"twerwart"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"twerwend","weight":1,"content":"twerwend"}]}}},"a":{"type":"internal","weight":1,"values":["k","s"],"children":{"k":{"type":"leaf","weight":1,"entries":[{"key":"twerakruoka","weight":1,"content":"tweråkruoka"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"tweraswaingg","weight":1,"content":"tweråswaingg"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"twerunggruger","weight":1,"content":"twerunggruger"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"twerkam","weight":1,"content":"twerkam"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"twerraitt","weight":1,"content":"twerraitt"}]}}},"s":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"twesk","weight":1,"content":"twesk"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"tweska","weight":1,"content":"tweska"}]}}}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"twemm","weight":1,"content":"twemm"}]}}},"a":{"type":"internal","weight":5,"values":["r","s","d"," "],"children":{"r":{"type":"leaf","weight":5,"entries":[{"key":"twar","weight":5,"content":"twär"}]},"s":{"type":"leaf","weight":5,"entries":[{"key":"twask","weight":5,"content":"twask"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"twadd","weight":1,"content":"twädd"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"twa undrað","weight":1,"content":"twå undrað"}]}}},"i":{"type":"internal","weight":5,"values":["s","k","n"],"children":{"s":{"type":"internal","weight":5,"values":["a","e"],"children":{"a":{"type":"internal","weight":5,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"twisa","weight":5,"content":"twisä"}]},"ð":{"type":"leaf","weight":4,"entries":[{"key":"twisað","weight":4,"content":"twisäð"}]}}},"e":{"type":"leaf","weight":3,"entries":[{"key":"twiseð","weight":3,"content":"twiseð"}]}}},"k":{"type":"leaf","weight":2,"entries":[{"key":"twiksam","weight":2,"content":"twiksam"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"twinggeð","weight":1,"content":"twinggeð"}]}}}}}}},"b":{"type":"internal","weight":121,"values":["a","y","o","i","e","r","j","u","l"],"children":{"a":{"type":"internal","weight":121,"values":["r","ð","i","n","k","s","a"],"children":{"r":{"type":"internal","weight":121,"values":["﷐","n","a"],"children":{"﷐":{"type":"leaf","weight":121,"entries":[{"key":"bar","weight":121,"content":"bar"}]},"n":{"type":"leaf","weight":8,"entries":[{"key":"barnal","weight":8,"content":"bårną̊l"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"bara","weight":3,"content":"bara"}]}}},"i":{"type":"internal","weight":9,"values":["d","ð","t"],"children":{"d":{"type":"internal","weight":9,"values":["d"],"children":{"d":{"type":"internal","weight":9,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"baidd","weight":9,"content":"baidd"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"baidde","weight":1,"content":"baidde"}]}}}}},"ð":{"type":"internal","weight":6,"values":["a","e","i"," "],"children":{"a":{"type":"internal","weight":6,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"baiða","weight":6,"content":"baiða"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"baiðað","weight":1,"content":"baiðað"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"baiðe","weight":1,"content":"baiðe"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"baiðið","weight":1,"content":"baiðið"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"baið lite","weight":1,"content":"baið lite"}]}}},"t":{"type":"internal","weight":3,"values":["t","﷐","a"],"children":{"t":{"type":"leaf","weight":3,"entries":[{"key":"baitt","weight":3,"content":"baitt"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"bait","weight":2,"content":"bait"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"baitas","weight":2,"content":"baitas"}]}}}}},"ð":{"type":"internal","weight":15,"values":["e","u","a","r",null],"children":{"e":{"type":"leaf","weight":15,"entries":[{"key":"baðer","weight":15,"content":"båðer"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"baðum","weight":3,"content":"båðum"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"bað","weight":1,"content":"båð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"baða","weight":1,"content":"baða"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"baðruomeð","weight":1,"content":"baðruomeð"}]}}},"n":{"type":"internal","weight":3,"values":["d"],"children":{"d":{"type":"leaf","weight":3,"entries":[{"key":"bandeð","weight":3,"content":"bandeð"},{"key":"band","weight":2,"content":"band"}]}}},"k":{"type":"internal","weight":1,"values":["a","k","t"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"bakað","weight":1,"content":"bäkäð"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"bakkeð","weight":1,"content":"bakkeð"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"bakterium","weight":1,"content":"bakterium"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"basað","weight":1,"content":"bäsäð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"baaiðum","weight":1,"content":"baaiðum"}]}}},"y":{"type":"internal","weight":97,"values":["r","o","s","g","d","m","t","n","'","e",null],"children":{"r":{"type":"internal","weight":97,"values":["d","t"," ","e","a"],"children":{"d":{"type":"internal","weight":97,"values":["﷐"," ","a","e","u"],"children":{"﷐":{"type":"leaf","weight":97,"entries":[{"key":"byrd","weight":97,"content":"byrd"}]}," ":{"type":"leaf","weight":2,"entries":[{"key":"byrd a","weight":2,"content":"byrd ą̊"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"byrdas","weight":2,"content":"byrdas"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"byrdes","weight":1,"content":"byrdes"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"byrdum","weight":1,"content":"byrdum"}]}}},"t":{"type":"leaf","weight":15,"entries":[{"key":"byrt","weight":15,"content":"byrt"}]}," ":{"type":"leaf","weight":6,"entries":[{"key":"byr a","weight":6,"content":"byr ą̊"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"byrer","weight":1,"content":"byrer"}]},"a":{"type":"internal","weight":1,"values":["n","e"],"children":{"n":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["d"],"children":{"d":{"type":"internal","weight":1,"values":["n","a"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"byranendn","weight":1,"content":"byrånendn"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"byranendam","weight":1,"content":"byrånendam"}]}}}}}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"byraendn","weight":1,"content":"byråendn"}]}}}}},"o":{"type":"internal","weight":33,"values":["n","v","r"],"children":{"n":{"type":"internal","weight":33,"values":["n"],"children":{"n":{"type":"internal","weight":33,"values":["a","﷐","u","e","f","d","k","l","r","t"],"children":{"a":{"type":"internal","weight":33,"values":["r","y",null],"children":{"r":{"type":"leaf","weight":33,"entries":[{"key":"byonnar","weight":33,"content":"byönnär"}]},"y":{"type":"internal","weight":3,"values":["v"],"children":{"v":{"type":"leaf","weight":3,"entries":[{"key":"byonnayve","weight":3,"content":"byönnåyvę"},{"key":"byonnayv","weight":3,"content":"byönnåyv"}]}}},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"byonna","weight":3,"content":"byönna"}]}}},"﷐":{"type":"leaf","weight":28,"entries":[{"key":"byonn","weight":28,"content":"byönn"}]},"u":{"type":"internal","weight":17,"values":["m","n","o"],"children":{"m":{"type":"internal","weight":17,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":17,"entries":[{"key":"byonnum","weight":17,"content":"byönnum"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"byonnumes","weight":1,"content":"byönnumes"}]}}},"n":{"type":"internal","weight":8,"values":["g"],"children":{"g":{"type":"internal","weight":8,"values":["g"],"children":{"g":{"type":"internal","weight":8,"values":["a","u",null],"children":{"a":{"type":"leaf","weight":8,"entries":[{"key":"byonnunggar","weight":8,"content":"byönnunggär"},{"key":"byonnungga","weight":3,"content":"byönnungga"}]},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"byonnungg","weight":2,"content":"byönnungg"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"byonnunggum","weight":2,"content":"byönnunggum"}]}}}}}}},"o":{"type":"internal","weight":3,"values":["n"],"children":{"n":{"type":"internal","weight":3,"values":["﷐","u","a"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"byonnuon","weight":3,"content":"byönnuon"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"byonnuonun","weight":2,"content":"byönnuonun"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"byonnuona","weight":1,"content":"byönnuona"}]}}}}}}},"e":{"type":"internal","weight":9,"values":["r","m"],"children":{"r":{"type":"leaf","weight":9,"entries":[{"key":"byonner","weight":9,"content":"byönner"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"byonnem","weight":2,"content":"byönnem"}]}}},"f":{"type":"leaf","weight":3,"entries":[{"key":"byonnfuoskerar","weight":3,"content":"byönnfuoskerär"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"byonndrite","weight":1,"content":"byönndrite"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"byonnkampis","weight":1,"content":"byönnkåmpis"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"byonnluptn","weight":1,"content":"byönnluptn"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"byonnramar","weight":1,"content":"byönnramär"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"byonntjaptar","weight":1,"content":"byönntjäptär"}]}}}}},"v":{"type":"internal","weight":11,"values":["e","a","d","u"],"children":{"e":{"type":"internal","weight":11,"values":["r","s"],"children":{"r":{"type":"leaf","weight":11,"entries":[{"key":"byover","weight":11,"content":"byöver"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"byoves","weight":1,"content":"byöves"}]}}},"d":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"byovd","weight":3,"content":"byövd"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"byovdes","weight":2,"content":"byövdes"}]}}},"a":{"type":"leaf","weight":5,"entries":[{"key":"byova","weight":5,"content":"byöva"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"byovum","weight":1,"content":"byövum"}]}}},"r":{"type":"internal","weight":3,"values":["k","t"],"children":{"k":{"type":"leaf","weight":3,"entries":[{"key":"byorkum","weight":3,"content":"byörkum"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"byortjin","weight":2,"content":"byörtjin"}]}}}}},"s":{"type":"internal","weight":8,"values":["s","t"],"children":{"s":{"type":"internal","weight":8,"values":["u","b","a"],"children":{"u":{"type":"internal","weight":8,"values":["﷐","n","r","m"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"byssu","weight":8,"content":"byssu"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"byssun","weight":2,"content":"byssun"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"byssur","weight":2,"content":"byssur"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"byssum","weight":1,"content":"byssum"}]}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"byssbuðum","weight":1,"content":"Byssbuðum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"byssa","weight":1,"content":"byssa"}]}}},"t":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["﷐","m","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"bystugu","weight":1,"content":"bystugu"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"bystugum","weight":1,"content":"bystugum"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"bystugun","weight":1,"content":"bystugun"}]}}}}}}}}}}},"g":{"type":"internal","weight":7,"values":["g","d"],"children":{"g":{"type":"internal","weight":7,"values":["d","t"],"children":{"d":{"type":"internal","weight":7,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"byggd","weight":7,"content":"byggd"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"byggde","weight":3,"content":"byggde"}]}}},"t":{"type":"leaf","weight":3,"entries":[{"key":"byggt","weight":3,"content":"byggt"}]}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"bygdegardem","weight":1,"content":"bygdegardem"}]}}},"d":{"type":"internal","weight":7,"values":["d"],"children":{"d":{"type":"internal","weight":7,"values":["j"],"children":{"j":{"type":"internal","weight":7,"values":["e","﷐","u","i"],"children":{"e":{"type":"leaf","weight":7,"entries":[{"key":"byddjer","weight":7,"content":"byddjer"}]},"﷐":{"type":"leaf","weight":5,"entries":[{"key":"byddj","weight":5,"content":"byddj"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"byddjum","weight":2,"content":"byddjum"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"byddjið","weight":1,"content":"byddjið"}]}}}}}}},"m":{"type":"leaf","weight":5,"entries":[{"key":"bymm","weight":5,"content":"bymm"}]},"t":{"type":"internal","weight":3,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"byt","weight":3,"content":"byt"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"bytas","weight":1,"content":"bytas"}]}}},"n":{"type":"leaf","weight":3,"entries":[{"key":"bynn","weight":3,"content":"bynn"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"by","weight":1,"content":"by"}]},"'":{"type":"leaf","weight":1,"entries":[{"key":"by'tt","weight":1,"content":"by'tt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"byer","weight":1,"content":"byer"}]}}},"o":{"type":"internal","weight":43,"values":["k","ð","g","e","l","n","s"],"children":{"ð":{"type":"leaf","weight":33,"entries":[{"key":"boð","weight":33,"content":"boð"}]},"k":{"type":"internal","weight":43,"values":["k","a","u"],"children":{"k":{"type":"internal","weight":43,"values":["a","e"],"children":{"a":{"type":"internal","weight":43,"values":["m","n"],"children":{"m":{"type":"leaf","weight":43,"entries":[{"key":"bokkam","weight":43,"content":"bokkam"}]},"n":{"type":"leaf","weight":19,"entries":[{"key":"bokkan","weight":19,"content":"bokkan"}]}}},"e":{"type":"leaf","weight":19,"entries":[{"key":"bokker","weight":19,"content":"bokker"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"boka","weight":1,"content":"boka"}]},"u":{"type":"internal","weight":1,"values":["g","n"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"bokuger","weight":1,"content":"bokuger"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"bokun","weight":1,"content":"bokun"}]}}}}},"g":{"type":"internal","weight":15,"values":["l","﷐","g"],"children":{"l":{"type":"leaf","weight":15,"entries":[{"key":"bogles","weight":15,"content":"bögles"}]},"﷐":{"type":"leaf","weight":6,"entries":[{"key":"bog","weight":6,"content":"bög"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"boggbjarr","weight":1,"content":"Boggbjärr"}]}}},"e":{"type":"leaf","weight":4,"entries":[{"key":"boem","weight":4,"content":"böem"}]},"l":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["e","d",null],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"boller","weight":2,"content":"boller"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"bolld","weight":1,"content":"bolld"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"boll","weight":1,"content":"boll"}]}}}}},"n":{"type":"leaf","weight":2,"entries":[{"key":"bon","weight":2,"content":"bön"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"bossldal","weight":1,"content":"Bossldal"}]}}},"i":{"type":"internal","weight":20,"values":["t","l","e","u","s","r","g","w","k"],"children":{"t":{"type":"internal","weight":20,"values":["﷐","i","y","a","n"],"children":{"﷐":{"type":"leaf","weight":20,"entries":[{"key":"bit","weight":20,"content":"bit"}]},"i":{"type":"leaf","weight":5,"entries":[{"key":"bitið","weight":5,"content":"bitið"}]},"y":{"type":"leaf","weight":5,"entries":[{"key":"bityðer","weight":5,"content":"bityðer"}]},"a":{"type":"internal","weight":3,"values":["i","l","r"],"children":{"l":{"type":"leaf","weight":1,"entries":[{"key":"bitala","weight":1,"content":"bitålå"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"bitar","weight":1,"content":"bitär"}]},"i":{"type":"leaf","weight":3,"entries":[{"key":"bitaiðsfra","weight":3,"content":"bitaiðsfrå"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"bitn","weight":1,"content":"bitn"}]}}},"l":{"type":"internal","weight":8,"values":["﷐","n","e","d","w","y","a"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"bil","weight":8,"content":"bil"}]},"n":{"type":"leaf","weight":8,"entries":[{"key":"biln","weight":8,"content":"biln"}]},"e":{"type":"leaf","weight":7,"entries":[{"key":"bilem","weight":7,"content":"bilem"},{"key":"bile","weight":1,"content":"bile"}]},"d":{"type":"internal","weight":3,"values":["﷐","o"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"bild","weight":3,"content":"bild"}]},"o":{"type":"leaf","weight":1,"entries":[{"key":"bildorum","weight":1,"content":"bildörum"}]}}},"w":{"type":"leaf","weight":1,"entries":[{"key":"bilweem","weight":1,"content":"bilweem"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"bilysningg","weight":1,"content":"bilysningg"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"bilar","weight":1,"content":"bilär"}]}}},"e":{"type":"internal","weight":6,"values":["t","n"],"children":{"t":{"type":"leaf","weight":6,"entries":[{"key":"biet","weight":6,"content":"biet"}]},"n":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"bien","weight":1,"content":"bien"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"bieneð","weight":1,"content":"bieneð"}]}}}}},"u":{"type":"internal","weight":5,"values":["o","n"],"children":{"o":{"type":"internal","weight":5,"values":["r","ð"],"children":{"r":{"type":"leaf","weight":5,"entries":[{"key":"biuorn","weight":5,"content":"biuorn"}]},"ð":{"type":"leaf","weight":3,"entries":[{"key":"biuoða","weight":3,"content":"biuoða"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"biundreram","weight":1,"content":"biundreram"}]}}},"s":{"type":"internal","weight":3,"values":["w","t"],"children":{"w":{"type":"internal","weight":3,"values":["a"],"children":{"a":{"type":"internal","weight":3,"values":["l"],"children":{"l":{"type":"internal","weight":3,"values":["l","i"],"children":{"l":{"type":"leaf","weight":3,"entries":[{"key":"biswallit","weight":3,"content":"biswällit"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"biswalit","weight":1,"content":"biswälit"}]}}}}}}},"t":{"type":"internal","weight":3,"values":["e","j"],"children":{"e":{"type":"internal","weight":3,"values":["m"],"children":{"m":{"type":"internal","weight":3,"values":["m","d"],"children":{"m":{"type":"internal","weight":3,"values":["t","d"],"children":{"t":{"type":"leaf","weight":3,"entries":[{"key":"bistemmt","weight":3,"content":"bistemmt"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"bistemmd","weight":1,"content":"bistemmd"}]}}},"d":{"type":"internal","weight":1,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"bistemd","weight":1,"content":"bistemd"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"bistemder","weight":1,"content":"bistemder"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"bistemdu","weight":1,"content":"bistemdu"}]}}}}}}},"j":{"type":"leaf","weight":1,"entries":[{"key":"bistjieliger","weight":1,"content":"bistjieliger"}]}}}}},"r":{"type":"internal","weight":3,"values":["a","i"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"biravin","weight":3,"content":"biravin"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"birim","weight":2,"content":"birim"}]}}},"g":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["i"],"children":{"i":{"type":"internal","weight":3,"values":["p"],"children":{"p":{"type":"internal","weight":3,"values":["a","e","i"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"bigripa","weight":3,"content":"bigripa"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"bigriper","weight":1,"content":"bigriper"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"bigripið","weight":1,"content":"bigripið"}]}}}}}}}}},"w":{"type":"internal","weight":2,"values":["a","i"],"children":{"a":{"type":"internal","weight":2,"values":["r","k"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"biwara","weight":2,"content":"biwårå"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"biwaka","weight":1,"content":"biwåkå"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"biwis","weight":1,"content":"biwis"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"biktraðn","weight":1,"content":"biktråðn"}]}}},"e":{"type":"internal","weight":20,"values":["l","n","s","k","r","t","d"],"children":{"l":{"type":"internal","weight":20,"values":["l"],"children":{"l":{"type":"internal","weight":20,"values":["e","d","u","t","a","i",null],"children":{"e":{"type":"leaf","weight":20,"entries":[{"key":"beller","weight":20,"content":"beller"}]},"d":{"type":"leaf","weight":11,"entries":[{"key":"belld","weight":11,"content":"belld"}]},"undefined":{"type":"leaf","weight":6,"entries":[{"key":"bell","weight":6,"content":"bell"}]},"u":{"type":"leaf","weight":7,"entries":[{"key":"bellum","weight":7,"content":"bellum"}]},"t":{"type":"leaf","weight":4,"entries":[{"key":"bellt","weight":4,"content":"bellt"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"bella","weight":1,"content":"bella"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"bellið","weight":1,"content":"bellið"}]}}}}},"n":{"type":"leaf","weight":5,"entries":[{"key":"bend","weight":5,"content":"bend"}]},"s":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"best","weight":3,"content":"best"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"bestað","weight":1,"content":"bestað"}]}}}}},"k":{"type":"leaf","weight":3,"entries":[{"key":"bekk","weight":3,"content":"bekk"}]},"r":{"type":"internal","weight":2,"values":["e","u"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"bereð","weight":2,"content":"bereð"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"berum","weight":2,"content":"berum"}]}}},"t":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["j"],"children":{"j":{"type":"internal","weight":2,"values":["i","e"],"children":{"i":{"type":"leaf","weight":2,"entries":[{"key":"bettjin","weight":2,"content":"bettjin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"bettjem","weight":1,"content":"bettjem"}]}}}}}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"bedd","weight":1,"content":"bedd"}]}}},"r":{"type":"internal","weight":19,"values":["a","u","i","o","y","e"],"children":{"a":{"type":"internal","weight":19,"values":["﷐","g","t","d","k","n","s","ð"],"children":{"﷐":{"type":"leaf","weight":19,"entries":[{"key":"bra","weight":19,"content":"bra"}]},"g":{"type":"internal","weight":12,"values":["a","u"],"children":{"a":{"type":"internal","weight":12,"values":["﷐","r","ð",null],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"braga","weight":12,"content":"brågå"}]},"r":{"type":"leaf","weight":5,"entries":[{"key":"bragar","weight":5,"content":"brägär"}]},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"braga","weight":3,"content":"brägä"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"bragað","weight":2,"content":"brägäð"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"braguger","weight":1,"content":"braguger"}]}}},"t":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"bratt","weight":2,"content":"brått"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"bratter","weight":2,"content":"bråtter"}]}}}}},"d":{"type":"internal","weight":2,"values":["d"],"children":{"d":{"type":"internal","weight":2,"values":["a","u"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"bradda","weight":2,"content":"bradda"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"braddun","weight":1,"content":"braddun"}]}}}}},"k":{"type":"leaf","weight":2,"entries":[{"key":"brakað","weight":2,"content":"bräkäð"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"brann","weight":1,"content":"brann"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"brasu","weight":1,"content":"brasu"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"braðum","weight":1,"content":"bräðum"}]}}},"u":{"type":"internal","weight":11,"values":["k","t","n","o","s","f",null],"children":{"t":{"type":"internal","weight":10,"values":["a","i"],"children":{"a":{"type":"internal","weight":10,"values":["s"],"children":{"s":{"type":"leaf","weight":10,"entries":[{"key":"brutas","weight":10,"content":"brutås"},{"key":"brutas","weight":1,"content":"brutäs"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"brutið","weight":1,"content":"brutið"}]}}},"n":{"type":"internal","weight":7,"values":["n","e","d","s","t",null],"children":{"n":{"type":"leaf","weight":7,"entries":[{"key":"brunn","weight":7,"content":"brunn"}]},"e":{"type":"internal","weight":5,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"brune","weight":5,"content":"brune"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"bruner","weight":2,"content":"bruner"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"brun","weight":2,"content":"brun"}]},"d":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["v"],"children":{"v":{"type":"leaf","weight":1,"entries":[{"key":"brundgravar","weight":1,"content":"brundgrävär"},{"key":"brundgrav","weight":1,"content":"brundgrav"}]}}}}}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"brunswart","weight":1,"content":"brunswart"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"brunt","weight":1,"content":"brunt"}]}}},"k":{"type":"internal","weight":11,"values":["e","a",null],"children":{"a":{"type":"internal","weight":6,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"bruka","weight":6,"content":"bruka"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"brukað","weight":1,"content":"brukað"}]}}},"e":{"type":"internal","weight":11,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":11,"entries":[{"key":"brukeð","weight":11,"content":"brukeð"}]},"r":{"type":"leaf","weight":3,"entries":[{"key":"bruker","weight":3,"content":"bruker"}]}}},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"bruk","weight":4,"content":"bruk"}]}}},"o":{"type":"internal","weight":3,"values":["t","k"],"children":{"t":{"type":"internal","weight":3,"values":["j"],"children":{"j":{"type":"internal","weight":3,"values":["e","i"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"bruotje","weight":3,"content":"bruotje"},{"key":"bruotje","weight":1,"content":"bruotję"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"bruotjin","weight":1,"content":"bruotjin"}]}}}}},"k":{"type":"internal","weight":2,"values":["f","﷐"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"bruok","weight":1,"content":"bruok"}]},"f":{"type":"internal","weight":2,"values":["i"],"children":{"i":{"type":"internal","weight":2,"values":["k"],"children":{"k":{"type":"internal","weight":2,"values":["k"],"children":{"k":{"type":"internal","weight":2,"values":["u","a"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"bruokfikka","weight":1,"content":"bruokfikka"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"bruokfikku","weight":2,"content":"bruokfikku"}]}}}}}}}}}}}}},"s":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["e","a",null],"children":{"e":{"type":"internal","weight":2,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"brussneð","weight":2,"content":"brussneð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"brussner","weight":1,"content":"brussner"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"brussn","weight":1,"content":"brussn"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"brussna","weight":1,"content":"brussna"}]}}}}}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"bru","weight":1,"content":"bru"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"brufesteð","weight":1,"content":"brufesteð"}]}}},"o":{"type":"internal","weight":8,"values":["t"],"children":{"t":{"type":"internal","weight":8,"values":["t","u","i"],"children":{"t":{"type":"leaf","weight":8,"entries":[{"key":"brott","weight":8,"content":"brott"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"brotus","weight":1,"content":"brotus"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"broti","weight":1,"content":"broti"}]}}}}},"i":{"type":"internal","weight":9,"values":["n","e","ð","u"],"children":{"n":{"type":"internal","weight":9,"values":["d"],"children":{"d":{"type":"internal","weight":9,"values":["e","k","a","u","j","n","t"],"children":{"k":{"type":"internal","weight":7,"values":["a"],"children":{"a":{"type":"internal","weight":7,"values":["v"],"children":{"v":{"type":"internal","weight":7,"values":["t","﷐","e","i","a"],"children":{"t":{"type":"leaf","weight":7,"entries":[{"key":"brindkavtjyote","weight":7,"content":"brindkåvtjyöte"}]},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"brindkav","weight":4,"content":"brindkåv"}]},"e":{"type":"leaf","weight":4,"entries":[{"key":"brindkavem","weight":4,"content":"brindkåvem"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"brindkavin","weight":2,"content":"brindkåvin"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"brindkavar","weight":1,"content":"brindkåvär"}]}}}}}}},"a":{"type":"internal","weight":7,"values":["m","﷐","r","n"],"children":{"m":{"type":"leaf","weight":7,"entries":[{"key":"brindam","weight":7,"content":"brindam"}]},"﷐":{"type":"leaf","weight":5,"entries":[{"key":"brinda","weight":5,"content":"brinda"}]},"r":{"type":"leaf","weight":5,"entries":[{"key":"brindar","weight":5,"content":"brindär"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"brindan","weight":2,"content":"brindan"}]}}},"e":{"type":"leaf","weight":9,"entries":[{"key":"brinder","weight":9,"content":"brinder"},{"key":"brinde","weight":3,"content":"brinde"}]},"j":{"type":"leaf","weight":5,"entries":[{"key":"brindjakt","weight":5,"content":"brindjakt"}]},"n":{"type":"leaf","weight":5,"entries":[{"key":"brindn","weight":5,"content":"brindn"}]},"u":{"type":"internal","weight":6,"values":["k","m"],"children":{"k":{"type":"internal","weight":6,"values":["s"],"children":{"s":{"type":"internal","weight":6,"values":["a","n","e",null],"children":{"a":{"type":"leaf","weight":6,"entries":[{"key":"brinduksan","weight":6,"content":"brinduksan"}]},"n":{"type":"leaf","weight":5,"entries":[{"key":"brinduksn","weight":5,"content":"brinduksn"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"brinduks","weight":1,"content":"brinduks"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"brindukse","weight":1,"content":"brindukse"}]}}}}},"m":{"type":"leaf","weight":2,"entries":[{"key":"brindum","weight":2,"content":"brindum"}]}}},"t":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["y"],"children":{"y":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["﷐","e","i"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"brindtjyot","weight":1,"content":"brindtjyöt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"brindtjyoteð","weight":1,"content":"brindtjyöteð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"brindtjyoti","weight":1,"content":"brindtjyötį"}]}}}}}}}}}}}}}}},"e":{"type":"internal","weight":5,"values":["ð","d"],"children":{"ð":{"type":"internal","weight":5,"values":["w","﷐"],"children":{"w":{"type":"internal","weight":5,"values":["i"],"children":{"i":{"type":"internal","weight":5,"values":["d","ð"],"children":{"d":{"type":"leaf","weight":5,"entries":[{"key":"brieðwid","weight":5,"content":"brieðwid"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"brieðwið","weight":2,"content":"brieðwið"}]}}}}},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"brieð","weight":1,"content":"brieð"}]}}},"d":{"type":"leaf","weight":3,"entries":[{"key":"briedd","weight":3,"content":"briedd"}]}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"brið","weight":1,"content":"brið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"briuot","weight":1,"content":"briuot"}]}}},"y":{"type":"internal","weight":6,"values":["g","m","o",null],"children":{"g":{"type":"internal","weight":6,"values":["d"],"children":{"d":{"type":"leaf","weight":6,"entries":[{"key":"brygder","weight":6,"content":"brygder"},{"key":"brygd","weight":4,"content":"brygd"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"bry","weight":2,"content":"bry"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"brymseð","weight":1,"content":"brymseð"}]},"o":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["e","u"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"bryoker","weight":1,"content":"bryöker"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"bryokum","weight":1,"content":"bryökum"}]}}}}}}},"e":{"type":"internal","weight":4,"values":["s","t"],"children":{"s":{"type":"leaf","weight":4,"entries":[{"key":"bresteð","weight":4,"content":"bresteð"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"brett","weight":1,"content":"brett"}]}}}}},"j":{"type":"internal","weight":11,"values":["a","u"],"children":{"a":{"type":"internal","weight":11,"values":["r"],"children":{"r":{"type":"internal","weight":11,"values":["r","g","a",null],"children":{"r":{"type":"internal","weight":11,"values":["e","u","k",null],"children":{"e":{"type":"internal","weight":11,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":11,"entries":[{"key":"bjarre","weight":11,"content":"bjärre"}]},"ð":{"type":"leaf","weight":8,"entries":[{"key":"bjarreð","weight":8,"content":"bjärreð"}]}}},"u":{"type":"leaf","weight":6,"entries":[{"key":"bjarrum","weight":6,"content":"bjärrum"}]},"k":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["k","m"],"children":{"k":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["a","﷐","u"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"bjarrkallkulla","weight":2,"content":"bjärrkallkulla"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"bjarrkallkull","weight":1,"content":"bjärrkallkull"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"bjarrkallkullunes","weight":1,"content":"bjärrkallkullunes"}]}}}}}}}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"bjarrkallmaleð","weight":1,"content":"bjärrkallmåleð"}]}}}}}}}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"bjarr","weight":1,"content":"bjärr"}]}}},"g":{"type":"leaf","weight":5,"entries":[{"key":"bjargum","weight":5,"content":"bjärgum"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"bjar","weight":1,"content":"bjär"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"bjara","weight":1,"content":"bjärå"}]}}}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"bjuoða","weight":1,"content":"bjuoða"}]}}},"u":{"type":"internal","weight":8,"values":["ð","o","n","l","t","s","f","k"],"children":{"ð":{"type":"internal","weight":8,"values":["u","﷐","k","a","s","f"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"buð","weight":7,"content":"buð"}]},"k":{"type":"internal","weight":6,"values":["u"],"children":{"u":{"type":"internal","weight":6,"values":["l"],"children":{"l":{"type":"internal","weight":6,"values":["l"],"children":{"l":{"type":"internal","weight":6,"values":["a","﷐","u"],"children":{"a":{"type":"leaf","weight":6,"entries":[{"key":"buðkulla","weight":6,"content":"buðkulla"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"buðkull","weight":1,"content":"buðkull"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"buðkullur","weight":1,"content":"buðkullur"}]}}}}}}}}},"u":{"type":"leaf","weight":8,"entries":[{"key":"buðum","weight":8,"content":"buðum"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"buðar","weight":4,"content":"buðär"}]},"s":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["u","e"],"children":{"u":{"type":"internal","weight":2,"values":["g"],"children":{"g":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"leaf","weight":2,"entries":[{"key":"buðstugun","weight":2,"content":"buðstugun"},{"key":"buðstugu","weight":1,"content":"buðstugu"}]}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"buðstelle","weight":1,"content":"buðstelle"}]}}}}},"f":{"type":"leaf","weight":1,"entries":[{"key":"buðfuotjeð","weight":1,"content":"buðfuotjeð"}]}}},"o":{"type":"internal","weight":5,"values":["r","ð","t","k","m","s"],"children":{"r":{"type":"internal","weight":5,"values":["d","i"],"children":{"d":{"type":"internal","weight":5,"values":["e","﷐"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"buordeð","weight":5,"content":"buordeð"},{"key":"buorde","weight":2,"content":"buordę"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"buord","weight":2,"content":"buord"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"buorið","weight":1,"content":"buorið"}]}}},"t":{"type":"internal","weight":2,"values":["j"],"children":{"j":{"type":"internal","weight":2,"values":["e","i"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"buotje","weight":2,"content":"buotję"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"buotjin","weight":2,"content":"buotjin"}]}}}}},"k":{"type":"leaf","weight":2,"entries":[{"key":"buok","weight":2,"content":"buok"}]},"m":{"type":"internal","weight":1,"values":["u","a"],"children":{"u":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["s","n"],"children":{"s":{"type":"leaf","weight":1,"entries":[{"key":"buomullstuss","weight":1,"content":"buomullstuss"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"buomulln","weight":1,"content":"buomulln"}]}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"buomað","weight":1,"content":"buomað"}]}}},"s":{"type":"internal","weight":1,"values":["k","s","t"],"children":{"k":{"type":"internal","weight":1,"values":["e","u"],"children":{"e":{"type":"internal","weight":1,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"buoske","weight":1,"content":"buoske"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"buosker","weight":1,"content":"buosker"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"buoskum","weight":1,"content":"buoskum"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"buossllbjarr","weight":1,"content":"Buossllbjärr"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"buosteð","weight":1,"content":"buosteð"}]}}},"ð":{"type":"leaf","weight":3,"entries":[{"key":"buoðið","weight":3,"content":"buoðið"},{"key":"buoð","weight":1,"content":"buoð"}]}}},"n":{"type":"leaf","weight":2,"entries":[{"key":"bune","weight":2,"content":"bune"}]},"t":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["﷐","e","n","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"butt","weight":1,"content":"butt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"butte","weight":1,"content":"butte"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"buttn","weight":1,"content":"buttn"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"buttum","weight":1,"content":"buttum"}]}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"buswissleð","weight":1,"content":"buswissleð"}]},"l":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["n","﷐"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"bulla","weight":1,"content":"bulla"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"bullan","weight":2,"content":"bullan"}]}}}}}}},"f":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["k","t"],"children":{"k":{"type":"leaf","weight":1,"entries":[{"key":"bufuok","weight":1,"content":"bufuok"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"bufuotjeð","weight":1,"content":"bufuotjeð"}]}}}}}}},"k":{"type":"internal","weight":1,"values":["k","u"],"children":{"k":{"type":"leaf","weight":1,"entries":[{"key":"bukkelrais","weight":1,"content":"Bukkelrais"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"bukullur","weight":1,"content":"bukullur"}]}}}}},"l":{"type":"internal","weight":5,"values":["i","u","a","e","o","y"],"children":{"i":{"type":"internal","weight":5,"values":["s","o"],"children":{"s":{"type":"leaf","weight":5,"entries":[{"key":"blis","weight":5,"content":"blis"}]},"o":{"type":"internal","weight":1,"values":["m"],"children":{"m":{"type":"internal","weight":1,"values":["m"],"children":{"m":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"bliomme","weight":1,"content":"bliomme"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"bliommem","weight":1,"content":"bliommem"}]}}}}}}}}}}},"u":{"type":"leaf","weight":4,"entries":[{"key":"bluoð","weight":4,"content":"bluoð"}]},"a":{"type":"internal","weight":4,"values":["s","﷐","k","t","b","e"],"children":{"s":{"type":"internal","weight":4,"values":["t","﷐","e"],"children":{"t":{"type":"internal","weight":4,"values":["e","a","n"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"blastem","weight":4,"content":"blästem"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"blasta","weight":2,"content":"blästa"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"blastn","weight":1,"content":"blästn"}]}}},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"blas","weight":2,"content":"blås"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"blaseð","weight":2,"content":"bläseð"}]}}},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"bla","weight":3,"content":"blå"}]},"k":{"type":"internal","weight":3,"values":["k"],"children":{"k":{"type":"internal","weight":3,"values":["e","a"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"blakka","weight":2,"content":"blakka"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"blakker","weight":3,"content":"blakker"}]}}}}},"t":{"type":"internal","weight":2,"values":["w","t"],"children":{"w":{"type":"leaf","weight":2,"entries":[{"key":"blatwat","weight":2,"content":"blätwåt"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"blatt","weight":1,"content":"blått"}]}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"blabessuppu","weight":1,"content":"blåbessuppu"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"blaer","weight":1,"content":"blåer"}]}}},"e":{"type":"internal","weight":1,"values":["s","n"],"children":{"s":{"type":"leaf","weight":1,"entries":[{"key":"blestem","weight":1,"content":"blestem"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"blendað","weight":1,"content":"blendað"}]}}},"o":{"type":"internal","weight":1,"values":["'","t"],"children":{"'":{"type":"leaf","weight":1,"entries":[{"key":"blo'tt","weight":1,"content":"blo'tt"}]},"t":{"type":"internal","weight":1,"values":["e","m","a","b",null],"children":{"e":{"type":"internal","weight":1,"values":["r","ð"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"blotera","weight":1,"content":"blotera"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"bloteð","weight":1,"content":"bloteð"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"blotmuosan","weight":1,"content":"blotmuosån"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"blot","weight":1,"content":"blot"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"blotan","weight":1,"content":"blotan"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"blotbroð","weight":1,"content":"blotbroð"}]}}}}},"y":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["p"],"children":{"p":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"blyaspenn","weight":1,"content":"blyaspenn"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"blyaspennur","weight":1,"content":"blyaspennur"}]}}}}}}}}}}}}}}}}}}},"k":{"type":"internal","weight":116,"values":["a","u","e","r","l","o","w","n"],"children":{"a":{"type":"internal","weight":116,"values":["m","y","l","p","n","v","u","s","k","i","r","t","ð","b","j","f"],"children":{"m":{"type":"internal","weight":116,"values":["﷐","p"],"children":{"﷐":{"type":"leaf","weight":116,"entries":[{"key":"kam","weight":116,"content":"kam"}]},"p":{"type":"internal","weight":4,"values":["i"],"children":{"i":{"type":"internal","weight":4,"values":["s"],"children":{"s":{"type":"internal","weight":4,"values":["﷐","n","a"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"kampis","weight":4,"content":"kåmpis"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"kampisn","weight":2,"content":"kåmpisn"}]},"a":{"type":"internal","weight":1,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"kampisa","weight":1,"content":"kåmpisa"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"kampisar","weight":1,"content":"kåmpisär"}]}}}}}}}}}}},"y":{"type":"internal","weight":53,"values":["t","u","a"],"children":{"t":{"type":"internal","weight":53,"values":["t","﷐","a","e","s","u"],"children":{"t":{"type":"internal","weight":53,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":53,"entries":[{"key":"kaytt","weight":53,"content":"kåytt"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"kayttið","weight":1,"content":"kåyttið"}]}}},"﷐":{"type":"leaf","weight":21,"entries":[{"key":"kayt","weight":21,"content":"kåyt"}]},"a":{"type":"leaf","weight":6,"entries":[{"key":"kayta","weight":6,"content":"kåyta"}]},"e":{"type":"internal","weight":4,"values":["r","n"],"children":{"r":{"type":"leaf","weight":4,"entries":[{"key":"kayter","weight":4,"content":"kåyter"}]},"n":{"type":"leaf","weight":3,"entries":[{"key":"kaytend","weight":3,"content":"kåytend"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"kaytskuona","weight":1,"content":"kåytskuona"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"kaytum","weight":1,"content":"kåytum"}]}}},"u":{"type":"internal","weight":12,"values":["n","﷐","r"],"children":{"n":{"type":"leaf","weight":12,"entries":[{"key":"kayun","weight":12,"content":"kåyun"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"kayu","weight":3,"content":"kåyu"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"kayur","weight":1,"content":"kåyur"}]}}},"a":{"type":"leaf","weight":6,"entries":[{"key":"kaya","weight":6,"content":"kåya"}]}}},"l":{"type":"internal","weight":15,"values":["l","a","o","s","y"],"children":{"l":{"type":"internal","weight":15,"values":["n","﷐","e","a"],"children":{"n":{"type":"leaf","weight":15,"entries":[{"key":"kalln","weight":15,"content":"kalln"}]},"﷐":{"type":"leaf","weight":11,"entries":[{"key":"kall","weight":11,"content":"kall"}]},"e":{"type":"internal","weight":6,"values":["m","r"],"children":{"m":{"type":"leaf","weight":6,"entries":[{"key":"kallem","weight":6,"content":"kallem"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"kaller","weight":1,"content":"kaller"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"kallar","weight":2,"content":"kallär"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"kalas","weight":1,"content":"kalas"}]},"o":{"type":"leaf","weight":1,"entries":[{"key":"kalogg","weight":1,"content":"kalogg"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"kalsaunggun","weight":1,"content":"kalsaunggun"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"kalyddje","weight":1,"content":"kalyddję"}]}}},"p":{"type":"internal","weight":12,"values":["i","p"],"children":{"i":{"type":"leaf","weight":12,"entries":[{"key":"kapittleð","weight":12,"content":"kapittleð"}]},"p":{"type":"internal","weight":2,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"kapp","weight":2,"content":"kapp"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"kappaleð","weight":1,"content":"kappaleð"}]}}}}},"n":{"type":"internal","weight":10,"values":["e","s","t","n","a"],"children":{"e":{"type":"internal","weight":10,"values":["n"],"children":{"n":{"type":"internal","weight":10,"values":["d","n"],"children":{"d":{"type":"leaf","weight":10,"entries":[{"key":"kanenda","weight":10,"content":"kanenda"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"kanennda","weight":2,"content":"kanennda"}]}}}}},"s":{"type":"leaf","weight":9,"entries":[{"key":"kanstji","weight":9,"content":"kanstji"}]},"t":{"type":"internal","weight":4,"values":["n","e"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"kantn","weight":4,"content":"kantn"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kantem","weight":1,"content":"kantem"}]}}},"n":{"type":"leaf","weight":3,"entries":[{"key":"kann","weight":3,"content":"kann"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"kanaiv","weight":1,"content":"kanaiv"}]}}},"v":{"type":"internal","weight":6,"values":["i","e"],"children":{"i":{"type":"leaf","weight":6,"entries":[{"key":"kavin","weight":6,"content":"kåvin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kavem","weight":1,"content":"kåvem"}]}}},"u":{"type":"internal","weight":4,"values":["t","l"],"children":{"t":{"type":"internal","weight":4,"values":["n","﷐","e"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"kautn","weight":4,"content":"kautn"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"kaut","weight":1,"content":"kaut"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kautem","weight":1,"content":"kautem"}]}}},"l":{"type":"internal","weight":4,"values":["u"],"children":{"u":{"type":"leaf","weight":4,"entries":[{"key":"kaulun","weight":4,"content":"kaulun"},{"key":"kaulu","weight":4,"content":"kaulu"}]}}}}},"s":{"type":"internal","weight":4,"values":["t","u"],"children":{"t":{"type":"internal","weight":4,"values":["e","j"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"kasteð","weight":4,"content":"kasteð"}]},"j":{"type":"leaf","weight":2,"entries":[{"key":"kastji","weight":2,"content":"kastjį"}]}}},"u":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["d","g"],"children":{"d":{"type":"leaf","weight":2,"entries":[{"key":"kasundjin","weight":2,"content":"kasundjin"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"kasungg","weight":1,"content":"kasungg"}]}}}}}}},"k":{"type":"internal","weight":4,"values":["a"],"children":{"a":{"type":"internal","weight":4,"values":["o"],"children":{"o":{"type":"internal","weight":4,"values":["﷐","k"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"kakao","weight":4,"content":"kakao"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"kakaokapp","weight":1,"content":"kakaokapp"}]}}}}}}},"i":{"type":"internal","weight":4,"values":["p"],"children":{"p":{"type":"internal","weight":4,"values":["a","e"],"children":{"e":{"type":"internal","weight":3,"values":["n","ð","r"],"children":{"n":{"type":"internal","weight":3,"values":["d"],"children":{"d":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"kaipend","weight":3,"content":"kaipend"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kaipendes","weight":1,"content":"kaipendes"}]}}}}},"ð":{"type":"leaf","weight":3,"entries":[{"key":"kaipeð","weight":3,"content":"kaipeð"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"kaiper","weight":2,"content":"kaiper"}]}}},"a":{"type":"leaf","weight":4,"entries":[{"key":"kaipað","weight":4,"content":"kaipað"},{"key":"kaipa","weight":1,"content":"kaipa"}]}}}}},"r":{"type":"internal","weight":4,"values":["u","t"],"children":{"u":{"type":"internal","weight":4,"values":["l"],"children":{"l":{"type":"internal","weight":4,"values":["i"],"children":{"i":{"type":"internal","weight":4,"values":["n","g"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"karulin","weight":4,"content":"karulin"}]},"g":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"karulig","weight":1,"content":"karulig"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"karuliger","weight":1,"content":"karuliger"}]}}}}}}}}},"t":{"type":"internal","weight":1,"values":["a","u"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"karta","weight":1,"content":"karta"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"kartun","weight":1,"content":"kartun"}]}}}}},"t":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"katt","weight":2,"content":"katt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kattem","weight":1,"content":"kattem"}]}}}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"kabbum","weight":1,"content":"kabbum"}]},"ð":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"kaða","weight":2,"content":"kåðå"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"kaðað","weight":1,"content":"käðäð"}]}}}}},"j":{"type":"leaf","weight":1,"entries":[{"key":"kaju","weight":1,"content":"kåju"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"kafikappar","weight":1,"content":"kafikappär"}]}}},"e":{"type":"internal","weight":49,"values":["n","l"],"children":{"n":{"type":"internal","weight":49,"values":["n"],"children":{"n":{"type":"internal","weight":49,"values":["d","e","t",null],"children":{"d":{"type":"internal","weight":49,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":49,"entries":[{"key":"kennd","weight":49,"content":"kennd"}]},"e":{"type":"leaf","weight":13,"entries":[{"key":"kenndes","weight":13,"content":"kenndes"}]}}},"undefined":{"type":"leaf","weight":8,"entries":[{"key":"kenn","weight":8,"content":"kenn"}]},"e":{"type":"internal","weight":5,"values":["r","s"],"children":{"r":{"type":"leaf","weight":5,"entries":[{"key":"kenner","weight":5,"content":"kenner"}]},"s":{"type":"leaf","weight":4,"entries":[{"key":"kennes","weight":4,"content":"kennes"}]}}},"t":{"type":"internal","weight":3,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"kennt","weight":3,"content":"kennt"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"kenntas","weight":1,"content":"kenntas"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kenntes","weight":1,"content":"kenntes"}]}}}}}}},"l":{"type":"internal","weight":5,"values":["d","i","l"],"children":{"d":{"type":"internal","weight":5,"values":["u","b"],"children":{"u":{"type":"leaf","weight":5,"entries":[{"key":"keldun","weight":5,"content":"keldun"}]},"b":{"type":"leaf","weight":3,"entries":[{"key":"keldbekk","weight":3,"content":"keldbekk"}]}}},"i":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["d","g"],"children":{"d":{"type":"internal","weight":2,"values":["j"],"children":{"j":{"type":"internal","weight":2,"values":["i","e"],"children":{"i":{"type":"leaf","weight":2,"entries":[{"key":"kelindjin","weight":2,"content":"kelindjin"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"kelindje","weight":2,"content":"kelindję"}]}}}}},"g":{"type":"internal","weight":2,"values":["g"],"children":{"g":{"type":"internal","weight":2,"values":["a","e","u",null],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"kelinggar","weight":2,"content":"kelinggär"}]},"e":{"type":"internal","weight":2,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"kelingge","weight":2,"content":"kelingge"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"kelingger","weight":2,"content":"kelingger"}]}}},"u":{"type":"leaf","weight":2,"entries":[{"key":"kelinggum","weight":2,"content":"kelinggum"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"kelingg","weight":1,"content":"kelingg"}]}}}}}}}}},"l":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["d","g"],"children":{"d":{"type":"leaf","weight":1,"entries":[{"key":"kellindjin","weight":1,"content":"kellindjin"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"kellingg","weight":1,"content":"kellingg"}]}}}}}}}}}}},"u":{"type":"internal","weight":66,"values":["m","o","l","n","p","w","d","a","r","s","v"],"children":{"o":{"type":"internal","weight":37,"values":["g","l","r","s"],"children":{"g":{"type":"internal","weight":37,"values":["a","e","i","u"],"children":{"a":{"type":"internal","weight":37,"values":["﷐","ð","r"],"children":{"﷐":{"type":"leaf","weight":37,"entries":[{"key":"kuoga","weight":37,"content":"kuogä"},{"key":"kuoga","weight":16,"content":"kuogå"}]},"ð":{"type":"leaf","weight":16,"entries":[{"key":"kuogað","weight":16,"content":"kuogäð"},{"key":"kuogað","weight":1,"content":"kuogåð"}]},"r":{"type":"leaf","weight":4,"entries":[{"key":"kuogar","weight":4,"content":"kuogär"}]}}},"e":{"type":"leaf","weight":4,"entries":[{"key":"kuogeð","weight":4,"content":"kuogeð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"kuogið","weight":1,"content":"kuogið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"kuogum","weight":1,"content":"kuogum"}]}}},"l":{"type":"leaf","weight":8,"entries":[{"key":"kuolmark","weight":8,"content":"Kuolmark"}]},"r":{"type":"internal","weight":5,"values":["p"],"children":{"p":{"type":"internal","weight":5,"values":["i","a","e","u",null],"children":{"i":{"type":"leaf","weight":5,"entries":[{"key":"kuorpin","weight":5,"content":"kuorpin"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"kuorpar","weight":2,"content":"kuorpär"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"kuorp","weight":1,"content":"kuorp"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kuorpem","weight":1,"content":"kuorpem"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"kuorpum","weight":1,"content":"kuorpum"}]}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"kuosta","weight":1,"content":"kuosta"}]}}},"m":{"type":"internal","weight":66,"values":["i","b","a","u"],"children":{"i":{"type":"leaf","weight":66,"entries":[{"key":"kumið","weight":66,"content":"kumið"}]},"b":{"type":"leaf","weight":51,"entries":[{"key":"kumb","weight":51,"content":"kumb"}]},"a":{"type":"leaf","weight":15,"entries":[{"key":"kuma","weight":15,"content":"kumå"}]},"u":{"type":"leaf","weight":4,"entries":[{"key":"kumum","weight":4,"content":"kumum"}]}}},"l":{"type":"internal","weight":35,"values":["l","e"],"children":{"l":{"type":"internal","weight":35,"values":["u","a",null],"children":{"u":{"type":"internal","weight":35,"values":["r","m","n",null],"children":{"r":{"type":"leaf","weight":35,"entries":[{"key":"kullur","weight":35,"content":"kullur"}]},"m":{"type":"leaf","weight":10,"entries":[{"key":"kullum","weight":10,"content":"kullum"}]},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"kullu","weight":2,"content":"kullų"},{"key":"kullu","weight":2,"content":"kullu"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"kullun","weight":2,"content":"kullun"}]}}},"undefined":{"type":"leaf","weight":5,"entries":[{"key":"kull","weight":5,"content":"kull"}]},"a":{"type":"leaf","weight":6,"entries":[{"key":"kulla","weight":6,"content":"kulla"},{"key":"kulla","weight":2,"content":"kullą"}]}}},"e":{"type":"internal","weight":3,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":3,"entries":[{"key":"kuleð","weight":3,"content":"kuleð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"kuler","weight":1,"content":"kuler"}]}}}}},"n":{"type":"internal","weight":4,"values":["n"],"children":{"n":{"type":"internal","weight":4,"values":["a","u","d","i"],"children":{"a":{"type":"leaf","weight":4,"entries":[{"key":"kunna","weight":4,"content":"kunna"}]},"u":{"type":"internal","weight":1,"values":["g","n","t"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"kunnug","weight":1,"content":"kunnug"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"kunnun","weight":1,"content":"kunnun"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"kunnut","weight":1,"content":"kunnut"}]}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"kunnde","weight":1,"content":"kunnde"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"kunnið","weight":1,"content":"kunnið"}]}}}}},"p":{"type":"internal","weight":3,"values":["p"],"children":{"p":{"type":"internal","weight":3,"values":["e","m","a"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"kuppe","weight":3,"content":"kuppe"}]},"m":{"type":"internal","weight":2,"values":["o"],"children":{"o":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["k"],"children":{"k":{"type":"internal","weight":2,"values":["t","e"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"kuppmorkt","weight":2,"content":"kuppmörkt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kuppmorkest","weight":1,"content":"kuppmörkest"}]}}}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"kuppam","weight":1,"content":"kuppam"}]}}}}},"w":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["t"],"children":{"t":{"type":"internal","weight":2,"values":["e",null],"children":{"e":{"type":"internal","weight":2,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"kuwerte","weight":2,"content":"kuwertę"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"kuwerteð","weight":2,"content":"kuwerteð"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"kuwert","weight":1,"content":"kuwert"}]}}}}}}}}},"d":{"type":"internal","weight":1,"values":["d"],"children":{"d":{"type":"internal","weight":1,"values":["n","e"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"kuddn","weight":1,"content":"kuddn"}]},"e":{"type":"internal","weight":1,"values":["m","r"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"kuddem","weight":1,"content":"kuddem"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"kudder","weight":1,"content":"kudder"}]}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"kuagað","weight":1,"content":"kuägäð"}]},"r":{"type":"internal","weight":1,"values":["s","k"],"children":{"s":{"type":"leaf","weight":1,"entries":[{"key":"kursum","weight":1,"content":"kursum"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"kurk","weight":1,"content":"kurk"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"kusulit","weight":1,"content":"kusulit"}]},"v":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"internal","weight":1,"values":["﷐","m","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"kuva","weight":1,"content":"kuvą̊"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"kuvam","weight":1,"content":"kuvåm"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"kuvan","weight":1,"content":"kuvån"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"kuvelkwiðn","weight":1,"content":"kuvelkwiðn"}]}}}}},"l":{"type":"internal","weight":20,"values":["i","a","u","e","y","o"],"children":{"i":{"type":"internal","weight":20,"values":["e","t","v","p"],"children":{"e":{"type":"internal","weight":20,"values":["v","n","m"],"children":{"v":{"type":"leaf","weight":20,"entries":[{"key":"kliev","weight":20,"content":"kliev"}]},"n":{"type":"internal","weight":5,"values":["t","﷐","u"],"children":{"t":{"type":"leaf","weight":5,"entries":[{"key":"klient","weight":5,"content":"klient"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"klien","weight":2,"content":"klien"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"klienu","weight":1,"content":"klienu"}]}}},"m":{"type":"internal","weight":1,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"kliem","weight":1,"content":"kliem"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"kliema","weight":1,"content":"kliema"}]}}}}},"t":{"type":"internal","weight":5,"values":["t"],"children":{"t":{"type":"internal","weight":5,"values":["e","k"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"klittem","weight":5,"content":"Klittem"}]},"k":{"type":"internal","weight":5,"values":["a","e"],"children":{"a":{"type":"internal","weight":5,"values":["l"],"children":{"l":{"type":"internal","weight":5,"values":["l"],"children":{"l":{"type":"internal","weight":5,"values":["a","e"],"children":{"a":{"type":"leaf","weight":5,"entries":[{"key":"klittkallar","weight":5,"content":"klittkallär"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"klittkaller","weight":1,"content":"klittkaller"}]}}}}}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"klittkellinggar","weight":1,"content":"klittkellinggär"}]}}}}}}},"v":{"type":"leaf","weight":1,"entries":[{"key":"klivið","weight":1,"content":"klivið"}]},"p":{"type":"internal","weight":1,"values":["p"],"children":{"p":{"type":"internal","weight":1,"values":["e","u"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"klipper","weight":1,"content":"klipper"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"klippum","weight":1,"content":"klippum"}]}}}}}}},"u":{"type":"internal","weight":4,"values":["o","k"],"children":{"o":{"type":"internal","weight":4,"values":["k"],"children":{"k":{"type":"internal","weight":4,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"kluok","weight":4,"content":"kluok"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"kluoker","weight":1,"content":"kluoker"}]}}}}},"k":{"type":"leaf","weight":3,"entries":[{"key":"klukka","weight":3,"content":"klukka"}]}}},"e":{"type":"leaf","weight":4,"entries":[{"key":"klemmd","weight":4,"content":"klemmd"}]},"a":{"type":"internal","weight":7,"values":["u","i","p","n","r"],"children":{"i":{"type":"leaf","weight":4,"entries":[{"key":"klaiv","weight":4,"content":"klaiv"}]},"u":{"type":"internal","weight":7,"values":["t"],"children":{"t":{"type":"internal","weight":7,"values":["u","﷐","a","e","s"],"children":{"u":{"type":"leaf","weight":7,"entries":[{"key":"klautum","weight":7,"content":"klautum"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"klaut","weight":2,"content":"klaut"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"klautstakk","weight":1,"content":"klautstakk"}]},"a":{"type":"internal","weight":2,"values":["﷐","r",null],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"klauta","weight":2,"content":"klautą"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"klautar","weight":1,"content":"klautär"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"klauta","weight":1,"content":"klauta"}]}}},"e":{"type":"leaf","weight":2,"entries":[{"key":"klauter","weight":2,"content":"klauter"}]}}}}},"p":{"type":"leaf","weight":3,"entries":[{"key":"klappeð","weight":3,"content":"klappeð"}]},"n":{"type":"internal","weight":3,"values":["i"],"children":{"i":{"type":"internal","weight":3,"values":["n"],"children":{"n":{"type":"internal","weight":3,"values":["d","g"],"children":{"d":{"type":"internal","weight":3,"values":["j"],"children":{"j":{"type":"internal","weight":3,"values":["e","i"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"klanindje","weight":3,"content":"klänindje"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"klanindjin","weight":1,"content":"klänindjin"}]}}}}},"g":{"type":"leaf","weight":1,"entries":[{"key":"klaningg","weight":1,"content":"kläningg"}]}}}}}}},"r":{"type":"internal","weight":2,"values":["﷐","e","i","a",null],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"klar","weight":2,"content":"klar"}]},"e":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"klareðum","weight":1,"content":"klareðum"},{"key":"klareð","weight":1,"content":"klareð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"klarer","weight":1,"content":"klarer"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"klarið","weight":1,"content":"klarið"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"klar","weight":1,"content":"klår"}]},"a":{"type":"internal","weight":1,"values":["ð","n"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"klarað","weight":1,"content":"klarað"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"klaran","weight":1,"content":"klåran"}]}}}}}}},"y":{"type":"internal","weight":2,"values":["o"],"children":{"o":{"type":"internal","weight":2,"values":["n","r","m"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"klyonar","weight":2,"content":"klyönär"}]},"r":{"type":"internal","weight":2,"values":["a","d"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"klyora","weight":2,"content":"klyöra"}]},"d":{"type":"leaf","weight":2,"entries":[{"key":"klyord","weight":2,"content":"klyörd"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"klyomm","weight":1,"content":"klyömm"}]}}}}},"o":{"type":"leaf","weight":1,"entries":[{"key":"klover","weight":1,"content":"klover"}]}}},"o":{"type":"internal","weight":20,"values":["l","m","n","r","p"],"children":{"l":{"type":"internal","weight":20,"values":["l","d"],"children":{"l":{"type":"internal","weight":20,"values":["﷐","a","d","t","u"],"children":{"﷐":{"type":"leaf","weight":20,"entries":[{"key":"koll","weight":20,"content":"koll"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"kolla","weight":4,"content":"kolla"}]},"d":{"type":"leaf","weight":4,"entries":[{"key":"kolld","weight":4,"content":"kolld"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"kollum","weight":3,"content":"kollum"}]},"t":{"type":"leaf","weight":4,"entries":[{"key":"kollt","weight":4,"content":"kollt"}]}}},"d":{"type":"internal","weight":2,"values":["g","a",null],"children":{"g":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"internal","weight":2,"values":["a","e"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"koldgraðar","weight":2,"content":"koldgraðär"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"koldgraðer","weight":2,"content":"koldgraðer"}]}}}}}}}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"kold","weight":2,"content":"kold"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"koldan","weight":1,"content":"koldan"}]}}}}},"m":{"type":"leaf","weight":8,"entries":[{"key":"kom","weight":8,"content":"kom"}]},"n":{"type":"leaf","weight":8,"entries":[{"key":"kontrollem","weight":8,"content":"kontrollem"}]},"r":{"type":"internal","weight":6,"values":["d","g"],"children":{"d":{"type":"internal","weight":6,"values":["j"],"children":{"j":{"type":"internal","weight":6,"values":["i","e"],"children":{"i":{"type":"leaf","weight":6,"entries":[{"key":"kordjin","weight":6,"content":"kordjin"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"kordjem","weight":3,"content":"kordjem"},{"key":"kordje","weight":1,"content":"kordję"}]}}}}},"g":{"type":"leaf","weight":1,"entries":[{"key":"korg","weight":1,"content":"korg"}]}}},"p":{"type":"internal","weight":2,"values":["p"],"children":{"p":{"type":"internal","weight":2,"values":["﷐","l","k"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"kopp","weight":2,"content":"kopp"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"koppleð","weight":2,"content":"koppleð"}]},"k":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["y"],"children":{"y":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["n",null],"children":{"n":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["d"],"children":{"d":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["e","i"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"koppkaytnindje","weight":1,"content":"koppkåytnindje"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"koppkaytnindjin","weight":1,"content":"koppkåytnindjin"}]}}}}}}}}}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"koppkayt","weight":1,"content":"koppkåyt"}]}}}}}}}}}}}}}}},"r":{"type":"internal","weight":22,"values":["i","a","y","u","o"],"children":{"i":{"type":"internal","weight":22,"values":["p","s","n"],"children":{"p":{"type":"internal","weight":22,"values":["p"],"children":{"p":{"type":"internal","weight":22,"values":["u","e","a","w","i",null],"children":{"u":{"type":"internal","weight":22,"values":["m","o"],"children":{"m":{"type":"leaf","weight":22,"entries":[{"key":"krippum","weight":22,"content":"krippum"}]},"o":{"type":"leaf","weight":1,"entries":[{"key":"krippuop","weight":1,"content":"krippuop"}]}}},"e":{"type":"internal","weight":17,"values":["r","m"],"children":{"r":{"type":"leaf","weight":17,"entries":[{"key":"kripper","weight":17,"content":"kripper"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"krippem","weight":1,"content":"krippem"}]}}},"a":{"type":"leaf","weight":7,"entries":[{"key":"krippar","weight":7,"content":"krippär"},{"key":"krippa","weight":2,"content":"krippa"},{"key":"krippa","weight":2,"content":"krippą"}]},"undefined":{"type":"leaf","weight":5,"entries":[{"key":"kripp","weight":5,"content":"kripp"}]},"w":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"krippwask","weight":1,"content":"krippwask"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"krippwasker","weight":1,"content":"krippwasker"}]}}}}}}}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"krippin","weight":1,"content":"krippin"}]}}}}},"s":{"type":"internal","weight":4,"values":["t","s"],"children":{"t":{"type":"leaf","weight":4,"entries":[{"key":"kristallkaulu","weight":4,"content":"kristallkaulu"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"krissneð","weight":1,"content":"krissneð"}]}}},"n":{"type":"internal","weight":3,"values":["g"],"children":{"g":{"type":"internal","weight":3,"values":["g"],"children":{"g":{"type":"internal","weight":3,"values":["e"," ","t","u"],"children":{" ":{"type":"leaf","weight":2,"entries":[{"key":"kringg dig","weight":2,"content":"kringg dig"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"kringgeð","weight":3,"content":"kringgeð"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"kringgt","weight":1,"content":"kringgt"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"kringgum","weight":1,"content":"kringgum"}]}}}}}}}}},"y":{"type":"internal","weight":10,"values":["t","o","p"],"children":{"t":{"type":"internal","weight":10,"values":["y"],"children":{"y":{"type":"internal","weight":10,"values":["r"],"children":{"r":{"type":"internal","weight":10,"values":["e","﷐","u"],"children":{"e":{"type":"leaf","weight":10,"entries":[{"key":"krytyreð","weight":10,"content":"krytyreð"}]},"﷐":{"type":"leaf","weight":7,"entries":[{"key":"krytyr","weight":7,"content":"krytyr"}]},"u":{"type":"leaf","weight":3,"entries":[{"key":"krytyrum","weight":3,"content":"krytyrum"}]}}}}}}},"o":{"type":"leaf","weight":1,"entries":[{"key":"kryotjer","weight":1,"content":"kryötjer"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"krypptes","weight":1,"content":"krypptes"}]}}},"a":{"type":"internal","weight":12,"values":["y","k","m","u","p"],"children":{"y":{"type":"leaf","weight":12,"entries":[{"key":"kraysse","weight":12,"content":"kråysse"}]},"k":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["e","a"],"children":{"e":{"type":"internal","weight":2,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"krakseð","weight":2,"content":"krakseð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"krakser","weight":1,"content":"krakser"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"kraksa","weight":1,"content":"kraksa"}]}}}}},"m":{"type":"leaf","weight":2,"entries":[{"key":"krameð","weight":2,"content":"krameð"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"kraungna","weight":2,"content":"kraungna"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"krapt","weight":1,"content":"krapt"}]}}},"u":{"type":"internal","weight":6,"values":["p","o"],"children":{"p":{"type":"internal","weight":6,"values":["p"],"children":{"p":{"type":"internal","weight":6,"values":["e","i","u"],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"kruppem","weight":6,"content":"kruppem"}]},"i":{"type":"leaf","weight":2,"entries":[{"key":"kruppin","weight":2,"content":"kruppin"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"kruppum","weight":1,"content":"kruppum"}]}}}}},"o":{"type":"leaf","weight":1,"entries":[{"key":"kruokugum","weight":1,"content":"kruokugum"}]}}},"o":{"type":"internal","weight":4,"values":["p","s","k"],"children":{"s":{"type":"internal","weight":3,"values":["s"],"children":{"s":{"type":"leaf","weight":3,"entries":[{"key":"krosskeldun","weight":3,"content":"Krosskeldun"},{"key":"kross","weight":1,"content":"kross"}]}}},"p":{"type":"leaf","weight":4,"entries":[{"key":"kropp","weight":4,"content":"kropp"},{"key":"krop","weight":2,"content":"krop"}]},"k":{"type":"leaf","weight":2,"entries":[{"key":"krokkeð","weight":2,"content":"krokkeð"}]}}}}},"w":{"type":"internal","weight":14,"values":["e","i","a"],"children":{"e":{"type":"internal","weight":14,"values":["r","ð","l","g","m"],"children":{"r":{"type":"internal","weight":14,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":14,"entries":[{"key":"kwer","weight":14,"content":"kwer"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"kwere","weight":3,"content":"kwere"}]}}},"ð":{"type":"leaf","weight":13,"entries":[{"key":"kweða","weight":13,"content":"kweðå"}]},"l":{"type":"internal","weight":7,"values":["d","l"],"children":{"d":{"type":"internal","weight":7,"values":["n","a","e",null],"children":{"n":{"type":"leaf","weight":7,"entries":[{"key":"kweldn","weight":7,"content":"kweldn"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"kwelda","weight":3,"content":"kweldą"},{"key":"kwelda","weight":3,"content":"kwelda"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"kweldem","weight":2,"content":"kweldem"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"kweld","weight":1,"content":"kweld"}]}}},"l":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["﷐","j"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"kwells","weight":1,"content":"kwells"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"kwellsjata","weight":1,"content":"kwellsjätå"}]}}}}}}},"g":{"type":"internal","weight":4,"values":["e","l"],"children":{"l":{"type":"internal","weight":3,"values":["u"],"children":{"u":{"type":"internal","weight":3,"values":["r","m"],"children":{"r":{"type":"leaf","weight":3,"entries":[{"key":"kweglur","weight":3,"content":"kweglur"}]},"m":{"type":"leaf","weight":2,"entries":[{"key":"kweglum","weight":2,"content":"kweglum"}]}}}}},"e":{"type":"leaf","weight":4,"entries":[{"key":"kwegel","weight":4,"content":"kwegel"}]}}},"m":{"type":"leaf","weight":2,"entries":[{"key":"kwemtun","weight":2,"content":"kwemtun"}]}}},"i":{"type":"internal","weight":9,"values":["s","ð","m","t"],"children":{"s":{"type":"internal","weight":9,"values":["t"],"children":{"t":{"type":"internal","weight":9,"values":["a","n","u","e",null],"children":{"a":{"type":"leaf","weight":9,"entries":[{"key":"kwistar","weight":9,"content":"kwistär"},{"key":"kwista","weight":1,"content":"kwista"}]},"n":{"type":"leaf","weight":5,"entries":[{"key":"kwistn","weight":5,"content":"kwistn"}]},"u":{"type":"leaf","weight":5,"entries":[{"key":"kwistum","weight":5,"content":"kwistum"}]},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"kwist","weight":4,"content":"kwist"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"kwister","weight":2,"content":"kwister"}]}}}}},"ð":{"type":"internal","weight":9,"values":["n","﷐","i","k"],"children":{"n":{"type":"leaf","weight":9,"entries":[{"key":"kwiðn","weight":9,"content":"kwiðn"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"kwið","weight":2,"content":"kwið"}]},"i":{"type":"internal","weight":2,"values":["m","r"],"children":{"m":{"type":"leaf","weight":2,"entries":[{"key":"kwiðim","weight":2,"content":"kwiðim"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"kwiðir","weight":1,"content":"kwiðir"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"kwiðkuppar","weight":1,"content":"kwiðkuppär"}]}}},"m":{"type":"leaf","weight":6,"entries":[{"key":"kwim","weight":6,"content":"kwim"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"kwitt","weight":1,"content":"kwitt"}]}}},"a":{"type":"internal","weight":2,"values":["ð","i"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"kwað","weight":2,"content":"kwað"}]},"i":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["g","n","t"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"kwainggluger","weight":1,"content":"kwainggluger"},{"key":"kwaingglug","weight":1,"content":"kwaingglug"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"kwaingglun","weight":1,"content":"kwaingglun"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"kwaingglut","weight":1,"content":"kwaingglut"}]}}}}}}}}}}}}}}}}},"n":{"type":"internal","weight":3,"values":["a","e","i"],"children":{"a":{"type":"internal","weight":3,"values":["y","k","u","i"],"children":{"y":{"type":"internal","weight":3,"values":["t","'"],"children":{"t":{"type":"internal","weight":3,"values":["t","﷐","n"],"children":{"t":{"type":"leaf","weight":3,"entries":[{"key":"knaytt","weight":3,"content":"knåytt"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"knayt","weight":1,"content":"knåyt"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"knaytnevum","weight":1,"content":"knåytnevum"}]}}},"'":{"type":"leaf","weight":1,"entries":[{"key":"knay'tt","weight":1,"content":"knåy'tt"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"knakkeð","weight":1,"content":"knakkeð"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"knaul","weight":1,"content":"knaul"}]},"i":{"type":"internal","weight":1,"values":["v"],"children":{"v":{"type":"internal","weight":1,"values":["﷐","a","i"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"knaiv","weight":1,"content":"knaiv"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"knaiva","weight":1,"content":"knaiva"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"knaivin","weight":1,"content":"knaivin"}]}}}}}}},"e":{"type":"internal","weight":3,"values":["p","v"],"children":{"p":{"type":"leaf","weight":3,"entries":[{"key":"kneppt","weight":3,"content":"kneppt"}]},"v":{"type":"leaf","weight":2,"entries":[{"key":"knevlut","weight":2,"content":"knevlut"}]}}},"i":{"type":"internal","weight":2,"values":["n","s","m"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"knin","weight":2,"content":"knin"}]},"s":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["n","u"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"knisjunn","weight":1,"content":"Knisjunn"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"knisjuum","weight":1,"content":"Knisjuum"}]}}}}}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"knimm","weight":1,"content":"knimm"}]}}}}}}},"l":{"type":"internal","weight":123,"values":["i","u","a","y","e","o","j","l"],"children":{"i":{"type":"internal","weight":123,"values":["t","g","u","v","e","s","m","k","l","n","ð"],"children":{"t":{"type":"internal","weight":123,"values":["e","n","﷐","t","u"],"children":{"n":{"type":"leaf","weight":101,"entries":[{"key":"litn","weight":101,"content":"litn"}]},"﷐":{"type":"leaf","weight":87,"entries":[{"key":"lit","weight":87,"content":"lit"}]},"e":{"type":"leaf","weight":123,"entries":[{"key":"liteð","weight":123,"content":"liteð"},{"key":"lite","weight":114,"content":"lite"}]},"t":{"type":"internal","weight":12,"values":["﷐","e","n"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"litt","weight":12,"content":"litt"}]},"e":{"type":"leaf","weight":10,"entries":[{"key":"littera","weight":10,"content":"littera"}]},"n":{"type":"internal","weight":4,"values":["﷐","a","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"littn","weight":4,"content":"littn"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"littnað","weight":3,"content":"littnað"}]},"e":{"type":"internal","weight":1,"values":["d","r"],"children":{"d":{"type":"leaf","weight":1,"entries":[{"key":"littned","weight":1,"content":"littned"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"littner","weight":1,"content":"littner"}]}}}}}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"litu","weight":1,"content":"litu"}]}}},"g":{"type":"leaf","weight":12,"entries":[{"key":"ligg","weight":12,"content":"ligg"}]},"v":{"type":"internal","weight":11,"values":["e","a","d","i","u",null],"children":{"e":{"type":"leaf","weight":11,"entries":[{"key":"livendes","weight":11,"content":"livendes"}]},"a":{"type":"internal","weight":7,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"liva","weight":7,"content":"livå"}]},"r":{"type":"leaf","weight":5,"entries":[{"key":"livarn","weight":5,"content":"livärn"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"liv","weight":1,"content":"liv"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"livd","weight":1,"content":"livd"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"livið","weight":1,"content":"livið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"livum","weight":1,"content":"livum"}]}}},"u":{"type":"internal","weight":12,"values":["o"],"children":{"o":{"type":"internal","weight":12,"values":["ð","t","s","g"],"children":{"t":{"type":"internal","weight":10,"values":["a","e","w","j","r","d","k","m","s","g","t","u","f","b",null],"children":{"a":{"type":"leaf","weight":10,"entries":[{"key":"liuotans","weight":10,"content":"liuotans"}]},"e":{"type":"leaf","weight":5,"entries":[{"key":"liuotest","weight":5,"content":"liuotest"}]},"w":{"type":"internal","weight":4,"values":["e","a","i"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"liuotweðreð","weight":4,"content":"liuotweðreð"}]},"a":{"type":"internal","weight":1,"values":["r","s"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"liuotwarmt","weight":1,"content":"liuotwarmt"},{"key":"liuotwar","weight":1,"content":"liuotwar"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"liuotwasst","weight":1,"content":"liuotwasst"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"liuotwiktut","weight":1,"content":"liuotwiktut"}]}}},"j":{"type":"leaf","weight":3,"entries":[{"key":"liuotjalak","weight":3,"content":"liuotjälåk"}]},"r":{"type":"internal","weight":3,"values":["e"],"children":{"e":{"type":"internal","weight":3,"values":["d","m"],"children":{"d":{"type":"internal","weight":3,"values":["d"],"children":{"d":{"type":"leaf","weight":3,"entries":[{"key":"liuotredder","weight":3,"content":"liuotredder"},{"key":"liuotredd","weight":2,"content":"liuotredd"}]}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"liuotrema","weight":1,"content":"liuotrema"}]}}}}},"d":{"type":"internal","weight":2,"values":["i","u"],"children":{"i":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["﷐","t","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"liuotdis","weight":2,"content":"liuotdis"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"liuotdist","weight":2,"content":"liuotdist"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"liuotdiser","weight":1,"content":"liuotdiser"}]}}}}},"u":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["g","n"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"liuotduktig","weight":1,"content":"liuotduktig"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"liuotduktin","weight":1,"content":"liuotduktin"}]}}}}}}}}}}},"k":{"type":"internal","weight":1,"values":["r","a"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"liuotkringgt","weight":1,"content":"liuotkringgt"}]},"a":{"type":"internal","weight":1,"values":["l","y"],"children":{"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["e","n"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"liuotkallem","weight":1,"content":"liuotkallem"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"liuotkalln","weight":1,"content":"liuotkalln"}]}}}}},"y":{"type":"leaf","weight":1,"entries":[{"key":"liuotkayt","weight":1,"content":"liuotkåyt"}]}}}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"liuotmitjið","weight":1,"content":"liuotmitjið"}]},"s":{"type":"internal","weight":1,"values":["k","t"],"children":{"k":{"type":"leaf","weight":1,"entries":[{"key":"liuotskwapa","weight":1,"content":"liuotskwåpå"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"liuotstinner","weight":1,"content":"liuotstinner"}]}}},"g":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["u","t"],"children":{"u":{"type":"leaf","weight":1,"entries":[{"key":"liuotguouð","weight":1,"content":"liuotguouð"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"liuotguott","weight":1,"content":"liuotguott"}]}}}}}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"liuottyst","weight":1,"content":"liuottyst"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"liuotunggrun","weight":1,"content":"liuotunggrun"}]},"f":{"type":"internal","weight":1,"values":["o","u"],"children":{"o":{"type":"leaf","weight":1,"entries":[{"key":"liuotforskrekkter","weight":1,"content":"liuotförskrekkter"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"liuotfugeln","weight":1,"content":"liuotfugeln"}]}}},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"liuot","weight":2,"content":"liuot"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"liuotblis","weight":1,"content":"liuotblis"}]}}},"ð":{"type":"internal","weight":12,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":12,"entries":[{"key":"liuoð","weight":12,"content":"liuoð"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"liuoðeð","weight":2,"content":"liuoðeð"}]}}},"s":{"type":"internal","weight":7,"values":["e","t","b","n",null],"children":{"e":{"type":"internal","weight":7,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":7,"entries":[{"key":"liuoseð","weight":7,"content":"liuoseð"}]},"r":{"type":"leaf","weight":5,"entries":[{"key":"liuosera","weight":5,"content":"liuosera"}]}}},"t":{"type":"leaf","weight":5,"entries":[{"key":"liuost","weight":5,"content":"liuost"}]},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"liuos","weight":3,"content":"liuos"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"liuosbrun","weight":1,"content":"liuosbrun"}]},"n":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["d","g"],"children":{"d":{"type":"leaf","weight":1,"entries":[{"key":"liuosnindjin","weight":1,"content":"liuosnindjin"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"liuosningg","weight":1,"content":"liuosningg"}]}}}}}}}}},"g":{"type":"leaf","weight":1,"entries":[{"key":"liuoga","weight":1,"content":"liuoga"}]}}}}},"e":{"type":"internal","weight":10,"values":["p","t","v","r","s","k"],"children":{"p":{"type":"leaf","weight":10,"entries":[{"key":"liep","weight":10,"content":"liep"}]},"t":{"type":"internal","weight":4,"values":["t","﷐","u"],"children":{"t":{"type":"leaf","weight":4,"entries":[{"key":"liett","weight":4,"content":"liett"}]},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"liet","weight":4,"content":"liet"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"lietum","weight":1,"content":"lietum"}]}}},"v":{"type":"internal","weight":4,"values":["u","a","e","t","d"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"lieva","weight":3,"content":"lieva"}]},"u":{"type":"leaf","weight":4,"entries":[{"key":"lievur","weight":4,"content":"lievur"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"liever","weight":1,"content":"liever"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"lievt","weight":1,"content":"lievt"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"lievde","weight":1,"content":"lievde"}]}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"liera","weight":1,"content":"liera"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"liessn","weight":1,"content":"liessn"}]},"k":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"liekatt","weight":1,"content":"liekatt"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"liekattar","weight":1,"content":"liekattär"}]}}}}}}}}}}},"s":{"type":"internal","weight":4,"values":["s","l"],"children":{"s":{"type":"internal","weight":4,"values":["l"],"children":{"l":{"type":"internal","weight":4,"values":["u","﷐","a","k","p","g"],"children":{"u":{"type":"leaf","weight":4,"entries":[{"key":"lisslum","weight":4,"content":"lisslum"}]},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"lissl","weight":4,"content":"lissl"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"lisslan","weight":3,"content":"lisslan"}]},"k":{"type":"internal","weight":3,"values":["u"],"children":{"u":{"type":"internal","weight":3,"values":["l","v"],"children":{"l":{"type":"internal","weight":3,"values":["l"],"children":{"l":{"type":"internal","weight":3,"values":["a","u"],"children":{"a":{"type":"leaf","weight":3,"entries":[{"key":"lisslkulla","weight":3,"content":"lisslkulla"},{"key":"lisslkulla","weight":1,"content":"lisslkullą"}]},"u":{"type":"internal","weight":2,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"lisslkullu","weight":2,"content":"lisslkullu"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"lisslkullun","weight":1,"content":"lisslkullun"}]}}}}}}},"v":{"type":"leaf","weight":2,"entries":[{"key":"lisslkuvan","weight":2,"content":"lisslkuvån"}]}}}}},"p":{"type":"leaf","weight":2,"entries":[{"key":"lisslpaykan","weight":2,"content":"lisslpåykan"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"lisslgubbin","weight":1,"content":"lisslgubbin"}]}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"lislkullu","weight":1,"content":"lislkullu"}]}}},"m":{"type":"internal","weight":2,"values":["n","m"],"children":{"n":{"type":"internal","weight":2,"values":["a","e"],"children":{"a":{"type":"internal","weight":2,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"limna","weight":2,"content":"limna"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"limnað","weight":1,"content":"limnað"}]}}},"e":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"limneð","weight":1,"content":"limneð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"limner","weight":1,"content":"limner"}]}}}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"limmen","weight":1,"content":"limmen"}]}}},"k":{"type":"internal","weight":2,"values":["a","e"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"lika","weight":2,"content":"lika"}]},"e":{"type":"internal","weight":2,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"likeð","weight":2,"content":"likeð"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"liker","weight":2,"content":"liker"}]}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"lila","weight":1,"content":"lila"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"lindeð","weight":1,"content":"lindeð"}]},"ð":{"type":"internal","weight":1,"values":["e","u"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"liðer","weight":1,"content":"liðer"}]},"u":{"type":"internal","weight":1,"values":["g","n"],"children":{"g":{"type":"leaf","weight":1,"entries":[{"key":"liðug","weight":1,"content":"liðug"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"liðun","weight":1,"content":"liðun"}]}}}}}}},"u":{"type":"internal","weight":52,"values":["v","o","p","k","s","g","d","n","t","r"],"children":{"v":{"type":"internal","weight":52,"values":["﷐","a","e","i","u"],"children":{"﷐":{"type":"leaf","weight":52,"entries":[{"key":"luv","weight":52,"content":"luv"}]},"a":{"type":"internal","weight":3,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"luva","weight":3,"content":"luvå"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"luvar","weight":1,"content":"luvär"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"luveð","weight":1,"content":"luveð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"luvið","weight":1,"content":"luvið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"luvum","weight":1,"content":"luvum"}]}}},"o":{"type":"internal","weight":13,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":13,"entries":[{"key":"luo","weight":13,"content":"luo"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"luoðrett","weight":1,"content":"luoðrett"}]}}},"p":{"type":"internal","weight":10,"values":["t"],"children":{"t":{"type":"internal","weight":10,"values":["e","﷐","n","a"],"children":{"e":{"type":"internal","weight":10,"values":["﷐","ð","r"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"lupte","weight":10,"content":"lupte"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"lupteð","weight":1,"content":"lupteð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"lupter","weight":1,"content":"lupter"}]}}},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"lupt","weight":2,"content":"lupt"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"luptn","weight":2,"content":"luptn"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"luptar","weight":1,"content":"luptär"},{"key":"lupta","weight":1,"content":"lupta"}]}}}}},"k":{"type":"internal","weight":7,"values":["k"],"children":{"k":{"type":"internal","weight":7,"values":["a","e"],"children":{"e":{"type":"internal","weight":4,"values":["ð","n","r"],"children":{"ð":{"type":"leaf","weight":4,"entries":[{"key":"lukkeð","weight":4,"content":"lukkeð"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"lukkend","weight":1,"content":"lukkend"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"lukker","weight":1,"content":"lukker"}]}}},"a":{"type":"leaf","weight":7,"entries":[{"key":"lukka","weight":7,"content":"lukka"}]}}}}},"g":{"type":"leaf","weight":4,"entries":[{"key":"lugneð","weight":4,"content":"lugneð"}]},"s":{"type":"internal","weight":5,"values":["s"],"children":{"s":{"type":"internal","weight":5,"values":["﷐"," ","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"luss","weight":5,"content":"luss"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"luss wara","weight":1,"content":"luss wårå"}]},"e":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"lusseð","weight":1,"content":"lusseð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"lusser","weight":1,"content":"lusser"}]}}}}}}},"n":{"type":"internal","weight":2,"values":["g"],"children":{"g":{"type":"internal","weight":2,"values":["e","t","i","n","g"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"lungen","weight":2,"content":"lungen"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"lungt","weight":2,"content":"lungt"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"lungin","weight":1,"content":"lungin"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"lungnað","weight":1,"content":"lungnað"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"lunggum","weight":1,"content":"lunggum"}]}}}}},"d":{"type":"leaf","weight":3,"entries":[{"key":"luddur","weight":3,"content":"luddur"}]},"r":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"lureð","weight":1,"content":"lureð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"lurer","weight":1,"content":"lurer"}]}}}}},"t":{"type":"leaf","weight":2,"entries":[{"key":"lutun","weight":2,"content":"lutun"}]}}},"a":{"type":"internal","weight":46,"values":["g","i","u","r","t","n","s","a","k","ð","p","m",null],"children":{"g":{"type":"internal","weight":46,"values":["﷐","g","d","t","u","e",null],"children":{"﷐":{"type":"leaf","weight":46,"entries":[{"key":"lag","weight":46,"content":"låg"}]},"g":{"type":"internal","weight":24,"values":["d","t"],"children":{"d":{"type":"leaf","weight":24,"entries":[{"key":"laggd","weight":24,"content":"laggd"}]},"t":{"type":"leaf","weight":7,"entries":[{"key":"laggt","weight":7,"content":"laggt"}]}}},"d":{"type":"leaf","weight":14,"entries":[{"key":"lagd","weight":14,"content":"lagd"}]},"undefined":{"type":"leaf","weight":12,"entries":[{"key":"lag","weight":12,"content":"lag"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"lagt","weight":3,"content":"lagt"}]},"u":{"type":"internal","weight":2,"values":["﷐","r","m"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"lagu","weight":2,"content":"lågu"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"lagur","weight":1,"content":"lågur"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"lagum","weight":1,"content":"lagum"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"lageð","weight":1,"content":"lageð"}]}}},"i":{"type":"internal","weight":42,"values":["n","k","ð","v","u"],"children":{"n":{"type":"internal","weight":42,"values":["g","d"],"children":{"g":{"type":"internal","weight":42,"values":["g","t","s"],"children":{"g":{"type":"internal","weight":42,"values":["e","s","t"],"children":{"e":{"type":"internal","weight":42,"values":["r"],"children":{"r":{"type":"internal","weight":42,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":42,"entries":[{"key":"laingger","weight":42,"content":"laingger"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"lainggera","weight":4,"content":"lainggera"}]}}}}},"s":{"type":"leaf","weight":13,"entries":[{"key":"lainggst","weight":13,"content":"lainggst"}]},"t":{"type":"internal","weight":1,"values":["u","a"],"children":{"u":{"type":"leaf","weight":1,"entries":[{"key":"lainggtums","weight":1,"content":"lainggtums"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"lainggtas","weight":1,"content":"lainggtas"}]}}}}},"t":{"type":"internal","weight":2,"values":["a","e"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"laingtas","weight":2,"content":"laingtas"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"laingtes","weight":2,"content":"laingtes"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"laingst","weight":1,"content":"laingst"}]}}},"d":{"type":"internal","weight":4,"values":["j"],"children":{"j":{"type":"leaf","weight":4,"entries":[{"key":"laindje","weight":4,"content":"laindje"},{"key":"laindj","weight":4,"content":"laindj"}]}}}}},"k":{"type":"internal","weight":21,"values":["﷐","t","e","n","s"],"children":{"﷐":{"type":"leaf","weight":21,"entries":[{"key":"laik","weight":21,"content":"laik"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"laikt","weight":2,"content":"laikt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"laiken","weight":1,"content":"laiken"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"laikneð","weight":1,"content":"laikneð"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"laikso","weight":1,"content":"laikso"}]}}},"ð":{"type":"internal","weight":4,"values":["﷐","e","n"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"laið","weight":4,"content":"laið"}]},"e":{"type":"leaf","weight":4,"entries":[{"key":"laiðe","weight":4,"content":"Laiðe"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"laiðn","weight":2,"content":"Laiðn"}]}}},"v":{"type":"internal","weight":2,"values":["e","r"],"children":{"e":{"type":"internal","weight":2,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"laive","weight":2,"content":"laivę"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"laiveð","weight":2,"content":"laiveð"}]}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"laivredder","weight":1,"content":"laivredder"}]}}},"u":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"laiun","weight":1,"content":"laiun"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"laiune","weight":1,"content":"laiune"}]}}}}}}},"u":{"type":"internal","weight":21,"values":["n"],"children":{"n":{"type":"internal","weight":21,"values":["g"],"children":{"g":{"type":"internal","weight":21,"values":["g","b"],"children":{"g":{"type":"internal","weight":21,"values":["t","﷐","u","e","a","b"],"children":{"t":{"type":"leaf","weight":21,"entries":[{"key":"launggt","weight":21,"content":"launggt"}]},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"laungg","weight":4,"content":"laungg"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"launggu","weight":2,"content":"launggu"}]},"e":{"type":"internal","weight":1,"values":["n","r"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"launggenn","weight":1,"content":"Launggenn"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"laungger","weight":1,"content":"laungger"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"launggan","weight":1,"content":"launggan"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"launggbokkam","weight":1,"content":"launggbokkam"}]}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"laungbokkum","weight":1,"content":"laungbokkum"}]}}}}}}},"r":{"type":"internal","weight":17,"values":["﷐","d","t","e","i"],"children":{"﷐":{"type":"leaf","weight":17,"entries":[{"key":"lar","weight":17,"content":"lär"}]},"d":{"type":"internal","weight":10,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":10,"entries":[{"key":"lard","weight":10,"content":"lärd"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"lardið","weight":1,"content":"lärdið"}]}}},"t":{"type":"leaf","weight":9,"entries":[{"key":"lart","weight":9,"content":"lärt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"larer","weight":1,"content":"lärer"}]},"i":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["a","u"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"larinna","weight":1,"content":"lärinna"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"larinnun","weight":1,"content":"lärinnun"}]}}}}}}}}},"t":{"type":"internal","weight":16,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":16,"entries":[{"key":"lat","weight":16,"content":"lat"}]},"t":{"type":"leaf","weight":4,"entries":[{"key":"latt","weight":4,"content":"latt"}]}}},"n":{"type":"internal","weight":13,"values":["d","n"],"children":{"d":{"type":"internal","weight":13,"values":["e","a"],"children":{"e":{"type":"internal","weight":13,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":13,"entries":[{"key":"lande","weight":13,"content":"lande"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"landeð","weight":2,"content":"landeð"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"landa","weight":1,"content":"landa"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"lannsweem","weight":1,"content":"lannsweem"}]}}},"s":{"type":"internal","weight":5,"values":["s"],"children":{"s":{"type":"leaf","weight":5,"entries":[{"key":"lasseð","weight":5,"content":"lasseð"},{"key":"lass","weight":3,"content":"lass"}]}}},"k":{"type":"internal","weight":4,"values":["﷐","t","u","a"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"lak","weight":4,"content":"läk"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"lakte","weight":3,"content":"läkte"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"lakum","weight":2,"content":"läkum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"laka","weight":1,"content":"läka"}]}}},"ð":{"type":"internal","weight":3,"values":["u"],"children":{"u":{"type":"internal","weight":3,"values":["n","﷐","d","w"],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"laðun","weight":3,"content":"laðun"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"laðu","weight":3,"content":"laðu"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"laðudorar","weight":1,"content":"laðudörär"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"laðuweddjin","weight":1,"content":"laðuweddjin"}]}}}}},"a":{"type":"leaf","weight":5,"entries":[{"key":"laa","weight":5,"content":"läa"}]},"undefined":{"type":"leaf","weight":3,"entries":[{"key":"la","weight":3,"content":"lä"}]},"p":{"type":"internal","weight":3,"values":["﷐","t","e","p"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"lap","weight":3,"content":"läp"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"lapt","weight":2,"content":"läpt"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"lapeð","weight":2,"content":"läpeð"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"lappin","weight":1,"content":"lappin"}]}}},"m":{"type":"internal","weight":2,"values":["p","a"],"children":{"p":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["r","﷐","n"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"lampur","weight":2,"content":"lampur"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"lampu","weight":1,"content":"lampu"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"lampun","weight":1,"content":"lampun"}]}}}}},"a":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"lamað","weight":1,"content":"lämäð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"lamara","weight":1,"content":"lämärä"}]}}}}}}},"e":{"type":"internal","weight":9,"values":["g","p","r","s","ð"],"children":{"g":{"type":"internal","weight":9,"values":["g","u"],"children":{"g":{"type":"leaf","weight":9,"entries":[{"key":"legg","weight":9,"content":"legg"}]},"u":{"type":"internal","weight":3,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"legu","weight":3,"content":"legu"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"legun","weight":1,"content":"legun"}]}}}}},"p":{"type":"leaf","weight":2,"entries":[{"key":"leppem","weight":2,"content":"leppem"}]},"r":{"type":"internal","weight":2,"values":["b"],"children":{"b":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"internal","weight":2,"values":["e","u"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"lerblaðer","weight":2,"content":"lerblaðer"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"lerblaðum","weight":2,"content":"lerblaðum"}]}}}}}}}}}}},"s":{"type":"internal","weight":2,"values":["﷐","i","n","a"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"les","weight":2,"content":"les"}]},"i":{"type":"internal","weight":1,"values":["n","ð"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"lesin","weight":1,"content":"lesin"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"lesið","weight":1,"content":"lesið"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"lesnindje","weight":1,"content":"lesnindje"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"lesa","weight":1,"content":"leså"}]}}},"ð":{"type":"internal","weight":1,"values":["e","r"],"children":{"e":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"internal","weight":1,"values":["﷐","b","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"leðer","weight":1,"content":"leðer"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"leðerbiter","weight":1,"content":"leðerbiter"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"leðern","weight":1,"content":"leðern"}]}}}}},"r":{"type":"leaf","weight":1,"entries":[{"key":"leðrar","weight":1,"content":"leðrär"}]}}}}},"o":{"type":"internal","weight":6,"values":["t","p","v","s","g"],"children":{"t":{"type":"leaf","weight":6,"entries":[{"key":"lot","weight":6,"content":"lot"}]},"p":{"type":"internal","weight":4,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"lop","weight":4,"content":"lop"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"lopa","weight":1,"content":"lopa"}]}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"lossneð","weight":1,"content":"lossneð"}]},"v":{"type":"internal","weight":2,"values":["e","﷐"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"lov","weight":1,"content":"lov"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"loveð","weight":2,"content":"loveð"}]}}},"g":{"type":"leaf","weight":1,"entries":[{"key":"log","weight":1,"content":"log"}]}}},"y":{"type":"internal","weight":11,"values":["p","s","k","n","o","'"],"children":{"p":{"type":"internal","weight":11,"values":["t"],"children":{"t":{"type":"internal","weight":11,"values":["e","a"],"children":{"e":{"type":"leaf","weight":11,"entries":[{"key":"lypteð","weight":11,"content":"lypteð"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"lypta","weight":3,"content":"lypta"}]}}}}},"s":{"type":"internal","weight":3,"values":["t","a","e","k"],"children":{"t":{"type":"leaf","weight":3,"entries":[{"key":"lyst","weight":3,"content":"lyst"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"lysa","weight":1,"content":"lysa"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"lyser","weight":1,"content":"lyser"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"lysknappem","weight":1,"content":"lysknappem"}]}}},"k":{"type":"internal","weight":2,"values":["k"],"children":{"k":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["i"],"children":{"i":{"type":"internal","weight":2,"values":["g","n"],"children":{"g":{"type":"leaf","weight":2,"entries":[{"key":"lykklig","weight":2,"content":"lykklig"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"lykklin","weight":2,"content":"lykklin"}]}}}}}}}}},"n":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["n","i"],"children":{"n":{"type":"internal","weight":1,"values":["u","a","e","t"],"children":{"u":{"type":"leaf","weight":1,"entries":[{"key":"lyngnun","weight":1,"content":"lyngnun"}]},"a":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"lyngna","weight":1,"content":"lyngna"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"lyngnað","weight":1,"content":"lyngnað"}]}}},"e":{"type":"leaf","weight":1,"entries":[{"key":"lyngner","weight":1,"content":"lyngner"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"lyngnt","weight":1,"content":"lyngnt"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"lyngin","weight":1,"content":"lyngin"}]}}}}},"o":{"type":"leaf","weight":1,"entries":[{"key":"lyolit","weight":1,"content":"lyölit"}]},"'":{"type":"leaf","weight":1,"entries":[{"key":"ly'tt","weight":1,"content":"ly'tt"}]}}},"j":{"type":"internal","weight":4,"values":["u"],"children":{"u":{"type":"internal","weight":4,"values":["o"],"children":{"o":{"type":"internal","weight":4,"values":["ð","t","s"],"children":{"ð":{"type":"leaf","weight":4,"entries":[{"key":"ljuoð","weight":4,"content":"ljuoð"}]},"t":{"type":"internal","weight":3,"values":["f","﷐","b","g","m","r","t","w","s","d","k","l","n","i"],"children":{"f":{"type":"internal","weight":3,"values":["a","r"],"children":{"a":{"type":"internal","weight":3,"values":["i"],"children":{"i":{"type":"internal","weight":3,"values":["n"],"children":{"n":{"type":"internal","weight":3,"values":["g"],"children":{"g":{"type":"internal","weight":3,"values":["i","n"],"children":{"i":{"type":"leaf","weight":3,"entries":[{"key":"ljuotfaingin","weight":3,"content":"ljuotfaingin"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"ljuotfaingner","weight":1,"content":"ljuotfaingner"}]}}}}}}}}},"r":{"type":"leaf","weight":2,"entries":[{"key":"ljuotfrek","weight":2,"content":"ljuotfrek"}]}}},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"ljuot","weight":2,"content":"ljuot"}]},"b":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["a","y"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"ljuotbra","weight":2,"content":"ljuotbra"}]},"y":{"type":"leaf","weight":1,"entries":[{"key":"ljuotbrygd","weight":1,"content":"ljuotbrygd"}]}}}}},"g":{"type":"internal","weight":2,"values":["r","l","u"],"children":{"r":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"ljuotgrann","weight":2,"content":"ljuotgrann"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"ljuotgrannt","weight":2,"content":"ljuotgrannt"}]}}}}}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"ljuotglað","weight":1,"content":"ljuotglað"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"ljuotguott","weight":1,"content":"ljuotguott"}]}}},"m":{"type":"internal","weight":2,"values":["i","u"],"children":{"i":{"type":"leaf","weight":2,"entries":[{"key":"ljuotmitjið","weight":2,"content":"ljuotmitjið"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"ljuotmuosk","weight":1,"content":"ljuotmuosk"}]}}},"r":{"type":"leaf","weight":2,"entries":[{"key":"ljuotraðn","weight":2,"content":"ljuoträðn"}]},"t":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["a"],"children":{"a":{"type":"internal","weight":2,"values":["t","i"],"children":{"t":{"type":"leaf","weight":2,"entries":[{"key":"ljuottratt","weight":2,"content":"ljuotträtt"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"ljuottraivas","weight":1,"content":"ljuottraivas"}]}}}}}}},"w":{"type":"leaf","weight":2,"entries":[{"key":"ljuotwellt","weight":2,"content":"ljuotwellt"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"ljuotstraitt","weight":1,"content":"ljuotstraitt"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"ljuotdjara","weight":1,"content":"ljuotdjärå"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"ljuotkaipend","weight":1,"content":"ljuotkaipend"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"ljuotlaunggt","weight":1,"content":"ljuotlaunggt"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"ljuotnuog","weight":1,"content":"ljuotnuog"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"ljuotintressirað","weight":1,"content":"ljuotintressirað"}]}}},"s":{"type":"internal","weight":1,"values":["a","t",null],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"ljuosarun","weight":1,"content":"ljuosårun"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"ljuost","weight":1,"content":"ljuost"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"ljuos","weight":1,"content":"ljuos"}]}}}}}}}}},"l":{"type":"leaf","weight":1,"entries":[{"key":"llaggd","weight":1,"content":"llaggd"}]}}},"y":{"type":"internal","weight":63,"values":["v","r","o","p","m","t"],"children":{"v":{"type":"internal","weight":63,"values":["y","s"],"children":{"y":{"type":"internal","weight":63,"values":["r"],"children":{"r":{"type":"internal","weight":63,"values":["a","﷐","l","o","r","t"],"children":{"﷐":{"type":"leaf","weight":61,"entries":[{"key":"yvyr","weight":61,"content":"yvyr"}]},"a":{"type":"leaf","weight":63,"entries":[{"key":"yvyrað","weight":63,"content":"yvyrað"}]},"l":{"type":"leaf","weight":5,"entries":[{"key":"yvyrliva","weight":5,"content":"yvyrlivå"}]},"o":{"type":"leaf","weight":2,"entries":[{"key":"yvyrollt","weight":2,"content":"yvyrollt"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"yvyrraska","weight":2,"content":"yvyrraska"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"yvyrtygaðer","weight":1,"content":"yvyrtygaðer"}]}}}}},"s":{"type":"leaf","weight":60,"entries":[{"key":"yvst","weight":60,"content":"yvst"}]}}},"r":{"type":"internal","weight":27,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":27,"entries":[{"key":"yr","weight":27,"content":"yr"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"yrmerkt","weight":1,"content":"yrmerkt"}]}}},"o":{"type":"internal","weight":24,"values":["p","g","r","l"],"children":{"p":{"type":"internal","weight":24,"values":["t","a"],"children":{"t":{"type":"internal","weight":24,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":24,"entries":[{"key":"yopt","weight":24,"content":"yöpt"}]},"e":{"type":"leaf","weight":12,"entries":[{"key":"yopte","weight":12,"content":"yöpte"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"yopa","weight":1,"content":"yöpa"}]}}},"g":{"type":"internal","weight":3,"values":["e"],"children":{"e":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["﷐","n","a","f"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"yoger","weight":3,"content":"yöger"}]},"n":{"type":"internal","weight":3,"values":["e"],"children":{"e":{"type":"internal","weight":3,"values":["v"],"children":{"v":{"type":"internal","weight":3,"values":["a"],"children":{"a":{"type":"internal","weight":3,"values":["n","m"],"children":{"n":{"type":"leaf","weight":3,"entries":[{"key":"yogernevan","weight":3,"content":"yögernevån"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"yogernevam","weight":1,"content":"yögernevåm"}]}}}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"yogerarmin","weight":1,"content":"yögerarmin"}]},"f":{"type":"leaf","weight":1,"entries":[{"key":"yogerframfuotn","weight":1,"content":"yögerframfuotn"}]}}}}}}},"r":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["m"],"children":{"m":{"type":"internal","weight":2,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"yorum","weight":2,"content":"yörum"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"yorumer","weight":2,"content":"yörumer"}]}}}}}}},"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["d"],"children":{"d":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"yollande","weight":1,"content":"Yöllandę"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"yollandeð","weight":1,"content":"Yöllandeð"}]}}}}}}}}}}}}}}},"p":{"type":"internal","weight":3,"values":["p"],"children":{"p":{"type":"internal","weight":3,"values":["e","n"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"yppenspisem","weight":3,"content":"yppenspisem"}]},"n":{"type":"internal","weight":1,"values":["a","i"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"yppnas","weight":1,"content":"yppnas"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"yppningg","weight":1,"content":"yppningg"}]}}}}}}},"m":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["e","u"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"ymse","weight":2,"content":"ymse"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"ymsum","weight":1,"content":"ymsum"}]}}}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"ytun","weight":1,"content":"ytun"}]}}},"r":{"type":"internal","weight":54,"values":["i","e","a","u","o","w","y"],"children":{"i":{"type":"internal","weight":54,"values":["n","g","k","e","a","s","t"],"children":{"n":{"type":"internal","weight":54,"values":["g","d"],"children":{"g":{"type":"internal","weight":54,"values":["g"],"children":{"g":{"type":"internal","weight":54,"values":["u","a"],"children":{"u":{"type":"leaf","weight":54,"entries":[{"key":"ringgum","weight":54,"content":"ringgum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"ringgar","weight":1,"content":"ringgär"}]}}}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"rindje","weight":1,"content":"rindje"}]}}},"g":{"type":"internal","weight":31,"values":["a"],"children":{"a":{"type":"internal","weight":31,"values":["v"],"children":{"v":{"type":"internal","weight":31,"values":["u",null],"children":{"u":{"type":"internal","weight":31,"values":["r","m"],"children":{"r":{"type":"leaf","weight":31,"entries":[{"key":"rigavur","weight":31,"content":"rigåvur"}]},"m":{"type":"leaf","weight":10,"entries":[{"key":"rigavum","weight":10,"content":"rigåvum"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"rigav","weight":1,"content":"rigåv"}]}}}}}}},"k":{"type":"internal","weight":13,"values":["t"],"children":{"t":{"type":"internal","weight":13,"values":["u"],"children":{"u":{"type":"internal","weight":13,"values":["t","g","n"],"children":{"t":{"type":"leaf","weight":13,"entries":[{"key":"riktut","weight":13,"content":"riktut"}]},"g":{"type":"internal","weight":6,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"riktug","weight":6,"content":"riktug"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"riktugum","weight":1,"content":"riktugum"}]}}},"n":{"type":"leaf","weight":2,"entries":[{"key":"riktun","weight":2,"content":"riktun"}]}}}}}}},"e":{"type":"internal","weight":9,"values":["ð","p","n","v"],"children":{"ð":{"type":"internal","weight":9,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":9,"entries":[{"key":"rieð","weight":9,"content":"rieð"}]},"u":{"type":"leaf","weight":8,"entries":[{"key":"rieðu","weight":8,"content":"rieðu"}]}}},"p":{"type":"leaf","weight":6,"entries":[{"key":"riepeð","weight":6,"content":"riepeð"},{"key":"riep","weight":1,"content":"riep"}]},"n":{"type":"internal","weight":2,"values":["e","a","t","u",null],"children":{"e":{"type":"internal","weight":2,"values":["s","r"],"children":{"s":{"type":"leaf","weight":2,"entries":[{"key":"rienest","weight":2,"content":"rienest"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"riener","weight":1,"content":"riener"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"rienan","weight":2,"content":"rienan"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"rient","weight":1,"content":"rient"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"rienu","weight":1,"content":"rienu"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"rien","weight":1,"content":"rien"}]}}},"v":{"type":"leaf","weight":2,"entries":[{"key":"rievus","weight":2,"content":"rievus"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"riagireð","weight":1,"content":"riagireð"}]},"s":{"type":"internal","weight":1,"values":["e","u"],"children":{"e":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"internal","weight":1,"values":["v"],"children":{"v":{"type":"internal","weight":1,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"riserv","weight":1,"content":"riserv"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"riservat","weight":1,"content":"riservat"}]}}}}}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"risultateð","weight":1,"content":"risultateð"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"riteð","weight":1,"content":"riteð"}]}}},"e":{"type":"internal","weight":42,"values":["m","t","k","d","l","n"],"children":{"t":{"type":"internal","weight":40,"values":["t"],"children":{"t":{"type":"internal","weight":40,"values":["﷐","n","j"],"children":{"﷐":{"type":"leaf","weight":40,"entries":[{"key":"rett","weight":40,"content":"rett"}]},"n":{"type":"leaf","weight":16,"entries":[{"key":"rettnu","weight":16,"content":"rettnu"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"rettj","weight":1,"content":"rettj"}]}}}}},"m":{"type":"internal","weight":42,"values":["d","e","a","t",null],"children":{"d":{"type":"internal","weight":42,"values":["e","﷐","u"],"children":{"﷐":{"type":"leaf","weight":38,"entries":[{"key":"remd","weight":38,"content":"remd"}]},"u":{"type":"leaf","weight":38,"entries":[{"key":"remdum","weight":38,"content":"remdum"}]},"e":{"type":"leaf","weight":42,"entries":[{"key":"remde","weight":42,"content":"remde"}]}}},"undefined":{"type":"leaf","weight":4,"entries":[{"key":"rem","weight":4,"content":"rem"}]},"e":{"type":"internal","weight":2,"values":["r","n"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"remer","weight":2,"content":"remer"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"remend","weight":1,"content":"remend"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"rema","weight":1,"content":"rema"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"remt","weight":1,"content":"remt"}]}}},"k":{"type":"internal","weight":19,"values":["k","﷐","a"],"children":{"k":{"type":"leaf","weight":19,"entries":[{"key":"rekkt","weight":19,"content":"rekkt"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"rek","weight":3,"content":"rek"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"reka","weight":1,"content":"rekå"}]}}},"d":{"type":"internal","weight":16,"values":["d"],"children":{"d":{"type":"internal","weight":16,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":16,"entries":[{"key":"redd","weight":16,"content":"redd"}]},"e":{"type":"internal","weight":9,"values":["r","ð"],"children":{"r":{"type":"leaf","weight":9,"entries":[{"key":"redder","weight":9,"content":"redder"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"reddeð","weight":2,"content":"reddeð"}]}}}}}}},"l":{"type":"internal","weight":9,"values":["l"],"children":{"l":{"type":"internal","weight":9,"values":["d","a","u"],"children":{"d":{"type":"internal","weight":9,"values":["a"],"children":{"a":{"type":"internal","weight":9,"values":["l"],"children":{"l":{"type":"internal","weight":9,"values":["s","i","n"],"children":{"s":{"type":"internal","weight":9,"values":["a","b"],"children":{"a":{"type":"internal","weight":9,"values":["ð"],"children":{"ð":{"type":"internal","weight":9,"values":["n","e"],"children":{"n":{"type":"leaf","weight":9,"entries":[{"key":"relldalsaðn","weight":9,"content":"Relldalsäðn"}]},"e":{"type":"leaf","weight":5,"entries":[{"key":"relldalsaðe","weight":5,"content":"Relldalsäðe"}]}}}}},"b":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"internal","weight":2,"values":["u","a"],"children":{"u":{"type":"leaf","weight":2,"entries":[{"key":"relldalsbuðum","weight":2,"content":"Relldalsbuðum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"relldalsbuðar","weight":1,"content":"Relldalsbuðär"}]}}}}}}}}},"i":{"type":"leaf","weight":4,"entries":[{"key":"relldalim","weight":4,"content":"Relldalim"}]},"n":{"type":"leaf","weight":4,"entries":[{"key":"relldaln","weight":4,"content":"Relldaln"}]}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"rella","weight":1,"content":"Rella"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"rellu","weight":1,"content":"Rellu"}]}}}}},"n":{"type":"internal","weight":9,"values":["n","s"],"children":{"n":{"type":"internal","weight":9,"values":["d","﷐","e"],"children":{"d":{"type":"leaf","weight":9,"entries":[{"key":"rennd","weight":9,"content":"rennd"}]},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"renn","weight":4,"content":"renn"}]},"e":{"type":"internal","weight":2,"values":["r","n"],"children":{"r":{"type":"internal","weight":2,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"renner","weight":2,"content":"renner"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"rennerar","weight":1,"content":"rennerär"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"rennendes","weight":1,"content":"rennendes"}]}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"rens","weight":1,"content":"rens"}]}}}}},"a":{"type":"internal","weight":33,"values":["i","ð","s","m","k","u","g","t","v","p","d"],"children":{"i":{"type":"internal","weight":33,"values":["s","t","v","n"],"children":{"s":{"type":"internal","weight":33,"values":["e","u","b",null],"children":{"e":{"type":"internal","weight":33,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":33,"entries":[{"key":"raise","weight":33,"content":"raisę"}]},"ð":{"type":"leaf","weight":16,"entries":[{"key":"raiseð","weight":16,"content":"raiseð"}]}}},"u":{"type":"internal","weight":18,"values":["t","g"],"children":{"t":{"type":"leaf","weight":18,"entries":[{"key":"raisut","weight":18,"content":"raisut"}]},"g":{"type":"leaf","weight":17,"entries":[{"key":"raisug","weight":17,"content":"raisug"}]}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"rais","weight":1,"content":"rais"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"raisbjarr","weight":1,"content":"Raisbjärr"}]}}},"t":{"type":"leaf","weight":22,"entries":[{"key":"raitt","weight":22,"content":"raitt"},{"key":"rait","weight":5,"content":"rait"}]},"v":{"type":"leaf","weight":9,"entries":[{"key":"raivas","weight":9,"content":"raivas"},{"key":"raiv","weight":3,"content":"raiv"}]},"n":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["n","e"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"raingner","weight":1,"content":"raingner"}]},"e":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["b","d"],"children":{"b":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["g"],"children":{"g":{"type":"internal","weight":1,"values":["a","i"],"children":{"a":{"type":"internal","weight":1,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"raingenbuga","weight":1,"content":"raingenbugå"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"raingenbugan","weight":1,"content":"raingenbugån"}]}}},"i":{"type":"leaf","weight":1,"entries":[{"key":"raingenbugir","weight":1,"content":"raingenbugir"}]}}}}}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"raingendrupir","weight":1,"content":"raingendrupir"}]}}}}}}}}}}},"ð":{"type":"leaf","weight":19,"entries":[{"key":"raðn","weight":19,"content":"räðn"},{"key":"rað","weight":6,"content":"rað"},{"key":"rað","weight":1,"content":"råð"}]},"s":{"type":"internal","weight":14,"values":["a","p","t"],"children":{"a":{"type":"internal","weight":14,"values":["﷐","r","ð"],"children":{"﷐":{"type":"leaf","weight":14,"entries":[{"key":"rasa","weight":14,"content":"räsä"},{"key":"rasa","weight":8,"content":"råså"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"rasar","weight":2,"content":"räsär"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"rasað","weight":1,"content":"räsäð"}]}}},"p":{"type":"internal","weight":4,"values":["r"],"children":{"r":{"type":"internal","weight":4,"values":["e"],"children":{"e":{"type":"internal","weight":4,"values":["k"],"children":{"k":{"type":"internal","weight":4,"values":["k"],"children":{"k":{"type":"internal","weight":4,"values":["l"],"children":{"l":{"type":"internal","weight":4,"values":["u"],"children":{"u":{"type":"internal","weight":4,"values":["n","g"],"children":{"n":{"type":"leaf","weight":4,"entries":[{"key":"rasprekklun","weight":4,"content":"räsprekklun"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"rasprekklug","weight":1,"content":"räsprekklug"}]}}}}}}}}}}}}}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"rastn","weight":1,"content":"rästn"}]}}},"m":{"type":"internal","weight":13,"values":["u","﷐","b","a"],"children":{"u":{"type":"leaf","weight":13,"entries":[{"key":"ramum","weight":13,"content":"ramum"}]},"﷐":{"type":"leaf","weight":5,"entries":[{"key":"ram","weight":5,"content":"ram"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"rambleð","weight":1,"content":"rambleð"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"rama","weight":1,"content":"råma"}]}}},"k":{"type":"internal","weight":13,"values":["﷐","a","k","e"],"children":{"﷐":{"type":"leaf","weight":13,"entries":[{"key":"rak","weight":13,"content":"rak"}]},"a":{"type":"internal","weight":7,"values":["﷐","ð","s"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"raka","weight":7,"content":"råka"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"rakað","weight":2,"content":"råkað"}]},"s":{"type":"leaf","weight":2,"entries":[{"key":"rakas","weight":2,"content":"råkas"}]}}},"k":{"type":"internal","weight":2,"values":["e","a","b","w"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"rakke","weight":2,"content":"rakke"}]},"a":{"type":"internal","weight":1,"values":["﷐","l","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"rakka","weight":1,"content":"rakka"}]},"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["e","u"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"rakkaller","weight":1,"content":"rakkaller"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"rakkallum","weight":1,"content":"rakkallum"}]}}}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"rakkan","weight":1,"content":"rakkan"}]}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"rakkband","weight":1,"content":"rakkband"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"rakkweper","weight":1,"content":"rakkweper"}]}}},"e":{"type":"internal","weight":1,"values":["s","ð","r"],"children":{"s":{"type":"leaf","weight":1,"entries":[{"key":"rakes","weight":1,"content":"råkes"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"rakeð","weight":1,"content":"råkeð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"raker","weight":1,"content":"råker"}]}}}}},"u":{"type":"internal","weight":3,"values":["n","k"],"children":{"n":{"type":"internal","weight":3,"values":["g"],"children":{"g":{"type":"internal","weight":3,"values":["e"],"children":{"e":{"type":"internal","weight":3,"values":["n"],"children":{"n":{"type":"internal","weight":3,"values":["b"],"children":{"b":{"type":"internal","weight":3,"values":["e"],"children":{"e":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["e","﷐","u"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"raungenbere","weight":3,"content":"raungenbere"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"raungenber","weight":1,"content":"raungenber"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"raungenberum","weight":1,"content":"raungenberum"}]}}}}}}}}}}}}}}},"k":{"type":"leaf","weight":2,"entries":[{"key":"rauk","weight":2,"content":"rauk"}]}}},"g":{"type":"leaf","weight":2,"entries":[{"key":"ragg","weight":2,"content":"ragg"}]},"t":{"type":"internal","weight":2,"values":["j","t"],"children":{"j":{"type":"internal","weight":2,"values":["i","e"],"children":{"i":{"type":"leaf","weight":2,"entries":[{"key":"ratjin","weight":2,"content":"rätjin"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"ratjem","weight":2,"content":"rätjem"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"rattjin","weight":1,"content":"rattjin"}]}}},"v":{"type":"leaf","weight":1,"entries":[{"key":"ravleð","weight":1,"content":"ravleð"}]},"p":{"type":"leaf","weight":1,"entries":[{"key":"rappeð","weight":1,"content":"rappeð"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"raddjin","weight":1,"content":"raddjin"}]}}},"u":{"type":"internal","weight":13,"values":["n","o","s","k","l"],"children":{"n":{"type":"leaf","weight":13,"entries":[{"key":"runt","weight":13,"content":"runt"}]},"o":{"type":"internal","weight":4,"values":["g","m","l","t"],"children":{"g":{"type":"internal","weight":4,"values":["a"],"children":{"a":{"type":"internal","weight":4,"values":["r"],"children":{"r":{"type":"internal","weight":4,"values":["d"],"children":{"d":{"type":"internal","weight":4,"values":["e","n"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"ruogardem","weight":4,"content":"ruogardem"}]},"n":{"type":"leaf","weight":4,"entries":[{"key":"ruogardn","weight":4,"content":"ruogardn"}]}}}}}}}}},"m":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"ruom","weight":3,"content":"ruom"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"ruomeð","weight":3,"content":"ruomeð"}]}}},"l":{"type":"internal","weight":3,"values":["i"],"children":{"i":{"type":"internal","weight":3,"values":["t","﷐","g","n"],"children":{"t":{"type":"leaf","weight":3,"entries":[{"key":"ruolit","weight":3,"content":"ruolit"}]},"﷐":{"type":"leaf","weight":2,"entries":[{"key":"ruoli","weight":2,"content":"ruoli"}]},"g":{"type":"internal","weight":2,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"ruolig","weight":2,"content":"ruolig"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"ruoliger","weight":1,"content":"ruoliger"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"ruoligu","weight":1,"content":"ruoligu"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"ruolin","weight":1,"content":"ruolin"}]}}}}},"t":{"type":"internal","weight":2,"values":["u","﷐","n"],"children":{"u":{"type":"internal","weight":2,"values":["r","m"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"ruotur","weight":2,"content":"ruotur"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"ruotum","weight":1,"content":"ruotum"}]}}},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"ruot","weight":1,"content":"Ruot"}]},"n":{"type":"internal","weight":1,"values":["d","e"],"children":{"d":{"type":"leaf","weight":1,"entries":[{"key":"ruotndalim","weight":1,"content":"Ruotndalim"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"ruotne","weight":1,"content":"Ruotne"}]}}}}}}},"s":{"type":"leaf","weight":2,"entries":[{"key":"rusta","weight":2,"content":"rusta"}]},"k":{"type":"leaf","weight":2,"entries":[{"key":"rukkeð","weight":2,"content":"rukkeð"}]},"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["a","e"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"rulla","weight":1,"content":"rulla"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"rulleð","weight":1,"content":"rulleð"}]}}}}}}},"o":{"type":"internal","weight":7,"values":["v","ð","t","u"],"children":{"v":{"type":"internal","weight":7,"values":["﷐","i","e","u","a"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"rov","weight":7,"content":"röv"}]},"i":{"type":"internal","weight":7,"values":["n","m","r"],"children":{"n":{"type":"leaf","weight":7,"entries":[{"key":"rovin","weight":7,"content":"rövin"},{"key":"rovin","weight":5,"content":"rovin"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"rovim","weight":1,"content":"rövim"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"rovir","weight":1,"content":"rövir"}]}}},"e":{"type":"leaf","weight":5,"entries":[{"key":"rove","weight":5,"content":"rovę"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"rovum","weight":1,"content":"rövum"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"rovalyttja","weight":1,"content":"rövålyttja"}]}}},"ð":{"type":"internal","weight":6,"values":["﷐","e","u","a","b","p"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"roð","weight":6,"content":"roð"}]},"e":{"type":"internal","weight":2,"values":["r","t"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"roðer","weight":2,"content":"roðer"}]},"t":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["a","u"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"roðetta","weight":1,"content":"roðetta"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"roðettu","weight":1,"content":"roðettu"}]}}}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"roðan","weight":1,"content":"roðan"}]},"b":{"type":"leaf","weight":1,"entries":[{"key":"roðbiln","weight":1,"content":"roðbiln"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"roðu","weight":2,"content":"roðu"}]},"p":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["﷐","a","u"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"roðpjukett","weight":1,"content":"roðpjukett"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"roðpjuketta","weight":1,"content":"roðpjuketta"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"roðpjukettun","weight":1,"content":"roðpjukettun"}]}}}}}}}}}}}}}}}}},"t":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["n","u"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"rottnað","weight":1,"content":"rottnað"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"rottur","weight":1,"content":"rottur"}]}}}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"routndaln","weight":1,"content":"Routndaln"}]}}},"y":{"type":"internal","weight":6,"values":["d","g","o","m","k","t"],"children":{"d":{"type":"internal","weight":6,"values":["d"],"children":{"d":{"type":"internal","weight":6,"values":["j"],"children":{"j":{"type":"internal","weight":6,"values":["e","i"],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"ryddjem","weight":6,"content":"ryddjem"}]},"i":{"type":"leaf","weight":4,"entries":[{"key":"ryddjin","weight":4,"content":"ryddjin"}]}}}}}}},"g":{"type":"leaf","weight":3,"entries":[{"key":"rygg","weight":3,"content":"rygg"}]},"o":{"type":"internal","weight":2,"values":["m"],"children":{"m":{"type":"internal","weight":2,"values":["d","e","u"],"children":{"d":{"type":"leaf","weight":2,"entries":[{"key":"ryomdes","weight":2,"content":"ryömdes"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"ryomes","weight":2,"content":"ryömes"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"ryomums","weight":1,"content":"ryömums"}]}}}}},"m":{"type":"internal","weight":1,"values":["m","d","s"],"children":{"m":{"type":"internal","weight":1,"values":["a","d"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"rymma","weight":1,"content":"rymma"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"rymmdalim","weight":1,"content":"Rymmdalim"}]}}},"d":{"type":"leaf","weight":1,"entries":[{"key":"rymdaln","weight":1,"content":"Rymdaln"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"rymsk sig","weight":1,"content":"rymsk sig"}]}}},"k":{"type":"leaf","weight":1,"entries":[{"key":"rykkt","weight":1,"content":"rykkt"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"ryttjið","weight":1,"content":"ryttjið"}]}}},"w":{"type":"internal","weight":7,"values":["i","a"],"children":{"i":{"type":"internal","weight":7,"values":["e","ð"],"children":{"e":{"type":"leaf","weight":7,"entries":[{"key":"rwieð","weight":7,"content":"rwieð"}]},"ð":{"type":"leaf","weight":4,"entries":[{"key":"rwiðið","weight":4,"content":"rwiðið"}]}}},"a":{"type":"leaf","weight":6,"entries":[{"key":"rwaiða","weight":6,"content":"rwaiða"}]}}}}},"j":{"type":"internal","weight":52,"values":["a","u","e","o"],"children":{"a":{"type":"internal","weight":52,"values":["p","t","r","g","l","k","s",null],"children":{"p":{"type":"internal","weight":52,"values":["﷐","i","l","u","a","s","t"],"children":{"﷐":{"type":"leaf","weight":52,"entries":[{"key":"jap","weight":52,"content":"jåp"}]},"i":{"type":"leaf","weight":3,"entries":[{"key":"japið","weight":3,"content":"jåpið"}]},"l":{"type":"leaf","weight":2,"entries":[{"key":"japloser","weight":2,"content":"jåploser"}]},"u":{"type":"internal","weight":2,"values":["m"],"children":{"m":{"type":"leaf","weight":2,"entries":[{"key":"japum","weight":2,"content":"jåpum"},{"key":"japums að","weight":1,"content":"jåpums að"}]}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"japas","weight":2,"content":"jåpas"},{"key":"japa","weight":1,"content":"jåpa"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"japsamm","weight":1,"content":"jåpsamm"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"japtes","weight":1,"content":"jåptes"}]}}},"t":{"type":"internal","weight":39,"values":["a","﷐","u"],"children":{"a":{"type":"leaf","weight":39,"entries":[{"key":"jata","weight":39,"content":"jätå"}]},"﷐":{"type":"leaf","weight":15,"entries":[{"key":"jat","weight":15,"content":"jät"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"jatum","weight":1,"content":"jätum"}]}}},"undefined":{"type":"leaf","weight":36,"entries":[{"key":"ja","weight":36,"content":"ja"}]},"r":{"type":"internal","weight":32,"values":["﷐","t","f","e","u"],"children":{"﷐":{"type":"leaf","weight":32,"entries":[{"key":"jar","weight":32,"content":"jär"}]},"f":{"type":"leaf","weight":2,"entries":[{"key":"jarfra","weight":2,"content":"järfrą̊"}]},"t":{"type":"leaf","weight":3,"entries":[{"key":"jartað","weight":3,"content":"järtað"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"jareter","weight":1,"content":"järeter"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"jarum","weight":1,"content":"järum"}]}}},"g":{"type":"internal","weight":12,"values":["e","g"],"children":{"e":{"type":"internal","weight":12,"values":["r"],"children":{"r":{"type":"leaf","weight":12,"entries":[{"key":"jagern","weight":12,"content":"jägern"},{"key":"jager","weight":2,"content":"jäger"}]}}},"g":{"type":"leaf","weight":4,"entries":[{"key":"jagg","weight":4,"content":"jägg"}]}}},"l":{"type":"internal","weight":9,"values":["t","l","d","a","m"],"children":{"t":{"type":"leaf","weight":9,"entries":[{"key":"jalt","weight":9,"content":"jält"}]},"l":{"type":"leaf","weight":9,"entries":[{"key":"jallt","weight":9,"content":"jällt"}]},"d":{"type":"internal","weight":9,"values":["n","e","k","a"],"children":{"n":{"type":"leaf","weight":9,"entries":[{"key":"jaldn","weight":9,"content":"jäldn"}]},"e":{"type":"leaf","weight":9,"entries":[{"key":"jaldem","weight":9,"content":"jäldem"}]},"k":{"type":"leaf","weight":2,"entries":[{"key":"jaldkalln","weight":2,"content":"jäldkalln"}]},"a":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["a","d"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"jaldausa","weight":1,"content":"jäldausa"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"jaldausdorum","weight":1,"content":"jäldausdörum"}]}}}}}}}}},"a":{"type":"internal","weight":6,"values":["k"],"children":{"k":{"type":"internal","weight":6,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"jalak","weight":6,"content":"jälåk"}]},"e":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"leaf","weight":2,"entries":[{"key":"jalakera","weight":2,"content":"jälåkera"},{"key":"jalaker","weight":1,"content":"jälåker"}]}}}}}}},"m":{"type":"internal","weight":3,"values":["i","e"],"children":{"i":{"type":"leaf","weight":3,"entries":[{"key":"jalmin","weight":3,"content":"jälmin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"jalmem","weight":1,"content":"jälmem"}]}}}}},"k":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["﷐","e","k"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"jakt","weight":3,"content":"jakt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"jakte","weight":1,"content":"jakte"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"jaktkayun","weight":1,"content":"jaktkåyun"}]}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"jasso","weight":1,"content":"jasso"}]}}},"u":{"type":"internal","weight":46,"values":["﷐","s","o","u"],"children":{"﷐":{"type":"leaf","weight":46,"entries":[{"key":"ju","weight":46,"content":"ju"}]},"s":{"type":"leaf","weight":37,"entries":[{"key":"just","weight":37,"content":"just"}]},"o":{"type":"internal","weight":4,"values":["l","t","r"],"children":{"l":{"type":"leaf","weight":4,"entries":[{"key":"juol","weight":4,"content":"juol"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"juotað","weight":1,"content":"juotað"},{"key":"juot","weight":1,"content":"juot"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"juordgubbsmuoseð","weight":1,"content":"juordgubbsmuoseð"}]}}},"u":{"type":"internal","weight":1,"values":["ð"],"children":{"ð":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"juuða","weight":1,"content":"juuðå"},{"key":"juuða","weight":1,"content":"juuðą̊"}]}}}}}}},"e":{"type":"leaf","weight":14,"entries":[{"key":"jen","weight":14,"content":"jen"}]},"o":{"type":"internal","weight":4,"values":["b"],"children":{"b":{"type":"internal","weight":4,"values":["b"],"children":{"b":{"type":"internal","weight":4,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"jobb","weight":4,"content":"jobb"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"jobbeð","weight":2,"content":"jobbeð"}]}}}}}}}}},"g":{"type":"internal","weight":42,"values":["a","o","u","r","n","l","e"],"children":{"a":{"type":"internal","weight":42,"values":["r","i","u","v","n","p","m","s","t"],"children":{"r":{"type":"internal","weight":42,"values":["d","t","e",null],"children":{"d":{"type":"internal","weight":42,"values":["﷐","e","n","u"],"children":{"﷐":{"type":"leaf","weight":42,"entries":[{"key":"gard","weight":42,"content":"gard"}]},"e":{"type":"internal","weight":6,"values":["﷐","m"],"children":{"﷐":{"type":"leaf","weight":6,"entries":[{"key":"garde","weight":6,"content":"garde"}]},"m":{"type":"leaf","weight":5,"entries":[{"key":"gardem","weight":5,"content":"gardem"}]}}},"n":{"type":"leaf","weight":1,"entries":[{"key":"gardn","weight":1,"content":"gardn"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"gardum","weight":1,"content":"gardum"}]}}},"t":{"type":"leaf","weight":38,"entries":[{"key":"gart","weight":38,"content":"gart"}]},"undefined":{"type":"leaf","weight":2,"entries":[{"key":"gar","weight":2,"content":"gar"},{"key":"gar","weight":2,"content":"går"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"garer","weight":2,"content":"garer"}]}}},"i":{"type":"internal","weight":30,"values":["n","ð"],"children":{"n":{"type":"leaf","weight":30,"entries":[{"key":"gainum","weight":30,"content":"gainum"}]},"ð":{"type":"leaf","weight":17,"entries":[{"key":"gaið","weight":17,"content":"gaið"}]}}},"u":{"type":"internal","weight":19,"values":["n"],"children":{"n":{"type":"internal","weight":19,"values":["g","d"],"children":{"g":{"type":"internal","weight":19,"values":["g"],"children":{"g":{"type":"internal","weight":19,"values":["﷐","a","i"],"children":{"﷐":{"type":"leaf","weight":19,"entries":[{"key":"gaungg","weight":19,"content":"gaungg"}]},"a":{"type":"leaf","weight":3,"entries":[{"key":"gaungga","weight":3,"content":"gaungga"}]},"i":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"leaf","weight":1,"entries":[{"key":"gaunggienne","weight":1,"content":"gaunggienne"},{"key":"gaunggienn","weight":1,"content":"gaunggienn"}]}}}}}}}}}}},"d":{"type":"leaf","weight":3,"entries":[{"key":"gaundjin","weight":3,"content":"gaundjin"}]}}}}},"v":{"type":"internal","weight":7,"values":["﷐","t"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"gav","weight":7,"content":"gav"},{"key":"gav","weight":1,"content":"gäv"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"gavt","weight":1,"content":"gävt"}]}}},"p":{"type":"internal","weight":3,"values":["a"],"children":{"a":{"type":"internal","weight":3,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"gapa","weight":3,"content":"gäpä"},{"key":"gapa","weight":1,"content":"gåpå"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"gapað","weight":1,"content":"gäpäð"}]}}}}},"n":{"type":"internal","weight":4,"values":["t"],"children":{"t":{"type":"internal","weight":4,"values":["a","e"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"gantes","weight":3,"content":"gantes"}]},"a":{"type":"leaf","weight":4,"entries":[{"key":"gantas","weight":4,"content":"gantas"}]}}}}},"m":{"type":"internal","weight":2,"values":["t","b","a"],"children":{"t":{"type":"internal","weight":2,"values":["k","s","t"],"children":{"k":{"type":"leaf","weight":2,"entries":[{"key":"gamtkall","weight":2,"content":"gamtkall"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"gamtskansn","weight":1,"content":"gamtskansn"}]},"t":{"type":"internal","weight":1,"values":["o"],"children":{"o":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["e","n"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"gamttollem","weight":1,"content":"gamttollem"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"gamttolln","weight":1,"content":"gamttolln"}]}}}}}}}}}}},"b":{"type":"internal","weight":2,"values":["e","l"],"children":{"e":{"type":"internal","weight":2,"values":["l"],"children":{"l":{"type":"internal","weight":2,"values":["w","u"],"children":{"w":{"type":"leaf","weight":2,"entries":[{"key":"gambelweem","weight":2,"content":"gambelweem"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"gambeluostn","weight":1,"content":"gambeluostn"}]}}}}},"l":{"type":"internal","weight":2,"values":["a","e","u"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"gamblan","weight":2,"content":"gamblan"}]},"e":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"leaf","weight":1,"entries":[{"key":"gamblera","weight":1,"content":"gamblera"},{"key":"gambler","weight":1,"content":"gambler"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"gamblu","weight":1,"content":"gamblu"}]}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"gamal","weight":1,"content":"gåmål"}]}}},"s":{"type":"internal","weight":2,"values":["n","i"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"gasn","weight":2,"content":"gasn"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"gasið","weight":1,"content":"gasið"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"gatun","weight":1,"content":"gatun"}]}}},"o":{"type":"internal","weight":40,"values":["﷐","r","u"],"children":{"﷐":{"type":"leaf","weight":40,"entries":[{"key":"go","weight":40,"content":"go"}]},"r":{"type":"leaf","weight":13,"entries":[{"key":"gor","weight":13,"content":"gor"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"goum","weight":2,"content":"goum"}]}}},"u":{"type":"internal","weight":26,"values":["o","n","l","ð","b"],"children":{"o":{"type":"internal","weight":26,"values":["t","v","ð","l","j"],"children":{"t":{"type":"leaf","weight":26,"entries":[{"key":"guott","weight":26,"content":"guott"}]},"v":{"type":"leaf","weight":9,"entries":[{"key":"guoveð","weight":9,"content":"guoveð"}]},"ð":{"type":"internal","weight":5,"values":["﷐","j","t","w","e","a"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"guoð","weight":5,"content":"guoð"}]},"j":{"type":"leaf","weight":1,"entries":[{"key":"guoðjata","weight":1,"content":"guoðjätå"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"guoðtratt","weight":1,"content":"guoðträtt"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"guoðweðreð","weight":1,"content":"guoðweðreð"}]},"e":{"type":"internal","weight":1,"values":["s","r"],"children":{"s":{"type":"leaf","weight":1,"entries":[{"key":"guoðestað","weight":1,"content":"guoðestað"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"guoðera","weight":1,"content":"guoðera"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"guoða","weight":1,"content":"guoða"}]}}},"l":{"type":"internal","weight":2,"values":["e","﷐","t"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"guoler","weight":2,"content":"guoler"}]},"﷐":{"type":"leaf","weight":1,"entries":[{"key":"guol","weight":1,"content":"guol"}]},"t":{"type":"leaf","weight":1,"entries":[{"key":"guolt","weight":1,"content":"guolt"}]}}},"j":{"type":"leaf","weight":1,"entries":[{"key":"guojata","weight":1,"content":"guojätå"}]}}},"n":{"type":"internal","weight":8,"values":["g","a","n"],"children":{"g":{"type":"internal","weight":8,"values":["g"],"children":{"g":{"type":"internal","weight":8,"values":["e","a"],"children":{"e":{"type":"internal","weight":8,"values":["ð"],"children":{"ð":{"type":"internal","weight":8,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"gunggeð","weight":8,"content":"gunggeð"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"gunggeðið","weight":1,"content":"gunggeðið"}]}}}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"gungga","weight":1,"content":"gungga"}]}}}}},"a":{"type":"leaf","weight":2,"entries":[{"key":"gunatt","weight":2,"content":"gunatt"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"gunnggeð","weight":1,"content":"gunnggeð"}]}}},"l":{"type":"internal","weight":4,"values":["l"],"children":{"l":{"type":"internal","weight":4,"values":["e","l","s"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"gulleð","weight":4,"content":"gulleð"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"gulllitaðu","weight":1,"content":"gulllitåðu"}]},"s":{"type":"leaf","weight":1,"entries":[{"key":"gullsmitað","weight":1,"content":"gullsmitåð"}]}}}}},"ð":{"type":"internal","weight":3,"values":["e","﷐","a"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"guðelin","weight":3,"content":"guðelin"}]},"﷐":{"type":"leaf","weight":3,"entries":[{"key":"guð","weight":3,"content":"guð"}]},"a":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["﷐"," "],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"guðan","weight":1,"content":"guðan"}]}," ":{"type":"leaf","weight":1,"entries":[{"key":"guðan sig","weight":1,"content":"guðan sig"}]}}}}}}},"b":{"type":"leaf","weight":1,"entries":[{"key":"gubbe","weight":1,"content":"gubbe"}]}}},"r":{"type":"internal","weight":21,"values":["a","y","o","e","i","u"],"children":{"a":{"type":"internal","weight":21,"values":["l","﷐","n","s","v","m","t","e","i","j"],"children":{"l":{"type":"leaf","weight":21,"entries":[{"key":"grall","weight":21,"content":"grall"}]},"﷐":{"type":"leaf","weight":16,"entries":[{"key":"gra","weight":16,"content":"grå"}]},"n":{"type":"internal","weight":12,"values":["n"],"children":{"n":{"type":"internal","weight":12,"values":["t","﷐","s","n","e","a","w","m","u"],"children":{"t":{"type":"leaf","weight":12,"entries":[{"key":"grannt","weight":12,"content":"grannt"}]},"﷐":{"type":"leaf","weight":11,"entries":[{"key":"grann","weight":11,"content":"grann"}]},"s":{"type":"leaf","weight":9,"entries":[{"key":"grannstienn","weight":9,"content":"grannstienn"}]},"n":{"type":"leaf","weight":5,"entries":[{"key":"grannn","weight":5,"content":"grannn"}]},"e":{"type":"leaf","weight":4,"entries":[{"key":"granner","weight":4,"content":"granner"}]},"a":{"type":"internal","weight":3,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"granna","weight":3,"content":"granna"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"grannan","weight":1,"content":"grannan"}]}}},"w":{"type":"internal","weight":1,"values":["e","y"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"grannweðreð","weight":1,"content":"grannweðreð"}]},"y":{"type":"internal","weight":1,"values":["a","u"],"children":{"a":{"type":"leaf","weight":1,"entries":[{"key":"grannwya","weight":1,"content":"grannwya"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"grannwyum","weight":1,"content":"grannwyum"}]}}}}},"m":{"type":"leaf","weight":1,"entries":[{"key":"grannmorgun","weight":1,"content":"grannmorgun"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"grannum","weight":1,"content":"grannum"}]}}}}},"s":{"type":"internal","weight":8,"values":["i","e","s"],"children":{"i":{"type":"internal","weight":8,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"grasi","weight":8,"content":"grasį"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"grasira","weight":1,"content":"grasira"}]}}},"e":{"type":"leaf","weight":3,"entries":[{"key":"graseð","weight":3,"content":"graseð"}]},"s":{"type":"internal","weight":1,"values":["i","t"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"grassireð","weight":1,"content":"grassireð"}]},"t":{"type":"internal","weight":1,"values":["r"],"children":{"r":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["'","n"],"children":{"'":{"type":"leaf","weight":1,"entries":[{"key":"grasstra'mm","weight":1,"content":"grassträ'mm"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"grasstrane","weight":1,"content":"grassträne"}]}}}}}}}}}}},"v":{"type":"internal","weight":5,"values":["﷐","a"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"grav","weight":5,"content":"grav"}]},"a":{"type":"internal","weight":2,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"grava","weight":2,"content":"gråvå"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"gravar","weight":2,"content":"grävär"}]}}}}},"m":{"type":"leaf","weight":2,"entries":[{"key":"grammatitjin","weight":2,"content":"grammatitjin"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"gratt","weight":2,"content":"grått"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"graera","weight":2,"content":"gråera"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"graina","weight":1,"content":"graina"}]},"j":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["m","r"],"children":{"m":{"type":"leaf","weight":1,"entries":[{"key":"grajum","weight":1,"content":"gräjum"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"grajur","weight":1,"content":"gräjur"}]}}}}}}},"y":{"type":"internal","weight":16,"values":["v","o"],"children":{"v":{"type":"internal","weight":16,"values":["l","e"],"children":{"l":{"type":"leaf","weight":16,"entries":[{"key":"gryvleð","weight":16,"content":"gryvleð"}]},"e":{"type":"leaf","weight":9,"entries":[{"key":"gryvel","weight":9,"content":"gryvel"}]}}},"o":{"type":"internal","weight":2,"values":["n","p"],"children":{"n":{"type":"internal","weight":2,"values":["t","u"],"children":{"t":{"type":"internal","weight":2,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"gryont","weight":2,"content":"gryönt"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"gryontienn","weight":1,"content":"Gryöntienn"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"gryonu","weight":1,"content":"gryönu"}]}}},"p":{"type":"leaf","weight":1,"entries":[{"key":"gryoper","weight":1,"content":"gryöper"}]}}}}},"e":{"type":"internal","weight":6,"values":["t","n","s"],"children":{"t":{"type":"internal","weight":6,"values":["t"],"children":{"t":{"type":"internal","weight":6,"values":["j"],"children":{"j":{"type":"internal","weight":6,"values":["r"],"children":{"r":{"type":"internal","weight":6,"values":["a"],"children":{"a":{"type":"internal","weight":6,"values":["i"],"children":{"i":{"type":"internal","weight":6,"values":["s"],"children":{"s":{"type":"leaf","weight":6,"entries":[{"key":"grettjraiseð","weight":6,"content":"grettjraiseð"},{"key":"grettjrais","weight":1,"content":"grettjrais"}]}}}}}}}}}}}}},"n":{"type":"internal","weight":6,"values":["s"],"children":{"s":{"type":"internal","weight":6,"values":["e","﷐","n","l"],"children":{"e":{"type":"leaf","weight":6,"entries":[{"key":"grensem","weight":6,"content":"grensem"}]},"﷐":{"type":"leaf","weight":6,"entries":[{"key":"grens","weight":6,"content":"grens"}]},"n":{"type":"leaf","weight":4,"entries":[{"key":"grensn","weight":4,"content":"grensn"}]},"l":{"type":"leaf","weight":1,"entries":[{"key":"grenslandeð","weight":1,"content":"grenslandeð"}]}}}}},"s":{"type":"internal","weight":2,"values":["t","a","e"],"children":{"t":{"type":"internal","weight":2,"values":["e","a"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"grestes","weight":2,"content":"gręstes"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"grestas","weight":1,"content":"gręstas"}]}}},"a":{"type":"leaf","weight":1,"entries":[{"key":"gresas","weight":1,"content":"gresas"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"greses","weight":1,"content":"gręses"}]}}}}},"o":{"type":"internal","weight":7,"values":["n"],"children":{"n":{"type":"internal","weight":7,"values":["﷐","e","u"],"children":{"﷐":{"type":"leaf","weight":7,"entries":[{"key":"gron","weight":7,"content":"gron"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"grone","weight":2,"content":"grone"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"gronum","weight":2,"content":"gronum"}]}}}}},"i":{"type":"internal","weight":4,"values":["e","s"],"children":{"e":{"type":"leaf","weight":4,"entries":[{"key":"grien","weight":4,"content":"grien"}]},"s":{"type":"internal","weight":3,"values":["t"],"children":{"t":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"grist","weight":3,"content":"grist"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"gristera","weight":2,"content":"gristera"}]}}}}}}},"u":{"type":"internal","weight":1,"values":["o","s"],"children":{"o":{"type":"internal","weight":1,"values":["p","v"],"children":{"p":{"type":"leaf","weight":1,"entries":[{"key":"gruopin","weight":1,"content":"gruopin"},{"key":"gruop","weight":1,"content":"gruop"}]},"v":{"type":"leaf","weight":1,"entries":[{"key":"gruovum","weight":1,"content":"gruovum"}]}}},"s":{"type":"internal","weight":1,"values":["i","w"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"grusi","weight":1,"content":"grusį"}]},"w":{"type":"leaf","weight":1,"entries":[{"key":"grusweem","weight":1,"content":"grusweem"}]}}}}}}},"n":{"type":"internal","weight":17,"values":["u","a","o"],"children":{"u":{"type":"internal","weight":17,"values":["k","o"],"children":{"k":{"type":"internal","weight":17,"values":["a","e"],"children":{"a":{"type":"internal","weight":17,"values":["ð","﷐","r",null],"children":{"ð":{"type":"leaf","weight":17,"entries":[{"key":"gnukað","weight":17,"content":"gnukäð"},{"key":"gnukað","weight":4,"content":"gnukåð"}]},"﷐":{"type":"leaf","weight":5,"entries":[{"key":"gnuka","weight":5,"content":"gnukå"}]},"r":{"type":"leaf","weight":3,"entries":[{"key":"gnukar","weight":3,"content":"gnukär"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"gnuka","weight":1,"content":"gnukä"}]}}},"e":{"type":"leaf","weight":3,"entries":[{"key":"gnukeð","weight":3,"content":"gnukeð"}]}}},"o":{"type":"leaf","weight":7,"entries":[{"key":"gnuog","weight":7,"content":"gnuog"}]}}},"a":{"type":"internal","weight":2,"values":["i","g","r"],"children":{"i":{"type":"leaf","weight":2,"entries":[{"key":"gnaið","weight":2,"content":"gnaið"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"gnaga","weight":1,"content":"gnågå"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"gnar","weight":1,"content":"gnar"}]}}},"o":{"type":"leaf","weight":1,"entries":[{"key":"gnoug","weight":1,"content":"gnoug"}]}}},"l":{"type":"internal","weight":7,"values":["a","e","i","u"],"children":{"a":{"type":"internal","weight":7,"values":["m","e","ð","s"],"children":{"e":{"type":"leaf","weight":5,"entries":[{"key":"glaemað","weight":5,"content":"gläemäð"}]},"m":{"type":"leaf","weight":7,"entries":[{"key":"glamað","weight":7,"content":"glämäð"}]},"ð":{"type":"internal","weight":3,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"glað","weight":3,"content":"glað"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"glaðir","weight":1,"content":"glaðir"}]}}},"s":{"type":"internal","weight":1,"values":["e","i","k","r","u"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"glase","weight":1,"content":"glasę"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"glasi","weight":1,"content":"glasį"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"glaskaul","weight":1,"content":"glaskaul"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"glasruta","weight":1,"content":"glasruta"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"glasum","weight":1,"content":"glasum"}]}}}}},"e":{"type":"internal","weight":5,"values":["m"],"children":{"m":{"type":"internal","weight":5,"values":["m","t"],"children":{"m":{"type":"internal","weight":5,"values":["t","d","e","a"],"children":{"t":{"type":"leaf","weight":5,"entries":[{"key":"glemmt","weight":5,"content":"glemmt"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"glemmd","weight":1,"content":"glemmd"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"glemmer","weight":1,"content":"glemmer"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"glemma","weight":1,"content":"glemma"}]}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"glemt","weight":1,"content":"glemt"}]}}}}},"i":{"type":"internal","weight":5,"values":["m"],"children":{"m":{"type":"internal","weight":5,"values":["a","e"],"children":{"a":{"type":"leaf","weight":5,"entries":[{"key":"glimað","weight":5,"content":"glimäð"},{"key":"glima","weight":1,"content":"glimå"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"glimer","weight":1,"content":"glimer"}]}}}}},"u":{"type":"internal","weight":2,"values":["ð"],"children":{"ð":{"type":"internal","weight":2,"values":["r"],"children":{"r":{"type":"internal","weight":2,"values":["e"],"children":{"e":{"type":"internal","weight":2,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"gluðreð","weight":2,"content":"gluðreð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"gluðrer","weight":1,"content":"gluðrer"}]}}}}}}}}}}},"e":{"type":"internal","weight":4,"values":["m","r"],"children":{"m":{"type":"internal","weight":4,"values":["d","a","t"],"children":{"d":{"type":"internal","weight":4,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":4,"entries":[{"key":"gemd","weight":4,"content":"gemd"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"gemdes","weight":1,"content":"gemdes"}]}}},"a":{"type":"leaf","weight":3,"entries":[{"key":"gema","weight":3,"content":"gema"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"gemt","weight":2,"content":"gemt"}]}}},"r":{"type":"internal","weight":2,"values":["d"],"children":{"d":{"type":"internal","weight":2,"values":["e","a"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"gerde","weight":2,"content":"gerde"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"gerda","weight":1,"content":"gerda"}]}}}}}}}}},"p":{"type":"internal","weight":24,"values":["r","a","o","i","j","u","l","e"],"children":{"r":{"type":"internal","weight":24,"values":["i","e","o","u"],"children":{"i":{"type":"internal","weight":24,"values":["s","n","k"],"children":{"s":{"type":"leaf","weight":24,"entries":[{"key":"prisiss","weight":24,"content":"prisiss"}]},"n":{"type":"internal","weight":9,"values":["s"],"children":{"s":{"type":"internal","weight":9,"values":["e"],"children":{"e":{"type":"internal","weight":9,"values":["s"],"children":{"s":{"type":"internal","weight":9,"values":["s"],"children":{"s":{"type":"internal","weight":9,"values":["k","a","u"],"children":{"k":{"type":"leaf","weight":9,"entries":[{"key":"prinsesskraungnu","weight":9,"content":"prinsesskraungnu"}]},"a":{"type":"leaf","weight":2,"entries":[{"key":"prinsessa","weight":2,"content":"prinsessa"}]},"u":{"type":"internal","weight":2,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"prinsessu","weight":2,"content":"prinsessų"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"prinsessur","weight":2,"content":"prinsessur"}]}}}}}}}}}}}}},"k":{"type":"internal","weight":2,"values":["k"],"children":{"k":{"type":"internal","weight":2,"values":["u"],"children":{"u":{"type":"internal","weight":2,"values":["n","g"],"children":{"n":{"type":"leaf","weight":2,"entries":[{"key":"prikkun","weight":2,"content":"prikkun"}]},"g":{"type":"leaf","weight":1,"entries":[{"key":"prikkuger","weight":1,"content":"prikkuger"}]}}}}}}}}},"e":{"type":"internal","weight":8,"values":["s"],"children":{"s":{"type":"internal","weight":8,"values":["t"],"children":{"t":{"type":"internal","weight":8,"values":["b"],"children":{"b":{"type":"internal","weight":8,"values":["u"],"children":{"u":{"type":"internal","weight":8,"values":["d","ð"],"children":{"d":{"type":"internal","weight":8,"values":["u","e"],"children":{"u":{"type":"leaf","weight":8,"entries":[{"key":"prestbudum","weight":8,"content":"Prestbudum"}]},"e":{"type":"leaf","weight":3,"entries":[{"key":"prestbuder","weight":3,"content":"Prestbuder"}]}}},"ð":{"type":"leaf","weight":1,"entries":[{"key":"prestbuðsknallem","weight":1,"content":"Prestbuðsknallem"}]}}}}}}}}}}},"o":{"type":"internal","weight":5,"values":["b"],"children":{"b":{"type":"internal","weight":5,"values":["l"],"children":{"l":{"type":"internal","weight":5,"values":["i"],"children":{"i":{"type":"internal","weight":5,"values":["e"],"children":{"e":{"type":"internal","weight":5,"values":["m"],"children":{"m":{"type":"internal","weight":5,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":5,"entries":[{"key":"probliem","weight":5,"content":"probliem"}]},"e":{"type":"leaf","weight":4,"entries":[{"key":"probliemeð","weight":4,"content":"probliemeð"}]}}}}}}}}}}}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"prutestira","weight":1,"content":"prutestira"}]}}},"a":{"type":"internal","weight":16,"values":["y","﷐","s","r","p","i","k","n"],"children":{"y":{"type":"internal","weight":16,"values":["t","k"],"children":{"t":{"type":"leaf","weight":16,"entries":[{"key":"paytjin","weight":16,"content":"påytjin"}]},"k":{"type":"internal","weight":12,"values":["a","u",null],"children":{"a":{"type":"internal","weight":12,"values":["n","m"],"children":{"n":{"type":"leaf","weight":12,"entries":[{"key":"paykan","weight":12,"content":"påykan"}]},"m":{"type":"leaf","weight":6,"entries":[{"key":"paykam","weight":6,"content":"påykam"}]}}},"undefined":{"type":"leaf","weight":5,"entries":[{"key":"payk","weight":5,"content":"påyk"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"paykum","weight":1,"content":"påykum"}]}}}}},"﷐":{"type":"leaf","weight":14,"entries":[{"key":"pa","weight":14,"content":"på"}]},"s":{"type":"internal","weight":8,"values":["s"],"children":{"s":{"type":"internal","weight":8,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":8,"entries":[{"key":"pass","weight":8,"content":"pass"}]},"e":{"type":"leaf","weight":8,"entries":[{"key":"passe","weight":8,"content":"passe"}]}}}}},"r":{"type":"internal","weight":4,"values":["k","﷐","r","a"],"children":{"k":{"type":"internal","weight":4,"values":["i"],"children":{"i":{"type":"internal","weight":4,"values":["r"],"children":{"r":{"type":"internal","weight":4,"values":["i","a"],"children":{"i":{"type":"leaf","weight":4,"entries":[{"key":"parkirindjin","weight":4,"content":"parkirindjin"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"parkira","weight":1,"content":"parkira"}]}}}}}}},"﷐":{"type":"leaf","weight":4,"entries":[{"key":"par","weight":4,"content":"par"}]},"r":{"type":"leaf","weight":2,"entries":[{"key":"parrkirað","weight":2,"content":"parrkirað"}]},"a":{"type":"leaf","weight":1,"entries":[{"key":"paralysira","weight":1,"content":"paralysira"}]}}},"i":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["a","t","d","s","u","e",null],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"painas","weight":2,"content":"painas"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"paint","weight":2,"content":"paint"}]},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"pain","weight":1,"content":"pain"}]},"d":{"type":"internal","weight":2,"values":["e","﷐"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"paind","weight":1,"content":"paind"}]},"e":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["﷐","i"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"paindes","weight":2,"content":"paindes"}]},"i":{"type":"leaf","weight":1,"entries":[{"key":"paindesið","weight":1,"content":"paindesið"}]}}}}}}},"s":{"type":"leaf","weight":1,"entries":[{"key":"painskliger","weight":1,"content":"painskliger"}]},"u":{"type":"leaf","weight":1,"entries":[{"key":"painut","weight":1,"content":"painut"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"painer","weight":1,"content":"painer"}]}}}}},"p":{"type":"internal","weight":3,"values":["i","p"],"children":{"i":{"type":"internal","weight":3,"values":["r"],"children":{"r":{"type":"internal","weight":3,"values":["﷐","u"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"papir","weight":3,"content":"papir"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"papirum","weight":2,"content":"papirum"}]}}}}},"p":{"type":"internal","weight":2,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"papp","weight":2,"content":"papp"}]},"e":{"type":"leaf","weight":2,"entries":[{"key":"papper","weight":2,"content":"papper"}]}}}}},"k":{"type":"internal","weight":1,"values":["i"],"children":{"i":{"type":"internal","weight":1,"values":["e"],"children":{"e":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"pakiet","weight":1,"content":"pakiet"}]},"e":{"type":"internal","weight":1,"values":["﷐","ð"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"pakiete","weight":1,"content":"pakietę"}]},"ð":{"type":"leaf","weight":1,"entries":[{"key":"pakieteð","weight":1,"content":"pakieteð"}]}}}}}}}}}}},"n":{"type":"internal","weight":1,"values":["n"],"children":{"n":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["k"],"children":{"k":{"type":"internal","weight":1,"values":["u"],"children":{"u":{"type":"internal","weight":1,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"pannkaku","weight":1,"content":"pannkaku"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"pannkakur","weight":1,"content":"pannkakur"}]}}}}}}}}}}}}}}},"o":{"type":"internal","weight":7,"values":["r","i","l","y"],"children":{"r":{"type":"internal","weight":7,"values":["r"],"children":{"r":{"type":"internal","weight":7,"values":["f"],"children":{"f":{"type":"internal","weight":7,"values":["y"],"children":{"y":{"type":"internal","weight":7,"values":["r"],"children":{"r":{"type":"internal","weight":7,"values":["s","d","e","n",null],"children":{"s":{"type":"internal","weight":7,"values":["t"],"children":{"t":{"type":"internal","weight":7,"values":["i"],"children":{"i":{"type":"internal","weight":7,"values":["e"],"children":{"e":{"type":"leaf","weight":7,"entries":[{"key":"porrfyrstienn","weight":7,"content":"porrfyrstienn"},{"key":"porrfyrstie","weight":4,"content":"porrfyrstįe"}]}}}}}}},"undefined":{"type":"leaf","weight":1,"entries":[{"key":"porrfyr","weight":1,"content":"porrfyr"}]},"d":{"type":"leaf","weight":1,"entries":[{"key":"porrfyrdammin","weight":1,"content":"Porrfyrdammin"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"porrfyrem","weight":1,"content":"porrfyrem"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"porrfyrn","weight":1,"content":"porrfyrn"}]}}}}}}}}}}},"i":{"type":"leaf","weight":6,"entries":[{"key":"poitjin","weight":6,"content":"poitjin"}]},"l":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"poll","weight":1,"content":"poll"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"pollem","weight":1,"content":"pollem"}]}}}}},"y":{"type":"leaf","weight":1,"entries":[{"key":"poytjin","weight":1,"content":"poytjin"}]}}},"i":{"type":"internal","weight":7,"values":["p","k","e","s","n"],"children":{"p":{"type":"internal","weight":7,"values":["t","﷐","e"],"children":{"t":{"type":"leaf","weight":7,"entries":[{"key":"pipte","weight":7,"content":"pipte"}]},"﷐":{"type":"leaf","weight":6,"entries":[{"key":"pip","weight":6,"content":"pip"}]},"e":{"type":"internal","weight":1,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":1,"entries":[{"key":"pipeð","weight":1,"content":"pipeð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"piperkakur","weight":1,"content":"piperkakur"}]}}}}},"s":{"type":"leaf","weight":3,"entries":[{"key":"pister","weight":3,"content":"pister"}]},"k":{"type":"internal","weight":4,"values":["k"],"children":{"k":{"type":"internal","weight":4,"values":["e"],"children":{"e":{"type":"internal","weight":4,"values":["s","ð"],"children":{"s":{"type":"leaf","weight":4,"entries":[{"key":"pikkes","weight":4,"content":"pikkes"}]},"ð":{"type":"leaf","weight":2,"entries":[{"key":"pikkeð","weight":2,"content":"pikkeð"}]}}}}}}},"e":{"type":"internal","weight":4,"values":["k"],"children":{"k":{"type":"internal","weight":4,"values":["a","t","e"],"children":{"t":{"type":"internal","weight":3,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":3,"entries":[{"key":"piekt","weight":3,"content":"piekt"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"piekte","weight":1,"content":"piekte"}]}}},"a":{"type":"leaf","weight":4,"entries":[{"key":"pieka","weight":4,"content":"pieka"}]},"e":{"type":"internal","weight":2,"values":["ð","r"],"children":{"ð":{"type":"leaf","weight":2,"entries":[{"key":"piekeð","weight":2,"content":"piekeð"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"pieker","weight":1,"content":"pieker"}]}}}}}}},"n":{"type":"internal","weight":2,"values":["n"],"children":{"n":{"type":"internal","weight":2,"values":["a","u"],"children":{"a":{"type":"internal","weight":2,"values":["﷐","n"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"pinna","weight":2,"content":"pinna"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"pinnan","weight":1,"content":"pinnan"}]}}},"u":{"type":"leaf","weight":1,"entries":[{"key":"pinnum","weight":1,"content":"pinnum"}]}}}}}}},"j":{"type":"internal","weight":4,"values":["a","e"],"children":{"e":{"type":"leaf","weight":3,"entries":[{"key":"pjeksun","weight":3,"content":"pjeksun"}]},"a":{"type":"internal","weight":4,"values":["k"],"children":{"k":{"type":"internal","weight":4,"values":["s"],"children":{"s":{"type":"internal","weight":4,"values":["u","a"],"children":{"a":{"type":"leaf","weight":2,"entries":[{"key":"pjaksa","weight":2,"content":"pjäksa"}]},"u":{"type":"internal","weight":4,"values":["r","n","m"],"children":{"r":{"type":"leaf","weight":4,"entries":[{"key":"pjaksur","weight":4,"content":"pjäksur"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"pjaksun","weight":1,"content":"pjäksun"}]},"m":{"type":"leaf","weight":1,"entries":[{"key":"pjaksum","weight":1,"content":"pjäksum"}]}}}}}}}}}}},"u":{"type":"internal","weight":2,"values":["s","o"],"children":{"s":{"type":"internal","weight":2,"values":["s","t"],"children":{"s":{"type":"leaf","weight":2,"entries":[{"key":"puss","weight":2,"content":"puss"}]},"t":{"type":"leaf","weight":2,"entries":[{"key":"pusteð","weight":2,"content":"pusteð"}]}}},"o":{"type":"internal","weight":1,"values":["s"],"children":{"s":{"type":"internal","weight":1,"values":["t"],"children":{"t":{"type":"internal","weight":1,"values":["j"],"children":{"j":{"type":"internal","weight":1,"values":["a"],"children":{"a":{"type":"internal","weight":1,"values":["l"],"children":{"l":{"type":"internal","weight":1,"values":["d"],"children":{"d":{"type":"internal","weight":1,"values":["﷐","e","n"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"puostjald","weight":1,"content":"puostjäld"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"puostjaldem","weight":1,"content":"puostjäldem"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"puostjaldn","weight":1,"content":"puostjäldn"}]}}}}}}}}}}}}}}}}},"l":{"type":"internal","weight":2,"values":["a","y"],"children":{"a":{"type":"internal","weight":2,"values":["s","t"],"children":{"s":{"type":"internal","weight":2,"values":["s","t"],"children":{"s":{"type":"internal","weight":2,"values":["﷐","e"],"children":{"﷐":{"type":"leaf","weight":2,"entries":[{"key":"plass","weight":2,"content":"plass"}]},"e":{"type":"leaf","weight":1,"entries":[{"key":"plassem","weight":1,"content":"plassem"}]}}},"t":{"type":"internal","weight":1,"values":["e","k"],"children":{"e":{"type":"leaf","weight":1,"entries":[{"key":"plastem","weight":1,"content":"plastem"}]},"k":{"type":"leaf","weight":1,"entries":[{"key":"plastkafikappar","weight":1,"content":"plastkafikappär"}]}}}}},"t":{"type":"leaf","weight":1,"entries":[{"key":"platask","weight":1,"content":"plåtask"}]}}},"y":{"type":"leaf","weight":1,"entries":[{"key":"plyogde","weight":1,"content":"plyögde"}]}}},"e":{"type":"internal","weight":2,"values":["l","n"],"children":{"l":{"type":"internal","weight":2,"values":["s"],"children":{"s":{"type":"internal","weight":2,"values":["e","n","u","a"],"children":{"e":{"type":"leaf","weight":2,"entries":[{"key":"pelsem","weight":2,"content":"pelsem"}]},"n":{"type":"leaf","weight":2,"entries":[{"key":"pelsn","weight":2,"content":"pelsn"}]},"u":{"type":"leaf","weight":2,"entries":[{"key":"pelsum","weight":2,"content":"pelsum"}]},"a":{"type":"internal","weight":1,"values":["﷐","r"],"children":{"﷐":{"type":"leaf","weight":1,"entries":[{"key":"pelsa","weight":1,"content":"pelsa"}]},"r":{"type":"leaf","weight":1,"entries":[{"key":"pelsar","weight":1,"content":"pelsär"}]}}}}}}},"n":{"type":"internal","weight":1,"values":["i","n"],"children":{"i":{"type":"leaf","weight":1,"entries":[{"key":"peningg","weight":1,"content":"peningg"}]},"n":{"type":"leaf","weight":1,"entries":[{"key":"penningger","weight":1,"content":"penningger"}]}}}}}}},"h":{"type":"leaf","weight":2,"entries":[{"key":"haj","weight":2,"content":"häj"}]}}}}, {
  wordBreaker: wordBreakers['default'],
  searchTermToKey: definitions.searchTermToKey,
}));
})();